(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    809707,      34971]*)
(*NotebookOutlinePosition[    810393,      34995]*)
(*  CellTagsIndexPosition[    810349,      34991]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  StyleBox["Stokesian Dynamic Simulation of Two Spheres in an Simple & \
Oscillatory Shear Flow of a Newtonian Fluid", "Subsubtitle",
    FontSize->18,
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["\n",
    FontWeight->"Plain",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["Author's Data",
    FontSize->14,
    FontWeight->"Bold"],
  StyleBox[": ",
    FontSize->14],
  StyleBox["Housam BINOUS\nDepartment of Chemical Engineering\nNational \
Institute of Applied Sciences and Technology\nTunis, TUNISIA\nEmail: \
binoushousam@yahoo.com ",
    FontSize->14,
    FontWeight->"Plain"]
}], "Title",
  TextAlignment->Center,
  Background->RGBColor[0.605478, 0.996109, 0.605478]],

Cell[TextData[{
  StyleBox["Acknowledgement :",
    FontWeight->"Bold"],
  "\nThis program was originally written by Professor Ron Phillips during his \
PhD thesis at MIT in 1989. The code was adapted from Fortran 77 to ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  StyleBox["by Housam Binous",
    FontVariations->{"CompatibilityType"->0}],
  StyleBox[". ",
    FontSlant->"Italic"],
  StyleBox["Using Euler's integration scheme was one simplification, of the \
original code, that was performed by Housam Binous. This code is posted with \
permission from the original author.\n\nThe code call a .m file called \
VEL5.m, which needs four files ",
    FontVariations->{"CompatibilityType"->0}],
  "TEMPM.m, FTS.m, FTSMOB.m and SSI.m as well as two data file called data1.m \
and data2.m. \n"
}], "Subsubtitle",
  Background->RGBColor[0.773449, 0.996109, 0.996109]],

Cell[TextData[{
  StyleBox["Important Note:",
    FontWeight->"Bold"],
  " All files should be placed in the C: drive in the folder \
TwoSpheresShearFlow. If not, some changes to the Get instructions (<<) should \
be done by users.",
  StyleBox[" ",
    FontVariations->{"CompatibilityType"->0}]
}], "Subsubtitle",
  Background->RGBColor[1, 0.666667, 1]],

Cell["\<\
Stokesian Dynamics, a method developed by Brady and Bossis in the 80s, \
simulate the 3D motion of hydrodynamically interacting spheres at low \
Reynolds numbers.\
\>", "Subsubtitle",
  Background->GrayLevel[0.900008]],

Cell[CellGroupData[{

Cell["\<\
Two Spheres in an Oscillatory Shear Flow of a Newtonian fluid. \
\>", "Subsubtitle",
  Background->RGBColor[1, 1, 0.658824]],

Cell["<<Graphics`Graphics3D`", "Input"],

Cell["X[1]=0;Y[1]=1.05;Z[1]=0;X[2]=0;Y[2]=-1.05;Z[2]=0;", "Input"],

Cell["dt=0.1;", "Input"],

Cell["NSPH=2;NDIM=6 NSPH;Ng=3 NSPH;NX5=5 NSPH; ", "Input"],

Cell[CellGroupData[{

Cell["s=OpenRead[\"C:\\\\TwoSpheresShearFlow\\\\data1.m\"]", "Input"],

Cell[BoxData[
    \(InputStream["C:\\TwoSpheresShearFlow\\data1.m", 6]\)], "Output"]
}, Open  ]],

Cell["Off[General::\"spell1\"];", "Input"],

Cell["\<\
For[i=1,i<48,{RSS[i]=Read[s,Real];
X11AS[i]=Read[s,Real];
X12AS[i]=Read[s,Real];
Y11AS[i]=Read[s,Real];
Y12AS[i]=Read[s,Real];
Y11BS[i]=Read[s,Real];
Y12BS[i]=Read[s,Real];
X11CS[i]=Read[s,Real];
X12CS[i]=Read[s,Real];
Y11CS[i]=Read[s,Real];
Y12CS[i]=Read[s,Real];i++}]\
\>", "Input"],

Cell[CellGroupData[{

Cell["s=OpenRead[\"C:\\\\TwoSpheresShearFlow\\\\data2.m\"]", "Input"],

Cell[BoxData[
    \(InputStream["C:\\TwoSpheresShearFlow\\data2.m", 7]\)], "Output"]
}, Open  ]],

Cell["\<\
For[i=1,i<48,{RSS[i]=Read[s,Real];
Y11MS[i]=Read[s,Real];
Y12MS[i]=Read[s,Real];
X11MS[i]=Read[s,Real];
Z11MS[i]=Read[s,Real];
X12GS[i]=Read[s,Real];
Y11HS[i]=Read[s,Real];
Y12HS[i]=Read[s,Real];
Y12GS[i]=Read[s,Real];
X11GS[i]=Read[s,Real];
X12MS[i]=Read[s,Real];
Z12MS[i]=Read[s,Real];
Y11GS[i]=Read[s,Real];i++}]\
\>", "Input"],

Cell["\<\
X[1,0]=X[1];Y[1,0]=Y[1];Z[1,0]=Z[1];
X[2,0]=X[2];Y[2,0]=Y[2];Z[2,0]=Z[2];\
\>", "Input"],

Cell["WT=0.1;", "Input"],

Cell["G=10;", "Input"],

Cell[CellGroupData[{

Cell["Table[FU[i],{i,1,12}]", "Input"],

Cell[BoxData[
    \({0, 9.90215996212637`, 0, 0, 9.90215996212637`, 0, 0, 0, 0, 0, 0, 
      0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
For[t=1,t<1501,{<<\"C:\\\\TwoSpheresShearFlow\\\\VEL5.m\";
X[1,t]=X[1,t-1]+USS[1]*dt;Y[1,t]=Y[1,t-1]+USS[2]*dt;Z[1,t]=Z[1,t-1]+USS[3]*dt;\
X[2,t]=X[2,t-1]+USS[4]*dt;Y[2,t]=Y[2,t-1]+USS[5]*dt;Z[2,t]=Z[2,t-1]+USS[6]*dt;\
Print[t];t++}]\
\>", "Input"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \(4\)], "Print"],

Cell[BoxData[
    \(5\)], "Print"],

Cell[BoxData[
    \(6\)], "Print"],

Cell[BoxData[
    \(7\)], "Print"],

Cell[BoxData[
    \(8\)], "Print"],

Cell[BoxData[
    \(9\)], "Print"],

Cell[BoxData[
    \(10\)], "Print"],

Cell[BoxData[
    \(11\)], "Print"],

Cell[BoxData[
    \(12\)], "Print"],

Cell[BoxData[
    \(13\)], "Print"],

Cell[BoxData[
    \(14\)], "Print"],

Cell[BoxData[
    \(15\)], "Print"],

Cell[BoxData[
    \(16\)], "Print"],

Cell[BoxData[
    \(17\)], "Print"],

Cell[BoxData[
    \(18\)], "Print"],

Cell[BoxData[
    \(19\)], "Print"],

Cell[BoxData[
    \(20\)], "Print"],

Cell[BoxData[
    \(21\)], "Print"],

Cell[BoxData[
    \(22\)], "Print"],

Cell[BoxData[
    \(23\)], "Print"],

Cell[BoxData[
    \(24\)], "Print"],

Cell[BoxData[
    \(25\)], "Print"],

Cell[BoxData[
    \(26\)], "Print"],

Cell[BoxData[
    \(27\)], "Print"],

Cell[BoxData[
    \(28\)], "Print"],

Cell[BoxData[
    \(29\)], "Print"],

Cell[BoxData[
    \(30\)], "Print"],

Cell[BoxData[
    \(31\)], "Print"],

Cell[BoxData[
    \(32\)], "Print"],

Cell[BoxData[
    \(33\)], "Print"],

Cell[BoxData[
    \(34\)], "Print"],

Cell[BoxData[
    \(35\)], "Print"],

Cell[BoxData[
    \(36\)], "Print"],

Cell[BoxData[
    \(37\)], "Print"],

Cell[BoxData[
    \(38\)], "Print"],

Cell[BoxData[
    \(39\)], "Print"],

Cell[BoxData[
    \(40\)], "Print"],

Cell[BoxData[
    \(41\)], "Print"],

Cell[BoxData[
    \(42\)], "Print"],

Cell[BoxData[
    \(43\)], "Print"],

Cell[BoxData[
    \(44\)], "Print"],

Cell[BoxData[
    \(45\)], "Print"],

Cell[BoxData[
    \(46\)], "Print"],

Cell[BoxData[
    \(47\)], "Print"],

Cell[BoxData[
    \(48\)], "Print"],

Cell[BoxData[
    \(49\)], "Print"],

Cell[BoxData[
    \(50\)], "Print"],

Cell[BoxData[
    \(51\)], "Print"],

Cell[BoxData[
    \(52\)], "Print"],

Cell[BoxData[
    \(53\)], "Print"],

Cell[BoxData[
    \(54\)], "Print"],

Cell[BoxData[
    \(55\)], "Print"],

Cell[BoxData[
    \(56\)], "Print"],

Cell[BoxData[
    \(57\)], "Print"],

Cell[BoxData[
    \(58\)], "Print"],

Cell[BoxData[
    \(59\)], "Print"],

Cell[BoxData[
    \(60\)], "Print"],

Cell[BoxData[
    \(61\)], "Print"],

Cell[BoxData[
    \(62\)], "Print"],

Cell[BoxData[
    \(63\)], "Print"],

Cell[BoxData[
    \(64\)], "Print"],

Cell[BoxData[
    \(65\)], "Print"],

Cell[BoxData[
    \(66\)], "Print"],

Cell[BoxData[
    \(67\)], "Print"],

Cell[BoxData[
    \(68\)], "Print"],

Cell[BoxData[
    \(69\)], "Print"],

Cell[BoxData[
    \(70\)], "Print"],

Cell[BoxData[
    \(71\)], "Print"],

Cell[BoxData[
    \(72\)], "Print"],

Cell[BoxData[
    \(73\)], "Print"],

Cell[BoxData[
    \(74\)], "Print"],

Cell[BoxData[
    \(75\)], "Print"],

Cell[BoxData[
    \(76\)], "Print"],

Cell[BoxData[
    \(77\)], "Print"],

Cell[BoxData[
    \(78\)], "Print"],

Cell[BoxData[
    \(79\)], "Print"],

Cell[BoxData[
    \(80\)], "Print"],

Cell[BoxData[
    \(81\)], "Print"],

Cell[BoxData[
    \(82\)], "Print"],

Cell[BoxData[
    \(83\)], "Print"],

Cell[BoxData[
    \(84\)], "Print"],

Cell[BoxData[
    \(85\)], "Print"],

Cell[BoxData[
    \(86\)], "Print"],

Cell[BoxData[
    \(87\)], "Print"],

Cell[BoxData[
    \(88\)], "Print"],

Cell[BoxData[
    \(89\)], "Print"],

Cell[BoxData[
    \(90\)], "Print"],

Cell[BoxData[
    \(91\)], "Print"],

Cell[BoxData[
    \(92\)], "Print"],

Cell[BoxData[
    \(93\)], "Print"],

Cell[BoxData[
    \(94\)], "Print"],

Cell[BoxData[
    \(95\)], "Print"],

Cell[BoxData[
    \(96\)], "Print"],

Cell[BoxData[
    \(97\)], "Print"],

Cell[BoxData[
    \(98\)], "Print"],

Cell[BoxData[
    \(99\)], "Print"],

Cell[BoxData[
    \(100\)], "Print"],

Cell[BoxData[
    \(101\)], "Print"],

Cell[BoxData[
    \(102\)], "Print"],

Cell[BoxData[
    \(103\)], "Print"],

Cell[BoxData[
    \(104\)], "Print"],

Cell[BoxData[
    \(105\)], "Print"],

Cell[BoxData[
    \(106\)], "Print"],

Cell[BoxData[
    \(107\)], "Print"],

Cell[BoxData[
    \(108\)], "Print"],

Cell[BoxData[
    \(109\)], "Print"],

Cell[BoxData[
    \(110\)], "Print"],

Cell[BoxData[
    \(111\)], "Print"],

Cell[BoxData[
    \(112\)], "Print"],

Cell[BoxData[
    \(113\)], "Print"],

Cell[BoxData[
    \(114\)], "Print"],

Cell[BoxData[
    \(115\)], "Print"],

Cell[BoxData[
    \(116\)], "Print"],

Cell[BoxData[
    \(117\)], "Print"],

Cell[BoxData[
    \(118\)], "Print"],

Cell[BoxData[
    \(119\)], "Print"],

Cell[BoxData[
    \(120\)], "Print"],

Cell[BoxData[
    \(121\)], "Print"],

Cell[BoxData[
    \(122\)], "Print"],

Cell[BoxData[
    \(123\)], "Print"],

Cell[BoxData[
    \(124\)], "Print"],

Cell[BoxData[
    \(125\)], "Print"],

Cell[BoxData[
    \(126\)], "Print"],

Cell[BoxData[
    \(127\)], "Print"],

Cell[BoxData[
    \(128\)], "Print"],

Cell[BoxData[
    \(129\)], "Print"],

Cell[BoxData[
    \(130\)], "Print"],

Cell[BoxData[
    \(131\)], "Print"],

Cell[BoxData[
    \(132\)], "Print"],

Cell[BoxData[
    \(133\)], "Print"],

Cell[BoxData[
    \(134\)], "Print"],

Cell[BoxData[
    \(135\)], "Print"],

Cell[BoxData[
    \(136\)], "Print"],

Cell[BoxData[
    \(137\)], "Print"],

Cell[BoxData[
    \(138\)], "Print"],

Cell[BoxData[
    \(139\)], "Print"],

Cell[BoxData[
    \(140\)], "Print"],

Cell[BoxData[
    \(141\)], "Print"],

Cell[BoxData[
    \(142\)], "Print"],

Cell[BoxData[
    \(143\)], "Print"],

Cell[BoxData[
    \(144\)], "Print"],

Cell[BoxData[
    \(145\)], "Print"],

Cell[BoxData[
    \(146\)], "Print"],

Cell[BoxData[
    \(147\)], "Print"],

Cell[BoxData[
    \(148\)], "Print"],

Cell[BoxData[
    \(149\)], "Print"],

Cell[BoxData[
    \(150\)], "Print"],

Cell[BoxData[
    \(151\)], "Print"],

Cell[BoxData[
    \(152\)], "Print"],

Cell[BoxData[
    \(153\)], "Print"],

Cell[BoxData[
    \(154\)], "Print"],

Cell[BoxData[
    \(155\)], "Print"],

Cell[BoxData[
    \(156\)], "Print"],

Cell[BoxData[
    \(157\)], "Print"],

Cell[BoxData[
    \(158\)], "Print"],

Cell[BoxData[
    \(159\)], "Print"],

Cell[BoxData[
    \(160\)], "Print"],

Cell[BoxData[
    \(161\)], "Print"],

Cell[BoxData[
    \(162\)], "Print"],

Cell[BoxData[
    \(163\)], "Print"],

Cell[BoxData[
    \(164\)], "Print"],

Cell[BoxData[
    \(165\)], "Print"],

Cell[BoxData[
    \(166\)], "Print"],

Cell[BoxData[
    \(167\)], "Print"],

Cell[BoxData[
    \(168\)], "Print"],

Cell[BoxData[
    \(169\)], "Print"],

Cell[BoxData[
    \(170\)], "Print"],

Cell[BoxData[
    \(171\)], "Print"],

Cell[BoxData[
    \(172\)], "Print"],

Cell[BoxData[
    \(173\)], "Print"],

Cell[BoxData[
    \(174\)], "Print"],

Cell[BoxData[
    \(175\)], "Print"],

Cell[BoxData[
    \(176\)], "Print"],

Cell[BoxData[
    \(177\)], "Print"],

Cell[BoxData[
    \(178\)], "Print"],

Cell[BoxData[
    \(179\)], "Print"],

Cell[BoxData[
    \(180\)], "Print"],

Cell[BoxData[
    \(181\)], "Print"],

Cell[BoxData[
    \(182\)], "Print"],

Cell[BoxData[
    \(183\)], "Print"],

Cell[BoxData[
    \(184\)], "Print"],

Cell[BoxData[
    \(185\)], "Print"],

Cell[BoxData[
    \(186\)], "Print"],

Cell[BoxData[
    \(187\)], "Print"],

Cell[BoxData[
    \(188\)], "Print"],

Cell[BoxData[
    \(189\)], "Print"],

Cell[BoxData[
    \(190\)], "Print"],

Cell[BoxData[
    \(191\)], "Print"],

Cell[BoxData[
    \(192\)], "Print"],

Cell[BoxData[
    \(193\)], "Print"],

Cell[BoxData[
    \(194\)], "Print"],

Cell[BoxData[
    \(195\)], "Print"],

Cell[BoxData[
    \(196\)], "Print"],

Cell[BoxData[
    \(197\)], "Print"],

Cell[BoxData[
    \(198\)], "Print"],

Cell[BoxData[
    \(199\)], "Print"],

Cell[BoxData[
    \(200\)], "Print"],

Cell[BoxData[
    \(201\)], "Print"],

Cell[BoxData[
    \(202\)], "Print"],

Cell[BoxData[
    \(203\)], "Print"],

Cell[BoxData[
    \(204\)], "Print"],

Cell[BoxData[
    \(205\)], "Print"],

Cell[BoxData[
    \(206\)], "Print"],

Cell[BoxData[
    \(207\)], "Print"],

Cell[BoxData[
    \(208\)], "Print"],

Cell[BoxData[
    \(209\)], "Print"],

Cell[BoxData[
    \(210\)], "Print"],

Cell[BoxData[
    \(211\)], "Print"],

Cell[BoxData[
    \(212\)], "Print"],

Cell[BoxData[
    \(213\)], "Print"],

Cell[BoxData[
    \(214\)], "Print"],

Cell[BoxData[
    \(215\)], "Print"],

Cell[BoxData[
    \(216\)], "Print"],

Cell[BoxData[
    \(217\)], "Print"],

Cell[BoxData[
    \(218\)], "Print"],

Cell[BoxData[
    \(219\)], "Print"],

Cell[BoxData[
    \(220\)], "Print"],

Cell[BoxData[
    \(221\)], "Print"],

Cell[BoxData[
    \(222\)], "Print"],

Cell[BoxData[
    \(223\)], "Print"],

Cell[BoxData[
    \(224\)], "Print"],

Cell[BoxData[
    \(225\)], "Print"],

Cell[BoxData[
    \(226\)], "Print"],

Cell[BoxData[
    \(227\)], "Print"],

Cell[BoxData[
    \(228\)], "Print"],

Cell[BoxData[
    \(229\)], "Print"],

Cell[BoxData[
    \(230\)], "Print"],

Cell[BoxData[
    \(231\)], "Print"],

Cell[BoxData[
    \(232\)], "Print"],

Cell[BoxData[
    \(233\)], "Print"],

Cell[BoxData[
    \(234\)], "Print"],

Cell[BoxData[
    \(235\)], "Print"],

Cell[BoxData[
    \(236\)], "Print"],

Cell[BoxData[
    \(237\)], "Print"],

Cell[BoxData[
    \(238\)], "Print"],

Cell[BoxData[
    \(239\)], "Print"],

Cell[BoxData[
    \(240\)], "Print"],

Cell[BoxData[
    \(241\)], "Print"],

Cell[BoxData[
    \(242\)], "Print"],

Cell[BoxData[
    \(243\)], "Print"],

Cell[BoxData[
    \(244\)], "Print"],

Cell[BoxData[
    \(245\)], "Print"],

Cell[BoxData[
    \(246\)], "Print"],

Cell[BoxData[
    \(247\)], "Print"],

Cell[BoxData[
    \(248\)], "Print"],

Cell[BoxData[
    \(249\)], "Print"],

Cell[BoxData[
    \(250\)], "Print"],

Cell[BoxData[
    \(251\)], "Print"],

Cell[BoxData[
    \(252\)], "Print"],

Cell[BoxData[
    \(253\)], "Print"],

Cell[BoxData[
    \(254\)], "Print"],

Cell[BoxData[
    \(255\)], "Print"],

Cell[BoxData[
    \(256\)], "Print"],

Cell[BoxData[
    \(257\)], "Print"],

Cell[BoxData[
    \(258\)], "Print"],

Cell[BoxData[
    \(259\)], "Print"],

Cell[BoxData[
    \(260\)], "Print"],

Cell[BoxData[
    \(261\)], "Print"],

Cell[BoxData[
    \(262\)], "Print"],

Cell[BoxData[
    \(263\)], "Print"],

Cell[BoxData[
    \(264\)], "Print"],

Cell[BoxData[
    \(265\)], "Print"],

Cell[BoxData[
    \(266\)], "Print"],

Cell[BoxData[
    \(267\)], "Print"],

Cell[BoxData[
    \(268\)], "Print"],

Cell[BoxData[
    \(269\)], "Print"],

Cell[BoxData[
    \(270\)], "Print"],

Cell[BoxData[
    \(271\)], "Print"],

Cell[BoxData[
    \(272\)], "Print"],

Cell[BoxData[
    \(273\)], "Print"],

Cell[BoxData[
    \(274\)], "Print"],

Cell[BoxData[
    \(275\)], "Print"],

Cell[BoxData[
    \(276\)], "Print"],

Cell[BoxData[
    \(277\)], "Print"],

Cell[BoxData[
    \(278\)], "Print"],

Cell[BoxData[
    \(279\)], "Print"],

Cell[BoxData[
    \(280\)], "Print"],

Cell[BoxData[
    \(281\)], "Print"],

Cell[BoxData[
    \(282\)], "Print"],

Cell[BoxData[
    \(283\)], "Print"],

Cell[BoxData[
    \(284\)], "Print"],

Cell[BoxData[
    \(285\)], "Print"],

Cell[BoxData[
    \(286\)], "Print"],

Cell[BoxData[
    \(287\)], "Print"],

Cell[BoxData[
    \(288\)], "Print"],

Cell[BoxData[
    \(289\)], "Print"],

Cell[BoxData[
    \(290\)], "Print"],

Cell[BoxData[
    \(291\)], "Print"],

Cell[BoxData[
    \(292\)], "Print"],

Cell[BoxData[
    \(293\)], "Print"],

Cell[BoxData[
    \(294\)], "Print"],

Cell[BoxData[
    \(295\)], "Print"],

Cell[BoxData[
    \(296\)], "Print"],

Cell[BoxData[
    \(297\)], "Print"],

Cell[BoxData[
    \(298\)], "Print"],

Cell[BoxData[
    \(299\)], "Print"],

Cell[BoxData[
    \(300\)], "Print"],

Cell[BoxData[
    \(301\)], "Print"],

Cell[BoxData[
    \(302\)], "Print"],

Cell[BoxData[
    \(303\)], "Print"],

Cell[BoxData[
    \(304\)], "Print"],

Cell[BoxData[
    \(305\)], "Print"],

Cell[BoxData[
    \(306\)], "Print"],

Cell[BoxData[
    \(307\)], "Print"],

Cell[BoxData[
    \(308\)], "Print"],

Cell[BoxData[
    \(309\)], "Print"],

Cell[BoxData[
    \(310\)], "Print"],

Cell[BoxData[
    \(311\)], "Print"],

Cell[BoxData[
    \(312\)], "Print"],

Cell[BoxData[
    \(313\)], "Print"],

Cell[BoxData[
    \(314\)], "Print"],

Cell[BoxData[
    \(315\)], "Print"],

Cell[BoxData[
    \(316\)], "Print"],

Cell[BoxData[
    \(317\)], "Print"],

Cell[BoxData[
    \(318\)], "Print"],

Cell[BoxData[
    \(319\)], "Print"],

Cell[BoxData[
    \(320\)], "Print"],

Cell[BoxData[
    \(321\)], "Print"],

Cell[BoxData[
    \(322\)], "Print"],

Cell[BoxData[
    \(323\)], "Print"],

Cell[BoxData[
    \(324\)], "Print"],

Cell[BoxData[
    \(325\)], "Print"],

Cell[BoxData[
    \(326\)], "Print"],

Cell[BoxData[
    \(327\)], "Print"],

Cell[BoxData[
    \(328\)], "Print"],

Cell[BoxData[
    \(329\)], "Print"],

Cell[BoxData[
    \(330\)], "Print"],

Cell[BoxData[
    \(331\)], "Print"],

Cell[BoxData[
    \(332\)], "Print"],

Cell[BoxData[
    \(333\)], "Print"],

Cell[BoxData[
    \(334\)], "Print"],

Cell[BoxData[
    \(335\)], "Print"],

Cell[BoxData[
    \(336\)], "Print"],

Cell[BoxData[
    \(337\)], "Print"],

Cell[BoxData[
    \(338\)], "Print"],

Cell[BoxData[
    \(339\)], "Print"],

Cell[BoxData[
    \(340\)], "Print"],

Cell[BoxData[
    \(341\)], "Print"],

Cell[BoxData[
    \(342\)], "Print"],

Cell[BoxData[
    \(343\)], "Print"],

Cell[BoxData[
    \(344\)], "Print"],

Cell[BoxData[
    \(345\)], "Print"],

Cell[BoxData[
    \(346\)], "Print"],

Cell[BoxData[
    \(347\)], "Print"],

Cell[BoxData[
    \(348\)], "Print"],

Cell[BoxData[
    \(349\)], "Print"],

Cell[BoxData[
    \(350\)], "Print"],

Cell[BoxData[
    \(351\)], "Print"],

Cell[BoxData[
    \(352\)], "Print"],

Cell[BoxData[
    \(353\)], "Print"],

Cell[BoxData[
    \(354\)], "Print"],

Cell[BoxData[
    \(355\)], "Print"],

Cell[BoxData[
    \(356\)], "Print"],

Cell[BoxData[
    \(357\)], "Print"],

Cell[BoxData[
    \(358\)], "Print"],

Cell[BoxData[
    \(359\)], "Print"],

Cell[BoxData[
    \(360\)], "Print"],

Cell[BoxData[
    \(361\)], "Print"],

Cell[BoxData[
    \(362\)], "Print"],

Cell[BoxData[
    \(363\)], "Print"],

Cell[BoxData[
    \(364\)], "Print"],

Cell[BoxData[
    \(365\)], "Print"],

Cell[BoxData[
    \(366\)], "Print"],

Cell[BoxData[
    \(367\)], "Print"],

Cell[BoxData[
    \(368\)], "Print"],

Cell[BoxData[
    \(369\)], "Print"],

Cell[BoxData[
    \(370\)], "Print"],

Cell[BoxData[
    \(371\)], "Print"],

Cell[BoxData[
    \(372\)], "Print"],

Cell[BoxData[
    \(373\)], "Print"],

Cell[BoxData[
    \(374\)], "Print"],

Cell[BoxData[
    \(375\)], "Print"],

Cell[BoxData[
    \(376\)], "Print"],

Cell[BoxData[
    \(377\)], "Print"],

Cell[BoxData[
    \(378\)], "Print"],

Cell[BoxData[
    \(379\)], "Print"],

Cell[BoxData[
    \(380\)], "Print"],

Cell[BoxData[
    \(381\)], "Print"],

Cell[BoxData[
    \(382\)], "Print"],

Cell[BoxData[
    \(383\)], "Print"],

Cell[BoxData[
    \(384\)], "Print"],

Cell[BoxData[
    \(385\)], "Print"],

Cell[BoxData[
    \(386\)], "Print"],

Cell[BoxData[
    \(387\)], "Print"],

Cell[BoxData[
    \(388\)], "Print"],

Cell[BoxData[
    \(389\)], "Print"],

Cell[BoxData[
    \(390\)], "Print"],

Cell[BoxData[
    \(391\)], "Print"],

Cell[BoxData[
    \(392\)], "Print"],

Cell[BoxData[
    \(393\)], "Print"],

Cell[BoxData[
    \(394\)], "Print"],

Cell[BoxData[
    \(395\)], "Print"],

Cell[BoxData[
    \(396\)], "Print"],

Cell[BoxData[
    \(397\)], "Print"],

Cell[BoxData[
    \(398\)], "Print"],

Cell[BoxData[
    \(399\)], "Print"],

Cell[BoxData[
    \(400\)], "Print"],

Cell[BoxData[
    \(401\)], "Print"],

Cell[BoxData[
    \(402\)], "Print"],

Cell[BoxData[
    \(403\)], "Print"],

Cell[BoxData[
    \(404\)], "Print"],

Cell[BoxData[
    \(405\)], "Print"],

Cell[BoxData[
    \(406\)], "Print"],

Cell[BoxData[
    \(407\)], "Print"],

Cell[BoxData[
    \(408\)], "Print"],

Cell[BoxData[
    \(409\)], "Print"],

Cell[BoxData[
    \(410\)], "Print"],

Cell[BoxData[
    \(411\)], "Print"],

Cell[BoxData[
    \(412\)], "Print"],

Cell[BoxData[
    \(413\)], "Print"],

Cell[BoxData[
    \(414\)], "Print"],

Cell[BoxData[
    \(415\)], "Print"],

Cell[BoxData[
    \(416\)], "Print"],

Cell[BoxData[
    \(417\)], "Print"],

Cell[BoxData[
    \(418\)], "Print"],

Cell[BoxData[
    \(419\)], "Print"],

Cell[BoxData[
    \(420\)], "Print"],

Cell[BoxData[
    \(421\)], "Print"],

Cell[BoxData[
    \(422\)], "Print"],

Cell[BoxData[
    \(423\)], "Print"],

Cell[BoxData[
    \(424\)], "Print"],

Cell[BoxData[
    \(425\)], "Print"],

Cell[BoxData[
    \(426\)], "Print"],

Cell[BoxData[
    \(427\)], "Print"],

Cell[BoxData[
    \(428\)], "Print"],

Cell[BoxData[
    \(429\)], "Print"],

Cell[BoxData[
    \(430\)], "Print"],

Cell[BoxData[
    \(431\)], "Print"],

Cell[BoxData[
    \(432\)], "Print"],

Cell[BoxData[
    \(433\)], "Print"],

Cell[BoxData[
    \(434\)], "Print"],

Cell[BoxData[
    \(435\)], "Print"],

Cell[BoxData[
    \(436\)], "Print"],

Cell[BoxData[
    \(437\)], "Print"],

Cell[BoxData[
    \(438\)], "Print"],

Cell[BoxData[
    \(439\)], "Print"],

Cell[BoxData[
    \(440\)], "Print"],

Cell[BoxData[
    \(441\)], "Print"],

Cell[BoxData[
    \(442\)], "Print"],

Cell[BoxData[
    \(443\)], "Print"],

Cell[BoxData[
    \(444\)], "Print"],

Cell[BoxData[
    \(445\)], "Print"],

Cell[BoxData[
    \(446\)], "Print"],

Cell[BoxData[
    \(447\)], "Print"],

Cell[BoxData[
    \(448\)], "Print"],

Cell[BoxData[
    \(449\)], "Print"],

Cell[BoxData[
    \(450\)], "Print"],

Cell[BoxData[
    \(451\)], "Print"],

Cell[BoxData[
    \(452\)], "Print"],

Cell[BoxData[
    \(453\)], "Print"],

Cell[BoxData[
    \(454\)], "Print"],

Cell[BoxData[
    \(455\)], "Print"],

Cell[BoxData[
    \(456\)], "Print"],

Cell[BoxData[
    \(457\)], "Print"],

Cell[BoxData[
    \(458\)], "Print"],

Cell[BoxData[
    \(459\)], "Print"],

Cell[BoxData[
    \(460\)], "Print"],

Cell[BoxData[
    \(461\)], "Print"],

Cell[BoxData[
    \(462\)], "Print"],

Cell[BoxData[
    \(463\)], "Print"],

Cell[BoxData[
    \(464\)], "Print"],

Cell[BoxData[
    \(465\)], "Print"],

Cell[BoxData[
    \(466\)], "Print"],

Cell[BoxData[
    \(467\)], "Print"],

Cell[BoxData[
    \(468\)], "Print"],

Cell[BoxData[
    \(469\)], "Print"],

Cell[BoxData[
    \(470\)], "Print"],

Cell[BoxData[
    \(471\)], "Print"],

Cell[BoxData[
    \(472\)], "Print"],

Cell[BoxData[
    \(473\)], "Print"],

Cell[BoxData[
    \(474\)], "Print"],

Cell[BoxData[
    \(475\)], "Print"],

Cell[BoxData[
    \(476\)], "Print"],

Cell[BoxData[
    \(477\)], "Print"],

Cell[BoxData[
    \(478\)], "Print"],

Cell[BoxData[
    \(479\)], "Print"],

Cell[BoxData[
    \(480\)], "Print"],

Cell[BoxData[
    \(481\)], "Print"],

Cell[BoxData[
    \(482\)], "Print"],

Cell[BoxData[
    \(483\)], "Print"],

Cell[BoxData[
    \(484\)], "Print"],

Cell[BoxData[
    \(485\)], "Print"],

Cell[BoxData[
    \(486\)], "Print"],

Cell[BoxData[
    \(487\)], "Print"],

Cell[BoxData[
    \(488\)], "Print"],

Cell[BoxData[
    \(489\)], "Print"],

Cell[BoxData[
    \(490\)], "Print"],

Cell[BoxData[
    \(491\)], "Print"],

Cell[BoxData[
    \(492\)], "Print"],

Cell[BoxData[
    \(493\)], "Print"],

Cell[BoxData[
    \(494\)], "Print"],

Cell[BoxData[
    \(495\)], "Print"],

Cell[BoxData[
    \(496\)], "Print"],

Cell[BoxData[
    \(497\)], "Print"],

Cell[BoxData[
    \(498\)], "Print"],

Cell[BoxData[
    \(499\)], "Print"],

Cell[BoxData[
    \(500\)], "Print"],

Cell[BoxData[
    \(501\)], "Print"],

Cell[BoxData[
    \(502\)], "Print"],

Cell[BoxData[
    \(503\)], "Print"],

Cell[BoxData[
    \(504\)], "Print"],

Cell[BoxData[
    \(505\)], "Print"],

Cell[BoxData[
    \(506\)], "Print"],

Cell[BoxData[
    \(507\)], "Print"],

Cell[BoxData[
    \(508\)], "Print"],

Cell[BoxData[
    \(509\)], "Print"],

Cell[BoxData[
    \(510\)], "Print"],

Cell[BoxData[
    \(511\)], "Print"],

Cell[BoxData[
    \(512\)], "Print"],

Cell[BoxData[
    \(513\)], "Print"],

Cell[BoxData[
    \(514\)], "Print"],

Cell[BoxData[
    \(515\)], "Print"],

Cell[BoxData[
    \(516\)], "Print"],

Cell[BoxData[
    \(517\)], "Print"],

Cell[BoxData[
    \(518\)], "Print"],

Cell[BoxData[
    \(519\)], "Print"],

Cell[BoxData[
    \(520\)], "Print"],

Cell[BoxData[
    \(521\)], "Print"],

Cell[BoxData[
    \(522\)], "Print"],

Cell[BoxData[
    \(523\)], "Print"],

Cell[BoxData[
    \(524\)], "Print"],

Cell[BoxData[
    \(525\)], "Print"],

Cell[BoxData[
    \(526\)], "Print"],

Cell[BoxData[
    \(527\)], "Print"],

Cell[BoxData[
    \(528\)], "Print"],

Cell[BoxData[
    \(529\)], "Print"],

Cell[BoxData[
    \(530\)], "Print"],

Cell[BoxData[
    \(531\)], "Print"],

Cell[BoxData[
    \(532\)], "Print"],

Cell[BoxData[
    \(533\)], "Print"],

Cell[BoxData[
    \(534\)], "Print"],

Cell[BoxData[
    \(535\)], "Print"],

Cell[BoxData[
    \(536\)], "Print"],

Cell[BoxData[
    \(537\)], "Print"],

Cell[BoxData[
    \(538\)], "Print"],

Cell[BoxData[
    \(539\)], "Print"],

Cell[BoxData[
    \(540\)], "Print"],

Cell[BoxData[
    \(541\)], "Print"],

Cell[BoxData[
    \(542\)], "Print"],

Cell[BoxData[
    \(543\)], "Print"],

Cell[BoxData[
    \(544\)], "Print"],

Cell[BoxData[
    \(545\)], "Print"],

Cell[BoxData[
    \(546\)], "Print"],

Cell[BoxData[
    \(547\)], "Print"],

Cell[BoxData[
    \(548\)], "Print"],

Cell[BoxData[
    \(549\)], "Print"],

Cell[BoxData[
    \(550\)], "Print"],

Cell[BoxData[
    \(551\)], "Print"],

Cell[BoxData[
    \(552\)], "Print"],

Cell[BoxData[
    \(553\)], "Print"],

Cell[BoxData[
    \(554\)], "Print"],

Cell[BoxData[
    \(555\)], "Print"],

Cell[BoxData[
    \(556\)], "Print"],

Cell[BoxData[
    \(557\)], "Print"],

Cell[BoxData[
    \(558\)], "Print"],

Cell[BoxData[
    \(559\)], "Print"],

Cell[BoxData[
    \(560\)], "Print"],

Cell[BoxData[
    \(561\)], "Print"],

Cell[BoxData[
    \(562\)], "Print"],

Cell[BoxData[
    \(563\)], "Print"],

Cell[BoxData[
    \(564\)], "Print"],

Cell[BoxData[
    \(565\)], "Print"],

Cell[BoxData[
    \(566\)], "Print"],

Cell[BoxData[
    \(567\)], "Print"],

Cell[BoxData[
    \(568\)], "Print"],

Cell[BoxData[
    \(569\)], "Print"],

Cell[BoxData[
    \(570\)], "Print"],

Cell[BoxData[
    \(571\)], "Print"],

Cell[BoxData[
    \(572\)], "Print"],

Cell[BoxData[
    \(573\)], "Print"],

Cell[BoxData[
    \(574\)], "Print"],

Cell[BoxData[
    \(575\)], "Print"],

Cell[BoxData[
    \(576\)], "Print"],

Cell[BoxData[
    \(577\)], "Print"],

Cell[BoxData[
    \(578\)], "Print"],

Cell[BoxData[
    \(579\)], "Print"],

Cell[BoxData[
    \(580\)], "Print"],

Cell[BoxData[
    \(581\)], "Print"],

Cell[BoxData[
    \(582\)], "Print"],

Cell[BoxData[
    \(583\)], "Print"],

Cell[BoxData[
    \(584\)], "Print"],

Cell[BoxData[
    \(585\)], "Print"],

Cell[BoxData[
    \(586\)], "Print"],

Cell[BoxData[
    \(587\)], "Print"],

Cell[BoxData[
    \(588\)], "Print"],

Cell[BoxData[
    \(589\)], "Print"],

Cell[BoxData[
    \(590\)], "Print"],

Cell[BoxData[
    \(591\)], "Print"],

Cell[BoxData[
    \(592\)], "Print"],

Cell[BoxData[
    \(593\)], "Print"],

Cell[BoxData[
    \(594\)], "Print"],

Cell[BoxData[
    \(595\)], "Print"],

Cell[BoxData[
    \(596\)], "Print"],

Cell[BoxData[
    \(597\)], "Print"],

Cell[BoxData[
    \(598\)], "Print"],

Cell[BoxData[
    \(599\)], "Print"],

Cell[BoxData[
    \(600\)], "Print"],

Cell[BoxData[
    \(601\)], "Print"],

Cell[BoxData[
    \(602\)], "Print"],

Cell[BoxData[
    \(603\)], "Print"],

Cell[BoxData[
    \(604\)], "Print"],

Cell[BoxData[
    \(605\)], "Print"],

Cell[BoxData[
    \(606\)], "Print"],

Cell[BoxData[
    \(607\)], "Print"],

Cell[BoxData[
    \(608\)], "Print"],

Cell[BoxData[
    \(609\)], "Print"],

Cell[BoxData[
    \(610\)], "Print"],

Cell[BoxData[
    \(611\)], "Print"],

Cell[BoxData[
    \(612\)], "Print"],

Cell[BoxData[
    \(613\)], "Print"],

Cell[BoxData[
    \(614\)], "Print"],

Cell[BoxData[
    \(615\)], "Print"],

Cell[BoxData[
    \(616\)], "Print"],

Cell[BoxData[
    \(617\)], "Print"],

Cell[BoxData[
    \(618\)], "Print"],

Cell[BoxData[
    \(619\)], "Print"],

Cell[BoxData[
    \(620\)], "Print"],

Cell[BoxData[
    \(621\)], "Print"],

Cell[BoxData[
    \(622\)], "Print"],

Cell[BoxData[
    \(623\)], "Print"],

Cell[BoxData[
    \(624\)], "Print"],

Cell[BoxData[
    \(625\)], "Print"],

Cell[BoxData[
    \(626\)], "Print"],

Cell[BoxData[
    \(627\)], "Print"],

Cell[BoxData[
    \(628\)], "Print"],

Cell[BoxData[
    \(629\)], "Print"],

Cell[BoxData[
    \(630\)], "Print"],

Cell[BoxData[
    \(631\)], "Print"],

Cell[BoxData[
    \(632\)], "Print"],

Cell[BoxData[
    \(633\)], "Print"],

Cell[BoxData[
    \(634\)], "Print"],

Cell[BoxData[
    \(635\)], "Print"],

Cell[BoxData[
    \(636\)], "Print"],

Cell[BoxData[
    \(637\)], "Print"],

Cell[BoxData[
    \(638\)], "Print"],

Cell[BoxData[
    \(639\)], "Print"],

Cell[BoxData[
    \(640\)], "Print"],

Cell[BoxData[
    \(641\)], "Print"],

Cell[BoxData[
    \(642\)], "Print"],

Cell[BoxData[
    \(643\)], "Print"],

Cell[BoxData[
    \(644\)], "Print"],

Cell[BoxData[
    \(645\)], "Print"],

Cell[BoxData[
    \(646\)], "Print"],

Cell[BoxData[
    \(647\)], "Print"],

Cell[BoxData[
    \(648\)], "Print"],

Cell[BoxData[
    \(649\)], "Print"],

Cell[BoxData[
    \(650\)], "Print"],

Cell[BoxData[
    \(651\)], "Print"],

Cell[BoxData[
    \(652\)], "Print"],

Cell[BoxData[
    \(653\)], "Print"],

Cell[BoxData[
    \(654\)], "Print"],

Cell[BoxData[
    \(655\)], "Print"],

Cell[BoxData[
    \(656\)], "Print"],

Cell[BoxData[
    \(657\)], "Print"],

Cell[BoxData[
    \(658\)], "Print"],

Cell[BoxData[
    \(659\)], "Print"],

Cell[BoxData[
    \(660\)], "Print"],

Cell[BoxData[
    \(661\)], "Print"],

Cell[BoxData[
    \(662\)], "Print"],

Cell[BoxData[
    \(663\)], "Print"],

Cell[BoxData[
    \(664\)], "Print"],

Cell[BoxData[
    \(665\)], "Print"],

Cell[BoxData[
    \(666\)], "Print"],

Cell[BoxData[
    \(667\)], "Print"],

Cell[BoxData[
    \(668\)], "Print"],

Cell[BoxData[
    \(669\)], "Print"],

Cell[BoxData[
    \(670\)], "Print"],

Cell[BoxData[
    \(671\)], "Print"],

Cell[BoxData[
    \(672\)], "Print"],

Cell[BoxData[
    \(673\)], "Print"],

Cell[BoxData[
    \(674\)], "Print"],

Cell[BoxData[
    \(675\)], "Print"],

Cell[BoxData[
    \(676\)], "Print"],

Cell[BoxData[
    \(677\)], "Print"],

Cell[BoxData[
    \(678\)], "Print"],

Cell[BoxData[
    \(679\)], "Print"],

Cell[BoxData[
    \(680\)], "Print"],

Cell[BoxData[
    \(681\)], "Print"],

Cell[BoxData[
    \(682\)], "Print"],

Cell[BoxData[
    \(683\)], "Print"],

Cell[BoxData[
    \(684\)], "Print"],

Cell[BoxData[
    \(685\)], "Print"],

Cell[BoxData[
    \(686\)], "Print"],

Cell[BoxData[
    \(687\)], "Print"],

Cell[BoxData[
    \(688\)], "Print"],

Cell[BoxData[
    \(689\)], "Print"],

Cell[BoxData[
    \(690\)], "Print"],

Cell[BoxData[
    \(691\)], "Print"],

Cell[BoxData[
    \(692\)], "Print"],

Cell[BoxData[
    \(693\)], "Print"],

Cell[BoxData[
    \(694\)], "Print"],

Cell[BoxData[
    \(695\)], "Print"],

Cell[BoxData[
    \(696\)], "Print"],

Cell[BoxData[
    \(697\)], "Print"],

Cell[BoxData[
    \(698\)], "Print"],

Cell[BoxData[
    \(699\)], "Print"],

Cell[BoxData[
    \(700\)], "Print"],

Cell[BoxData[
    \(701\)], "Print"],

Cell[BoxData[
    \(702\)], "Print"],

Cell[BoxData[
    \(703\)], "Print"],

Cell[BoxData[
    \(704\)], "Print"],

Cell[BoxData[
    \(705\)], "Print"],

Cell[BoxData[
    \(706\)], "Print"],

Cell[BoxData[
    \(707\)], "Print"],

Cell[BoxData[
    \(708\)], "Print"],

Cell[BoxData[
    \(709\)], "Print"],

Cell[BoxData[
    \(710\)], "Print"],

Cell[BoxData[
    \(711\)], "Print"],

Cell[BoxData[
    \(712\)], "Print"],

Cell[BoxData[
    \(713\)], "Print"],

Cell[BoxData[
    \(714\)], "Print"],

Cell[BoxData[
    \(715\)], "Print"],

Cell[BoxData[
    \(716\)], "Print"],

Cell[BoxData[
    \(717\)], "Print"],

Cell[BoxData[
    \(718\)], "Print"],

Cell[BoxData[
    \(719\)], "Print"],

Cell[BoxData[
    \(720\)], "Print"],

Cell[BoxData[
    \(721\)], "Print"],

Cell[BoxData[
    \(722\)], "Print"],

Cell[BoxData[
    \(723\)], "Print"],

Cell[BoxData[
    \(724\)], "Print"],

Cell[BoxData[
    \(725\)], "Print"],

Cell[BoxData[
    \(726\)], "Print"],

Cell[BoxData[
    \(727\)], "Print"],

Cell[BoxData[
    \(728\)], "Print"],

Cell[BoxData[
    \(729\)], "Print"],

Cell[BoxData[
    \(730\)], "Print"],

Cell[BoxData[
    \(731\)], "Print"],

Cell[BoxData[
    \(732\)], "Print"],

Cell[BoxData[
    \(733\)], "Print"],

Cell[BoxData[
    \(734\)], "Print"],

Cell[BoxData[
    \(735\)], "Print"],

Cell[BoxData[
    \(736\)], "Print"],

Cell[BoxData[
    \(737\)], "Print"],

Cell[BoxData[
    \(738\)], "Print"],

Cell[BoxData[
    \(739\)], "Print"],

Cell[BoxData[
    \(740\)], "Print"],

Cell[BoxData[
    \(741\)], "Print"],

Cell[BoxData[
    \(742\)], "Print"],

Cell[BoxData[
    \(743\)], "Print"],

Cell[BoxData[
    \(744\)], "Print"],

Cell[BoxData[
    \(745\)], "Print"],

Cell[BoxData[
    \(746\)], "Print"],

Cell[BoxData[
    \(747\)], "Print"],

Cell[BoxData[
    \(748\)], "Print"],

Cell[BoxData[
    \(749\)], "Print"],

Cell[BoxData[
    \(750\)], "Print"],

Cell[BoxData[
    \(751\)], "Print"],

Cell[BoxData[
    \(752\)], "Print"],

Cell[BoxData[
    \(753\)], "Print"],

Cell[BoxData[
    \(754\)], "Print"],

Cell[BoxData[
    \(755\)], "Print"],

Cell[BoxData[
    \(756\)], "Print"],

Cell[BoxData[
    \(757\)], "Print"],

Cell[BoxData[
    \(758\)], "Print"],

Cell[BoxData[
    \(759\)], "Print"],

Cell[BoxData[
    \(760\)], "Print"],

Cell[BoxData[
    \(761\)], "Print"],

Cell[BoxData[
    \(762\)], "Print"],

Cell[BoxData[
    \(763\)], "Print"],

Cell[BoxData[
    \(764\)], "Print"],

Cell[BoxData[
    \(765\)], "Print"],

Cell[BoxData[
    \(766\)], "Print"],

Cell[BoxData[
    \(767\)], "Print"],

Cell[BoxData[
    \(768\)], "Print"],

Cell[BoxData[
    \(769\)], "Print"],

Cell[BoxData[
    \(770\)], "Print"],

Cell[BoxData[
    \(771\)], "Print"],

Cell[BoxData[
    \(772\)], "Print"],

Cell[BoxData[
    \(773\)], "Print"],

Cell[BoxData[
    \(774\)], "Print"],

Cell[BoxData[
    \(775\)], "Print"],

Cell[BoxData[
    \(776\)], "Print"],

Cell[BoxData[
    \(777\)], "Print"],

Cell[BoxData[
    \(778\)], "Print"],

Cell[BoxData[
    \(779\)], "Print"],

Cell[BoxData[
    \(780\)], "Print"],

Cell[BoxData[
    \(781\)], "Print"],

Cell[BoxData[
    \(782\)], "Print"],

Cell[BoxData[
    \(783\)], "Print"],

Cell[BoxData[
    \(784\)], "Print"],

Cell[BoxData[
    \(785\)], "Print"],

Cell[BoxData[
    \(786\)], "Print"],

Cell[BoxData[
    \(787\)], "Print"],

Cell[BoxData[
    \(788\)], "Print"],

Cell[BoxData[
    \(789\)], "Print"],

Cell[BoxData[
    \(790\)], "Print"],

Cell[BoxData[
    \(791\)], "Print"],

Cell[BoxData[
    \(792\)], "Print"],

Cell[BoxData[
    \(793\)], "Print"],

Cell[BoxData[
    \(794\)], "Print"],

Cell[BoxData[
    \(795\)], "Print"],

Cell[BoxData[
    \(796\)], "Print"],

Cell[BoxData[
    \(797\)], "Print"],

Cell[BoxData[
    \(798\)], "Print"],

Cell[BoxData[
    \(799\)], "Print"],

Cell[BoxData[
    \(800\)], "Print"],

Cell[BoxData[
    \(801\)], "Print"],

Cell[BoxData[
    \(802\)], "Print"],

Cell[BoxData[
    \(803\)], "Print"],

Cell[BoxData[
    \(804\)], "Print"],

Cell[BoxData[
    \(805\)], "Print"],

Cell[BoxData[
    \(806\)], "Print"],

Cell[BoxData[
    \(807\)], "Print"],

Cell[BoxData[
    \(808\)], "Print"],

Cell[BoxData[
    \(809\)], "Print"],

Cell[BoxData[
    \(810\)], "Print"],

Cell[BoxData[
    \(811\)], "Print"],

Cell[BoxData[
    \(812\)], "Print"],

Cell[BoxData[
    \(813\)], "Print"],

Cell[BoxData[
    \(814\)], "Print"],

Cell[BoxData[
    \(815\)], "Print"],

Cell[BoxData[
    \(816\)], "Print"],

Cell[BoxData[
    \(817\)], "Print"],

Cell[BoxData[
    \(818\)], "Print"],

Cell[BoxData[
    \(819\)], "Print"],

Cell[BoxData[
    \(820\)], "Print"],

Cell[BoxData[
    \(821\)], "Print"],

Cell[BoxData[
    \(822\)], "Print"],

Cell[BoxData[
    \(823\)], "Print"],

Cell[BoxData[
    \(824\)], "Print"],

Cell[BoxData[
    \(825\)], "Print"],

Cell[BoxData[
    \(826\)], "Print"],

Cell[BoxData[
    \(827\)], "Print"],

Cell[BoxData[
    \(828\)], "Print"],

Cell[BoxData[
    \(829\)], "Print"],

Cell[BoxData[
    \(830\)], "Print"],

Cell[BoxData[
    \(831\)], "Print"],

Cell[BoxData[
    \(832\)], "Print"],

Cell[BoxData[
    \(833\)], "Print"],

Cell[BoxData[
    \(834\)], "Print"],

Cell[BoxData[
    \(835\)], "Print"],

Cell[BoxData[
    \(836\)], "Print"],

Cell[BoxData[
    \(837\)], "Print"],

Cell[BoxData[
    \(838\)], "Print"],

Cell[BoxData[
    \(839\)], "Print"],

Cell[BoxData[
    \(840\)], "Print"],

Cell[BoxData[
    \(841\)], "Print"],

Cell[BoxData[
    \(842\)], "Print"],

Cell[BoxData[
    \(843\)], "Print"],

Cell[BoxData[
    \(844\)], "Print"],

Cell[BoxData[
    \(845\)], "Print"],

Cell[BoxData[
    \(846\)], "Print"],

Cell[BoxData[
    \(847\)], "Print"],

Cell[BoxData[
    \(848\)], "Print"],

Cell[BoxData[
    \(849\)], "Print"],

Cell[BoxData[
    \(850\)], "Print"],

Cell[BoxData[
    \(851\)], "Print"],

Cell[BoxData[
    \(852\)], "Print"],

Cell[BoxData[
    \(853\)], "Print"],

Cell[BoxData[
    \(854\)], "Print"],

Cell[BoxData[
    \(855\)], "Print"],

Cell[BoxData[
    \(856\)], "Print"],

Cell[BoxData[
    \(857\)], "Print"],

Cell[BoxData[
    \(858\)], "Print"],

Cell[BoxData[
    \(859\)], "Print"],

Cell[BoxData[
    \(860\)], "Print"],

Cell[BoxData[
    \(861\)], "Print"],

Cell[BoxData[
    \(862\)], "Print"],

Cell[BoxData[
    \(863\)], "Print"],

Cell[BoxData[
    \(864\)], "Print"],

Cell[BoxData[
    \(865\)], "Print"],

Cell[BoxData[
    \(866\)], "Print"],

Cell[BoxData[
    \(867\)], "Print"],

Cell[BoxData[
    \(868\)], "Print"],

Cell[BoxData[
    \(869\)], "Print"],

Cell[BoxData[
    \(870\)], "Print"],

Cell[BoxData[
    \(871\)], "Print"],

Cell[BoxData[
    \(872\)], "Print"],

Cell[BoxData[
    \(873\)], "Print"],

Cell[BoxData[
    \(874\)], "Print"],

Cell[BoxData[
    \(875\)], "Print"],

Cell[BoxData[
    \(876\)], "Print"],

Cell[BoxData[
    \(877\)], "Print"],

Cell[BoxData[
    \(878\)], "Print"],

Cell[BoxData[
    \(879\)], "Print"],

Cell[BoxData[
    \(880\)], "Print"],

Cell[BoxData[
    \(881\)], "Print"],

Cell[BoxData[
    \(882\)], "Print"],

Cell[BoxData[
    \(883\)], "Print"],

Cell[BoxData[
    \(884\)], "Print"],

Cell[BoxData[
    \(885\)], "Print"],

Cell[BoxData[
    \(886\)], "Print"],

Cell[BoxData[
    \(887\)], "Print"],

Cell[BoxData[
    \(888\)], "Print"],

Cell[BoxData[
    \(889\)], "Print"],

Cell[BoxData[
    \(890\)], "Print"],

Cell[BoxData[
    \(891\)], "Print"],

Cell[BoxData[
    \(892\)], "Print"],

Cell[BoxData[
    \(893\)], "Print"],

Cell[BoxData[
    \(894\)], "Print"],

Cell[BoxData[
    \(895\)], "Print"],

Cell[BoxData[
    \(896\)], "Print"],

Cell[BoxData[
    \(897\)], "Print"],

Cell[BoxData[
    \(898\)], "Print"],

Cell[BoxData[
    \(899\)], "Print"],

Cell[BoxData[
    \(900\)], "Print"],

Cell[BoxData[
    \(901\)], "Print"],

Cell[BoxData[
    \(902\)], "Print"],

Cell[BoxData[
    \(903\)], "Print"],

Cell[BoxData[
    \(904\)], "Print"],

Cell[BoxData[
    \(905\)], "Print"],

Cell[BoxData[
    \(906\)], "Print"],

Cell[BoxData[
    \(907\)], "Print"],

Cell[BoxData[
    \(908\)], "Print"],

Cell[BoxData[
    \(909\)], "Print"],

Cell[BoxData[
    \(910\)], "Print"],

Cell[BoxData[
    \(911\)], "Print"],

Cell[BoxData[
    \(912\)], "Print"],

Cell[BoxData[
    \(913\)], "Print"],

Cell[BoxData[
    \(914\)], "Print"],

Cell[BoxData[
    \(915\)], "Print"],

Cell[BoxData[
    \(916\)], "Print"],

Cell[BoxData[
    \(917\)], "Print"],

Cell[BoxData[
    \(918\)], "Print"],

Cell[BoxData[
    \(919\)], "Print"],

Cell[BoxData[
    \(920\)], "Print"],

Cell[BoxData[
    \(921\)], "Print"],

Cell[BoxData[
    \(922\)], "Print"],

Cell[BoxData[
    \(923\)], "Print"],

Cell[BoxData[
    \(924\)], "Print"],

Cell[BoxData[
    \(925\)], "Print"],

Cell[BoxData[
    \(926\)], "Print"],

Cell[BoxData[
    \(927\)], "Print"],

Cell[BoxData[
    \(928\)], "Print"],

Cell[BoxData[
    \(929\)], "Print"],

Cell[BoxData[
    \(930\)], "Print"],

Cell[BoxData[
    \(931\)], "Print"],

Cell[BoxData[
    \(932\)], "Print"],

Cell[BoxData[
    \(933\)], "Print"],

Cell[BoxData[
    \(934\)], "Print"],

Cell[BoxData[
    \(935\)], "Print"],

Cell[BoxData[
    \(936\)], "Print"],

Cell[BoxData[
    \(937\)], "Print"],

Cell[BoxData[
    \(938\)], "Print"],

Cell[BoxData[
    \(939\)], "Print"],

Cell[BoxData[
    \(940\)], "Print"],

Cell[BoxData[
    \(941\)], "Print"],

Cell[BoxData[
    \(942\)], "Print"],

Cell[BoxData[
    \(943\)], "Print"],

Cell[BoxData[
    \(944\)], "Print"],

Cell[BoxData[
    \(945\)], "Print"],

Cell[BoxData[
    \(946\)], "Print"],

Cell[BoxData[
    \(947\)], "Print"],

Cell[BoxData[
    \(948\)], "Print"],

Cell[BoxData[
    \(949\)], "Print"],

Cell[BoxData[
    \(950\)], "Print"],

Cell[BoxData[
    \(951\)], "Print"],

Cell[BoxData[
    \(952\)], "Print"],

Cell[BoxData[
    \(953\)], "Print"],

Cell[BoxData[
    \(954\)], "Print"],

Cell[BoxData[
    \(955\)], "Print"],

Cell[BoxData[
    \(956\)], "Print"],

Cell[BoxData[
    \(957\)], "Print"],

Cell[BoxData[
    \(958\)], "Print"],

Cell[BoxData[
    \(959\)], "Print"],

Cell[BoxData[
    \(960\)], "Print"],

Cell[BoxData[
    \(961\)], "Print"],

Cell[BoxData[
    \(962\)], "Print"],

Cell[BoxData[
    \(963\)], "Print"],

Cell[BoxData[
    \(964\)], "Print"],

Cell[BoxData[
    \(965\)], "Print"],

Cell[BoxData[
    \(966\)], "Print"],

Cell[BoxData[
    \(967\)], "Print"],

Cell[BoxData[
    \(968\)], "Print"],

Cell[BoxData[
    \(969\)], "Print"],

Cell[BoxData[
    \(970\)], "Print"],

Cell[BoxData[
    \(971\)], "Print"],

Cell[BoxData[
    \(972\)], "Print"],

Cell[BoxData[
    \(973\)], "Print"],

Cell[BoxData[
    \(974\)], "Print"],

Cell[BoxData[
    \(975\)], "Print"],

Cell[BoxData[
    \(976\)], "Print"],

Cell[BoxData[
    \(977\)], "Print"],

Cell[BoxData[
    \(978\)], "Print"],

Cell[BoxData[
    \(979\)], "Print"],

Cell[BoxData[
    \(980\)], "Print"],

Cell[BoxData[
    \(981\)], "Print"],

Cell[BoxData[
    \(982\)], "Print"],

Cell[BoxData[
    \(983\)], "Print"],

Cell[BoxData[
    \(984\)], "Print"],

Cell[BoxData[
    \(985\)], "Print"],

Cell[BoxData[
    \(986\)], "Print"],

Cell[BoxData[
    \(987\)], "Print"],

Cell[BoxData[
    \(988\)], "Print"],

Cell[BoxData[
    \(989\)], "Print"],

Cell[BoxData[
    \(990\)], "Print"],

Cell[BoxData[
    \(991\)], "Print"],

Cell[BoxData[
    \(992\)], "Print"],

Cell[BoxData[
    \(993\)], "Print"],

Cell[BoxData[
    \(994\)], "Print"],

Cell[BoxData[
    \(995\)], "Print"],

Cell[BoxData[
    \(996\)], "Print"],

Cell[BoxData[
    \(997\)], "Print"],

Cell[BoxData[
    \(998\)], "Print"],

Cell[BoxData[
    \(999\)], "Print"],

Cell[BoxData[
    \(1000\)], "Print"],

Cell[BoxData[
    \(1001\)], "Print"],

Cell[BoxData[
    \(1002\)], "Print"],

Cell[BoxData[
    \(1003\)], "Print"],

Cell[BoxData[
    \(1004\)], "Print"],

Cell[BoxData[
    \(1005\)], "Print"],

Cell[BoxData[
    \(1006\)], "Print"],

Cell[BoxData[
    \(1007\)], "Print"],

Cell[BoxData[
    \(1008\)], "Print"],

Cell[BoxData[
    \(1009\)], "Print"],

Cell[BoxData[
    \(1010\)], "Print"],

Cell[BoxData[
    \(1011\)], "Print"],

Cell[BoxData[
    \(1012\)], "Print"],

Cell[BoxData[
    \(1013\)], "Print"],

Cell[BoxData[
    \(1014\)], "Print"],

Cell[BoxData[
    \(1015\)], "Print"],

Cell[BoxData[
    \(1016\)], "Print"],

Cell[BoxData[
    \(1017\)], "Print"],

Cell[BoxData[
    \(1018\)], "Print"],

Cell[BoxData[
    \(1019\)], "Print"],

Cell[BoxData[
    \(1020\)], "Print"],

Cell[BoxData[
    \(1021\)], "Print"],

Cell[BoxData[
    \(1022\)], "Print"],

Cell[BoxData[
    \(1023\)], "Print"],

Cell[BoxData[
    \(1024\)], "Print"],

Cell[BoxData[
    \(1025\)], "Print"],

Cell[BoxData[
    \(1026\)], "Print"],

Cell[BoxData[
    \(1027\)], "Print"],

Cell[BoxData[
    \(1028\)], "Print"],

Cell[BoxData[
    \(1029\)], "Print"],

Cell[BoxData[
    \(1030\)], "Print"],

Cell[BoxData[
    \(1031\)], "Print"],

Cell[BoxData[
    \(1032\)], "Print"],

Cell[BoxData[
    \(1033\)], "Print"],

Cell[BoxData[
    \(1034\)], "Print"],

Cell[BoxData[
    \(1035\)], "Print"],

Cell[BoxData[
    \(1036\)], "Print"],

Cell[BoxData[
    \(1037\)], "Print"],

Cell[BoxData[
    \(1038\)], "Print"],

Cell[BoxData[
    \(1039\)], "Print"],

Cell[BoxData[
    \(1040\)], "Print"],

Cell[BoxData[
    \(1041\)], "Print"],

Cell[BoxData[
    \(1042\)], "Print"],

Cell[BoxData[
    \(1043\)], "Print"],

Cell[BoxData[
    \(1044\)], "Print"],

Cell[BoxData[
    \(1045\)], "Print"],

Cell[BoxData[
    \(1046\)], "Print"],

Cell[BoxData[
    \(1047\)], "Print"],

Cell[BoxData[
    \(1048\)], "Print"],

Cell[BoxData[
    \(1049\)], "Print"],

Cell[BoxData[
    \(1050\)], "Print"],

Cell[BoxData[
    \(1051\)], "Print"],

Cell[BoxData[
    \(1052\)], "Print"],

Cell[BoxData[
    \(1053\)], "Print"],

Cell[BoxData[
    \(1054\)], "Print"],

Cell[BoxData[
    \(1055\)], "Print"],

Cell[BoxData[
    \(1056\)], "Print"],

Cell[BoxData[
    \(1057\)], "Print"],

Cell[BoxData[
    \(1058\)], "Print"],

Cell[BoxData[
    \(1059\)], "Print"],

Cell[BoxData[
    \(1060\)], "Print"],

Cell[BoxData[
    \(1061\)], "Print"],

Cell[BoxData[
    \(1062\)], "Print"],

Cell[BoxData[
    \(1063\)], "Print"],

Cell[BoxData[
    \(1064\)], "Print"],

Cell[BoxData[
    \(1065\)], "Print"],

Cell[BoxData[
    \(1066\)], "Print"],

Cell[BoxData[
    \(1067\)], "Print"],

Cell[BoxData[
    \(1068\)], "Print"],

Cell[BoxData[
    \(1069\)], "Print"],

Cell[BoxData[
    \(1070\)], "Print"],

Cell[BoxData[
    \(1071\)], "Print"],

Cell[BoxData[
    \(1072\)], "Print"],

Cell[BoxData[
    \(1073\)], "Print"],

Cell[BoxData[
    \(1074\)], "Print"],

Cell[BoxData[
    \(1075\)], "Print"],

Cell[BoxData[
    \(1076\)], "Print"],

Cell[BoxData[
    \(1077\)], "Print"],

Cell[BoxData[
    \(1078\)], "Print"],

Cell[BoxData[
    \(1079\)], "Print"],

Cell[BoxData[
    \(1080\)], "Print"],

Cell[BoxData[
    \(1081\)], "Print"],

Cell[BoxData[
    \(1082\)], "Print"],

Cell[BoxData[
    \(1083\)], "Print"],

Cell[BoxData[
    \(1084\)], "Print"],

Cell[BoxData[
    \(1085\)], "Print"],

Cell[BoxData[
    \(1086\)], "Print"],

Cell[BoxData[
    \(1087\)], "Print"],

Cell[BoxData[
    \(1088\)], "Print"],

Cell[BoxData[
    \(1089\)], "Print"],

Cell[BoxData[
    \(1090\)], "Print"],

Cell[BoxData[
    \(1091\)], "Print"],

Cell[BoxData[
    \(1092\)], "Print"],

Cell[BoxData[
    \(1093\)], "Print"],

Cell[BoxData[
    \(1094\)], "Print"],

Cell[BoxData[
    \(1095\)], "Print"],

Cell[BoxData[
    \(1096\)], "Print"],

Cell[BoxData[
    \(1097\)], "Print"],

Cell[BoxData[
    \(1098\)], "Print"],

Cell[BoxData[
    \(1099\)], "Print"],

Cell[BoxData[
    \(1100\)], "Print"],

Cell[BoxData[
    \(1101\)], "Print"],

Cell[BoxData[
    \(1102\)], "Print"],

Cell[BoxData[
    \(1103\)], "Print"],

Cell[BoxData[
    \(1104\)], "Print"],

Cell[BoxData[
    \(1105\)], "Print"],

Cell[BoxData[
    \(1106\)], "Print"],

Cell[BoxData[
    \(1107\)], "Print"],

Cell[BoxData[
    \(1108\)], "Print"],

Cell[BoxData[
    \(1109\)], "Print"],

Cell[BoxData[
    \(1110\)], "Print"],

Cell[BoxData[
    \(1111\)], "Print"],

Cell[BoxData[
    \(1112\)], "Print"],

Cell[BoxData[
    \(1113\)], "Print"],

Cell[BoxData[
    \(1114\)], "Print"],

Cell[BoxData[
    \(1115\)], "Print"],

Cell[BoxData[
    \(1116\)], "Print"],

Cell[BoxData[
    \(1117\)], "Print"],

Cell[BoxData[
    \(1118\)], "Print"],

Cell[BoxData[
    \(1119\)], "Print"],

Cell[BoxData[
    \(1120\)], "Print"],

Cell[BoxData[
    \(1121\)], "Print"],

Cell[BoxData[
    \(1122\)], "Print"],

Cell[BoxData[
    \(1123\)], "Print"],

Cell[BoxData[
    \(1124\)], "Print"],

Cell[BoxData[
    \(1125\)], "Print"],

Cell[BoxData[
    \(1126\)], "Print"],

Cell[BoxData[
    \(1127\)], "Print"],

Cell[BoxData[
    \(1128\)], "Print"],

Cell[BoxData[
    \(1129\)], "Print"],

Cell[BoxData[
    \(1130\)], "Print"],

Cell[BoxData[
    \(1131\)], "Print"],

Cell[BoxData[
    \(1132\)], "Print"],

Cell[BoxData[
    \(1133\)], "Print"],

Cell[BoxData[
    \(1134\)], "Print"],

Cell[BoxData[
    \(1135\)], "Print"],

Cell[BoxData[
    \(1136\)], "Print"],

Cell[BoxData[
    \(1137\)], "Print"],

Cell[BoxData[
    \(1138\)], "Print"],

Cell[BoxData[
    \(1139\)], "Print"],

Cell[BoxData[
    \(1140\)], "Print"],

Cell[BoxData[
    \(1141\)], "Print"],

Cell[BoxData[
    \(1142\)], "Print"],

Cell[BoxData[
    \(1143\)], "Print"],

Cell[BoxData[
    \(1144\)], "Print"],

Cell[BoxData[
    \(1145\)], "Print"],

Cell[BoxData[
    \(1146\)], "Print"],

Cell[BoxData[
    \(1147\)], "Print"],

Cell[BoxData[
    \(1148\)], "Print"],

Cell[BoxData[
    \(1149\)], "Print"],

Cell[BoxData[
    \(1150\)], "Print"],

Cell[BoxData[
    \(1151\)], "Print"],

Cell[BoxData[
    \(1152\)], "Print"],

Cell[BoxData[
    \(1153\)], "Print"],

Cell[BoxData[
    \(1154\)], "Print"],

Cell[BoxData[
    \(1155\)], "Print"],

Cell[BoxData[
    \(1156\)], "Print"],

Cell[BoxData[
    \(1157\)], "Print"],

Cell[BoxData[
    \(1158\)], "Print"],

Cell[BoxData[
    \(1159\)], "Print"],

Cell[BoxData[
    \(1160\)], "Print"],

Cell[BoxData[
    \(1161\)], "Print"],

Cell[BoxData[
    \(1162\)], "Print"],

Cell[BoxData[
    \(1163\)], "Print"],

Cell[BoxData[
    \(1164\)], "Print"],

Cell[BoxData[
    \(1165\)], "Print"],

Cell[BoxData[
    \(1166\)], "Print"],

Cell[BoxData[
    \(1167\)], "Print"],

Cell[BoxData[
    \(1168\)], "Print"],

Cell[BoxData[
    \(1169\)], "Print"],

Cell[BoxData[
    \(1170\)], "Print"],

Cell[BoxData[
    \(1171\)], "Print"],

Cell[BoxData[
    \(1172\)], "Print"],

Cell[BoxData[
    \(1173\)], "Print"],

Cell[BoxData[
    \(1174\)], "Print"],

Cell[BoxData[
    \(1175\)], "Print"],

Cell[BoxData[
    \(1176\)], "Print"],

Cell[BoxData[
    \(1177\)], "Print"],

Cell[BoxData[
    \(1178\)], "Print"],

Cell[BoxData[
    \(1179\)], "Print"],

Cell[BoxData[
    \(1180\)], "Print"],

Cell[BoxData[
    \(1181\)], "Print"],

Cell[BoxData[
    \(1182\)], "Print"],

Cell[BoxData[
    \(1183\)], "Print"],

Cell[BoxData[
    \(1184\)], "Print"],

Cell[BoxData[
    \(1185\)], "Print"],

Cell[BoxData[
    \(1186\)], "Print"],

Cell[BoxData[
    \(1187\)], "Print"],

Cell[BoxData[
    \(1188\)], "Print"],

Cell[BoxData[
    \(1189\)], "Print"],

Cell[BoxData[
    \(1190\)], "Print"],

Cell[BoxData[
    \(1191\)], "Print"],

Cell[BoxData[
    \(1192\)], "Print"],

Cell[BoxData[
    \(1193\)], "Print"],

Cell[BoxData[
    \(1194\)], "Print"],

Cell[BoxData[
    \(1195\)], "Print"],

Cell[BoxData[
    \(1196\)], "Print"],

Cell[BoxData[
    \(1197\)], "Print"],

Cell[BoxData[
    \(1198\)], "Print"],

Cell[BoxData[
    \(1199\)], "Print"],

Cell[BoxData[
    \(1200\)], "Print"],

Cell[BoxData[
    \(1201\)], "Print"],

Cell[BoxData[
    \(1202\)], "Print"],

Cell[BoxData[
    \(1203\)], "Print"],

Cell[BoxData[
    \(1204\)], "Print"],

Cell[BoxData[
    \(1205\)], "Print"],

Cell[BoxData[
    \(1206\)], "Print"],

Cell[BoxData[
    \(1207\)], "Print"],

Cell[BoxData[
    \(1208\)], "Print"],

Cell[BoxData[
    \(1209\)], "Print"],

Cell[BoxData[
    \(1210\)], "Print"],

Cell[BoxData[
    \(1211\)], "Print"],

Cell[BoxData[
    \(1212\)], "Print"],

Cell[BoxData[
    \(1213\)], "Print"],

Cell[BoxData[
    \(1214\)], "Print"],

Cell[BoxData[
    \(1215\)], "Print"],

Cell[BoxData[
    \(1216\)], "Print"],

Cell[BoxData[
    \(1217\)], "Print"],

Cell[BoxData[
    \(1218\)], "Print"],

Cell[BoxData[
    \(1219\)], "Print"],

Cell[BoxData[
    \(1220\)], "Print"],

Cell[BoxData[
    \(1221\)], "Print"],

Cell[BoxData[
    \(1222\)], "Print"],

Cell[BoxData[
    \(1223\)], "Print"],

Cell[BoxData[
    \(1224\)], "Print"],

Cell[BoxData[
    \(1225\)], "Print"],

Cell[BoxData[
    \(1226\)], "Print"],

Cell[BoxData[
    \(1227\)], "Print"],

Cell[BoxData[
    \(1228\)], "Print"],

Cell[BoxData[
    \(1229\)], "Print"],

Cell[BoxData[
    \(1230\)], "Print"],

Cell[BoxData[
    \(1231\)], "Print"],

Cell[BoxData[
    \(1232\)], "Print"],

Cell[BoxData[
    \(1233\)], "Print"],

Cell[BoxData[
    \(1234\)], "Print"],

Cell[BoxData[
    \(1235\)], "Print"],

Cell[BoxData[
    \(1236\)], "Print"],

Cell[BoxData[
    \(1237\)], "Print"],

Cell[BoxData[
    \(1238\)], "Print"],

Cell[BoxData[
    \(1239\)], "Print"],

Cell[BoxData[
    \(1240\)], "Print"],

Cell[BoxData[
    \(1241\)], "Print"],

Cell[BoxData[
    \(1242\)], "Print"],

Cell[BoxData[
    \(1243\)], "Print"],

Cell[BoxData[
    \(1244\)], "Print"],

Cell[BoxData[
    \(1245\)], "Print"],

Cell[BoxData[
    \(1246\)], "Print"],

Cell[BoxData[
    \(1247\)], "Print"],

Cell[BoxData[
    \(1248\)], "Print"],

Cell[BoxData[
    \(1249\)], "Print"],

Cell[BoxData[
    \(1250\)], "Print"],

Cell[BoxData[
    \(1251\)], "Print"],

Cell[BoxData[
    \(1252\)], "Print"],

Cell[BoxData[
    \(1253\)], "Print"],

Cell[BoxData[
    \(1254\)], "Print"],

Cell[BoxData[
    \(1255\)], "Print"],

Cell[BoxData[
    \(1256\)], "Print"],

Cell[BoxData[
    \(1257\)], "Print"],

Cell[BoxData[
    \(1258\)], "Print"],

Cell[BoxData[
    \(1259\)], "Print"],

Cell[BoxData[
    \(1260\)], "Print"],

Cell[BoxData[
    \(1261\)], "Print"],

Cell[BoxData[
    \(1262\)], "Print"],

Cell[BoxData[
    \(1263\)], "Print"],

Cell[BoxData[
    \(1264\)], "Print"],

Cell[BoxData[
    \(1265\)], "Print"],

Cell[BoxData[
    \(1266\)], "Print"],

Cell[BoxData[
    \(1267\)], "Print"],

Cell[BoxData[
    \(1268\)], "Print"],

Cell[BoxData[
    \(1269\)], "Print"],

Cell[BoxData[
    \(1270\)], "Print"],

Cell[BoxData[
    \(1271\)], "Print"],

Cell[BoxData[
    \(1272\)], "Print"],

Cell[BoxData[
    \(1273\)], "Print"],

Cell[BoxData[
    \(1274\)], "Print"],

Cell[BoxData[
    \(1275\)], "Print"],

Cell[BoxData[
    \(1276\)], "Print"],

Cell[BoxData[
    \(1277\)], "Print"],

Cell[BoxData[
    \(1278\)], "Print"],

Cell[BoxData[
    \(1279\)], "Print"],

Cell[BoxData[
    \(1280\)], "Print"],

Cell[BoxData[
    \(1281\)], "Print"],

Cell[BoxData[
    \(1282\)], "Print"],

Cell[BoxData[
    \(1283\)], "Print"],

Cell[BoxData[
    \(1284\)], "Print"],

Cell[BoxData[
    \(1285\)], "Print"],

Cell[BoxData[
    \(1286\)], "Print"],

Cell[BoxData[
    \(1287\)], "Print"],

Cell[BoxData[
    \(1288\)], "Print"],

Cell[BoxData[
    \(1289\)], "Print"],

Cell[BoxData[
    \(1290\)], "Print"],

Cell[BoxData[
    \(1291\)], "Print"],

Cell[BoxData[
    \(1292\)], "Print"],

Cell[BoxData[
    \(1293\)], "Print"],

Cell[BoxData[
    \(1294\)], "Print"],

Cell[BoxData[
    \(1295\)], "Print"],

Cell[BoxData[
    \(1296\)], "Print"],

Cell[BoxData[
    \(1297\)], "Print"],

Cell[BoxData[
    \(1298\)], "Print"],

Cell[BoxData[
    \(1299\)], "Print"],

Cell[BoxData[
    \(1300\)], "Print"],

Cell[BoxData[
    \(1301\)], "Print"],

Cell[BoxData[
    \(1302\)], "Print"],

Cell[BoxData[
    \(1303\)], "Print"],

Cell[BoxData[
    \(1304\)], "Print"],

Cell[BoxData[
    \(1305\)], "Print"],

Cell[BoxData[
    \(1306\)], "Print"],

Cell[BoxData[
    \(1307\)], "Print"],

Cell[BoxData[
    \(1308\)], "Print"],

Cell[BoxData[
    \(1309\)], "Print"],

Cell[BoxData[
    \(1310\)], "Print"],

Cell[BoxData[
    \(1311\)], "Print"],

Cell[BoxData[
    \(1312\)], "Print"],

Cell[BoxData[
    \(1313\)], "Print"],

Cell[BoxData[
    \(1314\)], "Print"],

Cell[BoxData[
    \(1315\)], "Print"],

Cell[BoxData[
    \(1316\)], "Print"],

Cell[BoxData[
    \(1317\)], "Print"],

Cell[BoxData[
    \(1318\)], "Print"],

Cell[BoxData[
    \(1319\)], "Print"],

Cell[BoxData[
    \(1320\)], "Print"],

Cell[BoxData[
    \(1321\)], "Print"],

Cell[BoxData[
    \(1322\)], "Print"],

Cell[BoxData[
    \(1323\)], "Print"],

Cell[BoxData[
    \(1324\)], "Print"],

Cell[BoxData[
    \(1325\)], "Print"],

Cell[BoxData[
    \(1326\)], "Print"],

Cell[BoxData[
    \(1327\)], "Print"],

Cell[BoxData[
    \(1328\)], "Print"],

Cell[BoxData[
    \(1329\)], "Print"],

Cell[BoxData[
    \(1330\)], "Print"],

Cell[BoxData[
    \(1331\)], "Print"],

Cell[BoxData[
    \(1332\)], "Print"],

Cell[BoxData[
    \(1333\)], "Print"],

Cell[BoxData[
    \(1334\)], "Print"],

Cell[BoxData[
    \(1335\)], "Print"],

Cell[BoxData[
    \(1336\)], "Print"],

Cell[BoxData[
    \(1337\)], "Print"],

Cell[BoxData[
    \(1338\)], "Print"],

Cell[BoxData[
    \(1339\)], "Print"],

Cell[BoxData[
    \(1340\)], "Print"],

Cell[BoxData[
    \(1341\)], "Print"],

Cell[BoxData[
    \(1342\)], "Print"],

Cell[BoxData[
    \(1343\)], "Print"],

Cell[BoxData[
    \(1344\)], "Print"],

Cell[BoxData[
    \(1345\)], "Print"],

Cell[BoxData[
    \(1346\)], "Print"],

Cell[BoxData[
    \(1347\)], "Print"],

Cell[BoxData[
    \(1348\)], "Print"],

Cell[BoxData[
    \(1349\)], "Print"],

Cell[BoxData[
    \(1350\)], "Print"],

Cell[BoxData[
    \(1351\)], "Print"],

Cell[BoxData[
    \(1352\)], "Print"],

Cell[BoxData[
    \(1353\)], "Print"],

Cell[BoxData[
    \(1354\)], "Print"],

Cell[BoxData[
    \(1355\)], "Print"],

Cell[BoxData[
    \(1356\)], "Print"],

Cell[BoxData[
    \(1357\)], "Print"],

Cell[BoxData[
    \(1358\)], "Print"],

Cell[BoxData[
    \(1359\)], "Print"],

Cell[BoxData[
    \(1360\)], "Print"],

Cell[BoxData[
    \(1361\)], "Print"],

Cell[BoxData[
    \(1362\)], "Print"],

Cell[BoxData[
    \(1363\)], "Print"],

Cell[BoxData[
    \(1364\)], "Print"],

Cell[BoxData[
    \(1365\)], "Print"],

Cell[BoxData[
    \(1366\)], "Print"],

Cell[BoxData[
    \(1367\)], "Print"],

Cell[BoxData[
    \(1368\)], "Print"],

Cell[BoxData[
    \(1369\)], "Print"],

Cell[BoxData[
    \(1370\)], "Print"],

Cell[BoxData[
    \(1371\)], "Print"],

Cell[BoxData[
    \(1372\)], "Print"],

Cell[BoxData[
    \(1373\)], "Print"],

Cell[BoxData[
    \(1374\)], "Print"],

Cell[BoxData[
    \(1375\)], "Print"],

Cell[BoxData[
    \(1376\)], "Print"],

Cell[BoxData[
    \(1377\)], "Print"],

Cell[BoxData[
    \(1378\)], "Print"],

Cell[BoxData[
    \(1379\)], "Print"],

Cell[BoxData[
    \(1380\)], "Print"],

Cell[BoxData[
    \(1381\)], "Print"],

Cell[BoxData[
    \(1382\)], "Print"],

Cell[BoxData[
    \(1383\)], "Print"],

Cell[BoxData[
    \(1384\)], "Print"],

Cell[BoxData[
    \(1385\)], "Print"],

Cell[BoxData[
    \(1386\)], "Print"],

Cell[BoxData[
    \(1387\)], "Print"],

Cell[BoxData[
    \(1388\)], "Print"],

Cell[BoxData[
    \(1389\)], "Print"],

Cell[BoxData[
    \(1390\)], "Print"],

Cell[BoxData[
    \(1391\)], "Print"],

Cell[BoxData[
    \(1392\)], "Print"],

Cell[BoxData[
    \(1393\)], "Print"],

Cell[BoxData[
    \(1394\)], "Print"],

Cell[BoxData[
    \(1395\)], "Print"],

Cell[BoxData[
    \(1396\)], "Print"],

Cell[BoxData[
    \(1397\)], "Print"],

Cell[BoxData[
    \(1398\)], "Print"],

Cell[BoxData[
    \(1399\)], "Print"],

Cell[BoxData[
    \(1400\)], "Print"],

Cell[BoxData[
    \(1401\)], "Print"],

Cell[BoxData[
    \(1402\)], "Print"],

Cell[BoxData[
    \(1403\)], "Print"],

Cell[BoxData[
    \(1404\)], "Print"],

Cell[BoxData[
    \(1405\)], "Print"],

Cell[BoxData[
    \(1406\)], "Print"],

Cell[BoxData[
    \(1407\)], "Print"],

Cell[BoxData[
    \(1408\)], "Print"],

Cell[BoxData[
    \(1409\)], "Print"],

Cell[BoxData[
    \(1410\)], "Print"],

Cell[BoxData[
    \(1411\)], "Print"],

Cell[BoxData[
    \(1412\)], "Print"],

Cell[BoxData[
    \(1413\)], "Print"],

Cell[BoxData[
    \(1414\)], "Print"],

Cell[BoxData[
    \(1415\)], "Print"],

Cell[BoxData[
    \(1416\)], "Print"],

Cell[BoxData[
    \(1417\)], "Print"],

Cell[BoxData[
    \(1418\)], "Print"],

Cell[BoxData[
    \(1419\)], "Print"],

Cell[BoxData[
    \(1420\)], "Print"],

Cell[BoxData[
    \(1421\)], "Print"],

Cell[BoxData[
    \(1422\)], "Print"],

Cell[BoxData[
    \(1423\)], "Print"],

Cell[BoxData[
    \(1424\)], "Print"],

Cell[BoxData[
    \(1425\)], "Print"],

Cell[BoxData[
    \(1426\)], "Print"],

Cell[BoxData[
    \(1427\)], "Print"],

Cell[BoxData[
    \(1428\)], "Print"],

Cell[BoxData[
    \(1429\)], "Print"],

Cell[BoxData[
    \(1430\)], "Print"],

Cell[BoxData[
    \(1431\)], "Print"],

Cell[BoxData[
    \(1432\)], "Print"],

Cell[BoxData[
    \(1433\)], "Print"],

Cell[BoxData[
    \(1434\)], "Print"],

Cell[BoxData[
    \(1435\)], "Print"],

Cell[BoxData[
    \(1436\)], "Print"],

Cell[BoxData[
    \(1437\)], "Print"],

Cell[BoxData[
    \(1438\)], "Print"],

Cell[BoxData[
    \(1439\)], "Print"],

Cell[BoxData[
    \(1440\)], "Print"],

Cell[BoxData[
    \(1441\)], "Print"],

Cell[BoxData[
    \(1442\)], "Print"],

Cell[BoxData[
    \(1443\)], "Print"],

Cell[BoxData[
    \(1444\)], "Print"],

Cell[BoxData[
    \(1445\)], "Print"],

Cell[BoxData[
    \(1446\)], "Print"],

Cell[BoxData[
    \(1447\)], "Print"],

Cell[BoxData[
    \(1448\)], "Print"],

Cell[BoxData[
    \(1449\)], "Print"],

Cell[BoxData[
    \(1450\)], "Print"],

Cell[BoxData[
    \(1451\)], "Print"],

Cell[BoxData[
    \(1452\)], "Print"],

Cell[BoxData[
    \(1453\)], "Print"],

Cell[BoxData[
    \(1454\)], "Print"],

Cell[BoxData[
    \(1455\)], "Print"],

Cell[BoxData[
    \(1456\)], "Print"],

Cell[BoxData[
    \(1457\)], "Print"],

Cell[BoxData[
    \(1458\)], "Print"],

Cell[BoxData[
    \(1459\)], "Print"],

Cell[BoxData[
    \(1460\)], "Print"],

Cell[BoxData[
    \(1461\)], "Print"],

Cell[BoxData[
    \(1462\)], "Print"],

Cell[BoxData[
    \(1463\)], "Print"],

Cell[BoxData[
    \(1464\)], "Print"],

Cell[BoxData[
    \(1465\)], "Print"],

Cell[BoxData[
    \(1466\)], "Print"],

Cell[BoxData[
    \(1467\)], "Print"],

Cell[BoxData[
    \(1468\)], "Print"],

Cell[BoxData[
    \(1469\)], "Print"],

Cell[BoxData[
    \(1470\)], "Print"],

Cell[BoxData[
    \(1471\)], "Print"],

Cell[BoxData[
    \(1472\)], "Print"],

Cell[BoxData[
    \(1473\)], "Print"],

Cell[BoxData[
    \(1474\)], "Print"],

Cell[BoxData[
    \(1475\)], "Print"],

Cell[BoxData[
    \(1476\)], "Print"],

Cell[BoxData[
    \(1477\)], "Print"],

Cell[BoxData[
    \(1478\)], "Print"],

Cell[BoxData[
    \(1479\)], "Print"],

Cell[BoxData[
    \(1480\)], "Print"],

Cell[BoxData[
    \(1481\)], "Print"],

Cell[BoxData[
    \(1482\)], "Print"],

Cell[BoxData[
    \(1483\)], "Print"],

Cell[BoxData[
    \(1484\)], "Print"],

Cell[BoxData[
    \(1485\)], "Print"],

Cell[BoxData[
    \(1486\)], "Print"],

Cell[BoxData[
    \(1487\)], "Print"],

Cell[BoxData[
    \(1488\)], "Print"],

Cell[BoxData[
    \(1489\)], "Print"],

Cell[BoxData[
    \(1490\)], "Print"],

Cell[BoxData[
    \(1491\)], "Print"],

Cell[BoxData[
    \(1492\)], "Print"],

Cell[BoxData[
    \(1493\)], "Print"],

Cell[BoxData[
    \(1494\)], "Print"],

Cell[BoxData[
    \(1495\)], "Print"],

Cell[BoxData[
    \(1496\)], "Print"],

Cell[BoxData[
    \(1497\)], "Print"],

Cell[BoxData[
    \(1498\)], "Print"],

Cell[BoxData[
    \(1499\)], "Print"],

Cell[BoxData[
    \(1500\)], "Print"]
}, Open  ]],

Cell["\<\
plt[i_]:=Show[Graphics[{{RGBColor[1,0,0],PointSize[0.05],Point[{X[1,i],Y[1,i]}\
]},{RGBColor[0,0,1],PointSize[0.05],Point[{X[2,i],Y[2,i]}]}}],AspectRatio->1,\
PlotRange->{{-4,4},{-4,4}},Frame->True]\
\>", "Input"],

Cell["<<Graphics`Animation`", "Input"],

Cell[CellGroupData[{

Cell["Animate[plt[n],{n,1,500,50}]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[.125 -0.0125 -6 -9 ]
[.125 -0.0125 6 0 ]
[.25 -0.0125 -6 -9 ]
[.25 -0.0125 6 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -3 -9 ]
[.625 -0.0125 3 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -3 -9 ]
[.875 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -12 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -12 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -6 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -6 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-3)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-2)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-1)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(2)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-3)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-2)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-1)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(1)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(2)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(3)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(4)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.125 .99375 m
.125 1 L
s
.25 .99375 m
.25 1 L
s
.375 .99375 m
.375 1 L
s
.5 .99375 m
.5 1 L
s
.625 .99375 m
.625 1 L
s
.75 .99375 m
.75 1 L
s
.875 .99375 m
.875 1 L
s
.125 Mabswid
.025 .99625 m
.025 1 L
s
.05 .99625 m
.05 1 L
s
.075 .99625 m
.075 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.175 .99625 m
.175 1 L
s
.2 .99625 m
.2 1 L
s
.225 .99625 m
.225 1 L
s
.275 .99625 m
.275 1 L
s
.3 .99625 m
.3 1 L
s
.325 .99625 m
.325 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.425 .99625 m
.425 1 L
s
.45 .99625 m
.45 1 L
s
.475 .99625 m
.475 1 L
s
.525 .99625 m
.525 1 L
s
.55 .99625 m
.55 1 L
s
.575 .99625 m
.575 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.675 .99625 m
.675 1 L
s
.7 .99625 m
.7 1 L
s
.725 .99625 m
.725 1 L
s
.775 .99625 m
.775 1 L
s
.8 .99625 m
.8 1 L
s
.825 .99625 m
.825 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.925 .99625 m
.925 1 L
s
.95 .99625 m
.95 1 L
s
.975 .99625 m
.975 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.49019 .63125 Mdot
0 0 1 r
.50981 .36875 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool0039oo`8001moo`@001ioo`D001Yoo`8001moo`D001aoo`@001moo`80025oo`<0005oo`00<Goo
00@007ooOol001ioo`03001oogoo025oo`03001oogoo01Uoo`04001oogoo000POol00`00Oomoo`0L
Ool00`00Oomoo`0OOol01000Oomoo`008Goo0@000Goo0Goo000cOol00`00Oomoo`0NOol00`00Oomo
o`0POol00`00Oomoo`0IOol01000Oomoo`0087oo00<007ooOol07Goo00<007ooOol087oo00<007oo
Ool07Goo1@000Goo000[Ool40005Ool00`00Oomoo`0FOol40004Ool00`00Oomoo`0GOol40004Ool0
0`00Oomoo`0IOol01000Oomoo`0087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol077oo
00@007ooOol0009oo`00<Goo00@007ooOol001ioo`04001oogoo000POol00`00Oomoo`0IOol01000
Oomoo`0087oo00<007ooOol077oo00@007ooOol001ioo`04001oogoo000OOol00`00Ool00002Ool0
039oo`80021oo`80021oo`8001aoo`80021oo`8001moo`80021oo`80025oo`80009oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`003gooo`003`000goo000?Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Moo`04001oogoo0004Ool00`00Oomoo`3oOol;
Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<00?moo`Uoo`<000=oo`0000=oo`0000000P00
1Goo00<007ooOol00Woo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`001goo100017oo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool00`00
Oomoo`05Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`<00?moo`Uo
o`<000=oo`0000=oo`0000000P0017oo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo0007Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01
Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01
Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01
Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0Q7oo1@0OPGoo00<0
07ooOol00Goo000?Ool20024Ool701mnOol30003Ool000moo`03001oogoo089oo`T07gmoo`03001o
ogoo005oo`003goo00<007ooOol0PGoo2`0OOWoo00<007ooOol00Goo000?Ool00`00Oomoo`20Ool=
01mmOol00`00Oomoo`01Ool000Moo`D000=oo`03001oogoo081oo`d07geoo`03001oogoo005oo`00
2Goo00<007ooOol00goo00<007ooOol0P7oo3@0OOGoo00<007ooOol00Goo0009Ool00`00Oomoo`03
Ool30020Ool=01mkOol30003Ool00003Ool00000008000Aoo`03001oogoo00=oo`03001oogoo081o
o`d07geoo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0PGoo2`0OOWoo00<007oo
Ool00Goo0008Ool20005Ool00`00Oomoo`22Ool901moOol00`00Oomoo`01Ool000moo`03001oogoo
08=oo`L07h1oo`03001oogoo005oo`003goo00<007ooOol0Q7oo1@0OPGoo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`0027oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<0
07ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo0`00ogoo2Goo0`000goo0007
Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0OWoo1G`0Qgoo
00<007ooOol00Goo000?Ool00`00Oomoo`1mOol7O026Ool00`00Oomoo`01Ool000moo`03001oogoo
07aoo`Ul08Eoo`03001oogoo005oo`001goo1@000goo00<007ooOol0Ngoo2g`0Q7oo00<007ooOol0
0Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`1jOol=O023Ool00`00Oomoo`01Ool000Uoo`03001o
ogoo00=oo`<007Yoo`el085oo`<000=oo`002Goo00<007ooOol00goo00<007ooOol0NWoo3G`0Pgoo
00<007ooOol00Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`1jOol=O023Ool00`00Oomoo`01Ool0
00Qoo`8000Eoo`03001oogoo07Yoo`el08=oo`03001oogoo005oo`003goo00<007ooOol0Ngoo2g`0
Q7oo00<007ooOol00Goo000?Ool00`00Oomoo`1lOol9O025Ool00`00Oomoo`01Ool000moo`8007io
o`Ml08Aoo`<000=oo`003goo00<007ooOol0OWoo1G`0Qgoo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000mo
o`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000mo
o`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo
000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000mo
o`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo
000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000mo
o`03001oogoo0?moo`]oo`03001oogoo005oo`001goo100017oo00<007ooOol0ogoo2goo00<007oo
Ool00Goo0007Ool00`00Oomoo`05Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`03001o
ogoo00Aoo`<00?moo`Uoo`<000=oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007oo
Ool00Goo0007Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`0027oo0P001Goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo
0009Ool00`00Oomoo`03Ool3003oOol9Ool30003Ool000Yoo`03001oogoo009oo`03001oogoo0?mo
o`]oo`03001oogoo005oo`001goo00@007ooOol000Aoo`03001oogoo0?moo`]oo`03001oogoo005o
o`0027oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0009Ool30003Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo005oo`001goo1@000gooo`003`000goo0007Ool01000Oomoo`00ogoo
5Woo0008Ool00`00Ool0003oOolFOol000Uoo`800?mooaIoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-4.4574, -4.39039, 0.0297797, \
0.0297797}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[.125 -0.0125 -6 -9 ]
[.125 -0.0125 6 0 ]
[.25 -0.0125 -6 -9 ]
[.25 -0.0125 6 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -3 -9 ]
[.625 -0.0125 3 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -3 -9 ]
[.875 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -12 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -12 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -6 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -6 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-3)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-2)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-1)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(2)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-3)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-2)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-1)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(1)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(2)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(3)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(4)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.125 .99375 m
.125 1 L
s
.25 .99375 m
.25 1 L
s
.375 .99375 m
.375 1 L
s
.5 .99375 m
.5 1 L
s
.625 .99375 m
.625 1 L
s
.75 .99375 m
.75 1 L
s
.875 .99375 m
.875 1 L
s
.125 Mabswid
.025 .99625 m
.025 1 L
s
.05 .99625 m
.05 1 L
s
.075 .99625 m
.075 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.175 .99625 m
.175 1 L
s
.2 .99625 m
.2 1 L
s
.225 .99625 m
.225 1 L
s
.275 .99625 m
.275 1 L
s
.3 .99625 m
.3 1 L
s
.325 .99625 m
.325 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.425 .99625 m
.425 1 L
s
.45 .99625 m
.45 1 L
s
.475 .99625 m
.475 1 L
s
.525 .99625 m
.525 1 L
s
.55 .99625 m
.55 1 L
s
.575 .99625 m
.575 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.675 .99625 m
.675 1 L
s
.7 .99625 m
.7 1 L
s
.725 .99625 m
.725 1 L
s
.775 .99625 m
.775 1 L
s
.8 .99625 m
.8 1 L
s
.825 .99625 m
.825 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.925 .99625 m
.925 1 L
s
.95 .99625 m
.95 1 L
s
.975 .99625 m
.975 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.37951 .85206 Mdot
0 0 1 r
.62049 .14794 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool0039oo`8001moo`@001ioo`D001Yoo`8001moo`D001aoo`@001moo`80025oo`<0005oo`00<Goo
00@007ooOol001ioo`03001oogoo025oo`03001oogoo01Uoo`04001oogoo000POol00`00Oomoo`0L
Ool00`00Oomoo`0OOol01000Oomoo`008Goo0@000Goo0Goo000cOol00`00Oomoo`0NOol00`00Oomo
o`0POol00`00Oomoo`0IOol01000Oomoo`0087oo00<007ooOol07Goo00<007ooOol087oo00<007oo
Ool07Goo1@000Goo000[Ool40005Ool00`00Oomoo`0FOol40004Ool00`00Oomoo`0GOol40004Ool0
0`00Oomoo`0IOol01000Oomoo`0087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol077oo
00@007ooOol0009oo`00<Goo00@007ooOol001ioo`04001oogoo000POol00`00Oomoo`0IOol01000
Oomoo`0087oo00<007ooOol077oo00@007ooOol001ioo`04001oogoo000OOol00`00Ool00002Ool0
039oo`80021oo`80021oo`8001aoo`80021oo`8001moo`80021oo`80025oo`80009oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`003gooo`003`000goo000?Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Moo`04001oogoo0004Ool00`00Oomoo`3oOol;
Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<00?moo`Uoo`<000=oo`0000=oo`0000000P00
1Goo00<007ooOol00Woo00<007ooOol0XGoo1@0OI7oo00<007ooOol00Goo0007Ool01000Oomoo`00
17oo00<007ooOol0X7oo1`0OHgoo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`2OOol901mR
Ool00`00Oomoo`01Ool000moo`03001oogoo09ioo`/07f5oo`03001oogoo005oo`003goo00<007oo
Ool0WGoo3@0OH7oo00<007ooOol00Goo000?Ool00`00Oomoo`2MOol=01mPOol00`00Oomoo`01Ool0
00moo`8009ioo`d07eioo`<000=oo`003goo00<007ooOol0WGoo3@0OH7oo00<007ooOol00Goo000?
Ool00`00Oomoo`2MOol=01mPOol00`00Oomoo`01Ool000moo`03001oogoo09ioo`/07f5oo`03001o
ogoo005oo`003goo00<007ooOol0Wgoo2@0OHWoo00<007ooOol00Goo000?Ool00`00Oomoo`2POol7
01mSOol00`00Oomoo`01Ool000moo`03001oogoo0:5oo`D07fAoo`03001oogoo005oo`003goo0P00
ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00
ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo1000
17oo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool00`00Oomoo`05Ool00`00Oomoo`3oOol;
Ool00`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`<00?moo`Uoo`<000=oo`0000=oo`0000000P00
17oo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Moo`D000=oo`03001oogoo
0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo0009Ool00`00Oomoo`03Ool3003oOol9Ool30003Ool00003Ool00000008000Aoo`03001oogoo
00=oo`03001oogoo0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`0027oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<0
07ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo0`00ogoo2Goo0`000goo0007
Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`001goo1@000goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<00?moo`Uo
o`<000=oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`8000Eoo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo
2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo100017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool00`00Oomoo`05Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`<00?moo`Uoo`<000=oo`002Goo00<007ooOol00goo
00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0
ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo065oo`El0:Aoo`03001oogoo005oo`003goo00<007ooOol0H7oo1g`0Xgoo00<007ooOol00Goo
000?Ool00`00Oomoo`1OOol9O02ROol00`00Oomoo`01Ool000moo`03001oogoo05ioo`]l0:5oo`03
001oogoo005oo`003goo00<007ooOol0GGoo3G`0X7oo00<007ooOol00Goo000?Ool2001NOol=O02N
Ool30003Ool000moo`03001oogoo05eoo`el0:1oo`03001oogoo005oo`003goo00<007ooOol0GGoo
3G`0X7oo00<007ooOol00Goo000?Ool00`00Oomoo`1MOol=O02POol00`00Oomoo`01Ool000moo`03
001oogoo05ioo`]l0:5oo`03001oogoo005oo`0027oo0P001Goo00<007ooOol0Ggoo2G`0XWoo00<0
07ooOol00Goo0007Ool01000Oomoo`0017oo00<007ooOol0H7oo1g`0Xgoo00<007ooOol00Goo0009
Ool00`00Oomoo`03Ool3001QOol5O02ROol30003Ool000Yoo`03001oogoo009oo`03001oogoo0?mo
o`]oo`03001oogoo005oo`001goo00@007ooOol000Aoo`03001oogoo0?moo`]oo`03001oogoo005o
o`0027oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0009Ool30003Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo005oo`001goo1@000gooo`003`000goo0007Ool01000Oomoo`00ogoo
5Woo0008Ool00`00Ool0003oOolFOol000Uoo`800?mooaIoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-4.4574, -4.39039, 0.0297797, \
0.0297797}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[.125 -0.0125 -6 -9 ]
[.125 -0.0125 6 0 ]
[.25 -0.0125 -6 -9 ]
[.25 -0.0125 6 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -3 -9 ]
[.625 -0.0125 3 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -3 -9 ]
[.875 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -12 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -12 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -6 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -6 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-3)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-2)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-1)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(2)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-3)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-2)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-1)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(1)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(2)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(3)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(4)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.125 .99375 m
.125 1 L
s
.25 .99375 m
.25 1 L
s
.375 .99375 m
.375 1 L
s
.5 .99375 m
.5 1 L
s
.625 .99375 m
.625 1 L
s
.75 .99375 m
.75 1 L
s
.875 .99375 m
.875 1 L
s
.125 Mabswid
.025 .99625 m
.025 1 L
s
.05 .99625 m
.05 1 L
s
.075 .99625 m
.075 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.175 .99625 m
.175 1 L
s
.2 .99625 m
.2 1 L
s
.225 .99625 m
.225 1 L
s
.275 .99625 m
.275 1 L
s
.3 .99625 m
.3 1 L
s
.325 .99625 m
.325 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.425 .99625 m
.425 1 L
s
.45 .99625 m
.45 1 L
s
.475 .99625 m
.475 1 L
s
.525 .99625 m
.525 1 L
s
.55 .99625 m
.55 1 L
s
.575 .99625 m
.575 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.675 .99625 m
.675 1 L
s
.7 .99625 m
.7 1 L
s
.725 .99625 m
.725 1 L
s
.775 .99625 m
.775 1 L
s
.8 .99625 m
.8 1 L
s
.825 .99625 m
.825 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.925 .99625 m
.925 1 L
s
.95 .99625 m
.95 1 L
s
.975 .99625 m
.975 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.35155 .92511 Mdot
0 0 1 r
.64845 .07489 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool0039oo`8001moo`@001ioo`D001Yoo`8001moo`D001aoo`@001moo`80025oo`<0005oo`00<Goo
00@007ooOol001ioo`03001oogoo025oo`03001oogoo01Uoo`04001oogoo000POol00`00Oomoo`0L
Ool00`00Oomoo`0OOol01000Oomoo`008Goo0@000Goo0Goo000cOol00`00Oomoo`0NOol00`00Oomo
o`0POol00`00Oomoo`0IOol01000Oomoo`0087oo00<007ooOol07Goo00<007ooOol087oo00<007oo
Ool07Goo1@000Goo000[Ool40005Ool00`00Oomoo`0FOol40004Ool00`00Oomoo`0GOol40004Ool0
0`00Oomoo`0IOol01000Oomoo`0087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol077oo
00@007ooOol0009oo`00<Goo00@007ooOol001ioo`04001oogoo000POol00`00Oomoo`0IOol01000
Oomoo`0087oo00<007ooOol077oo00@007ooOol001ioo`04001oogoo000OOol00`00Ool00002Ool0
039oo`80021oo`80021oo`8001aoo`80021oo`8001moo`80021oo`80025oo`80009oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`003gooo`003`000goo000?Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0:Uoo`D07eaoo`03001oogoo005oo`003goo00<007ooOol0
Z7oo1`0OFgoo00<007ooOol00Goo000?Ool00`00Oomoo`2WOol901mJOol00`00Oomoo`01Ool000mo
o`03001oogoo0:Ioo`/07eUoo`03001oogoo005oo`003goo00<007ooOol0YGoo3@0OF7oo00<007oo
Ool00Goo000?Ool00`00Oomoo`2UOol=01mHOol00`00Oomoo`01Ool000moo`800:Ioo`d07eIoo`<0
00=oo`003goo00<007ooOol0YGoo3@0OF7oo00<007ooOol00Goo000?Ool00`00Oomoo`2UOol=01mH
Ool00`00Oomoo`01Ool000moo`03001oogoo0:Ioo`/07eUoo`03001oogoo005oo`003goo00<007oo
Ool0Ygoo2@0OFWoo00<007ooOol00Goo000?Ool00`00Oomoo`2XOol701mKOol00`00Oomoo`01Ool0
00moo`800:Yoo`D07eYoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00
Oomoo`01Ool000Moo`04001oogoo0004Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`03
001oogoo00=oo`<00?moo`Uoo`<000=oo`0000=oo`0000000P001Goo00<007ooOol00Woo00<007oo
Ool0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007oo
Ool00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo
00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00
ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00
ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo1000
17oo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool00`00Oomoo`05Ool00`00Oomoo`3oOol;
Ool00`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`<00?moo`Uoo`<000=oo`0000=oo`0000000P00
17oo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Moo`D000=oo`03001oogoo
0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo0009Ool00`00Oomoo`03Ool3003oOol9Ool30003Ool00003Ool00000008000Aoo`03001oogoo
00=oo`03001oogoo0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`0027oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<0
07ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo0`00ogoo2Goo0`000goo0007
Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`001goo1@000goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<00?moo`Uo
o`<000=oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`8000Eoo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo
2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo100017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool00`00Oomoo`05Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`<00?moo`Uoo`<000=oo`002Goo00<007ooOol00goo
00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0
ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
27oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007oo
Ool0ogoo2goo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool3003oOol9Ool30003Ool000Yoo`03
001oogoo009oo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo00@007ooOol000Aoo`03001o
ogoo0?moo`]oo`03001oogoo005oo`0027oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo
000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo
005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`1IOol5O02/Ool00`00Oomoo`01Ool0
00moo`03001oogoo05Qoo`Ml0:]oo`03001oogoo005oo`003goo00<007ooOol0Egoo2G`0ZWoo00<0
07ooOol00Goo000?Ool00`00Oomoo`1FOol;O02YOol00`00Oomoo`01Ool000moo`03001oogoo05Eo
o`el0:Qoo`03001oogoo005oo`003goo00<007ooOol0EGoo3G`0Z7oo00<007ooOol00Goo000?Ool2
001FOol=O02VOol30003Ool000moo`03001oogoo05Eoo`el0:Qoo`03001oogoo005oo`003goo00<0
07ooOol0EGoo3G`0Z7oo00<007ooOol00Goo000?Ool00`00Oomoo`1FOol;O02YOol00`00Oomoo`01
Ool000moo`03001oogoo05Moo`Ul0:Yoo`03001oogoo005oo`003goo00<007ooOol0F7oo1g`0Zgoo
00<007ooOol00Goo000?Ool00`00Oomoo`1IOol5O02/Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0009Ool30003Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo005oo`001goo1@000gooo`003`000goo0007Ool01000Oomoo`00ogoo
5Woo0008Ool00`00Ool0003oOolFOol000Uoo`800?mooaIoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-4.4574, -4.39039, 0.0297797, \
0.0297797}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[.125 -0.0125 -6 -9 ]
[.125 -0.0125 6 0 ]
[.25 -0.0125 -6 -9 ]
[.25 -0.0125 6 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -3 -9 ]
[.625 -0.0125 3 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -3 -9 ]
[.875 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -12 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -12 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -6 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -6 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-3)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-2)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-1)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(2)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-3)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-2)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-1)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(1)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(2)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(3)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(4)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.125 .99375 m
.125 1 L
s
.25 .99375 m
.25 1 L
s
.375 .99375 m
.375 1 L
s
.5 .99375 m
.5 1 L
s
.625 .99375 m
.625 1 L
s
.75 .99375 m
.75 1 L
s
.875 .99375 m
.875 1 L
s
.125 Mabswid
.025 .99625 m
.025 1 L
s
.05 .99625 m
.05 1 L
s
.075 .99625 m
.075 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.175 .99625 m
.175 1 L
s
.2 .99625 m
.2 1 L
s
.225 .99625 m
.225 1 L
s
.275 .99625 m
.275 1 L
s
.3 .99625 m
.3 1 L
s
.325 .99625 m
.325 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.425 .99625 m
.425 1 L
s
.45 .99625 m
.45 1 L
s
.475 .99625 m
.475 1 L
s
.525 .99625 m
.525 1 L
s
.55 .99625 m
.55 1 L
s
.575 .99625 m
.575 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.675 .99625 m
.675 1 L
s
.7 .99625 m
.7 1 L
s
.725 .99625 m
.725 1 L
s
.775 .99625 m
.775 1 L
s
.8 .99625 m
.8 1 L
s
.825 .99625 m
.825 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.925 .99625 m
.925 1 L
s
.95 .99625 m
.95 1 L
s
.975 .99625 m
.975 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.34235 .94944 Mdot
0 0 1 r
.65765 .05056 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool0039oo`8001moo`@001ioo`D001Yoo`8001moo`D001aoo`@001moo`80025oo`<0005oo`00<Goo
00@007ooOol001ioo`03001oogoo025oo`03001oogoo01Uoo`04001oogoo000POol00`00Oomoo`0L
Ool00`00Oomoo`0OOol01000Oomoo`008Goo0@000Goo0Goo000cOol00`00Oomoo`0NOol00`00Oomo
o`0POol00`00Oomoo`0IOol01000Oomoo`0087oo00<007ooOol07Goo00<007ooOol087oo00<007oo
Ool07Goo1@000Goo000[Ool40005Ool00`00Oomoo`0FOol40004Ool00`00Oomoo`0GOol40004Ool0
0`00Oomoo`0IOol01000Oomoo`0087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol077oo
00@007ooOol0009oo`00<Goo00@007ooOol001ioo`04001oogoo000POol00`00Oomoo`0IOol01000
Oomoo`0087oo00<007ooOol077oo00@007ooOol001ioo`04001oogoo000OOol00`00Ool00002Ool0
039oo`80021oo`80021oo`8001aoo`80021oo`8001moo`80021oo`80025oo`80009oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`003gooo`003`000goo000?Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`2[Ool501mJ
Ool00`00Oomoo`01Ool000moo`03001oogoo0:Yoo`L07eUoo`03001oogoo005oo`003goo00<007oo
Ool0ZGoo2@0OF7oo00<007ooOol00Goo000?Ool00`00Oomoo`2XOol;01mGOol00`00Oomoo`01Ool0
00moo`03001oogoo0:Moo`d07eIoo`03001oogoo005oo`003goo00<007ooOol0Ygoo3@0OEWoo00<0
07ooOol00Goo000?Ool2002XOol=01mDOol30003Ool000moo`03001oogoo0:Moo`d07eIoo`03001o
ogoo005oo`003goo00<007ooOol0Ygoo3@0OEWoo00<007ooOol00Goo000?Ool00`00Oomoo`2XOol;
01mGOol00`00Oomoo`01Ool000moo`03001oogoo0:Uoo`T07eQoo`03001oogoo005oo`003goo00<0
07ooOol0ZWoo1`0OFGoo00<007ooOol00Goo000?Ool00`00Oomoo`2[Ool501mJOol00`00Oomoo`01
Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01
Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00
Oomoo`01Ool000Moo`04001oogoo0004Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`03
001oogoo00=oo`<00?moo`Uoo`<000=oo`0000=oo`0000000P001Goo00<007ooOol00Woo00<007oo
Ool0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007oo
Ool00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo
00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00
ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00
ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo1000
17oo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool00`00Oomoo`05Ool00`00Oomoo`3oOol;
Ool00`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`<00?moo`Uoo`<000=oo`0000=oo`0000000P00
17oo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Moo`D000=oo`03001oogoo
0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo0009Ool00`00Oomoo`03Ool3003oOol9Ool30003Ool00003Ool00000008000Aoo`03001oogoo
00=oo`03001oogoo0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`0027oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<0
07ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo0`00ogoo2Goo0`000goo0007
Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`001goo1@000goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<00?moo`Uo
o`<000=oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`8000Eoo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo
2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo100017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool00`00Oomoo`05Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`<00?moo`Uoo`<000=oo`002Goo00<007ooOol00goo
00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0
ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
27oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007oo
Ool0ogoo2goo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool3003oOol9Ool30003Ool000Yoo`03
001oogoo009oo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo00@007ooOol000Aoo`03001o
ogoo0?moo`]oo`03001oogoo005oo`0027oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo
000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo
005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000mo
o`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo
000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo
005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000mo
o`03001oogoo05Moo`El0:ioo`03001oogoo005oo`003goo00<007ooOol0EWoo1g`0[Goo00<007oo
Ool00Goo000?Ool00`00Oomoo`1EOol9O02/Ool00`00Oomoo`01Ool000moo`03001oogoo05Aoo`]l
0:]oo`03001oogoo005oo`003goo00<007ooOol0Dgoo3G`0ZWoo00<007ooOol00Goo000?Ool00`00
Oomoo`1COol=O02ZOol00`00Oomoo`01Ool000moo`8005Aoo`el0:Qoo`<000=oo`003goo00<007oo
Ool0Dgoo3G`0ZWoo00<007ooOol00Goo000?Ool00`00Oomoo`1COol=O02ZOol00`00Oomoo`01Ool0
00moo`03001oogoo05Aoo`]l0:]oo`03001oogoo005oo`003goo00<007ooOol0EGoo2G`0[7oo00<0
07ooOol00Goo000?Ool00`00Oomoo`1FOol7O02]Ool00`00Oomoo`01Ool000moo`03001oogoo05Mo
o`El0:ioo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0009Ool30003Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo005oo`001goo1@000gooo`003`000goo0007Ool01000Oomoo`00ogoo
5Woo0008Ool00`00Ool0003oOolFOol000Uoo`800?mooaIoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-4.4574, -4.39039, 0.0297797, \
0.0297797}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[.125 -0.0125 -6 -9 ]
[.125 -0.0125 6 0 ]
[.25 -0.0125 -6 -9 ]
[.25 -0.0125 6 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -3 -9 ]
[.625 -0.0125 3 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -3 -9 ]
[.875 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -12 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -12 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -6 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -6 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-3)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-2)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-1)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(2)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-3)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-2)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-1)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(1)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(2)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(3)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(4)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.125 .99375 m
.125 1 L
s
.25 .99375 m
.25 1 L
s
.375 .99375 m
.375 1 L
s
.5 .99375 m
.5 1 L
s
.625 .99375 m
.625 1 L
s
.75 .99375 m
.75 1 L
s
.875 .99375 m
.875 1 L
s
.125 Mabswid
.025 .99625 m
.025 1 L
s
.05 .99625 m
.05 1 L
s
.075 .99625 m
.075 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.175 .99625 m
.175 1 L
s
.2 .99625 m
.2 1 L
s
.225 .99625 m
.225 1 L
s
.275 .99625 m
.275 1 L
s
.3 .99625 m
.3 1 L
s
.325 .99625 m
.325 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.425 .99625 m
.425 1 L
s
.45 .99625 m
.45 1 L
s
.475 .99625 m
.475 1 L
s
.525 .99625 m
.525 1 L
s
.55 .99625 m
.55 1 L
s
.575 .99625 m
.575 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.675 .99625 m
.675 1 L
s
.7 .99625 m
.7 1 L
s
.725 .99625 m
.725 1 L
s
.775 .99625 m
.775 1 L
s
.8 .99625 m
.8 1 L
s
.825 .99625 m
.825 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.925 .99625 m
.925 1 L
s
.95 .99625 m
.95 1 L
s
.975 .99625 m
.975 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.34811 .93418 Mdot
0 0 1 r
.65189 .06582 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool0039oo`8001moo`@001ioo`D001Yoo`8001moo`D001aoo`@001moo`80025oo`<0005oo`00<Goo
00@007ooOol001ioo`03001oogoo025oo`03001oogoo01Uoo`04001oogoo000POol00`00Oomoo`0L
Ool00`00Oomoo`0OOol01000Oomoo`008Goo0@000Goo0Goo000cOol00`00Oomoo`0NOol00`00Oomo
o`0POol00`00Oomoo`0IOol01000Oomoo`0087oo00<007ooOol07Goo00<007ooOol087oo00<007oo
Ool07Goo1@000Goo000[Ool40005Ool00`00Oomoo`0FOol40004Ool00`00Oomoo`0GOol40004Ool0
0`00Oomoo`0IOol01000Oomoo`0087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol077oo
00@007ooOol0009oo`00<Goo00@007ooOol001ioo`04001oogoo000POol00`00Oomoo`0IOol01000
Oomoo`0087oo00<007ooOol077oo00@007ooOol001ioo`04001oogoo000OOol00`00Ool00002Ool0
039oo`80021oo`80021oo`8001aoo`80021oo`8001moo`80021oo`80025oo`80009oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`003gooo`003`000goo000?Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0:Yoo`D07e]oo`03001oogoo005oo`003goo00<007ooOol0ZGoo1`0OFWoo00<007ooOol00Goo000?
Ool2002YOol901mGOol30003Ool000moo`03001oogoo0:Moo`/07eQoo`03001oogoo005oo`003goo
00<007ooOol0YWoo3@0OEgoo00<007ooOol00Goo000?Ool00`00Oomoo`2VOol=01mGOol00`00Oomo
o`01Ool000moo`03001oogoo0:Ioo`d07eMoo`03001oogoo005oo`003goo00<007ooOol0YWoo3@0O
Egoo00<007ooOol00Goo000?Ool00`00Oomoo`2VOol=01mGOol00`00Oomoo`01Ool000moo`800:Qo
o`/07eIoo`<000=oo`003goo00<007ooOol0Z7oo2@0OFGoo00<007ooOol00Goo000?Ool00`00Oomo
o`2YOol701mJOol00`00Oomoo`01Ool000moo`03001oogoo0:Yoo`D07e]oo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01
Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00
Oomoo`01Ool000Moo`04001oogoo0004Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`03
001oogoo00=oo`<00?moo`Uoo`<000=oo`0000=oo`0000000P001Goo00<007ooOol00Woo00<007oo
Ool0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007oo
Ool00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo
00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00
ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00
ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo1000
17oo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool00`00Oomoo`05Ool00`00Oomoo`3oOol;
Ool00`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`<00?moo`Uoo`<000=oo`0000=oo`0000000P00
17oo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Moo`D000=oo`03001oogoo
0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo0009Ool00`00Oomoo`03Ool3003oOol9Ool30003Ool00003Ool00000008000Aoo`03001oogoo
00=oo`03001oogoo0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`0027oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<0
07ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo0`00ogoo2Goo0`000goo0007
Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`001goo1@000goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<00?moo`Uo
o`<000=oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`8000Eoo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo
2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo100017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool00`00Oomoo`05Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`<00?moo`Uoo`<000=oo`002Goo00<007ooOol00goo
00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0
ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
27oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007oo
Ool0ogoo2goo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool3003oOol9Ool30003Ool000Yoo`03
001oogoo009oo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo00@007ooOol000Aoo`03001o
ogoo0?moo`]oo`03001oogoo005oo`0027oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo
000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo
005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000mo
o`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo
000?Ool00`00Oomoo`1HOol5O02]Ool00`00Oomoo`01Ool000moo`03001oogoo05Moo`Ml0:aoo`03
001oogoo005oo`003goo00<007ooOol0EWoo2G`0Zgoo00<007ooOol00Goo000?Ool2001FOol;O02X
Ool30003Ool000moo`03001oogoo05Aoo`el0:Uoo`03001oogoo005oo`003goo00<007ooOol0E7oo
3G`0ZGoo00<007ooOol00Goo000?Ool00`00Oomoo`1DOol=O02YOol00`00Oomoo`01Ool000moo`03
001oogoo05Aoo`el0:Uoo`03001oogoo005oo`003goo00<007ooOol0E7oo3G`0ZGoo00<007ooOol0
0Goo000?Ool00`00Oomoo`1EOol;O02ZOol00`00Oomoo`01Ool000moo`8005Moo`Ul0:Uoo`<000=o
o`003goo00<007ooOol0Egoo1g`0[7oo00<007ooOol00Goo000?Ool00`00Oomoo`1HOol5O02]Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0009Ool30003Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo005oo`001goo1@000gooo`003`000goo0007Ool01000Oomoo`00ogoo
5Woo0008Ool00`00Ool0003oOolFOol000Uoo`800?mooaIoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-4.4574, -4.39039, 0.0297797, \
0.0297797}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[.125 -0.0125 -6 -9 ]
[.125 -0.0125 6 0 ]
[.25 -0.0125 -6 -9 ]
[.25 -0.0125 6 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -3 -9 ]
[.625 -0.0125 3 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -3 -9 ]
[.875 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -12 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -12 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -6 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -6 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-3)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-2)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-1)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(2)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-3)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-2)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-1)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(1)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(2)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(3)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(4)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.125 .99375 m
.125 1 L
s
.25 .99375 m
.25 1 L
s
.375 .99375 m
.375 1 L
s
.5 .99375 m
.5 1 L
s
.625 .99375 m
.625 1 L
s
.75 .99375 m
.75 1 L
s
.875 .99375 m
.875 1 L
s
.125 Mabswid
.025 .99625 m
.025 1 L
s
.05 .99625 m
.05 1 L
s
.075 .99625 m
.075 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.175 .99625 m
.175 1 L
s
.2 .99625 m
.2 1 L
s
.225 .99625 m
.225 1 L
s
.275 .99625 m
.275 1 L
s
.3 .99625 m
.3 1 L
s
.325 .99625 m
.325 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.425 .99625 m
.425 1 L
s
.45 .99625 m
.45 1 L
s
.475 .99625 m
.475 1 L
s
.525 .99625 m
.525 1 L
s
.55 .99625 m
.55 1 L
s
.575 .99625 m
.575 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.675 .99625 m
.675 1 L
s
.7 .99625 m
.7 1 L
s
.725 .99625 m
.725 1 L
s
.775 .99625 m
.775 1 L
s
.8 .99625 m
.8 1 L
s
.825 .99625 m
.825 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.925 .99625 m
.925 1 L
s
.95 .99625 m
.95 1 L
s
.975 .99625 m
.975 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.37086 .87446 Mdot
0 0 1 r
.62914 .12554 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool0039oo`8001moo`@001ioo`D001Yoo`8001moo`D001aoo`@001moo`80025oo`<0005oo`00<Goo
00@007ooOol001ioo`03001oogoo025oo`03001oogoo01Uoo`04001oogoo000POol00`00Oomoo`0L
Ool00`00Oomoo`0OOol01000Oomoo`008Goo0@000Goo0Goo000cOol00`00Oomoo`0NOol00`00Oomo
o`0POol00`00Oomoo`0IOol01000Oomoo`0087oo00<007ooOol07Goo00<007ooOol087oo00<007oo
Ool07Goo1@000Goo000[Ool40005Ool00`00Oomoo`0FOol40004Ool00`00Oomoo`0GOol40004Ool0
0`00Oomoo`0IOol01000Oomoo`0087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol077oo
00@007ooOol0009oo`00<Goo00@007ooOol001ioo`04001oogoo000POol00`00Oomoo`0IOol01000
Oomoo`0087oo00<007ooOol077oo00@007ooOol001ioo`04001oogoo000OOol00`00Ool00002Ool0
039oo`80021oo`80021oo`8001aoo`80021oo`8001moo`80021oo`80025oo`80009oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`003gooo`003`000goo000?Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`2TOol501mQOol00`00Oomoo`01Ool000moo`03001o
ogoo0:=oo`L07f1oo`03001oogoo005oo`003goo00<007ooOol0XWoo2@0OGgoo00<007ooOol00Goo
0008Ool20005Ool00`00Oomoo`2QOol;01mNOol00`00Oomoo`01Ool000Moo`04001oogoo0004Ool0
0`00Oomoo`2POol=01mMOol00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<00:1oo`d07e]oo`<0
00=oo`0000=oo`0000000P001Goo00<007ooOol00Woo00<007ooOol0X7oo3@0OGGoo00<007ooOol0
0Goo0007Ool01000Oomoo`0017oo00<007ooOol0X7oo3@0OGGoo00<007ooOol00Goo0008Ool20005
Ool00`00Oomoo`2POol=01mMOol00`00Oomoo`01Ool000moo`03001oogoo0:5oo`/07eioo`03001o
ogoo005oo`003goo00<007ooOol0XWoo2@0OGgoo00<007ooOol00Goo000?Ool00`00Oomoo`2SOol7
01mPOol00`00Oomoo`01Ool000moo`800:Eoo`D07emoo`<000=oo`003goo00<007ooOol0ogoo2goo
00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00
ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00
ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo1000
17oo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool00`00Oomoo`05Ool00`00Oomoo`3oOol;
Ool00`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`<00?moo`Uoo`<000=oo`0000=oo`0000000P00
17oo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Moo`D000=oo`03001oogoo
0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo0009Ool00`00Oomoo`03Ool3003oOol9Ool30003Ool00003Ool00000008000Aoo`03001oogoo
00=oo`03001oogoo0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`0027oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<0
07ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo0`00ogoo2Goo0`000goo0007
Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`001goo1@000goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<00?moo`Uo
o`<000=oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`8000Eoo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo
2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo100017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool00`00Oomoo`05Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`<00?moo`Uoo`<000=oo`002Goo00<007ooOol00goo
00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0
ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001o
ogoo05ioo`El0:Moo`03001oogoo005oo`003goo00<007ooOol0GGoo1g`0YWoo00<007ooOol00Goo
000?Ool00`00Oomoo`1LOol9O02UOol00`00Oomoo`01Ool000moo`03001oogoo05]oo`]l0:Aoo`03
001oogoo005oo`0027oo0P001Goo00<007ooOol0FWoo3G`0Xgoo00<007ooOol00Goo0007Ool01000
Oomoo`0017oo00<007ooOol0FWoo3G`0Xgoo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool3001J
Ool=O02QOol30003Ool000Yoo`03001oogoo009oo`03001oogoo05Yoo`el0:=oo`03001oogoo005o
o`001goo00@007ooOol000Aoo`03001oogoo05Yoo`el0:=oo`03001oogoo005oo`0027oo0P001Goo
00<007ooOol0Fgoo2g`0Y7oo00<007ooOol00Goo000?Ool00`00Oomoo`1LOol9O02UOol00`00Oomo
o`01Ool000moo`03001oogoo05eoo`Ml0:Ioo`03001oogoo005oo`003goo0P00Ggoo1G`0YGoo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0009Ool30003Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo005oo`001goo1@000gooo`003`000goo0007Ool01000Oomoo`00ogoo
5Woo0008Ool00`00Ool0003oOolFOol000Uoo`800?mooaIoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-4.4574, -4.39039, 0.0297797, \
0.0297797}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[.125 -0.0125 -6 -9 ]
[.125 -0.0125 6 0 ]
[.25 -0.0125 -6 -9 ]
[.25 -0.0125 6 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -3 -9 ]
[.625 -0.0125 3 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -3 -9 ]
[.875 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -12 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -12 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -6 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -6 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-3)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-2)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-1)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(2)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-3)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-2)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-1)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(1)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(2)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(3)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(4)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.125 .99375 m
.125 1 L
s
.25 .99375 m
.25 1 L
s
.375 .99375 m
.375 1 L
s
.5 .99375 m
.5 1 L
s
.625 .99375 m
.625 1 L
s
.75 .99375 m
.75 1 L
s
.875 .99375 m
.875 1 L
s
.125 Mabswid
.025 .99625 m
.025 1 L
s
.05 .99625 m
.05 1 L
s
.075 .99625 m
.075 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.175 .99625 m
.175 1 L
s
.2 .99625 m
.2 1 L
s
.225 .99625 m
.225 1 L
s
.275 .99625 m
.275 1 L
s
.3 .99625 m
.3 1 L
s
.325 .99625 m
.325 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.425 .99625 m
.425 1 L
s
.45 .99625 m
.45 1 L
s
.475 .99625 m
.475 1 L
s
.525 .99625 m
.525 1 L
s
.55 .99625 m
.55 1 L
s
.575 .99625 m
.575 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.675 .99625 m
.675 1 L
s
.7 .99625 m
.7 1 L
s
.725 .99625 m
.725 1 L
s
.775 .99625 m
.775 1 L
s
.8 .99625 m
.8 1 L
s
.825 .99625 m
.825 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.925 .99625 m
.925 1 L
s
.95 .99625 m
.95 1 L
s
.975 .99625 m
.975 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.43051 .72583 Mdot
0 0 1 r
.56949 .27417 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool0039oo`8001moo`@001ioo`D001Yoo`8001moo`D001aoo`@001moo`80025oo`<0005oo`00<Goo
00@007ooOol001ioo`03001oogoo025oo`03001oogoo01Uoo`04001oogoo000POol00`00Oomoo`0L
Ool00`00Oomoo`0OOol01000Oomoo`008Goo0@000Goo0Goo000cOol00`00Oomoo`0NOol00`00Oomo
o`0POol00`00Oomoo`0IOol01000Oomoo`0087oo00<007ooOol07Goo00<007ooOol087oo00<007oo
Ool07Goo1@000Goo000[Ool40005Ool00`00Oomoo`0FOol40004Ool00`00Oomoo`0GOol40004Ool0
0`00Oomoo`0IOol01000Oomoo`0087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol077oo
00@007ooOol0009oo`00<Goo00@007ooOol001ioo`04001oogoo000POol00`00Oomoo`0IOol01000
Oomoo`0087oo00<007ooOol077oo00@007ooOol001ioo`04001oogoo000OOol00`00Ool00002Ool0
039oo`80021oo`80021oo`8001aoo`80021oo`8001moo`80021oo`80025oo`80009oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`003gooo`003`000goo000?Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Moo`04001oogoo0004Ool00`00Oomoo`3oOol;
Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<00?moo`Uoo`<000=oo`0000=oo`0000000P00
1Goo00<007ooOol00Woo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`001goo100017oo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool00`00
Oomoo`05Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`<009Aoo`D0
7fmoo`<000=oo`0000=oo`0000000P0017oo00<007ooOol00goo00<007ooOol0Tgoo1`0OL7oo00<0
07ooOol00Goo0007Ool01000Oomoo`0017oo00<007ooOol0TWoo2@0OKgoo00<007ooOol00Goo0008
Ool20005Ool00`00Oomoo`2AOol;01m^Ool00`00Oomoo`01Ool000moo`03001oogoo091oo`d07feo
o`03001oogoo005oo`003goo00<007ooOol0T7oo3@0OKGoo00<007ooOol00Goo000?Ool2002AOol=
01m[Ool30003Ool000moo`03001oogoo091oo`d07feoo`03001oogoo005oo`003goo00<007ooOol0
T7oo3@0OKGoo00<007ooOol00Goo000?Ool00`00Oomoo`2AOol;01m^Ool00`00Oomoo`01Ool000mo
o`03001oogoo099oo`T07fmoo`03001oogoo005oo`003goo00<007ooOol0Tgoo1`0OL7oo00<007oo
Ool00Goo000?Ool00`00Oomoo`2DOol501maOol00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Moo`D000=oo`03001oogoo
0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo0009Ool00`00Oomoo`03Ool3003oOol9Ool30003Ool00003Ool00000008000Aoo`03001oogoo
00=oo`03001oogoo0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`0027oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<0
07ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo0`00ogoo2Goo0`000goo0007
Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`001goo1@000goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<00?moo`Uo
o`<000=oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`8000Eoo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo
2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo06ioo`El
09Moo`03001oogoo005oo`003goo00<007ooOol0KGoo1g`0UWoo00<007ooOol00Goo000?Ool00`00
Oomoo`1/Ool9O02EOol00`00Oomoo`01Ool000moo`03001oogoo06]oo`]l09Aoo`03001oogoo005o
o`003goo00<007ooOol0JWoo3G`0Tgoo00<007ooOol00Goo000?Ool2001[Ool=O02AOol30003Ool0
00moo`03001oogoo06Yoo`el09=oo`03001oogoo005oo`003goo00<007ooOol0JWoo3G`0Tgoo00<0
07ooOol00Goo000?Ool00`00Oomoo`1ZOol=O02COol00`00Oomoo`01Ool000moo`03001oogoo06]o
o`]l09Aoo`03001oogoo005oo`001goo100017oo00<007ooOol0K7oo2G`0UGoo00<007ooOol00Goo
0007Ool00`00Oomoo`05Ool00`00Oomoo`1]Ool7O02FOol00`00Oomoo`01Ool000Qoo`03001oogoo
00Aoo`<006ioo`El09Eoo`<000=oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007oo
Ool00Goo0007Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`0027oo0P001Goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo
0009Ool00`00Oomoo`03Ool3003oOol9Ool30003Ool000Yoo`03001oogoo009oo`03001oogoo0?mo
o`]oo`03001oogoo005oo`001goo00@007ooOol000Aoo`03001oogoo0?moo`]oo`03001oogoo005o
o`0027oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0009Ool30003Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo005oo`001goo1@000gooo`003`000goo0007Ool01000Oomoo`00ogoo
5Woo0008Ool00`00Ool0003oOolFOol000Uoo`800?mooaIoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-4.4574, -4.39039, 0.0297797, \
0.0297797}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[.125 -0.0125 -6 -9 ]
[.125 -0.0125 6 0 ]
[.25 -0.0125 -6 -9 ]
[.25 -0.0125 6 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -3 -9 ]
[.625 -0.0125 3 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -3 -9 ]
[.875 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -12 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -12 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -6 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -6 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-3)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-2)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-1)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(2)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-3)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-2)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-1)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(1)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(2)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(3)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(4)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.125 .99375 m
.125 1 L
s
.25 .99375 m
.25 1 L
s
.375 .99375 m
.375 1 L
s
.5 .99375 m
.5 1 L
s
.625 .99375 m
.625 1 L
s
.75 .99375 m
.75 1 L
s
.875 .99375 m
.875 1 L
s
.125 Mabswid
.025 .99625 m
.025 1 L
s
.05 .99625 m
.05 1 L
s
.075 .99625 m
.075 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.175 .99625 m
.175 1 L
s
.2 .99625 m
.2 1 L
s
.225 .99625 m
.225 1 L
s
.275 .99625 m
.275 1 L
s
.3 .99625 m
.3 1 L
s
.325 .99625 m
.325 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.425 .99625 m
.425 1 L
s
.45 .99625 m
.45 1 L
s
.475 .99625 m
.475 1 L
s
.525 .99625 m
.525 1 L
s
.55 .99625 m
.55 1 L
s
.575 .99625 m
.575 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.675 .99625 m
.675 1 L
s
.7 .99625 m
.7 1 L
s
.725 .99625 m
.725 1 L
s
.775 .99625 m
.775 1 L
s
.8 .99625 m
.8 1 L
s
.825 .99625 m
.825 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.925 .99625 m
.925 1 L
s
.95 .99625 m
.95 1 L
s
.975 .99625 m
.975 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.61685 .82064 Mdot
0 0 1 r
.38315 .17936 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool0039oo`8001moo`@001ioo`D001Yoo`8001moo`D001aoo`@001moo`80025oo`<0005oo`00<Goo
00@007ooOol001ioo`03001oogoo025oo`03001oogoo01Uoo`04001oogoo000POol00`00Oomoo`0L
Ool00`00Oomoo`0OOol01000Oomoo`008Goo0@000Goo0Goo000cOol00`00Oomoo`0NOol00`00Oomo
o`0POol00`00Oomoo`0IOol01000Oomoo`0087oo00<007ooOol07Goo00<007ooOol087oo00<007oo
Ool07Goo1@000Goo000[Ool40005Ool00`00Oomoo`0FOol40004Ool00`00Oomoo`0GOol40004Ool0
0`00Oomoo`0IOol01000Oomoo`0087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol077oo
00@007ooOol0009oo`00<Goo00@007ooOol001ioo`04001oogoo000POol00`00Oomoo`0IOol01000
Oomoo`0087oo00<007ooOol077oo00@007ooOol001ioo`04001oogoo000OOol00`00Ool00002Ool0
039oo`80021oo`80021oo`8001aoo`80021oo`8001moo`80021oo`80025oo`80009oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`003gooo`003`000goo000?Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00
Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Moo`04001oogoo0004Ool00`00Oomoo`3oOol;
Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<00?moo`Uoo`<000=oo`0000=oo`0000000P00
1Goo00<007ooOol00Woo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`1ROol501nSOol00`00
Oomoo`01Ool000moo`03001oogoo065oo`L07j9oo`03001oogoo005oo`003goo00<007ooOol0H7oo
2@0OXGoo00<007ooOol00Goo000?Ool00`00Oomoo`1OOol;01nPOol00`00Oomoo`01Ool000moo`03
001oogoo05ioo`d07imoo`03001oogoo005oo`003goo0P00Ggoo3@0OWGoo0`000goo000?Ool00`00
Oomoo`1NOol=01nOOol00`00Oomoo`01Ool000moo`03001oogoo05ioo`d07imoo`03001oogoo005o
o`003goo00<007ooOol0GWoo3@0OWgoo00<007ooOol00Goo000?Ool00`00Oomoo`1OOol;01nPOol0
0`00Oomoo`01Ool000moo`03001oogoo061oo`T07j5oo`03001oogoo005oo`003goo0P00HWoo1`0O
X7oo0`000goo000?Ool00`00Oomoo`1ROol501nSOol00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo1000
17oo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool00`00Oomoo`05Ool00`00Oomoo`3oOol;
Ool00`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`<00?moo`Uoo`<000=oo`0000=oo`0000000P00
17oo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Moo`D000=oo`03001oogoo
0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo0009Ool00`00Oomoo`03Ool3003oOol9Ool30003Ool00003Ool00000008000Aoo`03001oogoo
00=oo`03001oogoo0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`0027oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<0
07ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo0`00ogoo2Goo0`000goo0007
Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`001goo1@000goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<00?moo`Uo
o`<000=oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`8000Eoo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo
2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo100017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool00`00Oomoo`05Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`<00?moo`Uoo`<000=oo`002Goo00<007ooOol00goo
00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0
ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0:1oo`El06Eoo`03001oogoo005o
o`003goo0P00X7oo1g`0HWoo0`000goo000?Ool00`00Oomoo`2NOol9O01SOol00`00Oomoo`01Ool0
00moo`03001oogoo09eoo`]l069oo`03001oogoo005oo`003goo00<007ooOol0W7oo3G`0HGoo00<0
07ooOol00Goo000?Ool00`00Oomoo`2LOol=O01QOol00`00Oomoo`01Ool000moo`03001oogoo09ao
o`el065oo`03001oogoo005oo`003goo0P00WGoo3G`0Ggoo0`000goo000?Ool00`00Oomoo`2LOol=
O01QOol00`00Oomoo`01Ool000moo`03001oogoo09eoo`]l069oo`03001oogoo005oo`003goo00<0
07ooOol0WWoo2G`0Hgoo00<007ooOol00Goo000?Ool00`00Oomoo`2OOol7O01TOol00`00Oomoo`01
Ool000moo`03001oogoo0:1oo`El06Eoo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`0027oo0P001Goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo
0009Ool00`00Oomoo`03Ool3003oOol9Ool30003Ool000Yoo`03001oogoo009oo`03001oogoo0?mo
o`]oo`03001oogoo005oo`001goo00@007ooOol000Aoo`03001oogoo0?moo`]oo`03001oogoo005o
o`0027oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`00
0goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001o
ogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0009Ool30003Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo005oo`001goo1@000gooo`003`000goo0007Ool01000Oomoo`00ogoo
5Woo0008Ool00`00Ool0003oOolFOol000Uoo`800?mooaIoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-4.4574, -4.39039, 0.0297797, \
0.0297797}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[.125 -0.0125 -6 -9 ]
[.125 -0.0125 6 0 ]
[.25 -0.0125 -6 -9 ]
[.25 -0.0125 6 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -3 -9 ]
[.625 -0.0125 3 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -3 -9 ]
[.875 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -12 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -12 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -6 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -6 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-3)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-2)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-1)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(2)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-3)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-2)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-1)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(1)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(2)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(3)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(4)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.125 .99375 m
.125 1 L
s
.25 .99375 m
.25 1 L
s
.375 .99375 m
.375 1 L
s
.5 .99375 m
.5 1 L
s
.625 .99375 m
.625 1 L
s
.75 .99375 m
.75 1 L
s
.875 .99375 m
.875 1 L
s
.125 Mabswid
.025 .99625 m
.025 1 L
s
.05 .99625 m
.05 1 L
s
.075 .99625 m
.075 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.175 .99625 m
.175 1 L
s
.2 .99625 m
.2 1 L
s
.225 .99625 m
.225 1 L
s
.275 .99625 m
.275 1 L
s
.3 .99625 m
.3 1 L
s
.325 .99625 m
.325 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.425 .99625 m
.425 1 L
s
.45 .99625 m
.45 1 L
s
.475 .99625 m
.475 1 L
s
.525 .99625 m
.525 1 L
s
.55 .99625 m
.55 1 L
s
.575 .99625 m
.575 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.675 .99625 m
.675 1 L
s
.7 .99625 m
.7 1 L
s
.725 .99625 m
.725 1 L
s
.775 .99625 m
.775 1 L
s
.8 .99625 m
.8 1 L
s
.825 .99625 m
.825 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.925 .99625 m
.925 1 L
s
.95 .99625 m
.95 1 L
s
.975 .99625 m
.975 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.65531 .91486 Mdot
0 0 1 r
.34469 .08514 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool0039oo`8001moo`@001ioo`D001Yoo`8001moo`D001aoo`@001moo`80025oo`<0005oo`00<Goo
00@007ooOol001ioo`03001oogoo025oo`03001oogoo01Uoo`04001oogoo000POol00`00Oomoo`0L
Ool00`00Oomoo`0OOol01000Oomoo`008Goo0@000Goo0Goo000cOol00`00Oomoo`0NOol00`00Oomo
o`0POol00`00Oomoo`0IOol01000Oomoo`0087oo00<007ooOol07Goo00<007ooOol087oo00<007oo
Ool07Goo1@000Goo000[Ool40005Ool00`00Oomoo`0FOol40004Ool00`00Oomoo`0GOol40004Ool0
0`00Oomoo`0IOol01000Oomoo`0087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol077oo
00@007ooOol0009oo`00<Goo00@007ooOol001ioo`04001oogoo000POol00`00Oomoo`0IOol01000
Oomoo`0087oo00<007ooOol077oo00@007ooOol001ioo`04001oogoo000OOol00`00Ool00002Ool0
039oo`80021oo`80021oo`8001aoo`80021oo`8001moo`80021oo`80025oo`80009oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`003gooo`003`000goo000?Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003o
Ool:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
05Moo`D07jioo`03001oogoo005oo`003goo00<007ooOol0EWoo1`0O[Goo00<007ooOol00Goo000?
Ool00`00Oomoo`1EOol901n/Ool00`00Oomoo`01Ool000moo`8005Eoo`/07jUoo`<000=oo`003goo
00<007ooOol0Dgoo3@0OZWoo00<007ooOol00Goo000?Ool00`00Oomoo`1COol=01nZOol00`00Oomo
o`01Ool000moo`03001oogoo05=oo`d07jYoo`03001oogoo005oo`003goo00<007ooOol0Dgoo3@0O
ZWoo00<007ooOol00Goo000?Ool00`00Oomoo`1COol=01nZOol00`00Oomoo`01Ool000moo`8005Eo
o`/07jUoo`<000=oo`003goo00<007ooOol0EGoo2@0O[7oo00<007ooOol00Goo000?Ool00`00Oomo
o`1FOol701n]Ool00`00Oomoo`01Ool000moo`03001oogoo05Moo`D07jioo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00
Oomoo`01Ool000Moo`04001oogoo0004Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`03
001oogoo00=oo`<00?moo`Uoo`<000=oo`0000=oo`0000000P001Goo00<007ooOol00Woo00<007oo
Ool0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007oo
Ool00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo
00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00
ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00
ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo1000
17oo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool00`00Oomoo`05Ool00`00Oomoo`3oOol;
Ool00`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`<00?moo`Uoo`<000=oo`0000=oo`0000000P00
17oo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Moo`D000=oo`03001oogoo
0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo0009Ool00`00Oomoo`03Ool3003oOol9Ool30003Ool00003Ool00000008000Aoo`03001oogoo
00=oo`03001oogoo0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`0027oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<0
07ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo0`00ogoo2Goo0`000goo0007
Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`001goo1@000goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<00?moo`Uo
o`<000=oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`8000Eoo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo
2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo100017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool00`00Oomoo`05Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`<00?moo`Uoo`<000=oo`002Goo00<007ooOol00goo
00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0
ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
27oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007oo
Ool0ogoo2goo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool3003oOol9Ool30003Ool000Yoo`03
001oogoo009oo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo00@007ooOol000Aoo`03001o
ogoo0?moo`]oo`03001oogoo005oo`0027oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo
000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0:]oo`El05Yoo`03001o
ogoo005oo`003goo0P00Zgoo1g`0Egoo0`000goo000?Ool00`00Oomoo`2YOol9O01HOol00`00Oomo
o`01Ool000moo`03001oogoo0:Qoo`]l05Moo`03001oogoo005oo`003goo00<007ooOol0Ygoo3G`0
EWoo00<007ooOol00Goo000?Ool00`00Oomoo`2WOol=O01FOol00`00Oomoo`01Ool000moo`03001o
ogoo0:Moo`el05Ioo`03001oogoo005oo`003goo00<007ooOol0Ygoo3G`0EWoo00<007ooOol00Goo
000?Ool2002XOol=O01DOol30003Ool000moo`03001oogoo0:Qoo`]l05Moo`03001oogoo005oo`00
3goo00<007ooOol0ZGoo2G`0F7oo00<007ooOol00Goo000?Ool00`00Oomoo`2ZOol7O01IOol00`00
Oomoo`01Ool000moo`03001oogoo0:]oo`El05Yoo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yo
o`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0009Ool30003Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo005oo`001goo1@000gooo`003`000goo0007Ool01000Oomoo`00ogoo
5Woo0008Ool00`00Ool0003oOolFOol000Uoo`800?mooaIoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-4.4574, -4.39039, 0.0297797, \
0.0297797}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.125 0.5 0.125 [
[.125 -0.0125 -6 -9 ]
[.125 -0.0125 6 0 ]
[.25 -0.0125 -6 -9 ]
[.25 -0.0125 6 0 ]
[.375 -0.0125 -6 -9 ]
[.375 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.625 -0.0125 -3 -9 ]
[.625 -0.0125 3 0 ]
[.75 -0.0125 -3 -9 ]
[.75 -0.0125 3 0 ]
[.875 -0.0125 -3 -9 ]
[.875 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -12 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -12 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -6 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -6 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(-3)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(-2)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(-1)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(1)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(2)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(3)] .875 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(4)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-3)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-2)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-1)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(1)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(2)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(3)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(4)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
0 .99375 m
0 1 L
s
.125 .99375 m
.125 1 L
s
.25 .99375 m
.25 1 L
s
.375 .99375 m
.375 1 L
s
.5 .99375 m
.5 1 L
s
.625 .99375 m
.625 1 L
s
.75 .99375 m
.75 1 L
s
.875 .99375 m
.875 1 L
s
.125 Mabswid
.025 .99625 m
.025 1 L
s
.05 .99625 m
.05 1 L
s
.075 .99625 m
.075 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.175 .99625 m
.175 1 L
s
.2 .99625 m
.2 1 L
s
.225 .99625 m
.225 1 L
s
.275 .99625 m
.275 1 L
s
.3 .99625 m
.3 1 L
s
.325 .99625 m
.325 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.425 .99625 m
.425 1 L
s
.45 .99625 m
.45 1 L
s
.475 .99625 m
.475 1 L
s
.525 .99625 m
.525 1 L
s
.55 .99625 m
.55 1 L
s
.575 .99625 m
.575 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.675 .99625 m
.675 1 L
s
.7 .99625 m
.7 1 L
s
.725 .99625 m
.725 1 L
s
.775 .99625 m
.775 1 L
s
.8 .99625 m
.8 1 L
s
.825 .99625 m
.825 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.925 .99625 m
.925 1 L
s
.95 .99625 m
.95 1 L
s
.975 .99625 m
.975 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.67005 .95155 Mdot
0 0 1 r
.32995 .04845 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool0039oo`8001moo`@001ioo`D001Yoo`8001moo`D001aoo`@001moo`80025oo`<0005oo`00<Goo
00@007ooOol001ioo`03001oogoo025oo`03001oogoo01Uoo`04001oogoo000POol00`00Oomoo`0L
Ool00`00Oomoo`0OOol01000Oomoo`008Goo0@000Goo0Goo000cOol00`00Oomoo`0NOol00`00Oomo
o`0POol00`00Oomoo`0IOol01000Oomoo`0087oo00<007ooOol07Goo00<007ooOol087oo00<007oo
Ool07Goo1@000Goo000[Ool40005Ool00`00Oomoo`0FOol40004Ool00`00Oomoo`0GOol40004Ool0
0`00Oomoo`0IOol01000Oomoo`0087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol077oo
00@007ooOol0009oo`00<Goo00@007ooOol001ioo`04001oogoo000POol00`00Oomoo`0IOol01000
Oomoo`0087oo00<007ooOol077oo00@007ooOol001ioo`04001oogoo000OOol00`00Ool00002Ool0
039oo`80021oo`80021oo`8001aoo`80021oo`8001moo`80021oo`80025oo`80009oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`003gooo`003`000goo000?Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo
0?moo`]oo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`1COol501nb
Ool00`00Oomoo`01Ool000moo`03001oogoo059oo`L07k5oo`03001oogoo005oo`003goo00<007oo
Ool0DGoo2@0O/7oo00<007ooOol00Goo000?Ool00`00Oomoo`1@Ool;01n_Ool00`00Oomoo`01Ool0
00moo`03001oogoo04moo`d07jioo`03001oogoo005oo`003goo00<007ooOol0Cgoo3@0O[Woo00<0
07ooOol00Goo000?Ool2001@Ool=01n/Ool30003Ool000moo`03001oogoo04moo`d07jioo`03001o
ogoo005oo`003goo00<007ooOol0Cgoo3@0O[Woo00<007ooOol00Goo000?Ool00`00Oomoo`1@Ool;
01n_Ool00`00Oomoo`01Ool000moo`03001oogoo055oo`T07k1oo`03001oogoo005oo`003goo00<0
07ooOol0DWoo1`0O/Goo00<007ooOol00Goo000?Ool00`00Oomoo`1COol501nbOol00`00Oomoo`01
Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01
Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00
Oomoo`01Ool000Moo`04001oogoo0004Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`03
001oogoo00=oo`<00?moo`Uoo`<000=oo`0000=oo`0000000P001Goo00<007ooOol00Woo00<007oo
Ool0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007oo
Ool00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo
00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00
ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00
ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<0
07ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?mo
o`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomo
o`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo1000
17oo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool00`00Oomoo`05Ool00`00Oomoo`3oOol;
Ool00`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`<00?moo`Uoo`<000=oo`0000=oo`0000000P00
17oo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Moo`D000=oo`03001oogoo
0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol0
0Goo0009Ool00`00Oomoo`03Ool3003oOol9Ool30003Ool00003Ool00000008000Aoo`03001oogoo
00=oo`03001oogoo0?moo`]oo`03001oogoo005oo`002Goo00<007ooOol00goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03
001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?
Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005o
o`0027oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<0
07ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo0`00ogoo2Goo0`000goo0007
Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=o
o`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomo
o`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool3
0003Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`001goo1@000goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Uoo`03001oogoo00=oo`<00?moo`Uo
o`<000=oo`002Goo00<007ooOol00goo00<007ooOol0ogoo2goo00<007ooOol00Goo0009Ool00`00
Oomoo`03Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Qoo`8000Eoo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0ogoo2goo00<0
07ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo0P00ogoo
2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007oo
Ool0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001oogoo0?moo`]o
o`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3o
Ool;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo100017oo
00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool00`00Oomoo`05Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000Qoo`03001oogoo00Aoo`<00?moo`Uoo`<000=oo`002Goo00<007ooOol00goo
00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007ooOol0ogoo2goo
00<007ooOol00Goo0008Ool20005Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`800?moo`Yoo`<000=oo`003goo00<007ooOol0
ogoo2goo00<007ooOol00Goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
3goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000moo`03001o
ogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool0
0`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`00
27oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo0007Ool01000Oomoo`0017oo00<007oo
Ool0ogoo2goo00<007ooOol00Goo0009Ool00`00Oomoo`03Ool3003oOol9Ool30003Ool000Yoo`03
001oogoo009oo`03001oogoo0?moo`]oo`03001oogoo005oo`001goo00@007ooOol000Aoo`03001o
ogoo0?moo`]oo`03001oogoo005oo`0027oo0P001Goo00<007ooOol0ogoo2goo00<007ooOol00Goo
000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo
005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000mo
o`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo
000?Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo
005oo`003goo00<007ooOol0ogoo2goo00<007ooOol00Goo000?Ool2003oOol:Ool30003Ool000mo
o`03001oogoo0:moo`El05Ioo`03001oogoo005oo`003goo00<007ooOol0[Woo1g`0EGoo00<007oo
Ool00Goo000?Ool00`00Oomoo`2]Ool9O01DOol00`00Oomoo`01Ool000moo`03001oogoo0:aoo`]l
05=oo`03001oogoo005oo`003goo00<007ooOol0Zgoo3G`0DWoo00<007ooOol00Goo000?Ool00`00
Oomoo`2[Ool=O01BOol00`00Oomoo`01Ool000moo`800:aoo`el051oo`<000=oo`003goo00<007oo
Ool0Zgoo3G`0DWoo00<007ooOol00Goo000?Ool00`00Oomoo`2[Ool=O01BOol00`00Oomoo`01Ool0
00moo`03001oogoo0:aoo`]l05=oo`03001oogoo005oo`003goo00<007ooOol0[Goo2G`0E7oo00<0
07ooOol00Goo000?Ool00`00Oomoo`2^Ool7O01EOol00`00Oomoo`01Ool000moo`03001oogoo0:mo
o`El05Ioo`03001oogoo005oo`003goo0P00ogoo2Woo0`000goo000?Ool00`00Oomoo`3oOol;Ool0
0`00Oomoo`01Ool000moo`03001oogoo0?moo`]oo`03001oogoo005oo`003goo00<007ooOol0ogoo
2goo00<007ooOol00Goo0009Ool30003Ool00`00Oomoo`3oOol;Ool00`00Oomoo`01Ool000Yoo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo005oo`001goo1@000gooo`003`000goo0007Ool01000Oomoo`00ogoo
5Woo0008Ool00`00Ool0003oOolFOol000Uoo`800?mooaIoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-4.4574, -4.39039, 0.0297797, \
0.0297797}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  GeneratedCell->False,
  CellAutoOverwrite->False]
}, Open  ]],

Cell["ShowAnimation[Table[plt[n],{n,1,150,10}]]", "Input"],

Cell["\<\
tbl1=Chop[Table[{(Y[1,t]-Y[2,t]),X[1,t]-X[2,t]},{t,1,1500}]];\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\
ListPlot[tbl1,PlotJoined->True,PlotStyle->RGBColor[0,1,0],PlotRange->{{-1,10},\
{-4,4}}]\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0909091 0.0909091 0.309017 0.0772542 [
[.27273 .29652 -3 -9 ]
[.27273 .29652 3 0 ]
[.45455 .29652 -3 -9 ]
[.45455 .29652 3 0 ]
[.63636 .29652 -3 -9 ]
[.63636 .29652 3 0 ]
[.81818 .29652 -3 -9 ]
[.81818 .29652 3 0 ]
[1 .29652 -6 -9 ]
[1 .29652 6 0 ]
[.07841 0 -12 -4.5 ]
[.07841 0 0 4.5 ]
[.07841 .07725 -12 -4.5 ]
[.07841 .07725 0 4.5 ]
[.07841 .15451 -12 -4.5 ]
[.07841 .15451 0 4.5 ]
[.07841 .23176 -12 -4.5 ]
[.07841 .23176 0 4.5 ]
[.07841 .38627 -6 -4.5 ]
[.07841 .38627 0 4.5 ]
[.07841 .46353 -6 -4.5 ]
[.07841 .46353 0 4.5 ]
[.07841 .54078 -6 -4.5 ]
[.07841 .54078 0 4.5 ]
[.07841 .61803 -6 -4.5 ]
[.07841 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.27273 .30902 m
.27273 .31527 L
s
[(2)] .27273 .29652 0 1 Mshowa
.45455 .30902 m
.45455 .31527 L
s
[(4)] .45455 .29652 0 1 Mshowa
.63636 .30902 m
.63636 .31527 L
s
[(6)] .63636 .29652 0 1 Mshowa
.81818 .30902 m
.81818 .31527 L
s
[(8)] .81818 .29652 0 1 Mshowa
1 .30902 m
1 .31527 L
s
[(10)] 1 .29652 0 1 Mshowa
.125 Mabswid
.13636 .30902 m
.13636 .31277 L
s
.18182 .30902 m
.18182 .31277 L
s
.22727 .30902 m
.22727 .31277 L
s
.31818 .30902 m
.31818 .31277 L
s
.36364 .30902 m
.36364 .31277 L
s
.40909 .30902 m
.40909 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54545 .30902 m
.54545 .31277 L
s
.59091 .30902 m
.59091 .31277 L
s
.68182 .30902 m
.68182 .31277 L
s
.72727 .30902 m
.72727 .31277 L
s
.77273 .30902 m
.77273 .31277 L
s
.86364 .30902 m
.86364 .31277 L
s
.90909 .30902 m
.90909 .31277 L
s
.95455 .30902 m
.95455 .31277 L
s
.04545 .30902 m
.04545 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.09091 0 m
.09716 0 L
s
[(-4)] .07841 0 1 0 Mshowa
.09091 .07725 m
.09716 .07725 L
s
[(-3)] .07841 .07725 1 0 Mshowa
.09091 .15451 m
.09716 .15451 L
s
[(-2)] .07841 .15451 1 0 Mshowa
.09091 .23176 m
.09716 .23176 L
s
[(-1)] .07841 .23176 1 0 Mshowa
.09091 .38627 m
.09716 .38627 L
s
[(1)] .07841 .38627 1 0 Mshowa
.09091 .46353 m
.09716 .46353 L
s
[(2)] .07841 .46353 1 0 Mshowa
.09091 .54078 m
.09716 .54078 L
s
[(3)] .07841 .54078 1 0 Mshowa
.09091 .61803 m
.09716 .61803 L
s
[(4)] .07841 .61803 1 0 Mshowa
.125 Mabswid
.09091 .01545 m
.09466 .01545 L
s
.09091 .0309 m
.09466 .0309 L
s
.09091 .04635 m
.09466 .04635 L
s
.09091 .0618 m
.09466 .0618 L
s
.09091 .09271 m
.09466 .09271 L
s
.09091 .10816 m
.09466 .10816 L
s
.09091 .12361 m
.09466 .12361 L
s
.09091 .13906 m
.09466 .13906 L
s
.09091 .16996 m
.09466 .16996 L
s
.09091 .18541 m
.09466 .18541 L
s
.09091 .20086 m
.09466 .20086 L
s
.09091 .21631 m
.09466 .21631 L
s
.09091 .24721 m
.09466 .24721 L
s
.09091 .26266 m
.09466 .26266 L
s
.09091 .27812 m
.09466 .27812 L
s
.09091 .29357 m
.09466 .29357 L
s
.09091 .32447 m
.09466 .32447 L
s
.09091 .33992 m
.09466 .33992 L
s
.09091 .35537 m
.09466 .35537 L
s
.09091 .37082 m
.09466 .37082 L
s
.09091 .40172 m
.09466 .40172 L
s
.09091 .41717 m
.09466 .41717 L
s
.09091 .43262 m
.09466 .43262 L
s
.09091 .44807 m
.09466 .44807 L
s
.09091 .47898 m
.09466 .47898 L
s
.09091 .49443 m
.09466 .49443 L
s
.09091 .50988 m
.09466 .50988 L
s
.09091 .52533 m
.09466 .52533 L
s
.09091 .55623 m
.09466 .55623 L
s
.09091 .57168 m
.09466 .57168 L
s
.09091 .58713 m
.09466 .58713 L
s
.09091 .60258 m
.09466 .60258 L
s
.25 Mabswid
.09091 0 m
.09091 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
.5 Mabswid
.28182 .29689 m
.29106 .28443 L
.30536 .27397 L
.3201 .26553 L
.33407 .2585 L
.34704 .25248 L
.3591 .2472 L
.37034 .24247 L
.38087 .23819 L
.39077 .23427 L
.40013 .23063 L
.40901 .22725 L
.41746 .22407 L
.42552 .22108 L
.43324 .21825 L
.44064 .21555 L
.44776 .21299 L
.45461 .21053 L
.46123 .20818 L
.46762 .20592 L
.4738 .20375 L
.4798 .20165 L
.48561 .19963 L
.49126 .19767 L
.49674 .19578 L
.50208 .19394 L
.50728 .19215 L
.51235 .19042 L
.51729 .18874 L
.52211 .1871 L
.52682 .1855 L
.53142 .18394 L
.53591 .18242 L
.54031 .18094 L
.54461 .1795 L
.54882 .17808 L
.55294 .1767 L
.55698 .17535 L
.56094 .17403 L
.56482 .17273 L
.56862 .17147 L
.57236 .17022 L
.57602 .16901 L
.57961 .16782 L
.58313 .16665 L
.5866 .1655 L
.58999 .16438 L
.59333 .16327 L
.59661 .16219 L
.59983 .16113 L
Mistroke
.603 .16009 L
.60611 .15906 L
.60917 .15806 L
.61218 .15707 L
.61514 .1561 L
.61804 .15514 L
.6209 .15421 L
.62371 .15329 L
.62648 .15238 L
.62919 .15149 L
.63187 .15062 L
.6345 .14976 L
.63709 .14891 L
.63963 .14808 L
.64214 .14726 L
.6446 .14646 L
.64703 .14567 L
.64941 .1449 L
.65176 .14413 L
.65407 .14338 L
.65634 .14264 L
.65857 .14192 L
.66077 .1412 L
.66293 .1405 L
.66506 .13981 L
.66715 .13913 L
.66921 .13846 L
.67123 .13781 L
.67322 .13716 L
.67518 .13653 L
.67711 .1359 L
.679 .13529 L
.68086 .13469 L
.68269 .1341 L
.68449 .13352 L
.68625 .13294 L
.68799 .13238 L
.6897 .13183 L
.69137 .13129 L
.69302 .13076 L
.69464 .13024 L
.69623 .12972 L
.69779 .12922 L
.69932 .12873 L
.70082 .12824 L
.70229 .12776 L
.70374 .1273 L
.70516 .12684 L
.70655 .12639 L
.70792 .12595 L
Mistroke
.70925 .12552 L
.71057 .1251 L
.71185 .12469 L
.71311 .12428 L
.71434 .12388 L
.71554 .1235 L
.71672 .12312 L
.71788 .12275 L
.71901 .12238 L
.72011 .12203 L
.72118 .12168 L
.72224 .12134 L
.72326 .12101 L
.72427 .12069 L
.72524 .12038 L
.72619 .12007 L
.72712 .11977 L
.72803 .11948 L
.7289 .1192 L
.72976 .11893 L
.73059 .11866 L
.7314 .1184 L
.73218 .11815 L
.73294 .11791 L
.73367 .11767 L
.73438 .11744 L
.73507 .11722 L
.73573 .11701 L
.73637 .1168 L
.73699 .1166 L
.73758 .11641 L
.73815 .11623 L
.7387 .11606 L
.73923 .11589 L
.73973 .11573 L
.7402 .11557 L
.74066 .11543 L
.74109 .11529 L
.7415 .11516 L
.74189 .11503 L
.74225 .11492 L
.74259 .11481 L
.74291 .11471 L
.7432 .11461 L
.74347 .11452 L
.74372 .11444 L
.74395 .11437 L
.74416 .11431 L
.74434 .11425 L
.7445 .1142 L
Mistroke
.74463 .11415 L
.74475 .11412 L
.74484 .11409 L
.74491 .11406 L
.74496 .11405 L
.74498 .11404 L
.74498 .11404 L
.74496 .11405 L
.74492 .11406 L
.74485 .11408 L
.74476 .11411 L
.74465 .11415 L
.74452 .11419 L
.74437 .11424 L
.74419 .1143 L
.74399 .11436 L
.74376 .11443 L
.74352 .11451 L
.74325 .1146 L
.74296 .11469 L
.74264 .11479 L
.74231 .1149 L
.74195 .11501 L
.74157 .11514 L
.74116 .11527 L
.74073 .1154 L
.74028 .11555 L
.73981 .1157 L
.73931 .11586 L
.73879 .11603 L
.73825 .1162 L
.73769 .11638 L
.7371 .11657 L
.73648 .11677 L
.73585 .11697 L
.73519 .11718 L
.73451 .1174 L
.7338 .11763 L
.73307 .11786 L
.73232 .1181 L
.73154 .11835 L
.73074 .11861 L
.72992 .11887 L
.72907 .11915 L
.7282 .11943 L
.7273 .11972 L
.72638 .12001 L
.72543 .12032 L
.72446 .12063 L
.72347 .12095 L
Mistroke
.72245 .12127 L
.7214 .12161 L
.72034 .12195 L
.71924 .12231 L
.71812 .12267 L
.71698 .12303 L
.71581 .12341 L
.71461 .1238 L
.71339 .12419 L
.71214 .12459 L
.71086 .125 L
.70956 .12542 L
.70823 .12585 L
.70688 .12628 L
.7055 .12673 L
.70409 .12718 L
.70266 .12765 L
.70119 .12812 L
.6997 .1286 L
.69818 .12909 L
.69664 .12959 L
.69506 .1301 L
.69346 .13061 L
.69183 .13114 L
.69016 .13168 L
.68847 .13222 L
.68675 .13278 L
.685 .13335 L
.68322 .13392 L
.68141 .13451 L
.67956 .1351 L
.67769 .13571 L
.67578 .13633 L
.67384 .13696 L
.67187 .13759 L
.66987 .13824 L
.66784 .1389 L
.66577 .13957 L
.66366 .14026 L
.66152 .14095 L
.65935 .14166 L
.65714 .14237 L
.6549 .1431 L
.65262 .14385 L
.6503 .1446 L
.64794 .14537 L
.64555 .14615 L
.64312 .14694 L
.64064 .14774 L
.63813 .14856 L
Mistroke
.63558 .1494 L
.63299 .15024 L
.63035 .1511 L
.62767 .15198 L
.62495 .15287 L
.62218 .15378 L
.61937 .1547 L
.61651 .15563 L
.6136 .15659 L
.61064 .15756 L
.60764 .15855 L
.60458 .15955 L
.60147 .16057 L
.59831 .16161 L
.59509 .16267 L
.59182 .16375 L
.58849 .16485 L
.5851 .16597 L
.58165 .16712 L
.57814 .16828 L
.57456 .16947 L
.57091 .17068 L
.5672 .17191 L
.56342 .17317 L
.55956 .17445 L
.55563 .17577 L
.55163 .17711 L
.54754 .17848 L
.54336 .17988 L
.5391 .18131 L
.53475 .18277 L
.5303 .18427 L
.52576 .18581 L
.52111 .18738 L
.51635 .189 L
.51148 .19066 L
.5065 .19236 L
.50138 .19411 L
.49614 .19591 L
.49076 .19776 L
.48523 .19967 L
.47955 .20164 L
.4737 .20368 L
.46768 .20579 L
.46147 .20797 L
.45506 .21024 L
.44843 .2126 L
.44157 .21505 L
.43446 .21761 L
.42707 .2203 L
Mistroke
.41939 .22312 L
.41137 .22609 L
.403 .22923 L
.39422 .23256 L
.38499 .23612 L
.37526 .23995 L
.36497 .24409 L
.35402 .24861 L
.34232 .25361 L
.32976 .25921 L
.31619 .26561 L
.30145 .27313 L
.28538 .28233 L
.27198 .29423 L
.27278 .30989 L
.2737 .32498 L
.28927 .34287 L
.30859 .3546 L
.32566 .36339 L
.34082 .37055 L
.35447 .37665 L
.36694 .38201 L
.37845 .3868 L
.38915 .39116 L
.39917 .39516 L
.40861 .39888 L
.41754 .40235 L
.42602 .40561 L
.43411 .40869 L
.44184 .41161 L
.44925 .41439 L
.45637 .41705 L
.46322 .41959 L
.46984 .42203 L
.47622 .42437 L
.4824 .42663 L
.48839 .42881 L
.49419 .43092 L
.49983 .43296 L
.50531 .43494 L
.51064 .43686 L
.51583 .43872 L
.52089 .44053 L
.52582 .44229 L
.53063 .44401 L
.53533 .44568 L
.53992 .44731 L
.54441 .4489 L
.5488 .45045 L
.55309 .45197 L
Mistroke
.55729 .45346 L
.56141 .45491 L
.56544 .45632 L
.56939 .45771 L
.57326 .45907 L
.57706 .4604 L
.58078 .46171 L
.58443 .46299 L
.58802 .46424 L
.59153 .46547 L
.59499 .46668 L
.59838 .46786 L
.60171 .46902 L
.60498 .47016 L
.6082 .47128 L
.61136 .47238 L
.61446 .47345 L
.61751 .47451 L
.62051 .47556 L
.62346 .47658 L
.62636 .47758 L
.62921 .47857 L
.63202 .47954 L
.63478 .48049 L
.63749 .48143 L
.64016 .48235 L
.64278 .48326 L
.64536 .48415 L
.6479 .48503 L
.6504 .48589 L
.65285 .48674 L
.65527 .48757 L
.65765 .48839 L
.65999 .48919 L
.66229 .48999 L
.66455 .49076 L
.66678 .49153 L
.66897 .49228 L
.67112 .49302 L
.67324 .49375 L
.67533 .49447 L
.67738 .49517 L
.67939 .49586 L
.68138 .49654 L
.68332 .49721 L
.68524 .49787 L
.68713 .49852 L
.68898 .49915 L
.6908 .49978 L
.69259 .50039 L
Mistroke
.69435 .50099 L
.69608 .50158 L
.69777 .50216 L
.69944 .50274 L
.70108 .5033 L
.70269 .50385 L
.70427 .50439 L
.70582 .50492 L
.70734 .50544 L
.70883 .50595 L
.7103 .50645 L
.71173 .50694 L
.71314 .50742 L
.71453 .50789 L
.71588 .50836 L
.71721 .50881 L
.71851 .50925 L
.71978 .50969 L
.72103 .51011 L
.72225 .51053 L
.72344 .51094 L
.72461 .51134 L
.72575 .51173 L
.72687 .51211 L
.72796 .51248 L
.72903 .51284 L
.73007 .5132 L
.73108 .51354 L
.73207 .51388 L
.73304 .51421 L
.73398 .51453 L
.73489 .51484 L
.73578 .51515 L
.73665 .51544 L
.73749 .51573 L
.73831 .51601 L
.7391 .51628 L
.73987 .51654 L
.74062 .51679 L
.74134 .51704 L
.74204 .51728 L
.74271 .51751 L
.74336 .51773 L
.74399 .51794 L
.74459 .51814 L
.74517 .51834 L
.74572 .51853 L
.74626 .51871 L
.74676 .51889 L
.74725 .51905 L
Mistroke
.74771 .51921 L
.74815 .51936 L
.74857 .5195 L
.74896 .51963 L
.74933 .51976 L
.74968 .51988 L
.75 .51999 L
.7503 .52009 L
.75058 .52018 L
.75084 .52027 L
.75107 .52035 L
.75128 .52042 L
.75147 .52049 L
.75163 .52054 L
.75177 .52059 L
.75189 .52063 L
.75199 .52066 L
.75206 .52069 L
.75211 .52071 L
.75214 .52072 L
.75215 .52072 L
.75213 .52071 L
.75209 .5207 L
.75203 .52068 L
.75194 .52065 L
.75183 .52061 L
.7517 .52057 L
.75155 .52051 L
.75137 .52045 L
.75117 .52039 L
.75095 .52031 L
.75071 .52023 L
.75044 .52014 L
.75015 .52004 L
.74984 .51993 L
.7495 .51982 L
.74914 .5197 L
.74876 .51957 L
.74836 .51943 L
.74793 .51928 L
.74748 .51913 L
.747 .51897 L
.74651 .5188 L
.74599 .51862 L
.74544 .51844 L
.74488 .51824 L
.74429 .51804 L
.74367 .51783 L
.74303 .51762 L
.74237 .51739 L
Mistroke
.74169 .51716 L
.74098 .51692 L
.74025 .51667 L
.73949 .51641 L
.73871 .51614 L
.73791 .51587 L
.73708 .51559 L
.73623 .5153 L
.73535 .515 L
.73445 .51469 L
.73353 .51438 L
.73258 .51405 L
.7316 .51372 L
.7306 .51338 L
.72958 .51303 L
.72853 .51267 L
.72745 .51231 L
.72635 .51193 L
.72522 .51155 L
.72407 .51115 L
.72289 .51075 L
.72169 .51034 L
.72046 .50992 L
.71921 .50949 L
.71792 .50905 L
.71661 .50861 L
.71528 .50815 L
.71392 .50769 L
.71253 .50721 L
.71111 .50673 L
.70967 .50623 L
.70819 .50573 L
.70669 .50522 L
.70516 .5047 L
.70361 .50416 L
.70202 .50362 L
.70041 .50307 L
.69876 .50251 L
.69709 .50193 L
.69539 .50135 L
.69365 .50076 L
.69189 .50015 L
.6901 .49954 L
.68827 .49891 L
.68641 .49828 L
.68453 .49763 L
.68261 .49697 L
.68065 .4963 L
.67867 .49562 L
.67665 .49493 L
Mistroke
.6746 .49422 L
.67251 .49351 L
.67039 .49278 L
.66824 .49204 L
.66605 .49128 L
.66382 .49052 L
.66156 .48974 L
.65926 .48895 L
.65693 .48815 L
.65455 .48733 L
.65214 .4865 L
.64969 .48565 L
.64719 .48479 L
.64466 .48392 L
.64209 .48303 L
.63947 .48213 L
.63681 .48121 L
.63411 .48027 L
.63136 .47932 L
.62857 .47836 L
.62573 .47737 L
.62285 .47638 L
.61991 .47536 L
.61693 .47432 L
.61389 .47327 L
.61081 .4722 L
.60767 .47111 L
.60448 .47 L
.60123 .46887 L
.59792 .46772 L
.59456 .46654 L
.59114 .46535 L
.58765 .46413 L
.5841 .46289 L
.58049 .46163 L
.5768 .46034 L
.57305 .45902 L
.56923 .45768 L
.56533 .45631 L
.56135 .45491 L
.55729 .45349 L
.55315 .45203 L
.54893 .45054 L
.54461 .44901 L
.54021 .44745 L
.5357 .44585 L
.53109 .44421 L
.52638 .44254 L
.52156 .44082 L
.51661 .43905 L
Mistroke
.51155 .43724 L
.50636 .43538 L
.50103 .43346 L
.49556 .43149 L
.48993 .42945 L
.48415 .42735 L
.47819 .42518 L
.47204 .42294 L
.4657 .42061 L
.45915 .4182 L
.45237 .41569 L
.44534 .41307 L
.43804 .41034 L
.43044 .40748 L
.42252 .40447 L
.41424 .4013 L
.40557 .39795 L
.39644 .39438 L
.38681 .39057 L
.3766 .38647 L
.36572 .38202 L
.35406 .37714 L
.34146 .37172 L
.32773 .36559 L
.31257 .35851 L
.29554 .35 L
.27587 .33914 L
.27188 .32432 L
.27275 .30777 L
.27406 .29146 L
.29068 .274 L
.30991 .26256 L
.32686 .2539 L
.34192 .24683 L
.3555 .24078 L
.3679 .23547 L
.37935 .23071 L
.39001 .22637 L
.39999 .22239 L
.40939 .21869 L
.41829 .21523 L
.42675 .21198 L
.43481 .20891 L
.44252 .20599 L
.44991 .20322 L
.45702 .20057 L
.46386 .19803 L
.47045 .1956 L
.47683 .19326 L
.483 .191 L
Mistroke
.48897 .18882 L
.49477 .18671 L
.5004 .18468 L
.50587 .1827 L
.51119 .18078 L
.51638 .17892 L
.52143 .17711 L
.52635 .17535 L
.53116 .17364 L
.53585 .17196 L
.54044 .17033 L
.54492 .16874 L
.54931 .16719 L
.5536 .16567 L
.55779 .16419 L
.56191 .16274 L
.56593 .16132 L
.56988 .15993 L
.57375 .15857 L
.57754 .15724 L
.58126 .15593 L
.58491 .15465 L
.5885 .1534 L
.59201 .15217 L
.59547 .15096 L
.59886 .14978 L
.60219 .14862 L
.60546 .14748 L
.60867 .14636 L
.61183 .14526 L
.61494 .14418 L
.61799 .14312 L
.62099 .14208 L
.62394 .14106 L
.62683 .14005 L
.62969 .13906 L
.63249 .13809 L
.63525 .13714 L
.63796 .1362 L
.64063 .13527 L
.64325 .13437 L
.64583 .13347 L
.64837 .1326 L
.65087 .13173 L
.65333 .13089 L
.65574 .13005 L
.65812 .12923 L
.66046 .12843 L
.66276 .12763 L
.66503 .12685 L
Mistroke
.66726 .12609 L
.66945 .12533 L
.6716 .12459 L
.67372 .12386 L
.67581 .12314 L
.67786 .12244 L
.67988 .12175 L
.68186 .12106 L
.68381 .12039 L
.68573 .11974 L
.68761 .11909 L
.68947 .11845 L
.69129 .11783 L
.69308 .11721 L
.69484 .11661 L
.69657 .11602 L
.69827 .11543 L
.69994 .11486 L
.70158 .1143 L
.70319 .11375 L
.70477 .11321 L
.70632 .11268 L
.70785 .11215 L
.70934 .11164 L
.71081 .11114 L
.71225 .11065 L
.71366 .11017 L
.71504 .10969 L
.7164 .10923 L
.71773 .10877 L
.71903 .10833 L
.72031 .10789 L
.72155 .10747 L
.72278 .10705 L
.72397 .10664 L
.72514 .10624 L
.72629 .10585 L
.72741 .10547 L
.7285 .10509 L
.72957 .10473 L
.73061 .10437 L
.73163 .10402 L
.73262 .10369 L
.73359 .10336 L
.73453 .10303 L
.73545 .10272 L
.73634 .10242 L
.73721 .10212 L
.73806 .10183 L
.73888 .10155 L
Mistroke
.73967 .10128 L
.74044 .10102 L
.74119 .10076 L
.74192 .10052 L
.74262 .10028 L
.74329 .10005 L
.74394 .09982 L
.74457 .09961 L
.74518 .0994 L
.74576 .09921 L
.74632 .09901 L
.74686 .09883 L
.74737 .09866 L
.74786 .09849 L
.74832 .09833 L
.74876 .09818 L
.74918 .09804 L
.74958 .0979 L
.74995 .09778 L
.7503 .09766 L
.75063 .09755 L
.75093 .09744 L
.75122 .09735 L
.75148 .09726 L
.75171 .09718 L
.75192 .09711 L
.75212 .09704 L
.75228 .09698 L
.75243 .09693 L
.75255 .09689 L
.75265 .09686 L
.75273 .09683 L
.75278 .09681 L
.75281 .0968 L
.75282 .0968 L
.75281 .0968 L
.75277 .09682 L
.75271 .09684 L
.75263 .09686 L
.75253 .0969 L
.7524 .09694 L
.75225 .09699 L
.75208 .09705 L
.75188 .09712 L
.75167 .09719 L
.75143 .09728 L
.75116 .09737 L
.75088 .09746 L
.75057 .09757 L
.75024 .09768 L
Mistroke
.74988 .0978 L
.7495 .09793 L
.7491 .09807 L
.74868 .09821 L
.74823 .09836 L
.74776 .09852 L
.74727 .09869 L
.74675 .09887 L
.74622 .09905 L
.74565 .09924 L
.74507 .09944 L
.74446 .09965 L
.74383 .09986 L
.74317 .10009 L
.74249 .10032 L
.74179 .10056 L
.74106 .10081 L
.74031 .10106 L
.73953 .10133 L
.73873 .1016 L
.73791 .10188 L
.73706 .10217 L
.73619 .10247 L
.7353 .10277 L
.73438 .10309 L
.73343 .10341 L
.73246 .10374 L
.73147 .10408 L
.73045 .10443 L
.7294 .10478 L
.72833 .10515 L
.72724 .10552 L
.72612 .10591 L
.72497 .1063 L
.7238 .1067 L
.72261 .10711 L
.72138 .10752 L
.72013 .10795 L
.71886 .10839 L
.71755 .10883 L
.71623 .10929 L
.71487 .10975 L
.71349 .11022 L
.71208 .1107 L
.71064 .1112 L
.70917 .1117 L
.70768 .11221 L
.70616 .11273 L
.70461 .11326 L
.70303 .1138 L
Mistroke
.70142 .11435 L
.69979 .11491 L
.69812 .11548 L
.69643 .11606 L
.6947 .11665 L
.69295 .11726 L
.69116 .11787 L
.68935 .11849 L
.6875 .11912 L
.68562 .11977 L
.68371 .12043 L
.68176 .12109 L
.67979 .12177 L
.67778 .12246 L
.67574 .12316 L
.67366 .12388 L
.67155 .1246 L
.66941 .12534 L
.66723 .12609 L
.66501 .12685 L
.66276 .12763 L
.66047 .12842 L
.65815 .12922 L
.65579 .13003 L
.65339 .13086 L
.65094 .1317 L
.64846 .13256 L
.64594 .13343 L
.64338 .13431 L
.64078 .13521 L
.63814 .13613 L
.63545 .13706 L
.63271 .138 L
.62994 .13896 L
.62711 .13994 L
.62424 .14094 L
.62132 .14195 L
.61836 .14298 L
.61534 .14403 L
.61227 .14509 L
.60915 .14618 L
.60598 .14728 L
.60275 .14841 L
.59946 .14955 L
.59612 .15072 L
.59271 .15191 L
.58925 .15312 L
.58572 .15435 L
.58213 .15561 L
.57847 .15689 L
Mistroke
.57474 .1582 L
.57094 .15953 L
.56707 .16089 L
.56312 .16228 L
.5591 .1637 L
.55499 .16515 L
.55079 .16663 L
.54651 .16815 L
.54214 .1697 L
.53767 .17128 L
.5331 .1729 L
.52842 .17457 L
.52364 .17627 L
.51874 .17802 L
.51373 .17982 L
.50858 .18167 L
.50331 .18356 L
.49789 .18552 L
.49232 .18753 L
.4866 .18961 L
.4807 .19175 L
.47463 .19397 L
.46837 .19627 L
.46189 .19865 L
.4552 .20112 L
.44827 .2037 L
.44107 .20639 L
.4336 .2092 L
.4258 .21215 L
.41766 .21526 L
.40914 .21854 L
.4002 .22202 L
.39076 .22573 L
.38079 .22972 L
.37018 .23403 L
.35883 .23873 L
.34661 .24393 L
.33334 .24976 L
.31876 .25644 L
.30252 .26431 L
.28401 .27407 L
.27092 .2864 L
.27264 .30137 L
.2726 .31571 L
.27966 .3314 L
.29685 .34535 L
.31443 .35548 L
.3303 .36347 L
.34461 .37013 L
.35763 .37587 L
Mistroke
.36962 .38095 L
.38073 .38553 L
.39111 .38971 L
.40086 .39356 L
.41007 .39715 L
.4188 .4005 L
.42711 .40366 L
.43504 .40665 L
.44263 .40948 L
.44992 .41218 L
.45692 .41476 L
.46367 .41723 L
.47019 .4196 L
.47649 .42188 L
.48258 .42408 L
.48849 .42621 L
.49423 .42826 L
.49979 .43025 L
.50521 .43218 L
.51048 .43405 L
.51561 .43586 L
.52062 .43763 L
.5255 .43935 L
.53026 .44102 L
.53491 .44266 L
.53945 .44425 L
.5439 .4458 L
.54824 .44732 L
.5525 .4488 L
.55666 .45024 L
.56073 .45166 L
.56473 .45305 L
.56864 .4544 L
.57248 .45573 L
.57624 .45703 L
.57993 .4583 L
.58355 .45955 L
.58711 .46078 L
.59059 .46198 L
.59402 .46315 L
.59738 .46431 L
.60069 .46544 L
.60393 .46656 L
.60712 .46765 L
.61025 .46872 L
.61333 .46977 L
.61636 .47081 L
.61933 .47182 L
.62225 .47282 L
.62513 .4738 L
Mistroke
.62796 .47477 L
.63074 .47572 L
.63347 .47665 L
.63616 .47756 L
.63881 .47846 L
.64141 .47935 L
.64397 .48022 L
.64648 .48107 L
.64896 .48191 L
.65139 .48274 L
.65379 .48355 L
.65615 .48435 L
.65847 .48514 L
.66075 .48591 L
.66299 .48667 L
.6652 .48742 L
.66737 .48815 L
.6695 .48887 L
.6716 .48958 L
.67367 .49028 L
.6757 .49097 L
.67769 .49164 L
.67966 .49231 L
.68159 .49296 L
.68349 .4936 L
.68535 .49423 L
.68719 .49485 L
.68899 .49545 L
.69076 .49605 L
.6925 .49664 L
.69421 .49721 L
.69589 .49778 L
.69754 .49834 L
.69916 .49888 L
.70075 .49942 L
.70232 .49994 L
.70385 .50046 L
.70535 .50097 L
.70683 .50146 L
.70828 .50195 L
.7097 .50243 L
.71109 .5029 L
.71246 .50335 L
.7138 .5038 L
.71511 .50425 L
.71639 .50468 L
.71765 .5051 L
.71888 .50551 L
.72008 .50592 L
.72126 .50631 L
Mistroke
.72241 .5067 L
.72354 .50708 L
.72464 .50745 L
.72572 .50781 L
.72677 .50816 L
.72779 .5085 L
.72879 .50884 L
.72976 .50917 L
.73071 .50948 L
.73164 .50979 L
.73254 .5101 L
.73341 .51039 L
.73426 .51067 L
.73509 .51095 L
.73589 .51122 L
.73667 .51148 L
.73742 .51173 L
.73815 .51198 L
.73886 .51221 L
.73954 .51244 L
.7402 .51266 L
.74083 .51288 L
.74144 .51308 L
.74203 .51328 L
.74259 .51347 L
.74313 .51365 L
.74365 .51382 L
.74414 .51398 L
.74461 .51414 L
.74506 .51429 L
.74549 .51443 L
.74589 .51457 L
.74626 .51469 L
.74662 .51481 L
.74695 .51492 L
.74726 .51503 L
.74755 .51512 L
.74781 .51521 L
.74805 .51529 L
.74827 .51537 L
.74846 .51543 L
.74863 .51549 L
.74878 .51554 L
.74891 .51558 L
.74901 .51561 L
.74909 .51564 L
.74915 .51566 L
.74919 .51567 L
.7492 .51568 L
.74919 .51567 L
Mistroke
.74916 .51566 L
.7491 .51564 L
.74902 .51562 L
.74892 .51558 L
.7488 .51554 L
.74865 .51549 L
.74848 .51544 L
.74829 .51537 L
.74808 .5153 L
.74784 .51522 L
.74758 .51513 L
.7473 .51504 L
.74699 .51494 L
.74666 .51483 L
.74631 .51471 L
.74593 .51458 L
.74554 .51445 L
.74511 .51431 L
.74467 .51416 L
.7442 .514 L
.74371 .51384 L
.7432 .51367 L
.74266 .51349 L
.7421 .5133 L
.74152 .51311 L
.74091 .5129 L
.74028 .51269 L
.73963 .51247 L
.73895 .51225 L
.73825 .51201 L
.73752 .51177 L
.73677 .51152 L
.736 .51126 L
.7352 .51099 L
.73438 .51071 L
.73354 .51043 L
.73267 .51014 L
.73177 .50984 L
.73085 .50953 L
.72991 .50922 L
.72894 .50889 L
.72795 .50856 L
.72693 .50822 L
.72589 .50787 L
.72482 .50751 L
.72373 .50714 L
.72261 .50676 L
.72146 .50638 L
.72029 .50599 L
.71909 .50559 L
Mistroke
.71787 .50517 L
.71662 .50476 L
.71535 .50433 L
.71404 .50389 L
.71271 .50344 L
.71136 .50299 L
.70998 .50252 L
.70857 .50205 L
.70713 .50156 L
.70566 .50107 L
.70417 .50057 L
.70265 .50006 L
.7011 .49953 L
.69952 .499 L
.69791 .49846 L
.69627 .49791 L
.6946 .49735 L
.69291 .49678 L
.69118 .4962 L
.68942 .4956 L
.68764 .495 L
.68582 .49439 L
.68397 .49376 L
.68209 .49313 L
.68017 .49248 L
.67823 .49183 L
.67625 .49116 L
.67424 .49048 L
.67219 .48979 L
.67012 .48909 L
.668 .48837 L
.66585 .48764 L
.66367 .4869 L
.66145 .48615 L
.6592 .48539 L
.6569 .48461 L
.65457 .48382 L
.65221 .48302 L
.6498 .4822 L
.64735 .48137 L
.64487 .48053 L
.64234 .47967 L
.63977 .4788 L
.63716 .47791 L
.63451 .47701 L
.63182 .47609 L
.62908 .47516 L
.62629 .47421 L
.62346 .47324 L
.62058 .47226 L
Mistroke
.61765 .47126 L
.61467 .47025 L
.61165 .46921 L
.60857 .46816 L
.60544 .46709 L
.60225 .466 L
.59901 .46488 L
.59571 .46375 L
.59235 .4626 L
.58893 .46143 L
.58546 .46023 L
.58191 .45901 L
.5783 .45776 L
.57463 .4565 L
.57088 .4552 L
.56706 .45388 L
.56317 .45253 L
.5592 .45116 L
.55515 .44975 L
.55102 .44832 L
.5468 .44685 L
.54249 .44535 L
.53809 .44381 L
.53359 .44224 L
.52899 .44062 L
.52429 .43897 L
.51947 .43728 L
.51454 .43554 L
.50948 .43375 L
.5043 .43192 L
.49898 .43003 L
.49351 .42808 L
.48789 .42607 L
.48212 .424 L
.47617 .42186 L
.47003 .41965 L
.4637 .41735 L
.45716 .41497 L
.45039 .41249 L
.44337 .40991 L
.43609 .40721 L
.42851 .40438 L
.42061 .40141 L
.41235 .39827 L
.4037 .39495 L
.3946 .39142 L
.385 .38765 L
.37484 .38358 L
.36402 .37917 L
.35243 .37432 L
Mistroke
.33994 .36894 L
.32636 .36286 L
.31141 .35581 L
.29475 .34736 L
.27574 .33659 L
.27226 .32148 L
.27278 .30665 L
.27528 .29183 L
.29076 .27558 L
.30931 .2643 L
.32597 .25569 L
.34089 .24864 L
.35438 .24261 L
.36673 .23732 L
.37815 .23257 L
.38878 .22826 L
.39874 .22429 L
.40814 .22061 L
.41703 .21716 L
.42548 .21393 L
.43355 .21088 L
.44126 .20798 L
.44865 .20522 L
.45575 .20259 L
.46259 .20007 L
.46919 .19765 L
.47556 .19533 L
.48173 .19309 L
.48771 .19092 L
.49351 .18883 L
.49914 .18681 L
.50461 .18485 L
.50994 .18295 L
.51513 .1811 L
.52018 .1793 L
.52511 .17756 L
.52992 .17586 L
.53461 .1742 L
.5392 .17258 L
.54369 .171 L
.54807 .16946 L
.55236 .16796 L
.55657 .16648 L
.56068 .16505 L
.56471 .16364 L
.56866 .16226 L
.57253 .16091 L
.57633 .15959 L
.58005 .1583 L
.58371 .15703 L
Mistroke
.58729 .15579 L
.59081 .15457 L
.59427 .15337 L
.59766 .1522 L
.60099 .15104 L
.60427 .14991 L
.60748 .1488 L
.61065 .14771 L
.61375 .14664 L
.61681 .14559 L
.61981 .14456 L
.62276 .14354 L
.62566 .14255 L
.62852 .14157 L
.63133 .1406 L
.63409 .13966 L
.6368 .13873 L
.63947 .13781 L
.6421 .13691 L
.64468 .13603 L
.64723 .13516 L
.64973 .1343 L
.65219 .13346 L
.65461 .13263 L
.65699 .13182 L
.65933 .13102 L
.66164 .13023 L
.66391 .12946 L
.66614 .1287 L
.66833 .12795 L
.67049 .12722 L
.67262 .12649 L
.67471 .12578 L
.67676 .12508 L
.67878 .12439 L
.68077 .12372 L
.68272 .12305 L
.68465 .1224 L
.68654 .12176 L
.68839 .12113 L
.69022 .12051 L
.69201 .1199 L
.69378 .1193 L
.69551 .11871 L
.69722 .11813 L
.69889 .11756 L
.70053 .11701 L
.70215 .11646 L
.70373 .11592 L
.70529 .11539 L
Mistroke
.70682 .11488 L
.70832 .11437 L
.70979 .11387 L
.71123 .11338 L
.71265 .1129 L
.71403 .11243 L
.7154 .11197 L
.71673 .11152 L
.71804 .11108 L
.71932 .11064 L
.72057 .11022 L
.7218 .1098 L
.723 .1094 L
.72418 .109 L
.72532 .10861 L
.72645 .10823 L
.72755 .10786 L
.72862 .1075 L
.72967 .10714 L
.73069 .1068 L
.73169 .10646 L
.73266 .10613 L
.73361 .10581 L
.73453 .1055 L
.73543 .1052 L
.7363 .1049 L
.73715 .10462 L
.73798 .10434 L
.73878 .10407 L
.73956 .1038 L
.74031 .10355 L
.74104 .1033 L
.74175 .10307 L
.74243 .10283 L
.74309 .10261 L
.74372 .1024 L
.74433 .10219 L
.74492 .10199 L
.74548 .1018 L
.74603 .10162 L
.74654 .10145 L
.74704 .10128 L
.74751 .10112 L
.74796 .10097 L
.74838 .10083 L
.74879 .10069 L
.74917 .10056 L
.74952 .10044 L
.74986 .10033 L
.75017 .10022 L
Mistroke
.75046 .10013 L
.75072 .10004 L
.75096 .09996 L
.75118 .09988 L
.75138 .09982 L
.75156 .09976 L
.75171 .09971 L
.75184 .09966 L
.75194 .09963 L
.75203 .0996 L
.75209 .09958 L
.75213 .09956 L
.75214 .09956 L
.75214 .09956 L
.75211 .09957 L
.75206 .09959 L
.75198 .09961 L
.75189 .09965 L
.75177 .09969 L
.75162 .09973 L
.75146 .09979 L
.75127 .09985 L
.75106 .09992 L
.75083 .1 L
.75057 .10009 L
.7503 .10018 L
.75 .10028 L
.74967 .10039 L
.74933 .10051 L
.74896 .10063 L
.74856 .10077 L
.74815 .10091 L
.74771 .10105 L
.74725 .10121 L
.74677 .10137 L
.74626 .10154 L
.74573 .10172 L
.74518 .10191 L
.7446 .1021 L
.744 .1023 L
.74338 .10252 L
.74273 .10273 L
.74206 .10296 L
.74136 .10319 L
.74065 .10344 L
.73991 .10369 L
.73914 .10394 L
.73835 .10421 L
.73754 .10449 L
.7367 .10477 L
Mistroke
.73584 .10506 L
.73495 .10536 L
.73404 .10566 L
.73311 .10598 L
.73215 .1063 L
.73117 .10664 L
.73016 .10698 L
.72913 .10733 L
.72807 .10768 L
.72698 .10805 L
.72588 .10842 L
.72474 .10881 L
.72358 .1092 L
.7224 .1096 L
.72118 .11001 L
.71995 .11043 L
.71868 .11086 L
.71739 .11129 L
.71608 .11174 L
.71473 .11219 L
.71336 .11266 L
.71197 .11313 L
.71054 .11361 L
.70909 .1141 L
.70761 .11461 L
.7061 .11512 L
.70457 .11564 L
.703 .11617 L
.70141 .11671 L
.69979 .11726 L
.69814 .11782 L
.69646 .11839 L
.69475 .11897 L
.69301 .11956 L
.69124 .12016 L
.68944 .12077 L
.6876 .12139 L
.68574 .12202 L
.68385 .12267 L
.68192 .12332 L
.67996 .12399 L
.67797 .12467 L
.67595 .12535 L
.67389 .12606 L
.6718 .12677 L
.66967 .12749 L
.66751 .12823 L
.66531 .12898 L
.66308 .12974 L
.66081 .13051 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool001Ioo`<00?moo`Qoo`005goo00<007ooOol0ogoo1goo000DOol50004Ool3003oOol1Ool000io
o`@0009oo`04001oogoo0005Ool00`00Oomoo`3oOol1Ool001Eoo`03001oo`0000Eoo`03001oogoo
0?moo`5oo`005Woo0P001Goo00<007ooOol0ogoo0Goo000MOol2003oOol2Ool001eoo`03001oogoo
0?moo`5oo`007Goo00<007ooOol0ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`800?moo`9o
o`007Goo00<007ooOol0ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5o
o`007Goo00<007ooOol0ogoo0Goo000MOol2003oOol2Ool001eoo`03001oogoo0?moo`5oo`007Goo
00<007ooOol0ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`800?moo`9oo`007Goo00<007oo
Ool0ogoo0Goo000EOol20006Ool00`00Oomoo`3oOol1Ool001Aoo`04001oogoo0005Ool00`00Oomo
o`3oOol1Ool001Ioo`03001oogoo00Aoo`<00?moo`5oo`003Woo10001Goo00<007ooOol00goo00<0
07ooOol0ogoo0Goo000DOol01000Oomoo`001Goo00<007ooOol0ogoo0Goo000EOol20006Ool00`00
Oomoo`3oOol1Ool001eoo`800?moo`9oo`007Goo00<007ooOol0/7oo0P?PCWoo000MOol00`00Oomo
o`2^Ool40n1>Ool001eoo`03001oogoo0:]oo`D3h51oo`007Goo0P00ZGoo1@?PDgoo000MOol00`00
Oomoo`2UOol50n1FOol001eoo`03001oogoo0:9oo`D3h0Ioo`<3h51oo`007Goo00<007ooOol0Wgoo
1@?P1Woo10?PDWoo000MOol00`00Oomoo`2LOol50n06Ool40n1EOol001eoo`8009Yoo`D3h0Ioo`@3
h5Qoo`007Goo00<007ooOol0UWoo1P?P1Goo10?PFgoo000MOol00`00Oomoo`2DOol50n05Ool40n1N
Ool001eoo`03001oogoo095oo`D3h0Eoo`@3h65oo`007Goo0P00Sgoo1@?P1Goo10?PI7oo000MOol0
0`00Oomoo`2;Ool50n05Ool30n1XOol001Aoo`@000Eoo`03001oogoo08Qoo`D3h0Eoo`<3h6]oo`00
57oo00<007ooOol01Woo00<007ooOol0QGoo10?P1Goo10?PKWoo000EOol00`00Oomoo`05Ool30022
Ool50n04Ool40n1aOol000ioo`@000Aoo`03001oogoo00Aoo`03001oogoo07moo`D3h0Aoo`@3h7Ao
o`0057oo00@007ooOol000Eoo`03001oogoo07eoo`@3h0Aoo`@3h7Moo`005Goo0P001Woo00<007oo
Ool0NGoo1P?P0goo10?PNWoo000MOol2001hOol40n04Ool40n1mOol001eoo`03001oogoo07Aoo`D3
h0=oo`@3h81oo`007Goo00<007ooOol0LGoo10?P17oo10?PPgoo000MOol00`00Oomoo`1^Ool50n04
Ool30n26Ool001eoo`8006aoo`D3h0=oo`@3h8Uoo`007Goo00<007ooOol0JGoo10?P0goo10?PS7oo
000MOol00`00Oomoo`1WOol30n04Ool30n2?Ool001eoo`03001oogoo06=oo`H3h09oo`<3h99oo`00
7Goo00<007ooOol0HWoo0`?P0goo0`?PUGoo000MOol2001OOol40n03Ool30n2HOol001eoo`03001o
ogoo05aoo`@3h0=oo`83h9]oo`007Goo00<007ooOol0FWoo10?P0Woo0`?PWGoo000MOol00`00Oomo
o`1GOol30n02Ool40n2POol001eoo`8005Aoo`D3h09oo`@3h:9oo`007Goo00<007ooOol0D7oo1@?P
0goo0P?PYWoo000DOol50004Ool00`00Oomoo`1>Ool40n02Ool40n2XOol001Ioo`03001oogoo00Ao
o`03001oogoo04aoo`@3h003Ool3h0?P0083h:]oo`005Woo00<007ooOol017oo0`00BWoo0`?P0Woo
10?P[Goo000>Ool40004Ool00`00Oomoo`04Ool00`00Oomoo`17Ool40n000goo0n03h0020n2`Ool0
01Ioo`03001oogoo00Aoo`03001oogoo04Eoo`T3h;9oo`005Goo0P001Woo00<007ooOol0@Woo2@?P
]Goo000MOol20011Ool40n0017oo0n03h0?P^7oo000MOol00`00Oomoo`0oOol30n0017oo0n03h0?P
^Woo000MOol00`00Oomoo`0lOol80n2lOol001eoo`03001oogoo03Yoo`L3h;moo`007Goo0P00>Goo
1`?P`Goo000MOol00`00Oomoo`0fOol70n33Ool001eoo`03001oogoo02aoo`@000Aoo`L3h2Eoo`<0
02aoo`<002moo`8002aoo`D0009oo`8000Qoo`007Goo00<007ooOol0;7oo00<007ooOol00goo20?P
9goo00<007ooOol0:goo00@007ooOol002eoo`04001oogoo000]Ool01@00Oomoogoo00000Woo00<0
07ooOol01Goo000MOol00`00Oomoo`0]Ool02`00Oomoogoo0n1oo`?POol3h7oo0n009Woo1@00;7oo
00@007ooOol002eoo`04001oogoo000]Ool01@00Oomoogoo00000Woo00<007ooOol01Goo000MOol2
000_Ool01000Ool3h7oo1@?P9goo00@007ooOol002eoo`<002moo`8002ioo`05001oogooOol00002
Ool00`00Oomoo`05Ool001eoo`03001oogoo02aoo`05001oogoo0n1oo`040n0ZOol00`00Ool0000^
Ool00`00Oomoo`0]Ool01000Oomoo`00;Goo00D007ooOomoo`00009oo`03001oogoo00Eoo`007Goo
00<007ooOol0;Goo00<000?POol00`?P;Goo0P00;Woo0`00;Woo0P00;Goo0P0017oo0P0027oo000M
Ool00`00Oomoo`0^Ool30n000goo0n1oo`3<Ool001eoo`8002moo`83h003Ool3h7oo0<eoo`007Goo
00<007ooOol0;Woo0P?P00=oo`?POol0cGoo000MOol00`00Oomoo`0^Ool00`?POomoo`3?Ool001eo
o`03001oogoo02ioo`030n1oogoo0<moo`0017ooBP0000<3h0000000a0002goo000@Ool00`00Oomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`?POomo
o`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomo
o`09Ool00`00Oomoo`09Ool001eoo`03001oogoo02ioo`83h31oo`03001oogoo02ioo`03001oogoo
02ioo`03001oogoo02moo`03001oogoo00Uoo`007Goo00<007ooOol0;Woo0P?Pd7oo000MOol2000_
Ool20n3@Ool001eoo`03001oogoo02ioo`030n1oo`?P0<moo`007Goo00<007ooOol0;goo0`?PcWoo
000MOol00`00Oomoo`0_Ool00`?POol3h03>Ool001eoo`80031oo`83h003Ool3h0?P0<aoo`007Goo
00<007ooOol0<7oo1@?Pbgoo000MOol00`00Oomoo`0bOol40n3:Ool001eoo`03001oogoo03Aoo`@3
h<Qoo`007Goo00<007ooOol0=Woo10?PaWoo000MOol2000iOol30n35Ool001eoo`03001oogoo03Yo
o`<3h<=oo`007Goo00<007ooOol0?7oo0`?P`Goo000MOol00`00Oomoo`0nOol40n2nOol001eoo`80
045oo`@3h;aoo`007Goo00<007ooOol0@Woo10?P^Woo000DOol50004Ool00`00Oomoo`14Ool50n2g
Ool001Ioo`03001oogoo00Aoo`03001oogoo04Ioo`H3h;Aoo`005Woo00<007ooOol017oo0`00BGoo
1@?P/Woo000FOol00`00Oomoo`04Ool00`00Oomoo`1<Ool50n2_Ool001Ioo`03001oogoo00Aoo`03
001oogoo04moo`@3h:eoo`005Goo0P001Woo00<007ooOol0DGoo10?PZgoo000MOol2001EOol40n2X
Ool001eoo`03001oogoo05Ioo`@3h:Ioo`007Goo00<007ooOol0F7oo1P?PXWoo000MOol00`00Oomo
o`1JOol60n2POol001eoo`8005ioo`H3h9eoo`007Goo00<007ooOol0H7oo1@?PVgoo000MOol00`00
Oomoo`1SOol50n2HOol001eoo`03001oogoo06Eoo`H3h9Eoo`007Goo00<007ooOol0J7oo1P?PTWoo
000MOol2001/Ool60n2?Ool001eoo`03001oogoo06ioo`H3h8aoo`007Goo00<007ooOol0LGoo1@?P
RWoo000MOol00`00Oomoo`1dOol60n26Ool001eoo`8007Qoo`D3h8Aoo`007Goo00<007ooOol0NWoo
1@?PPGoo000DOol40005Ool00`00Oomoo`1mOol50n1nOol001Aoo`03001oogoo00Ioo`03001oogoo
081oo`D3h7]oo`005Goo00<007ooOol01Goo0`00PWoo1P?PN7oo000FOol00`00Oomoo`04Ool00`00
Oomoo`25Ool60n1eOol001Aoo`04001oogoo0005Ool00`00Oomoo`28Ool60n1bOol001Eoo`8000Io
o`03001oogoo08]oo`H3h6moo`007Goo0P00SWoo1`?PK7oo000MOol00`00Oomoo`2@Ool70n1YOol0
01eoo`03001oogoo09=oo`H3h6Moo`007Goo00<007ooOol0UWoo1`?PHgoo000MOol2002JOol60n1Q
Ool001eoo`03001oogoo09aoo`L3h5eoo`007Goo00<007ooOol0Wgoo1`?PFWoo000MOol00`00Oomo
o`2ROol70n1GOol001eoo`03001oogoo0:Eoo`H3h5Eoo`007Goo0P00ZGoo1`?PDGoo000MOol00`00
Oomoo`2[Ool60n1?Ool001eoo`03001oogoo0:eoo`D3h4ioo`007Goo00<007ooOol0/7oo0P?PCWoo
000MOol2003oOol2Ool001eoo`03001oogoo0?moo`5oo`005Goo0P001Woo00<007ooOol0ogoo0Goo
000DOol01000Oomoo`001Goo00<007ooOol0ogoo0Goo000FOol00`00Oomoo`04Ool3003oOol1Ool0
01Moo`03001oogoo00=oo`03001oogoo0?moo`5oo`0057oo00@007ooOol000Eoo`03001oogoo0?mo
o`5oo`005Goo0P001Woo00<007ooOol0ogoo0Goo000MOol2003oOol2Ool001eoo`03001oogoo0?mo
o`5oo`007Goo00<007ooOol0ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`800?moo`9oo`00
7Goo00<007ooOol0ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`03001oogoo0?moo`5oo`00
7Goo00<007ooOol0ogoo0Goo000MOol2003oOol2Ool001eoo`03001oogoo0?moo`5oo`007Goo00<0
07ooOol0ogoo0Goo000MOol00`00Oomoo`3oOol1Ool001eoo`800?moo`9oo`007Goo00<007ooOol0
ogoo0Goo000FOol30004Ool00`00Oomoo`3oOol1Ool001Moo`03001oogoo00=oo`03001oogoo0?mo
o`5oo`0057oo1@0017oo0`00ogoo0Goo000DOol01000Oomoo`00ogoo2Goo000EOol00`00Ool0003o
Ool9Ool001Ioo`800?moo`Uoo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.18768, -4.21441, \
0.0404817, 0.047637}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
tbl2=Chop[Table[{(X[1,t]-X[2,t]),Z[1,t]-Z[2,t]},{t,1,1500}]];\
\>", "Input"],

Cell[CellGroupData[{

Cell["ListPlot[tbl2,PlotJoined->True,PlotStyle->RGBColor[1,1,0]]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.500581 0.173561 0.309017 0.294302 [
[.15346 .29652 -6 -9 ]
[.15346 .29652 6 0 ]
[.32702 .29652 -6 -9 ]
[.32702 .29652 6 0 ]
[.67414 .29652 -3 -9 ]
[.67414 .29652 3 0 ]
[.8477 .29652 -3 -9 ]
[.8477 .29652 3 0 ]
[.48808 .01472 -12 -4.5 ]
[.48808 .01472 0 4.5 ]
[.48808 .16187 -24 -4.5 ]
[.48808 .16187 0 4.5 ]
[.48808 .45617 -18 -4.5 ]
[.48808 .45617 0 4.5 ]
[.48808 .60332 -6 -4.5 ]
[.48808 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15346 .30902 m
.15346 .31527 L
s
[(-2)] .15346 .29652 0 1 Mshowa
.32702 .30902 m
.32702 .31527 L
s
[(-1)] .32702 .29652 0 1 Mshowa
.67414 .30902 m
.67414 .31527 L
s
[(1)] .67414 .29652 0 1 Mshowa
.8477 .30902 m
.8477 .31527 L
s
[(2)] .8477 .29652 0 1 Mshowa
.125 Mabswid
.18817 .30902 m
.18817 .31277 L
s
.22288 .30902 m
.22288 .31277 L
s
.2576 .30902 m
.2576 .31277 L
s
.29231 .30902 m
.29231 .31277 L
s
.36173 .30902 m
.36173 .31277 L
s
.39644 .30902 m
.39644 .31277 L
s
.43116 .30902 m
.43116 .31277 L
s
.46587 .30902 m
.46587 .31277 L
s
.53529 .30902 m
.53529 .31277 L
s
.57001 .30902 m
.57001 .31277 L
s
.60472 .30902 m
.60472 .31277 L
s
.63943 .30902 m
.63943 .31277 L
s
.70885 .30902 m
.70885 .31277 L
s
.74357 .30902 m
.74357 .31277 L
s
.77828 .30902 m
.77828 .31277 L
s
.81299 .30902 m
.81299 .31277 L
s
.11875 .30902 m
.11875 .31277 L
s
.08403 .30902 m
.08403 .31277 L
s
.04932 .30902 m
.04932 .31277 L
s
.01461 .30902 m
.01461 .31277 L
s
.88242 .30902 m
.88242 .31277 L
s
.91713 .30902 m
.91713 .31277 L
s
.95184 .30902 m
.95184 .31277 L
s
.98655 .30902 m
.98655 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.50058 .01472 m
.50683 .01472 L
s
[(-1)] .48808 .01472 1 0 Mshowa
.50058 .16187 m
.50683 .16187 L
s
[(-0.5)] .48808 .16187 1 0 Mshowa
.50058 .45617 m
.50683 .45617 L
s
[(0.5)] .48808 .45617 1 0 Mshowa
.50058 .60332 m
.50683 .60332 L
s
[(1)] .48808 .60332 1 0 Mshowa
.125 Mabswid
.50058 .04415 m
.50433 .04415 L
s
.50058 .07358 m
.50433 .07358 L
s
.50058 .10301 m
.50433 .10301 L
s
.50058 .13244 m
.50433 .13244 L
s
.50058 .1913 m
.50433 .1913 L
s
.50058 .22073 m
.50433 .22073 L
s
.50058 .25016 m
.50433 .25016 L
s
.50058 .27959 m
.50433 .27959 L
s
.50058 .33845 m
.50433 .33845 L
s
.50058 .36788 m
.50433 .36788 L
s
.50058 .39731 m
.50433 .39731 L
s
.50058 .42674 m
.50433 .42674 L
s
.50058 .4856 m
.50433 .4856 L
s
.50058 .51503 m
.50433 .51503 L
s
.50058 .54446 m
.50433 .54446 L
s
.50058 .57389 m
.50433 .57389 L
s
.25 Mabswid
.50058 0 m
.50058 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 1 0 r
.5 Mabswid
.47333 .30902 m
.44535 .30902 L
.42184 .30902 L
.40288 .30902 L
.38709 .30902 L
.37356 .30902 L
.36169 .30902 L
.35108 .30902 L
.34147 .30902 L
.33264 .30902 L
.32448 .30902 L
.31687 .30902 L
.30974 .30902 L
.30302 .30902 L
.29665 .30902 L
.2906 .30902 L
.28484 .30902 L
.27933 .30902 L
.27404 .30902 L
.26897 .30902 L
.26408 .30902 L
.25938 .30902 L
.25483 .30902 L
.25043 .30902 L
.24617 .30902 L
.24204 .30902 L
.23804 .30902 L
.23414 .30902 L
.23036 .30902 L
.22667 .30902 L
.22308 .30902 L
.21959 .30902 L
.21618 .30902 L
.21285 .30902 L
.2096 .30902 L
.20642 .30902 L
.20332 .30902 L
.20028 .30902 L
.19731 .30902 L
.1944 .30902 L
.19155 .30902 L
.18877 .30902 L
.18603 .30902 L
.18336 .30902 L
.18073 .30902 L
.17816 .30902 L
.17563 .30902 L
.17315 .30902 L
.17072 .30902 L
.16833 .30902 L
Mistroke
.16599 .30902 L
.16369 .30902 L
.16143 .30902 L
.15921 .30902 L
.15703 .30902 L
.15489 .30902 L
.15278 .30902 L
.15071 .30902 L
.14868 .30902 L
.14668 .30902 L
.14472 .30902 L
.14279 .30902 L
.14089 .30902 L
.13902 .30902 L
.13719 .30902 L
.13538 .30902 L
.13361 .30902 L
.13186 .30902 L
.13015 .30902 L
.12846 .30902 L
.1268 .30902 L
.12517 .30902 L
.12356 .30902 L
.12199 .30902 L
.12044 .30902 L
.11891 .30902 L
.11741 .30902 L
.11594 .30902 L
.11449 .30902 L
.11306 .30902 L
.11166 .30902 L
.11028 .30902 L
.10893 .30902 L
.1076 .30902 L
.1063 .30902 L
.10501 .30902 L
.10375 .30902 L
.10251 .30902 L
.10129 .30902 L
.1001 .30902 L
.09893 .30902 L
.09777 .30902 L
.09664 .30902 L
.09553 .30902 L
.09444 .30902 L
.09338 .30902 L
.09233 .30902 L
.0913 .30902 L
.09029 .30902 L
.0893 .30902 L
Mistroke
.08834 .30902 L
.08739 .30902 L
.08646 .30902 L
.08555 .30902 L
.08466 .30902 L
.08379 .30902 L
.08293 .30902 L
.0821 .30902 L
.08128 .30902 L
.08049 .30902 L
.07971 .30902 L
.07895 .30902 L
.07821 .30902 L
.07748 .30902 L
.07678 .30902 L
.07609 .30902 L
.07542 .30902 L
.07477 .30902 L
.07414 .30902 L
.07352 .30902 L
.07292 .30902 L
.07234 .30902 L
.07177 .30902 L
.07123 .30902 L
.0707 .30902 L
.07018 .30902 L
.06969 .30902 L
.06921 .30902 L
.06875 .30902 L
.0683 .30902 L
.06787 .30902 L
.06746 .30902 L
.06707 .30902 L
.06669 .30902 L
.06633 .30902 L
.06599 .30902 L
.06566 .30902 L
.06535 .30902 L
.06505 .30902 L
.06477 .30902 L
.06451 .30902 L
.06427 .30902 L
.06404 .30902 L
.06383 .30902 L
.06363 .30902 L
.06345 .30902 L
.06329 .30902 L
.06314 .30902 L
.06301 .30902 L
.06289 .30902 L
Mistroke
.0628 .30902 L
.06271 .30902 L
.06265 .30902 L
.0626 .30902 L
.06256 .30902 L
.06255 .30902 L
.06254 .30902 L
.06256 .30902 L
.06259 .30902 L
.06264 .30902 L
.0627 .30902 L
.06278 .30902 L
.06288 .30902 L
.06299 .30902 L
.06312 .30902 L
.06326 .30902 L
.06342 .30902 L
.0636 .30902 L
.06379 .30902 L
.064 .30902 L
.06423 .30902 L
.06447 .30902 L
.06473 .30902 L
.06501 .30902 L
.0653 .30902 L
.06561 .30902 L
.06593 .30902 L
.06627 .30902 L
.06663 .30902 L
.067 .30902 L
.06739 .30902 L
.0678 .30902 L
.06823 .30902 L
.06867 .30902 L
.06913 .30902 L
.0696 .30902 L
.07009 .30902 L
.0706 .30902 L
.07113 .30902 L
.07167 .30902 L
.07223 .30902 L
.07281 .30902 L
.0734 .30902 L
.07402 .30902 L
.07465 .30902 L
.07529 .30902 L
.07596 .30902 L
.07664 .30902 L
.07734 .30902 L
.07806 .30902 L
Mistroke
.07879 .30902 L
.07955 .30902 L
.08032 .30902 L
.08111 .30902 L
.08192 .30902 L
.08275 .30902 L
.0836 .30902 L
.08446 .30902 L
.08534 .30902 L
.08625 .30902 L
.08717 .30902 L
.08811 .30902 L
.08907 .30902 L
.09005 .30902 L
.09105 .30902 L
.09207 .30902 L
.09311 .30902 L
.09417 .30902 L
.09525 .30902 L
.09635 .30902 L
.09747 .30902 L
.09861 .30902 L
.09978 .30902 L
.10096 .30902 L
.10217 .30902 L
.10339 .30902 L
.10464 .30902 L
.10592 .30902 L
.10721 .30902 L
.10853 .30902 L
.10987 .30902 L
.11123 .30902 L
.11261 .30902 L
.11402 .30902 L
.11546 .30902 L
.11692 .30902 L
.1184 .30902 L
.11991 .30902 L
.12144 .30902 L
.123 .30902 L
.12459 .30902 L
.1262 .30902 L
.12784 .30902 L
.1295 .30902 L
.1312 .30902 L
.13292 .30902 L
.13467 .30902 L
.13645 .30902 L
.13826 .30902 L
.1401 .30902 L
Mistroke
.14197 .30902 L
.14387 .30902 L
.14581 .30902 L
.14778 .30902 L
.14978 .30902 L
.15181 .30902 L
.15388 .30902 L
.15599 .30902 L
.15813 .30902 L
.16031 .30902 L
.16253 .30902 L
.16479 .30902 L
.16708 .30902 L
.16942 .30902 L
.17181 .30902 L
.17423 .30902 L
.1767 .30902 L
.17922 .30902 L
.18178 .30902 L
.1844 .30902 L
.18706 .30902 L
.18978 .30902 L
.19255 .30902 L
.19538 .30902 L
.19827 .30902 L
.20122 .30902 L
.20423 .30902 L
.20731 .30902 L
.21045 .30902 L
.21367 .30902 L
.21696 .30902 L
.22033 .30902 L
.22378 .30902 L
.22732 .30902 L
.23095 .30902 L
.23467 .30902 L
.23849 .30902 L
.24243 .30902 L
.24647 .30902 L
.25063 .30902 L
.25493 .30902 L
.25936 .30902 L
.26393 .30902 L
.26867 .30902 L
.27357 .30902 L
.27867 .30902 L
.28396 .30902 L
.28947 .30902 L
.29523 .30902 L
.30127 .30902 L
Mistroke
.3076 .30902 L
.31427 .30902 L
.32133 .30902 L
.32882 .30902 L
.33682 .30902 L
.34541 .30902 L
.35472 .30902 L
.36488 .30902 L
.3761 .30902 L
.38868 .30902 L
.40307 .30902 L
.41996 .30902 L
.44063 .30902 L
.46736 .30902 L
.50253 .30902 L
.53645 .30902 L
.57663 .30902 L
.60299 .30902 L
.62274 .30902 L
.63882 .30902 L
.65253 .30902 L
.66456 .30902 L
.67533 .30902 L
.68512 .30902 L
.69412 .30902 L
.70246 .30902 L
.71026 .30902 L
.71759 .30902 L
.72451 .30902 L
.73108 .30902 L
.73732 .30902 L
.74329 .30902 L
.749 .30902 L
.75447 .30902 L
.75974 .30902 L
.76482 .30902 L
.76972 .30902 L
.77445 .30902 L
.77904 .30902 L
.78348 .30902 L
.78779 .30902 L
.79197 .30902 L
.79604 .30902 L
.8 .30902 L
.80385 .30902 L
.80761 .30902 L
.81127 .30902 L
.81485 .30902 L
.81834 .30902 L
.82175 .30902 L
Mistroke
.82508 .30902 L
.82834 .30902 L
.83153 .30902 L
.83465 .30902 L
.8377 .30902 L
.84069 .30902 L
.84362 .30902 L
.84649 .30902 L
.84931 .30902 L
.85207 .30902 L
.85478 .30902 L
.85744 .30902 L
.86005 .30902 L
.86261 .30902 L
.86512 .30902 L
.86759 .30902 L
.87001 .30902 L
.87239 .30902 L
.87473 .30902 L
.87703 .30902 L
.87928 .30902 L
.8815 .30902 L
.88368 .30902 L
.88583 .30902 L
.88793 .30902 L
.89 .30902 L
.89204 .30902 L
.89404 .30902 L
.89601 .30902 L
.89795 .30902 L
.89985 .30902 L
.90172 .30902 L
.90356 .30902 L
.90537 .30902 L
.90715 .30902 L
.9089 .30902 L
.91062 .30902 L
.91231 .30902 L
.91397 .30902 L
.91561 .30902 L
.91722 .30902 L
.9188 .30902 L
.92036 .30902 L
.92188 .30902 L
.92339 .30902 L
.92486 .30902 L
.92632 .30902 L
.92774 .30902 L
.92914 .30902 L
.93052 .30902 L
Mistroke
.93187 .30902 L
.9332 .30902 L
.93451 .30902 L
.93579 .30902 L
.93705 .30902 L
.93829 .30902 L
.9395 .30902 L
.94069 .30902 L
.94186 .30902 L
.94301 .30902 L
.94413 .30902 L
.94524 .30902 L
.94632 .30902 L
.94738 .30902 L
.94842 .30902 L
.94944 .30902 L
.95044 .30902 L
.95141 .30902 L
.95237 .30902 L
.9533 .30902 L
.95422 .30902 L
.95512 .30902 L
.95599 .30902 L
.95685 .30902 L
.95768 .30902 L
.9585 .30902 L
.9593 .30902 L
.96007 .30902 L
.96083 .30902 L
.96157 .30902 L
.96229 .30902 L
.96299 .30902 L
.96367 .30902 L
.96434 .30902 L
.96498 .30902 L
.96561 .30902 L
.96622 .30902 L
.9668 .30902 L
.96737 .30902 L
.96793 .30902 L
.96846 .30902 L
.96897 .30902 L
.96947 .30902 L
.96995 .30902 L
.97041 .30902 L
.97085 .30902 L
.97128 .30902 L
.97169 .30902 L
.97208 .30902 L
.97245 .30902 L
Mistroke
.9728 .30902 L
.97314 .30902 L
.97346 .30902 L
.97376 .30902 L
.97404 .30902 L
.9743 .30902 L
.97455 .30902 L
.97478 .30902 L
.975 .30902 L
.97519 .30902 L
.97537 .30902 L
.97553 .30902 L
.97567 .30902 L
.9758 .30902 L
.97591 .30902 L
.976 .30902 L
.97607 .30902 L
.97613 .30902 L
.97616 .30902 L
.97619 .30902 L
.97619 .30902 L
.97618 .30902 L
.97615 .30902 L
.9761 .30902 L
.97603 .30902 L
.97595 .30902 L
.97585 .30902 L
.97573 .30902 L
.9756 .30902 L
.97545 .30902 L
.97528 .30902 L
.97509 .30902 L
.97489 .30902 L
.97467 .30902 L
.97443 .30902 L
.97417 .30902 L
.97389 .30902 L
.9736 .30902 L
.97329 .30902 L
.97297 .30902 L
.97262 .30902 L
.97226 .30902 L
.97188 .30902 L
.97148 .30902 L
.97107 .30902 L
.97063 .30902 L
.97018 .30902 L
.96971 .30902 L
.96922 .30902 L
.96872 .30902 L
Mistroke
.96819 .30902 L
.96765 .30902 L
.96709 .30902 L
.96651 .30902 L
.96592 .30902 L
.9653 .30902 L
.96467 .30902 L
.96402 .30902 L
.96334 .30902 L
.96265 .30902 L
.96195 .30902 L
.96122 .30902 L
.96047 .30902 L
.95971 .30902 L
.95892 .30902 L
.95812 .30902 L
.95729 .30902 L
.95645 .30902 L
.95559 .30902 L
.9547 .30902 L
.9538 .30902 L
.95288 .30902 L
.95194 .30902 L
.95097 .30902 L
.94999 .30902 L
.94899 .30902 L
.94796 .30902 L
.94692 .30902 L
.94585 .30902 L
.94476 .30902 L
.94365 .30902 L
.94252 .30902 L
.94137 .30902 L
.9402 .30902 L
.939 .30902 L
.93778 .30902 L
.93654 .30902 L
.93528 .30902 L
.93399 .30902 L
.93268 .30902 L
.93135 .30902 L
.92999 .30902 L
.92861 .30902 L
.9272 .30902 L
.92577 .30902 L
.92432 .30902 L
.92284 .30902 L
.92134 .30902 L
.91981 .30902 L
.91825 .30902 L
Mistroke
.91667 .30902 L
.91506 .30902 L
.91342 .30902 L
.91176 .30902 L
.91007 .30902 L
.90835 .30902 L
.9066 .30902 L
.90482 .30902 L
.90302 .30902 L
.90118 .30902 L
.89931 .30902 L
.89741 .30902 L
.89548 .30902 L
.89352 .30902 L
.89152 .30902 L
.88949 .30902 L
.88743 .30902 L
.88533 .30902 L
.8832 .30902 L
.88103 .30902 L
.87882 .30902 L
.87657 .30902 L
.87429 .30902 L
.87196 .30902 L
.8696 .30902 L
.86719 .30902 L
.86474 .30902 L
.86225 .30902 L
.85971 .30902 L
.85712 .30902 L
.85449 .30902 L
.8518 .30902 L
.84907 .30902 L
.84628 .30902 L
.84344 .30902 L
.84054 .30902 L
.83759 .30902 L
.83458 .30902 L
.8315 .30902 L
.82836 .30902 L
.82515 .30902 L
.82187 .30902 L
.81852 .30902 L
.81509 .30902 L
.81159 .30902 L
.808 .30902 L
.80432 .30902 L
.80055 .30902 L
.79669 .30902 L
.79272 .30902 L
Mistroke
.78865 .30902 L
.78446 .30902 L
.78016 .30902 L
.77572 .30902 L
.77115 .30902 L
.76643 .30902 L
.76156 .30902 L
.75652 .30902 L
.75129 .30902 L
.74587 .30902 L
.74023 .30902 L
.73435 .30902 L
.72821 .30902 L
.72178 .30902 L
.71503 .30902 L
.70791 .30902 L
.70038 .30902 L
.69237 .30902 L
.68381 .30902 L
.67459 .30902 L
.66459 .30902 L
.65363 .30902 L
.64145 .30902 L
.62769 .30902 L
.61176 .30902 L
.59265 .30902 L
.56825 .30902 L
.53496 .30902 L
.49777 .30902 L
.46113 .30902 L
.42192 .30902 L
.39621 .30902 L
.37676 .30902 L
.36087 .30902 L
.34729 .30902 L
.33535 .30902 L
.32465 .30902 L
.31491 .30902 L
.30596 .30902 L
.29764 .30902 L
.28987 .30902 L
.28257 .30902 L
.27567 .30902 L
.26912 .30902 L
.26289 .30902 L
.25694 .30902 L
.25124 .30902 L
.24577 .30902 L
.24051 .30902 L
.23544 .30902 L
Mistroke
.23055 .30902 L
.22581 .30902 L
.22124 .30902 L
.2168 .30902 L
.21249 .30902 L
.20831 .30902 L
.20424 .30902 L
.20028 .30902 L
.19643 .30902 L
.19268 .30902 L
.18901 .30902 L
.18544 .30902 L
.18195 .30902 L
.17854 .30902 L
.17521 .30902 L
.17195 .30902 L
.16876 .30902 L
.16564 .30902 L
.16259 .30902 L
.15959 .30902 L
.15666 .30902 L
.15379 .30902 L
.15097 .30902 L
.14821 .30902 L
.1455 .30902 L
.14284 .30902 L
.14023 .30902 L
.13767 .30902 L
.13515 .30902 L
.13268 .30902 L
.13026 .30902 L
.12788 .30902 L
.12553 .30902 L
.12324 .30902 L
.12098 .30902 L
.11876 .30902 L
.11657 .30902 L
.11443 .30902 L
.11232 .30902 L
.11025 .30902 L
.10821 .30902 L
.1062 .30902 L
.10423 .30902 L
.10229 .30902 L
.10039 .30902 L
.09852 .30902 L
.09667 .30902 L
.09486 .30902 L
.09308 .30902 L
.09133 .30902 L
Mistroke
.0896 .30902 L
.08791 .30902 L
.08624 .30902 L
.0846 .30902 L
.08299 .30902 L
.08141 .30902 L
.07985 .30902 L
.07832 .30902 L
.07682 .30902 L
.07534 .30902 L
.07388 .30902 L
.07245 .30902 L
.07105 .30902 L
.06967 .30902 L
.06831 .30902 L
.06698 .30902 L
.06567 .30902 L
.06439 .30902 L
.06313 .30902 L
.06189 .30902 L
.06067 .30902 L
.05948 .30902 L
.0583 .30902 L
.05715 .30902 L
.05603 .30902 L
.05492 .30902 L
.05384 .30902 L
.05277 .30902 L
.05173 .30902 L
.05071 .30902 L
.04971 .30902 L
.04873 .30902 L
.04777 .30902 L
.04683 .30902 L
.04591 .30902 L
.04502 .30902 L
.04414 .30902 L
.04328 .30902 L
.04244 .30902 L
.04162 .30902 L
.04082 .30902 L
.04004 .30902 L
.03928 .30902 L
.03854 .30902 L
.03782 .30902 L
.03711 .30902 L
.03643 .30902 L
.03576 .30902 L
.03511 .30902 L
.03449 .30902 L
Mistroke
.03388 .30902 L
.03329 .30902 L
.03271 .30902 L
.03216 .30902 L
.03162 .30902 L
.0311 .30902 L
.0306 .30902 L
.03012 .30902 L
.02966 .30902 L
.02921 .30902 L
.02879 .30902 L
.02838 .30902 L
.02798 .30902 L
.02761 .30902 L
.02725 .30902 L
.02691 .30902 L
.02659 .30902 L
.02629 .30902 L
.026 .30902 L
.02574 .30902 L
.02549 .30902 L
.02525 .30902 L
.02504 .30902 L
.02484 .30902 L
.02466 .30902 L
.0245 .30902 L
.02435 .30902 L
.02422 .30902 L
.02411 .30902 L
.02402 .30902 L
.02394 .30902 L
.02388 .30902 L
.02384 .30902 L
.02382 .30902 L
.02381 .30902 L
.02382 .30902 L
.02385 .30902 L
.02389 .30902 L
.02396 .30902 L
.02403 .30902 L
.02413 .30902 L
.02425 .30902 L
.02438 .30902 L
.02453 .30902 L
.02469 .30902 L
.02488 .30902 L
.02508 .30902 L
.0253 .30902 L
.02553 .30902 L
.02579 .30902 L
Mistroke
.02606 .30902 L
.02635 .30902 L
.02666 .30902 L
.02698 .30902 L
.02732 .30902 L
.02768 .30902 L
.02806 .30902 L
.02845 .30902 L
.02887 .30902 L
.0293 .30902 L
.02974 .30902 L
.03021 .30902 L
.0307 .30902 L
.0312 .30902 L
.03172 .30902 L
.03226 .30902 L
.03281 .30902 L
.03339 .30902 L
.03398 .30902 L
.03459 .30902 L
.03523 .30902 L
.03587 .30902 L
.03654 .30902 L
.03723 .30902 L
.03793 .30902 L
.03866 .30902 L
.0394 .30902 L
.04016 .30902 L
.04095 .30902 L
.04175 .30902 L
.04257 .30902 L
.04341 .30902 L
.04427 .30902 L
.04514 .30902 L
.04604 .30902 L
.04696 .30902 L
.0479 .30902 L
.04886 .30902 L
.04984 .30902 L
.05084 .30902 L
.05186 .30902 L
.0529 .30902 L
.05396 .30902 L
.05505 .30902 L
.05615 .30902 L
.05728 .30902 L
.05843 .30902 L
.0596 .30902 L
.06079 .30902 L
.062 .30902 L
Mistroke
.06324 .30902 L
.0645 .30902 L
.06578 .30902 L
.06709 .30902 L
.06841 .30902 L
.06977 .30902 L
.07114 .30902 L
.07254 .30902 L
.07397 .30902 L
.07541 .30902 L
.07689 .30902 L
.07839 .30902 L
.07991 .30902 L
.08146 .30902 L
.08304 .30902 L
.08464 .30902 L
.08627 .30902 L
.08793 .30902 L
.08961 .30902 L
.09133 .30902 L
.09307 .30902 L
.09484 .30902 L
.09664 .30902 L
.09847 .30902 L
.10033 .30902 L
.10222 .30902 L
.10414 .30902 L
.1061 .30902 L
.10809 .30902 L
.11011 .30902 L
.11216 .30902 L
.11425 .30902 L
.11638 .30902 L
.11854 .30902 L
.12073 .30902 L
.12297 .30902 L
.12524 .30902 L
.12756 .30902 L
.12991 .30902 L
.13231 .30902 L
.13475 .30902 L
.13723 .30902 L
.13975 .30902 L
.14233 .30902 L
.14495 .30902 L
.14762 .30902 L
.15034 .30902 L
.15311 .30902 L
.15593 .30902 L
.15881 .30902 L
Mistroke
.16175 .30902 L
.16474 .30902 L
.1678 .30902 L
.17092 .30902 L
.17411 .30902 L
.17737 .30902 L
.18069 .30902 L
.1841 .30902 L
.18758 .30902 L
.19114 .30902 L
.19479 .30902 L
.19852 .30902 L
.20236 .30902 L
.20629 .30902 L
.21032 .30902 L
.21447 .30902 L
.21874 .30902 L
.22312 .30902 L
.22765 .30902 L
.23231 .30902 L
.23713 .30902 L
.24211 .30902 L
.24727 .30902 L
.25262 .30902 L
.25818 .30902 L
.26397 .30902 L
.27001 .30902 L
.27633 .30902 L
.28296 .30902 L
.28993 .30902 L
.29731 .30902 L
.30513 .30902 L
.31347 .30902 L
.32243 .30902 L
.33211 .30902 L
.34268 .30902 L
.35436 .30902 L
.36745 .30902 L
.38245 .30902 L
.40015 .30902 L
.42208 .30902 L
.44976 .30902 L
.4834 .30902 L
.51562 .30902 L
.55087 .30902 L
.58221 .30902 L
.60497 .30902 L
.62292 .30902 L
.63787 .30902 L
.65077 .30902 L
Mistroke
.66219 .30902 L
.67248 .30902 L
.68187 .30902 L
.69053 .30902 L
.69858 .30902 L
.70612 .30902 L
.71321 .30902 L
.71992 .30902 L
.72628 .30902 L
.73235 .30902 L
.73814 .30902 L
.74369 .30902 L
.74902 .30902 L
.75415 .30902 L
.75909 .30902 L
.76386 .30902 L
.76848 .30902 L
.77295 .30902 L
.77728 .30902 L
.78148 .30902 L
.78556 .30902 L
.78953 .30902 L
.79339 .30902 L
.79715 .30902 L
.80082 .30902 L
.80439 .30902 L
.80788 .30902 L
.81129 .30902 L
.81461 .30902 L
.81787 .30902 L
.82105 .30902 L
.82416 .30902 L
.82721 .30902 L
.83019 .30902 L
.83311 .30902 L
.83597 .30902 L
.83878 .30902 L
.84153 .30902 L
.84422 .30902 L
.84687 .30902 L
.84946 .30902 L
.85201 .30902 L
.85451 .30902 L
.85696 .30902 L
.85937 .30902 L
.86174 .30902 L
.86406 .30902 L
.86635 .30902 L
.86859 .30902 L
.87079 .30902 L
Mistroke
.87296 .30902 L
.87509 .30902 L
.87718 .30902 L
.87924 .30902 L
.88126 .30902 L
.88325 .30902 L
.8852 .30902 L
.88712 .30902 L
.88901 .30902 L
.89087 .30902 L
.89269 .30902 L
.89449 .30902 L
.89625 .30902 L
.89799 .30902 L
.8997 .30902 L
.90138 .30902 L
.90303 .30902 L
.90465 .30902 L
.90624 .30902 L
.90781 .30902 L
.90935 .30902 L
.91087 .30902 L
.91236 .30902 L
.91383 .30902 L
.91526 .30902 L
.91668 .30902 L
.91807 .30902 L
.91944 .30902 L
.92078 .30902 L
.9221 .30902 L
.92339 .30902 L
.92466 .30902 L
.92591 .30902 L
.92714 .30902 L
.92834 .30902 L
.92952 .30902 L
.93068 .30902 L
.93182 .30902 L
.93293 .30902 L
.93403 .30902 L
.9351 .30902 L
.93615 .30902 L
.93718 .30902 L
.93819 .30902 L
.93918 .30902 L
.94015 .30902 L
.9411 .30902 L
.94203 .30902 L
.94294 .30902 L
.94383 .30902 L
Mistroke
.9447 .30902 L
.94555 .30902 L
.94638 .30902 L
.94719 .30902 L
.94798 .30902 L
.94875 .30902 L
.9495 .30902 L
.95024 .30902 L
.95095 .30902 L
.95165 .30902 L
.95233 .30902 L
.95299 .30902 L
.95363 .30902 L
.95425 .30902 L
.95485 .30902 L
.95544 .30902 L
.95601 .30902 L
.95656 .30902 L
.95709 .30902 L
.9576 .30902 L
.9581 .30902 L
.95857 .30902 L
.95903 .30902 L
.95948 .30902 L
.9599 .30902 L
.96031 .30902 L
.96069 .30902 L
.96107 .30902 L
.96142 .30902 L
.96176 .30902 L
.96208 .30902 L
.96238 .30902 L
.96266 .30902 L
.96293 .30902 L
.96318 .30902 L
.96341 .30902 L
.96362 .30902 L
.96382 .30902 L
.964 .30902 L
.96417 .30902 L
.96431 .30902 L
.96444 .30902 L
.96455 .30902 L
.96465 .30902 L
.96473 .30902 L
.96479 .30902 L
.96483 .30902 L
.96486 .30902 L
.96487 .30902 L
.96486 .30902 L
Mistroke
.96484 .30902 L
.96479 .30902 L
.96473 .30902 L
.96466 .30902 L
.96457 .30902 L
.96446 .30902 L
.96433 .30902 L
.96418 .30902 L
.96402 .30902 L
.96384 .30902 L
.96365 .30902 L
.96344 .30902 L
.96321 .30902 L
.96296 .30902 L
.96269 .30902 L
.96241 .30902 L
.96211 .30902 L
.9618 .30902 L
.96146 .30902 L
.96111 .30902 L
.96074 .30902 L
.96036 .30902 L
.95995 .30902 L
.95953 .30902 L
.95909 .30902 L
.95864 .30902 L
.95816 .30902 L
.95767 .30902 L
.95716 .30902 L
.95663 .30902 L
.95608 .30902 L
.95552 .30902 L
.95494 .30902 L
.95434 .30902 L
.95372 .30902 L
.95308 .30902 L
.95243 .30902 L
.95175 .30902 L
.95106 .30902 L
.95035 .30902 L
.94962 .30902 L
.94887 .30902 L
.94811 .30902 L
.94732 .30902 L
.94651 .30902 L
.94569 .30902 L
.94484 .30902 L
.94398 .30902 L
.9431 .30902 L
.9422 .30902 L
Mistroke
.94127 .30902 L
.94033 .30902 L
.93937 .30902 L
.93838 .30902 L
.93738 .30902 L
.93636 .30902 L
.93531 .30902 L
.93425 .30902 L
.93316 .30902 L
.93205 .30902 L
.93093 .30902 L
.92977 .30902 L
.9286 .30902 L
.92741 .30902 L
.92619 .30902 L
.92495 .30902 L
.92369 .30902 L
.92241 .30902 L
.9211 .30902 L
.91977 .30902 L
.91842 .30902 L
.91704 .30902 L
.91564 .30902 L
.91421 .30902 L
.91276 .30902 L
.91128 .30902 L
.90978 .30902 L
.90826 .30902 L
.9067 .30902 L
.90513 .30902 L
.90352 .30902 L
.90189 .30902 L
.90023 .30902 L
.89854 .30902 L
.89682 .30902 L
.89508 .30902 L
.8933 .30902 L
.8915 .30902 L
.88967 .30902 L
.8878 .30902 L
.88591 .30902 L
.88398 .30902 L
.88202 .30902 L
.88003 .30902 L
.878 .30902 L
.87594 .30902 L
.87384 .30902 L
.87171 .30902 L
.86954 .30902 L
.86733 .30902 L
Mistroke
.86509 .30902 L
.8628 .30902 L
.86048 .30902 L
.85811 .30902 L
.8557 .30902 L
.85325 .30902 L
.85076 .30902 L
.84821 .30902 L
.84562 .30902 L
.84298 .30902 L
.8403 .30902 L
.83755 .30902 L
.83476 .30902 L
.83191 .30902 L
.829 .30902 L
.82604 .30902 L
.82301 .30902 L
.81992 .30902 L
.81676 .30902 L
.81353 .30902 L
.81024 .30902 L
.80686 .30902 L
.80341 .30902 L
.79987 .30902 L
.79625 .30902 L
.79254 .30902 L
.78873 .30902 L
.78483 .30902 L
.78081 .30902 L
.77669 .30902 L
.77244 .30902 L
.76807 .30902 L
.76356 .30902 L
.75891 .30902 L
.7541 .30902 L
.74913 .30902 L
.74397 .30902 L
.73861 .30902 L
.73304 .30902 L
.72724 .30902 L
.72117 .30902 L
.71482 .30902 L
.70814 .30902 L
.7011 .30902 L
.69365 .30902 L
.68572 .30902 L
.67723 .30902 L
.6681 .30902 L
.65818 .30902 L
.6473 .30902 L
Mistroke
.63521 .30902 L
.62155 .30902 L
.60571 .30902 L
.58673 .30902 L
.56253 .30902 L
.52857 .30902 L
.49527 .30902 L
.46197 .30902 L
.42546 .30902 L
.40011 .30902 L
.38077 .30902 L
.36493 .30902 L
.3514 .30902 L
.3395 .30902 L
.32884 .30902 L
.31914 .30902 L
.31023 .30902 L
.30195 .30902 L
.29422 .30902 L
.28696 .30902 L
.2801 .30902 L
.27359 .30902 L
.26739 .30902 L
.26148 .30902 L
.25582 .30902 L
.25039 .30902 L
.24516 .30902 L
.24013 .30902 L
.23527 .30902 L
.23058 .30902 L
.22603 .30902 L
.22163 .30902 L
.21735 .30902 L
.2132 .30902 L
.20917 .30902 L
.20524 .30902 L
.20142 .30902 L
.19769 .30902 L
.19406 .30902 L
.19051 .30902 L
.18705 .30902 L
.18367 .30902 L
.18037 .30902 L
.17713 .30902 L
.17397 .30902 L
.17088 .30902 L
.16785 .30902 L
.16488 .30902 L
.16197 .30902 L
.15912 .30902 L
Mistroke
.15633 .30902 L
.15359 .30902 L
.1509 .30902 L
.14826 .30902 L
.14568 .30902 L
.14314 .30902 L
.14064 .30902 L
.13819 .30902 L
.13579 .30902 L
.13343 .30902 L
.13111 .30902 L
.12883 .30902 L
.12659 .30902 L
.12438 .30902 L
.12222 .30902 L
.12009 .30902 L
.118 .30902 L
.11595 .30902 L
.11392 .30902 L
.11194 .30902 L
.10998 .30902 L
.10806 .30902 L
.10617 .30902 L
.10431 .30902 L
.10249 .30902 L
.10069 .30902 L
.09892 .30902 L
.09718 .30902 L
.09548 .30902 L
.0938 .30902 L
.09214 .30902 L
.09052 .30902 L
.08892 .30902 L
.08735 .30902 L
.0858 .30902 L
.08428 .30902 L
.08279 .30902 L
.08132 .30902 L
.07988 .30902 L
.07846 .30902 L
.07707 .30902 L
.0757 .30902 L
.07435 .30902 L
.07303 .30902 L
.07173 .30902 L
.07046 .30902 L
.06921 .30902 L
.06798 .30902 L
.06677 .30902 L
.06558 .30902 L
Mistroke
.06442 .30902 L
.06328 .30902 L
.06216 .30902 L
.06106 .30902 L
.05998 .30902 L
.05893 .30902 L
.05789 .30902 L
.05688 .30902 L
.05588 .30902 L
.05491 .30902 L
.05396 .30902 L
.05302 .30902 L
.05211 .30902 L
.05122 .30902 L
.05035 .30902 L
.04949 .30902 L
.04866 .30902 L
.04784 .30902 L
.04705 .30902 L
.04627 .30902 L
.04551 .30902 L
.04478 .30902 L
.04406 .30902 L
.04336 .30902 L
.04268 .30902 L
.04201 .30902 L
.04137 .30902 L
.04074 .30902 L
.04013 .30902 L
.03954 .30902 L
.03897 .30902 L
.03842 .30902 L
.03789 .30902 L
.03737 .30902 L
.03687 .30902 L
.03639 .30902 L
.03592 .30902 L
.03548 .30902 L
.03505 .30902 L
.03464 .30902 L
.03425 .30902 L
.03387 .30902 L
.03352 .30902 L
.03318 .30902 L
.03285 .30902 L
.03255 .30902 L
.03226 .30902 L
.03199 .30902 L
.03174 .30902 L
.0315 .30902 L
Mistroke
.03129 .30902 L
.03108 .30902 L
.0309 .30902 L
.03073 .30902 L
.03058 .30902 L
.03045 .30902 L
.03034 .30902 L
.03024 .30902 L
.03016 .30902 L
.0301 .30902 L
.03005 .30902 L
.03002 .30902 L
.03001 .30902 L
.03001 .30902 L
.03003 .30902 L
.03007 .30902 L
.03013 .30902 L
.0302 .30902 L
.03029 .30902 L
.0304 .30902 L
.03053 .30902 L
.03067 .30902 L
.03083 .30902 L
.031 .30902 L
.0312 .30902 L
.03141 .30902 L
.03163 .30902 L
.03188 .30902 L
.03214 .30902 L
.03242 .30902 L
.03272 .30902 L
.03303 .30902 L
.03336 .30902 L
.03371 .30902 L
.03408 .30902 L
.03446 .30902 L
.03487 .30902 L
.03529 .30902 L
.03572 .30902 L
.03618 .30902 L
.03665 .30902 L
.03714 .30902 L
.03765 .30902 L
.03817 .30902 L
.03872 .30902 L
.03928 .30902 L
.03986 .30902 L
.04046 .30902 L
.04108 .30902 L
.04171 .30902 L
Mistroke
.04236 .30902 L
.04304 .30902 L
.04373 .30902 L
.04443 .30902 L
.04516 .30902 L
.04591 .30902 L
.04667 .30902 L
.04746 .30902 L
.04826 .30902 L
.04908 .30902 L
.04993 .30902 L
.05079 .30902 L
.05167 .30902 L
.05257 .30902 L
.05349 .30902 L
.05443 .30902 L
.05539 .30902 L
.05637 .30902 L
.05737 .30902 L
.05839 .30902 L
.05943 .30902 L
.0605 .30902 L
.06158 .30902 L
.06269 .30902 L
.06381 .30902 L
.06496 .30902 L
.06613 .30902 L
.06732 .30902 L
.06853 .30902 L
.06977 .30902 L
.07103 .30902 L
.07231 .30902 L
.07361 .30902 L
.07494 .30902 L
.07629 .30902 L
.07766 .30902 L
.07906 .30902 L
.08048 .30902 L
.08193 .30902 L
.0834 .30902 L
.08489 .30902 L
.08641 .30902 L
.08796 .30902 L
.08953 .30902 L
.09113 .30902 L
.09276 .30902 L
.09441 .30902 L
.0961 .30902 L
.0978 .30902 L
.09954 .30902 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00OSgoo00<007ooOol0
SWoo002?Ool00`00Oomoo`2>Ool008Moo`D000=oo`03001oogoo08ioo`00RGoo00<007ooOol00goo
00<007ooOol0SWoo0029Ool00`00Oomoo`03Ool3002>Ool0085oo`@000Aoo`03001oogoo00=oo`03
001oogoo08ioo`00RGoo00<007ooOol00goo00<007ooOol0SWoo0028Ool20005Ool00`00Oomoo`2>
Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03
001oogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo
00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0
SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomo
o`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008mo
o`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`8008moo`00
Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007oo
Ool0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?
Ool00`00Oomoo`2>Ool008moo`8008moo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool0
08moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool007aoo`8000Ao
o`8000Aoo`8000Eoo`03001oogoo08ioo`00Ngoo00@007ooOol000Qoo`04001oogoo0004Ool00`00
Oomoo`2>Ool007]oo`04001oogoo000;Ool00`00Oomoo`02Ool3002>Ool007Eoo`@0009oo`04001o
ogoo0009Ool20005Ool00`00Oomoo`2>Ool007]oo`04001oogoo0009Ool00`00Oomoo`04Ool00`00
Oomoo`2>Ool007aoo`8000Yoo`<000Aoo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool0
0`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool2002?Ool008mo
o`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo
08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo
00<007ooOol0SWoo002?Ool2002?Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?
Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomo
o`2>Ool008moo`03001oogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomoo`2>Ool008moo`03001o
ogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool002eoo`@002ioo`D002]oo`03
001oogoo02eoo`D002aoo`@002aoo`00;Goo00<007ooOol0<Goo00<007ooOol0:goo00<007ooOol0
;goo00<007ooOol0;7oo00<007ooOol0;Goo000^Ool00`00Oomoo`0`Ool00`00Oomoo`0[Ool00`00
Oomoo`0_Ool00`00Oomoo`0]Ool00`00Oomoo`0/Ool002Moo`@000Aoo`03001oogoo02Moo`@000Ao
o`03001oogoo02]oo`03001oogoo02moo`03001oogoo02ioo`03001oogoo02]oo`00;Goo00@007oo
Ool0031oo`03001oogoo02]oo`80031oo`03001oogoo02aoo`04001oogoo000/Ool002ioo`80031o
o`8002eoo`03001oogoo02ioo`8002moo`8002eoo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomo
o`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008mo
o`03001oogoo08ioo`001`00ogoP4WoP1`000Goo0005Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`03Ool002aoo`03001oogoo02moo`03001oogoo02ioo`03001oogoo
02moo`03001oogoo02ioo`03001oogoo02]oo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>
Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`80
08moo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo
00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0
SWoo002?Ool00`00Oomoo`2>Ool008moo`8008moo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomo
o`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008mo
o`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool2002?Ool008moo`03001oogoo08ioo`00
Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007oo
Ool0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?
Ool2002?Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool0
08moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo001lOol20004Ool20004Ool20005Ool00`00
Oomoo`2>Ool007]oo`04001oogoo0008Ool01000Oomoo`0017oo00<007ooOol0SWoo001kOol01000
Oomoo`002goo00<007ooOol00Woo0`00SWoo001kOol01000Oomoo`002Goo0P001Goo00<007ooOol0
SWoo001kOol01000Oomoo`002Goo00<007ooOol017oo00<007ooOol0SWoo001lOol2000:Ool30004
Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomo
o`2>Ool008moo`03001oogoo08ioo`00Sgoo0P00Sgoo002?Ool00`00Oomoo`2>Ool008moo`03001o
ogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00
Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo0P00Sgoo
002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00
Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool0
08moo`8008moo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08io
o`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<0
07ooOol0SWoo002?Ool00`00Oomoo`2>Ool008moo`8008moo`00Sgoo00<007ooOol0SWoo002?Ool0
0`00Oomoo`2>Ool008moo`03001oogoo08ioo`00Sgoo00<007ooOol0SWoo002?Ool00`00Oomoo`2>
Ool008Moo`D000=oo`03001oogoo08ioo`00RGoo00<007ooOol00goo00<007ooOol0SWoo0029Ool0
0`00Oomoo`03Ool3002>Ool008Uoo`03001oogoo00=oo`03001oogoo08ioo`00RGoo00<007ooOol0
0goo00<007ooOol0SWoo0028Ool20005Ool00`00Oomoo`2>Ool008moo`03001oogoo08ioo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-2.9012, -1.05358, \
0.0201941, 0.0119092}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["tbl3=Flatten[Chop[Table[{(X[1,t]-X[2,t])},{t,1,1500}]]];", "Input"],

Cell[CellGroupData[{

Cell["ListPlot[tbl3,PlotJoined->True,PlotStyle->RGBColor[0,0,1]]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000634921 0.309376 0.107267 [
[.15079 .29688 -9 -9 ]
[.15079 .29688 9 0 ]
[.27778 .29688 -9 -9 ]
[.27778 .29688 9 0 ]
[.40476 .29688 -9 -9 ]
[.40476 .29688 9 0 ]
[.53175 .29688 -9 -9 ]
[.53175 .29688 9 0 ]
[.65873 .29688 -12 -9 ]
[.65873 .29688 12 0 ]
[.78571 .29688 -12 -9 ]
[.78571 .29688 12 0 ]
[.9127 .29688 -12 -9 ]
[.9127 .29688 12 0 ]
[.01131 .09484 -12 -4.5 ]
[.01131 .09484 0 4.5 ]
[.01131 .20211 -12 -4.5 ]
[.01131 .20211 0 4.5 ]
[.01131 .41664 -6 -4.5 ]
[.01131 .41664 0 4.5 ]
[.01131 .52391 -6 -4.5 ]
[.01131 .52391 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15079 .30938 m
.15079 .31563 L
s
[(200)] .15079 .29688 0 1 Mshowa
.27778 .30938 m
.27778 .31563 L
s
[(400)] .27778 .29688 0 1 Mshowa
.40476 .30938 m
.40476 .31563 L
s
[(600)] .40476 .29688 0 1 Mshowa
.53175 .30938 m
.53175 .31563 L
s
[(800)] .53175 .29688 0 1 Mshowa
.65873 .30938 m
.65873 .31563 L
s
[(1000)] .65873 .29688 0 1 Mshowa
.78571 .30938 m
.78571 .31563 L
s
[(1200)] .78571 .29688 0 1 Mshowa
.9127 .30938 m
.9127 .31563 L
s
[(1400)] .9127 .29688 0 1 Mshowa
.125 Mabswid
.05556 .30938 m
.05556 .31313 L
s
.0873 .30938 m
.0873 .31313 L
s
.11905 .30938 m
.11905 .31313 L
s
.18254 .30938 m
.18254 .31313 L
s
.21429 .30938 m
.21429 .31313 L
s
.24603 .30938 m
.24603 .31313 L
s
.30952 .30938 m
.30952 .31313 L
s
.34127 .30938 m
.34127 .31313 L
s
.37302 .30938 m
.37302 .31313 L
s
.43651 .30938 m
.43651 .31313 L
s
.46825 .30938 m
.46825 .31313 L
s
.5 .30938 m
.5 .31313 L
s
.56349 .30938 m
.56349 .31313 L
s
.59524 .30938 m
.59524 .31313 L
s
.62698 .30938 m
.62698 .31313 L
s
.69048 .30938 m
.69048 .31313 L
s
.72222 .30938 m
.72222 .31313 L
s
.75397 .30938 m
.75397 .31313 L
s
.81746 .30938 m
.81746 .31313 L
s
.84921 .30938 m
.84921 .31313 L
s
.88095 .30938 m
.88095 .31313 L
s
.94444 .30938 m
.94444 .31313 L
s
.97619 .30938 m
.97619 .31313 L
s
.25 Mabswid
0 .30938 m
1 .30938 L
s
.02381 .09484 m
.03006 .09484 L
s
[(-2)] .01131 .09484 1 0 Mshowa
.02381 .20211 m
.03006 .20211 L
s
[(-1)] .01131 .20211 1 0 Mshowa
.02381 .41664 m
.03006 .41664 L
s
[(1)] .01131 .41664 1 0 Mshowa
.02381 .52391 m
.03006 .52391 L
s
[(2)] .01131 .52391 1 0 Mshowa
.125 Mabswid
.02381 .1163 m
.02756 .1163 L
s
.02381 .13775 m
.02756 .13775 L
s
.02381 .1592 m
.02756 .1592 L
s
.02381 .18066 m
.02756 .18066 L
s
.02381 .22356 m
.02756 .22356 L
s
.02381 .24502 m
.02756 .24502 L
s
.02381 .26647 m
.02756 .26647 L
s
.02381 .28792 m
.02756 .28792 L
s
.02381 .33083 m
.02756 .33083 L
s
.02381 .35228 m
.02756 .35228 L
s
.02381 .37374 m
.02756 .37374 L
s
.02381 .39519 m
.02756 .39519 L
s
.02381 .4381 m
.02756 .4381 L
s
.02381 .45955 m
.02756 .45955 L
s
.02381 .481 m
.02756 .481 L
s
.02381 .50246 m
.02756 .50246 L
s
.02381 .07339 m
.02756 .07339 L
s
.02381 .05194 m
.02756 .05194 L
s
.02381 .03048 m
.02756 .03048 L
s
.02381 .00903 m
.02756 .00903 L
s
.02381 .54536 m
.02756 .54536 L
s
.02381 .56682 m
.02756 .56682 L
s
.02381 .58827 m
.02756 .58827 L
s
.02381 .60972 m
.02756 .60972 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02444 .29253 m
.02508 .27524 L
.02571 .26071 L
.02635 .24899 L
.02698 .23923 L
.02762 .23088 L
.02825 .22354 L
.02889 .21698 L
.02952 .21104 L
.03016 .20558 L
.03079 .20054 L
.03143 .19584 L
.03206 .19143 L
.0327 .18727 L
.03333 .18334 L
.03397 .1796 L
.0346 .17604 L
.03524 .17263 L
.03587 .16937 L
.03651 .16623 L
.03714 .16321 L
.03778 .1603 L
.03841 .15749 L
.03905 .15477 L
.03968 .15214 L
.04032 .14959 L
.04095 .14711 L
.04159 .14471 L
.04222 .14237 L
.04286 .14009 L
.04349 .13787 L
.04413 .13571 L
.04476 .1336 L
.0454 .13155 L
.04603 .12954 L
.04667 .12757 L
.0473 .12566 L
.04794 .12378 L
.04857 .12194 L
.04921 .12015 L
.04984 .11839 L
.05048 .11666 L
.05111 .11497 L
.05175 .11332 L
.05238 .1117 L
.05302 .11011 L
.05365 .10854 L
.05429 .10701 L
.05492 .10551 L
.05556 .10404 L
Mistroke
.05619 .10259 L
.05683 .10117 L
.05746 .09977 L
.0581 .0984 L
.05873 .09705 L
.05937 .09573 L
.06 .09442 L
.06063 .09315 L
.06127 .09189 L
.0619 .09065 L
.06254 .08944 L
.06317 .08825 L
.06381 .08707 L
.06444 .08592 L
.06508 .08479 L
.06571 .08367 L
.06635 .08257 L
.06698 .08149 L
.06762 .08043 L
.06825 .07939 L
.06889 .07837 L
.06952 .07736 L
.07016 .07637 L
.07079 .07539 L
.07143 .07443 L
.07206 .07349 L
.0727 .07256 L
.07333 .07165 L
.07397 .07076 L
.0746 .06988 L
.07524 .06901 L
.07587 .06816 L
.07651 .06732 L
.07714 .0665 L
.07778 .06569 L
.07841 .0649 L
.07905 .06412 L
.07968 .06336 L
.08032 .0626 L
.08095 .06187 L
.08159 .06114 L
.08222 .06043 L
.08286 .05973 L
.08349 .05904 L
.08413 .05837 L
.08476 .05771 L
.0854 .05706 L
.08603 .05643 L
.08667 .0558 L
.0873 .05519 L
Mistroke
.08794 .05459 L
.08857 .05401 L
.08921 .05343 L
.08984 .05287 L
.09048 .05232 L
.09111 .05178 L
.09175 .05126 L
.09238 .05074 L
.09302 .05024 L
.09365 .04974 L
.09429 .04926 L
.09492 .04879 L
.09556 .04834 L
.09619 .04789 L
.09683 .04745 L
.09746 .04703 L
.0981 .04661 L
.09873 .04621 L
.09937 .04582 L
.1 .04544 L
.10063 .04507 L
.10127 .04471 L
.1019 .04436 L
.10254 .04402 L
.10317 .04369 L
.10381 .04338 L
.10444 .04307 L
.10508 .04277 L
.10571 .04249 L
.10635 .04221 L
.10698 .04195 L
.10762 .04169 L
.10825 .04145 L
.10889 .04122 L
.10952 .04099 L
.11016 .04078 L
.11079 .04058 L
.11143 .04039 L
.11206 .0402 L
.1127 .04003 L
.11333 .03987 L
.11397 .03972 L
.1146 .03958 L
.11524 .03945 L
.11587 .03933 L
.11651 .03921 L
.11714 .03911 L
.11778 .03902 L
.11841 .03894 L
.11905 .03887 L
Mistroke
.11968 .03881 L
.12032 .03876 L
.12095 .03872 L
.12159 .03869 L
.12222 .03867 L
.12286 .03866 L
.12349 .03865 L
.12413 .03866 L
.12476 .03868 L
.1254 .03871 L
.12603 .03875 L
.12667 .0388 L
.1273 .03886 L
.12794 .03893 L
.12857 .03901 L
.12921 .0391 L
.12984 .0392 L
.13048 .03931 L
.13111 .03943 L
.13175 .03956 L
.13238 .0397 L
.13302 .03985 L
.13365 .04001 L
.13429 .04018 L
.13492 .04036 L
.13556 .04055 L
.13619 .04075 L
.13683 .04096 L
.13746 .04118 L
.1381 .04141 L
.13873 .04165 L
.13937 .0419 L
.14 .04217 L
.14063 .04244 L
.14127 .04272 L
.1419 .04302 L
.14254 .04332 L
.14317 .04363 L
.14381 .04396 L
.14444 .04429 L
.14508 .04464 L
.14571 .045 L
.14635 .04537 L
.14698 .04574 L
.14762 .04613 L
.14825 .04653 L
.14889 .04694 L
.14952 .04737 L
.15016 .0478 L
.15079 .04824 L
Mistroke
.15143 .0487 L
.15206 .04916 L
.1527 .04964 L
.15333 .05013 L
.15397 .05063 L
.1546 .05114 L
.15524 .05166 L
.15587 .0522 L
.15651 .05275 L
.15714 .0533 L
.15778 .05387 L
.15841 .05446 L
.15905 .05505 L
.15968 .05565 L
.16032 .05627 L
.16095 .0569 L
.16159 .05755 L
.16222 .0582 L
.16286 .05887 L
.16349 .05955 L
.16413 .06024 L
.16476 .06095 L
.1654 .06167 L
.16603 .0624 L
.16667 .06314 L
.1673 .0639 L
.16794 .06467 L
.16857 .06546 L
.16921 .06626 L
.16984 .06707 L
.17048 .0679 L
.17111 .06874 L
.17175 .0696 L
.17238 .07047 L
.17302 .07136 L
.17365 .07226 L
.17429 .07318 L
.17492 .07411 L
.17556 .07506 L
.17619 .07602 L
.17683 .077 L
.17746 .07799 L
.1781 .07901 L
.17873 .08004 L
.17937 .08108 L
.18 .08215 L
.18063 .08323 L
.18127 .08433 L
.1819 .08545 L
.18254 .08659 L
Mistroke
.18317 .08774 L
.18381 .08892 L
.18444 .09011 L
.18508 .09133 L
.18571 .09257 L
.18635 .09383 L
.18698 .0951 L
.18762 .09641 L
.18825 .09773 L
.18889 .09908 L
.18952 .10045 L
.19016 .10184 L
.19079 .10326 L
.19143 .10471 L
.19206 .10618 L
.1927 .10768 L
.19333 .10921 L
.19397 .11076 L
.1946 .11235 L
.19524 .11396 L
.19587 .11561 L
.19651 .11729 L
.19714 .119 L
.19778 .12075 L
.19841 .12254 L
.19905 .12436 L
.19968 .12622 L
.20032 .12812 L
.20095 .13007 L
.20159 .13205 L
.20222 .13409 L
.20286 .13617 L
.20349 .1383 L
.20413 .14049 L
.20476 .14273 L
.2054 .14503 L
.20603 .1474 L
.20667 .14983 L
.2073 .15233 L
.20794 .1549 L
.20857 .15755 L
.20921 .16029 L
.20984 .16312 L
.21048 .16605 L
.21111 .16908 L
.21175 .17222 L
.21238 .1755 L
.21302 .17891 L
.21365 .18246 L
.21429 .18619 L
Mistroke
.21492 .19011 L
.21556 .19423 L
.21619 .19859 L
.21683 .20322 L
.21746 .20817 L
.2181 .21348 L
.21873 .21923 L
.21937 .22551 L
.22 .23244 L
.22063 .24022 L
.22127 .24911 L
.2219 .25955 L
.22254 .27232 L
.22317 .28885 L
.22381 .31058 L
.22444 .33155 L
.22508 .35638 L
.22571 .37267 L
.22635 .38487 L
.22698 .39481 L
.22762 .40329 L
.22825 .41072 L
.22889 .41738 L
.22952 .42343 L
.23016 .42899 L
.23079 .43415 L
.23143 .43897 L
.23206 .4435 L
.2327 .44777 L
.23333 .45183 L
.23397 .45569 L
.2346 .45938 L
.23524 .4629 L
.23587 .46629 L
.23651 .46955 L
.23714 .47268 L
.23778 .47571 L
.23841 .47864 L
.23905 .48147 L
.23968 .48422 L
.24032 .48688 L
.24095 .48947 L
.24159 .49198 L
.24222 .49443 L
.24286 .49681 L
.24349 .49913 L
.24413 .50139 L
.24476 .5036 L
.2454 .50576 L
.24603 .50787 L
Mistroke
.24667 .50993 L
.2473 .51194 L
.24794 .51391 L
.24857 .51584 L
.24921 .51773 L
.24984 .51958 L
.25048 .52139 L
.25111 .52316 L
.25175 .5249 L
.25238 .52661 L
.25302 .52828 L
.25365 .52993 L
.25429 .53154 L
.25492 .53312 L
.25556 .53467 L
.25619 .5362 L
.25683 .5377 L
.25746 .53917 L
.2581 .54061 L
.25873 .54203 L
.25937 .54343 L
.26 .5448 L
.26063 .54615 L
.26127 .54747 L
.2619 .54877 L
.26254 .55005 L
.26317 .55131 L
.26381 .55255 L
.26444 .55376 L
.26508 .55496 L
.26571 .55614 L
.26635 .55729 L
.26698 .55843 L
.26762 .55955 L
.26825 .56065 L
.26889 .56173 L
.26952 .56279 L
.27016 .56384 L
.27079 .56487 L
.27143 .56588 L
.27206 .56687 L
.2727 .56785 L
.27333 .56881 L
.27397 .56976 L
.2746 .57068 L
.27524 .5716 L
.27587 .57249 L
.27651 .57338 L
.27714 .57424 L
.27778 .57509 L
Mistroke
.27841 .57593 L
.27905 .57675 L
.27968 .57756 L
.28032 .57835 L
.28095 .57913 L
.28159 .57989 L
.28222 .58064 L
.28286 .58138 L
.28349 .5821 L
.28413 .58281 L
.28476 .58351 L
.2854 .58419 L
.28603 .58486 L
.28667 .58551 L
.2873 .58616 L
.28794 .58678 L
.28857 .5874 L
.28921 .58801 L
.28984 .5886 L
.29048 .58917 L
.29111 .58974 L
.29175 .59029 L
.29238 .59084 L
.29302 .59136 L
.29365 .59188 L
.29429 .59239 L
.29492 .59288 L
.29556 .59336 L
.29619 .59383 L
.29683 .59428 L
.29746 .59473 L
.2981 .59516 L
.29873 .59558 L
.29937 .59599 L
.3 .59639 L
.30063 .59678 L
.30127 .59715 L
.3019 .59752 L
.30254 .59787 L
.30317 .59821 L
.30381 .59854 L
.30444 .59886 L
.30508 .59917 L
.30571 .59946 L
.30635 .59975 L
.30698 .60002 L
.30762 .60028 L
.30825 .60054 L
.30889 .60078 L
.30952 .60101 L
Mistroke
.31016 .60122 L
.31079 .60143 L
.31143 .60163 L
.31206 .60181 L
.3127 .60199 L
.31333 .60215 L
.31397 .60231 L
.3146 .60245 L
.31524 .60258 L
.31587 .6027 L
.31651 .60281 L
.31714 .60291 L
.31778 .603 L
.31841 .60308 L
.31905 .60314 L
.31968 .6032 L
.32032 .60324 L
.32095 .60328 L
.32159 .6033 L
.32222 .60332 L
.32286 .60332 L
.32349 .60331 L
.32413 .60329 L
.32476 .60326 L
.3254 .60322 L
.32603 .60317 L
.32667 .60311 L
.3273 .60304 L
.32794 .60295 L
.32857 .60286 L
.32921 .60275 L
.32984 .60264 L
.33048 .60251 L
.33111 .60238 L
.33175 .60223 L
.33238 .60207 L
.33302 .6019 L
.33365 .60172 L
.33429 .60153 L
.33492 .60133 L
.33556 .60111 L
.33619 .60089 L
.33683 .60065 L
.33746 .60041 L
.3381 .60015 L
.33873 .59988 L
.33937 .5996 L
.34 .59931 L
.34063 .59901 L
.34127 .5987 L
Mistroke
.3419 .59838 L
.34254 .59804 L
.34317 .5977 L
.34381 .59734 L
.34444 .59697 L
.34508 .59659 L
.34571 .5962 L
.34635 .59579 L
.34698 .59538 L
.34762 .59495 L
.34825 .59452 L
.34889 .59407 L
.34952 .5936 L
.35016 .59313 L
.35079 .59265 L
.35143 .59215 L
.35206 .59164 L
.3527 .59112 L
.35333 .59059 L
.35397 .59004 L
.3546 .58948 L
.35524 .58891 L
.35587 .58833 L
.35651 .58773 L
.35714 .58713 L
.35778 .58651 L
.35841 .58587 L
.35905 .58523 L
.35968 .58457 L
.36032 .58389 L
.36095 .58321 L
.36159 .58251 L
.36222 .5818 L
.36286 .58107 L
.36349 .58033 L
.36413 .57958 L
.36476 .57881 L
.3654 .57803 L
.36603 .57724 L
.36667 .57643 L
.3673 .5756 L
.36794 .57477 L
.36857 .57391 L
.36921 .57304 L
.36984 .57216 L
.37048 .57126 L
.37111 .57035 L
.37175 .56942 L
.37238 .56847 L
.37302 .56751 L
Mistroke
.37365 .56653 L
.37429 .56554 L
.37492 .56453 L
.37556 .5635 L
.37619 .56245 L
.37683 .56139 L
.37746 .56031 L
.3781 .55921 L
.37873 .55809 L
.37937 .55696 L
.38 .5558 L
.38063 .55463 L
.38127 .55344 L
.3819 .55222 L
.38254 .55099 L
.38317 .54974 L
.38381 .54846 L
.38444 .54716 L
.38508 .54585 L
.38571 .5445 L
.38635 .54314 L
.38698 .54175 L
.38762 .54034 L
.38825 .5389 L
.38889 .53744 L
.38952 .53595 L
.39016 .53444 L
.39079 .5329 L
.39143 .53133 L
.39206 .52973 L
.3927 .5281 L
.39333 .52644 L
.39397 .52475 L
.3946 .52303 L
.39524 .52128 L
.39587 .51949 L
.39651 .51766 L
.39714 .5158 L
.39778 .51389 L
.39841 .51195 L
.39905 .50997 L
.39968 .50794 L
.40032 .50587 L
.40095 .50375 L
.40159 .50159 L
.40222 .49937 L
.40286 .4971 L
.40349 .49477 L
.40413 .49238 L
.40476 .48993 L
Mistroke
.4054 .48741 L
.40603 .48482 L
.40667 .48216 L
.4073 .47942 L
.40794 .4766 L
.40857 .47368 L
.40921 .47067 L
.40984 .46755 L
.41048 .46432 L
.41111 .46097 L
.41175 .45748 L
.41238 .45385 L
.41302 .45006 L
.41365 .44609 L
.41429 .44191 L
.41492 .43751 L
.41556 .43286 L
.41619 .42791 L
.41683 .42262 L
.41746 .41692 L
.4181 .41074 L
.41873 .40396 L
.41937 .39644 L
.42 .38793 L
.42063 .37809 L
.42127 .36628 L
.4219 .3512 L
.42254 .33062 L
.42317 .30764 L
.42381 .28499 L
.42444 .26076 L
.42508 .24487 L
.42571 .23285 L
.42635 .22303 L
.42698 .21463 L
.42762 .20726 L
.42825 .20064 L
.42889 .19463 L
.42952 .18909 L
.43016 .18395 L
.43079 .17915 L
.43143 .17464 L
.43206 .17037 L
.4327 .16633 L
.43333 .16247 L
.43397 .1588 L
.4346 .15527 L
.43524 .15189 L
.43587 .14864 L
.43651 .14551 L
Mistroke
.43714 .14248 L
.43778 .13956 L
.43841 .13673 L
.43905 .13399 L
.43968 .13133 L
.44032 .12874 L
.44095 .12623 L
.44159 .12378 L
.44222 .1214 L
.44286 .11908 L
.44349 .11682 L
.44413 .11461 L
.44476 .11245 L
.4454 .11034 L
.44603 .10828 L
.44667 .10627 L
.4473 .1043 L
.44794 .10237 L
.44857 .10048 L
.44921 .09863 L
.44984 .09682 L
.45048 .09505 L
.45111 .0933 L
.45175 .0916 L
.45238 .08992 L
.45302 .08828 L
.45365 .08667 L
.45429 .08508 L
.45492 .08353 L
.45556 .082 L
.45619 .0805 L
.45683 .07903 L
.45746 .07758 L
.4581 .07616 L
.45873 .07477 L
.45937 .07339 L
.46 .07205 L
.46063 .07072 L
.46127 .06942 L
.4619 .06814 L
.46254 .06688 L
.46317 .06564 L
.46381 .06442 L
.46444 .06322 L
.46508 .06204 L
.46571 .06089 L
.46635 .05975 L
.46698 .05863 L
.46762 .05753 L
.46825 .05644 L
Mistroke
.46889 .05538 L
.46952 .05433 L
.47016 .0533 L
.47079 .05229 L
.47143 .05129 L
.47206 .05031 L
.4727 .04935 L
.47333 .04841 L
.47397 .04748 L
.4746 .04656 L
.47524 .04566 L
.47587 .04478 L
.47651 .04391 L
.47714 .04306 L
.47778 .04222 L
.47841 .0414 L
.47905 .04059 L
.47968 .03979 L
.48032 .03901 L
.48095 .03825 L
.48159 .0375 L
.48222 .03676 L
.48286 .03603 L
.48349 .03532 L
.48413 .03463 L
.48476 .03394 L
.4854 .03327 L
.48603 .03262 L
.48667 .03197 L
.4873 .03134 L
.48794 .03072 L
.48857 .03012 L
.48921 .02952 L
.48984 .02894 L
.49048 .02838 L
.49111 .02782 L
.49175 .02728 L
.49238 .02675 L
.49302 .02623 L
.49365 .02572 L
.49429 .02523 L
.49492 .02475 L
.49556 .02428 L
.49619 .02382 L
.49683 .02337 L
.49746 .02294 L
.4981 .02251 L
.49873 .0221 L
.49937 .0217 L
.5 .02131 L
Mistroke
.50063 .02094 L
.50127 .02057 L
.5019 .02022 L
.50254 .01987 L
.50317 .01954 L
.50381 .01922 L
.50444 .01891 L
.50508 .01862 L
.50571 .01833 L
.50635 .01805 L
.50698 .01779 L
.50762 .01754 L
.50825 .01729 L
.50889 .01706 L
.50952 .01684 L
.51016 .01663 L
.51079 .01644 L
.51143 .01625 L
.51206 .01607 L
.5127 .01591 L
.51333 .01575 L
.51397 .01561 L
.5146 .01547 L
.51524 .01535 L
.51587 .01524 L
.51651 .01514 L
.51714 .01505 L
.51778 .01497 L
.51841 .0149 L
.51905 .01484 L
.51968 .0148 L
.52032 .01476 L
.52095 .01473 L
.52159 .01472 L
.52222 .01472 L
.52286 .01472 L
.52349 .01474 L
.52413 .01477 L
.52476 .01481 L
.5254 .01485 L
.52603 .01491 L
.52667 .01499 L
.5273 .01507 L
.52794 .01516 L
.52857 .01526 L
.52921 .01538 L
.52984 .0155 L
.53048 .01564 L
.53111 .01578 L
.53175 .01594 L
Mistroke
.53238 .01611 L
.53302 .01628 L
.53365 .01647 L
.53429 .01667 L
.53492 .01689 L
.53556 .01711 L
.53619 .01734 L
.53683 .01758 L
.53746 .01784 L
.5381 .01811 L
.53873 .01838 L
.53937 .01867 L
.54 .01897 L
.54063 .01928 L
.54127 .0196 L
.5419 .01994 L
.54254 .02028 L
.54317 .02064 L
.54381 .021 L
.54444 .02138 L
.54508 .02177 L
.54571 .02217 L
.54635 .02258 L
.54698 .02301 L
.54762 .02344 L
.54825 .02389 L
.54889 .02435 L
.54952 .02482 L
.55016 .02531 L
.55079 .0258 L
.55143 .02631 L
.55206 .02683 L
.5527 .02736 L
.55333 .0279 L
.55397 .02846 L
.5546 .02902 L
.55524 .0296 L
.55587 .0302 L
.55651 .0308 L
.55714 .03142 L
.55778 .03205 L
.55841 .0327 L
.55905 .03335 L
.55968 .03402 L
.56032 .0347 L
.56095 .0354 L
.56159 .03611 L
.56222 .03683 L
.56286 .03757 L
.56349 .03832 L
Mistroke
.56413 .03908 L
.56476 .03986 L
.5654 .04065 L
.56603 .04146 L
.56667 .04228 L
.5673 .04312 L
.56794 .04397 L
.56857 .04483 L
.56921 .04571 L
.56984 .04661 L
.57048 .04752 L
.57111 .04845 L
.57175 .04939 L
.57238 .05035 L
.57302 .05132 L
.57365 .05231 L
.57429 .05332 L
.57492 .05434 L
.57556 .05538 L
.57619 .05644 L
.57683 .05752 L
.57746 .05861 L
.5781 .05973 L
.57873 .06086 L
.57937 .06201 L
.58 .06318 L
.58063 .06436 L
.58127 .06557 L
.5819 .0668 L
.58254 .06805 L
.58317 .06932 L
.58381 .07061 L
.58444 .07192 L
.58508 .07326 L
.58571 .07462 L
.58635 .076 L
.58698 .07741 L
.58762 .07884 L
.58825 .08029 L
.58889 .08177 L
.58952 .08328 L
.59016 .08481 L
.59079 .08637 L
.59143 .08796 L
.59206 .08958 L
.5927 .09123 L
.59333 .09291 L
.59397 .09462 L
.5946 .09637 L
.59524 .09815 L
Mistroke
.59587 .09997 L
.59651 .10182 L
.59714 .10371 L
.59778 .10564 L
.59841 .10761 L
.59905 .10962 L
.59968 .11168 L
.60032 .11378 L
.60095 .11593 L
.60159 .11813 L
.60222 .12039 L
.60286 .1227 L
.60349 .12506 L
.60413 .12749 L
.60476 .12999 L
.6054 .13255 L
.60603 .13519 L
.60667 .1379 L
.6073 .14069 L
.60794 .14358 L
.60857 .14655 L
.60921 .14963 L
.60984 .15282 L
.61048 .15613 L
.61111 .15956 L
.61175 .16314 L
.61238 .16687 L
.61302 .17078 L
.61365 .17488 L
.61429 .17919 L
.61492 .18375 L
.61556 .18858 L
.61619 .19374 L
.61683 .19927 L
.61746 .20525 L
.6181 .21179 L
.61873 .219 L
.61937 .2271 L
.62 .23637 L
.62063 .24731 L
.62127 .26086 L
.6219 .27797 L
.62254 .29876 L
.62317 .31867 L
.62381 .34046 L
.62444 .35982 L
.62508 .37389 L
.62571 .38498 L
.62635 .39423 L
.62698 .4022 L
Mistroke
.62762 .40926 L
.62825 .41561 L
.62889 .42142 L
.62952 .42677 L
.63016 .43175 L
.63079 .4364 L
.63143 .44079 L
.63206 .44493 L
.6327 .44887 L
.63333 .45262 L
.63397 .4562 L
.6346 .45963 L
.63524 .46292 L
.63587 .46609 L
.63651 .46915 L
.63714 .47209 L
.63778 .47495 L
.63841 .47771 L
.63905 .48038 L
.63968 .48298 L
.64032 .4855 L
.64095 .48795 L
.64159 .49034 L
.64222 .49267 L
.64286 .49493 L
.64349 .49714 L
.64413 .4993 L
.64476 .5014 L
.6454 .50346 L
.64603 .50547 L
.64667 .50744 L
.6473 .50936 L
.64794 .51124 L
.64857 .51308 L
.64921 .51489 L
.64984 .51666 L
.65048 .51839 L
.65111 .52009 L
.65175 .52176 L
.65238 .52339 L
.65302 .525 L
.65365 .52657 L
.65429 .52812 L
.65492 .52963 L
.65556 .53112 L
.65619 .53258 L
.65683 .53402 L
.65746 .53543 L
.6581 .53682 L
.65873 .53818 L
Mistroke
.65937 .53952 L
.66 .54083 L
.66063 .54213 L
.66127 .5434 L
.6619 .54465 L
.66254 .54588 L
.66317 .54708 L
.66381 .54827 L
.66444 .54944 L
.66508 .55059 L
.66571 .55171 L
.66635 .55282 L
.66698 .55392 L
.66762 .55499 L
.66825 .55604 L
.66889 .55708 L
.66952 .5581 L
.67016 .5591 L
.67079 .56009 L
.67143 .56106 L
.67206 .56201 L
.6727 .56295 L
.67333 .56387 L
.67397 .56477 L
.6746 .56566 L
.67524 .56654 L
.67587 .5674 L
.67651 .56824 L
.67714 .56907 L
.67778 .56989 L
.67841 .57069 L
.67905 .57147 L
.67968 .57224 L
.68032 .573 L
.68095 .57375 L
.68159 .57448 L
.68222 .57519 L
.68286 .5759 L
.68349 .57659 L
.68413 .57726 L
.68476 .57792 L
.6854 .57857 L
.68603 .57921 L
.68667 .57984 L
.6873 .58045 L
.68794 .58105 L
.68857 .58163 L
.68921 .58221 L
.68984 .58277 L
.69048 .58332 L
Mistroke
.69111 .58386 L
.69175 .58438 L
.69238 .58489 L
.69302 .58539 L
.69365 .58588 L
.69429 .58636 L
.69492 .58683 L
.69556 .58728 L
.69619 .58772 L
.69683 .58815 L
.69746 .58857 L
.6981 .58898 L
.69873 .58937 L
.69937 .58976 L
.7 .59013 L
.70063 .59049 L
.70127 .59084 L
.7019 .59118 L
.70254 .59151 L
.70317 .59183 L
.70381 .59214 L
.70444 .59243 L
.70508 .59272 L
.70571 .59299 L
.70635 .59325 L
.70698 .5935 L
.70762 .59374 L
.70825 .59397 L
.70889 .59419 L
.70952 .5944 L
.71016 .5946 L
.71079 .59478 L
.71143 .59496 L
.71206 .59512 L
.7127 .59528 L
.71333 .59542 L
.71397 .59555 L
.7146 .59568 L
.71524 .59579 L
.71587 .59589 L
.71651 .59598 L
.71714 .59606 L
.71778 .59613 L
.71841 .59619 L
.71905 .59623 L
.71968 .59627 L
.72032 .5963 L
.72095 .59632 L
.72159 .59632 L
.72222 .59632 L
Mistroke
.72286 .5963 L
.72349 .59628 L
.72413 .59624 L
.72476 .59619 L
.7254 .59613 L
.72603 .59607 L
.72667 .59599 L
.7273 .5959 L
.72794 .5958 L
.72857 .59569 L
.72921 .59557 L
.72984 .59544 L
.73048 .59529 L
.73111 .59514 L
.73175 .59498 L
.73238 .5948 L
.73302 .59462 L
.73365 .59442 L
.73429 .59422 L
.73492 .594 L
.73556 .59377 L
.73619 .59353 L
.73683 .59328 L
.73746 .59302 L
.7381 .59275 L
.73873 .59247 L
.73937 .59218 L
.74 .59187 L
.74063 .59156 L
.74127 .59123 L
.7419 .59089 L
.74254 .59054 L
.74317 .59018 L
.74381 .58981 L
.74444 .58943 L
.74508 .58904 L
.74571 .58863 L
.74635 .58822 L
.74698 .58779 L
.74762 .58735 L
.74825 .5869 L
.74889 .58644 L
.74952 .58596 L
.75016 .58548 L
.75079 .58498 L
.75143 .58447 L
.75206 .58395 L
.7527 .58341 L
.75333 .58287 L
.75397 .58231 L
Mistroke
.7546 .58174 L
.75524 .58116 L
.75587 .58056 L
.75651 .57995 L
.75714 .57933 L
.75778 .5787 L
.75841 .57806 L
.75905 .5774 L
.75968 .57673 L
.76032 .57604 L
.76095 .57534 L
.76159 .57463 L
.76222 .57391 L
.76286 .57317 L
.76349 .57242 L
.76413 .57165 L
.76476 .57087 L
.7654 .57008 L
.76603 .56927 L
.76667 .56845 L
.7673 .56761 L
.76794 .56676 L
.76857 .5659 L
.76921 .56501 L
.76984 .56412 L
.77048 .56321 L
.77111 .56228 L
.77175 .56133 L
.77238 .56037 L
.77302 .5594 L
.77365 .55841 L
.77429 .5574 L
.77492 .55637 L
.77556 .55533 L
.77619 .55427 L
.77683 .55319 L
.77746 .55209 L
.7781 .55098 L
.77873 .54984 L
.77937 .54869 L
.78 .54752 L
.78063 .54633 L
.78127 .54512 L
.7819 .54389 L
.78254 .54263 L
.78317 .54136 L
.78381 .54006 L
.78444 .53875 L
.78508 .5374 L
.78571 .53604 L
Mistroke
.78635 .53465 L
.78698 .53324 L
.78762 .5318 L
.78825 .53034 L
.78889 .52885 L
.78952 .52734 L
.79016 .5258 L
.79079 .52422 L
.79143 .52262 L
.79206 .52099 L
.7927 .51933 L
.79333 .51764 L
.79397 .51591 L
.7946 .51415 L
.79524 .51235 L
.79587 .51052 L
.79651 .50865 L
.79714 .50674 L
.79778 .50479 L
.79841 .50279 L
.79905 .50075 L
.79968 .49867 L
.80032 .49653 L
.80095 .49435 L
.80159 .49211 L
.80222 .48982 L
.80286 .48746 L
.80349 .48505 L
.80413 .48257 L
.80476 .48002 L
.8054 .4774 L
.80603 .47469 L
.80667 .47191 L
.8073 .46903 L
.80794 .46606 L
.80857 .46298 L
.80921 .4598 L
.80984 .45649 L
.81048 .45305 L
.81111 .44946 L
.81175 .44571 L
.81238 .44178 L
.81302 .43766 L
.81365 .4333 L
.81429 .4287 L
.81492 .4238 L
.81556 .41855 L
.81619 .41291 L
.81683 .40678 L
.81746 .40005 L
Mistroke
.8181 .39258 L
.81873 .38414 L
.81937 .37435 L
.82 .36262 L
.82063 .34766 L
.82127 .32668 L
.8219 .3061 L
.82254 .28551 L
.82317 .26295 L
.82381 .24728 L
.82444 .23533 L
.82508 .22554 L
.82571 .21717 L
.82635 .20982 L
.82698 .20323 L
.82762 .19724 L
.82825 .19173 L
.82889 .18662 L
.82952 .18184 L
.83016 .17735 L
.83079 .17311 L
.83143 .16909 L
.83206 .16526 L
.8327 .1616 L
.83333 .15811 L
.83397 .15475 L
.8346 .15152 L
.83524 .14841 L
.83587 .14541 L
.83651 .1425 L
.83714 .13969 L
.83778 .13697 L
.83841 .13433 L
.83905 .13177 L
.83968 .12927 L
.84032 .12685 L
.84095 .12448 L
.84159 .12218 L
.84222 .11993 L
.84286 .11774 L
.84349 .1156 L
.84413 .11351 L
.84476 .11147 L
.8454 .10947 L
.84603 .10752 L
.84667 .10561 L
.8473 .10374 L
.84794 .1019 L
.84857 .1001 L
.84921 .09834 L
Mistroke
.84984 .09662 L
.85048 .09492 L
.85111 .09326 L
.85175 .09163 L
.85238 .09003 L
.85302 .08846 L
.85365 .08692 L
.85429 .08541 L
.85492 .08392 L
.85556 .08246 L
.85619 .08103 L
.85683 .07962 L
.85746 .07823 L
.8581 .07687 L
.85873 .07554 L
.85937 .07422 L
.86 .07293 L
.86063 .07166 L
.86127 .07041 L
.8619 .06918 L
.86254 .06797 L
.86317 .06679 L
.86381 .06562 L
.86444 .06447 L
.86508 .06334 L
.86571 .06223 L
.86635 .06114 L
.86698 .06006 L
.86762 .05901 L
.86825 .05797 L
.86889 .05695 L
.86952 .05594 L
.87016 .05496 L
.87079 .05398 L
.87143 .05303 L
.87206 .05209 L
.8727 .05117 L
.87333 .05026 L
.87397 .04937 L
.8746 .04849 L
.87524 .04763 L
.87587 .04678 L
.87651 .04595 L
.87714 .04514 L
.87778 .04433 L
.87841 .04355 L
.87905 .04277 L
.87968 .04201 L
.88032 .04126 L
.88095 .04053 L
Mistroke
.88159 .03981 L
.88222 .03911 L
.88286 .03842 L
.88349 .03774 L
.88413 .03707 L
.88476 .03642 L
.8854 .03578 L
.88603 .03515 L
.88667 .03454 L
.8873 .03394 L
.88794 .03335 L
.88857 .03277 L
.88921 .03221 L
.88984 .03165 L
.89048 .03112 L
.89111 .03059 L
.89175 .03007 L
.89238 .02957 L
.89302 .02908 L
.89365 .0286 L
.89429 .02813 L
.89492 .02767 L
.89556 .02723 L
.89619 .0268 L
.89683 .02637 L
.89746 .02597 L
.8981 .02557 L
.89873 .02518 L
.89937 .0248 L
.9 .02444 L
.90063 .02409 L
.90127 .02374 L
.9019 .02341 L
.90254 .02309 L
.90317 .02279 L
.90381 .02249 L
.90444 .0222 L
.90508 .02193 L
.90571 .02166 L
.90635 .02141 L
.90698 .02117 L
.90762 .02094 L
.90825 .02071 L
.90889 .0205 L
.90952 .02031 L
.91016 .02012 L
.91079 .01994 L
.91143 .01977 L
.91206 .01962 L
.9127 .01947 L
Mistroke
.91333 .01934 L
.91397 .01921 L
.9146 .0191 L
.91524 .01899 L
.91587 .0189 L
.91651 .01882 L
.91714 .01875 L
.91778 .01869 L
.91841 .01864 L
.91905 .0186 L
.91968 .01857 L
.92032 .01855 L
.92095 .01855 L
.92159 .01855 L
.92222 .01856 L
.92286 .01859 L
.92349 .01862 L
.92413 .01867 L
.92476 .01872 L
.9254 .01879 L
.92603 .01887 L
.92667 .01895 L
.9273 .01905 L
.92794 .01916 L
.92857 .01928 L
.92921 .01941 L
.92984 .01955 L
.93048 .0197 L
.93111 .01986 L
.93175 .02004 L
.93238 .02022 L
.93302 .02042 L
.93365 .02062 L
.93429 .02084 L
.93492 .02106 L
.93556 .0213 L
.93619 .02155 L
.93683 .02181 L
.93746 .02208 L
.9381 .02236 L
.93873 .02265 L
.93937 .02295 L
.94 .02327 L
.94063 .02359 L
.94127 .02393 L
.9419 .02428 L
.94254 .02464 L
.94317 .025 L
.94381 .02539 L
.94444 .02578 L
Mistroke
.94508 .02618 L
.94571 .0266 L
.94635 .02702 L
.94698 .02746 L
.94762 .02791 L
.94825 .02837 L
.94889 .02885 L
.94952 .02933 L
.95016 .02983 L
.95079 .03034 L
.95143 .03086 L
.95206 .03139 L
.9527 .03193 L
.95333 .03249 L
.95397 .03306 L
.9546 .03364 L
.95524 .03423 L
.95587 .03484 L
.95651 .03546 L
.95714 .03609 L
.95778 .03673 L
.95841 .03739 L
.95905 .03806 L
.95968 .03874 L
.96032 .03944 L
.96095 .04015 L
.96159 .04087 L
.96222 .04161 L
.96286 .04236 L
.96349 .04312 L
.96413 .0439 L
.96476 .04469 L
.9654 .04549 L
.96603 .04631 L
.96667 .04715 L
.9673 .048 L
.96794 .04886 L
.96857 .04974 L
.96921 .05063 L
.96984 .05154 L
.97048 .05247 L
.97111 .05341 L
.97175 .05436 L
.97238 .05534 L
.97302 .05632 L
.97365 .05733 L
.97429 .05835 L
.97492 .05939 L
.97556 .06045 L
.97619 .06152 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?
Ool000moo`800?mooa1oo`003goo00<007ooOol0QGoo1P0OPgoo000?Ool00`00Oomoo`22Ool401l4
Ool401mVOol601lDOol000moo`03001oogoo085oo`807`Yoo`807f=oo`<07`Aoo`@07a5oo`003goo
00<007ooOol0Ogoo0`0O3Goo0P0OGgoo0P0O2Woo0P0O47oo000?Ool00`00Oomoo`1nOol201l@Ool2
01mLOol301l=Ool201l>Ool000moo`8007ioo`807a9oo`807eYoo`807a1oo`807`eoo`003goo00<0
07ooOol0O7oo0P0O57oo0P0OF7oo0P0O4Woo0P0O37oo000?Ool00`00Oomoo`0EOol801mOOol00`0O
Oomoo`0DOol201mFOol201lDOol201l;Ool000moo`03001oogoo01=oo`<07`Moo`<07e]oo`0301mo
ogoo01Ioo`0301moogoo05Aoo`0301moogoo01Aoo`807`Yoo`003goo00<007ooOol04Goo0`0O2goo
0P0OFGoo0P0O6Goo00<07gooOol0DWoo00<07gooOol05Woo00<07gooOol027oo000?Ool00`00Oomo
o`0@Ool201l>Ool301mFOol201lJOol201mBOol201lIOol00`0OOomoo`07Ool000moo`80011oo`80
7a5oo`807eEoo`0301moogoo01Yoo`0301moogoo04moo`807aYoo`807`Qoo`003goo00<007ooOol0
3Woo00<07gooOol04Woo0P0ODgoo0P0O7Goo00<07gooOol0CWoo00<07gooOol06Woo00<07gooOol0
1Woo000?Ool00`00Oomoo`0=Ool201lEOol201mBOol00`0OOomoo`0LOol201m>Ool201lMOol00`0O
Oomoo`05Ool000moo`03001oogoo00aoo`807aMoo`0301moogoo04moo`807amoo`0301moogoo04ao
o`0301moogoo02Aoo`003goo00<007ooOol02goo0P0O67oo0P0OD7oo00<07gooOol07Woo0P0OC7oo
00<07gooOol09Goo000?Ool2000<Ool00`0OOomoo`0HOol201m>Ool00`0OOomoo`0POol00`0OOomo
o`1:Ool00`0OOomoo`0UOol000moo`03001oogoo00Yoo`0301moogoo01Yoo`807deoo`0301moogoo
021oo`0301moogoo04Uoo`0301moogoo02Ioo`003goo00<007ooOol02Goo0P0O7Goo00<07gooOol0
BWoo0P0O8goo00<07gooOol0B7oo00<07gooOol09Woo000?Ool00`00Oomoo`09Ool00`0OOomoo`0L
Ool201m;Ool00`0OOomoo`0ROol00`0OOomoo`17Ool201lXOol000Moo`@000Aoo`03001oogoo00Qo
o`0301moogoo01ioo`0301moogoo04Uoo`0301moogoo02=oo`0301moogoo04Ioo`0301moogoo02Mo
o`001goo00<007ooOol01Goo00<007ooOol027oo00<07gooOol07Woo0P0OBGoo00<07gooOol097oo
00<07gooOol0AGoo0P0O:Goo0008Ool00`00Oomoo`04Ool30007Ool00`0OOomoo`0POol00`0OOomo
o`17Ool00`0OOomoo`0TOol201m6Ool00`0OOomoo`0XOol00003Ool00000008000Aoo`03001oogoo
00=oo`03001oogoo00Moo`0301moogoo021oo`807dMoo`807bMoo`0301moogoo04Aoo`0301moogoo
02Qoo`001goo00@007ooOol000Aoo`03001oogoo00Ioo`0301moogoo029oo`0301moogoo04Eoo`03
01moogoo02Ioo`0301moogoo04=oo`0301moogoo02Uoo`0027oo0P001Goo00<007ooOol01Woo00<0
7gooOol08Woo0P0OAWoo00<07gooOol09Woo0P0OA7oo00<07gooOol0:Goo000?Ool00`00Oomoo`05
Ool00`0OOomoo`0TOol00`0OOomoo`13Ool201lYOol00`0OOomoo`12Ool00`0OOomoo`0YOol000mo
o`03001oogoo00Eoo`0301moogoo02Aoo`0301moogoo04=oo`0301moogoo02Qoo`0301moogoo045o
o`0301moogoo02Yoo`003goo0P001Woo00<07gooOol09Goo00<07gooOol0@Woo00<07gooOol0:7oo
0P0O@Woo00<07gooOol0:Woo000?Ool00`00Oomoo`04Ool00`0OOomoo`0VOol00`0OOomoo`12Ool0
0`0OOomoo`0YOol00`0OOomoo`10Ool00`0OOomoo`0ZOol000moo`03001oogoo00Aoo`0301moogoo
02Ioo`807d9oo`0301moogoo02Yoo`0301moogoo03moo`0301moogoo02]oo`003goo00<007ooOol0
17oo00<07gooOol09goo00<07gooOol0@7oo00<07gooOol0:Woo00<07gooOol0?goo00<07gooOol0
:goo000?Ool00`00Oomoo`03Ool00`0OOomoo`0XOol00`0OOomoo`10Ool00`0OOomoo`0ZOol201m0
Ool00`0OOomoo`0[Ool000moo`03001oogoo00=oo`0301moogoo02Qoo`807d1oo`807beoo`0301mo
ogoo03ioo`0301moogoo02]oo`003goo0P000goo0P0O:goo00<07gooOol0?Woo00<07gooOol0;7oo
00<07gooOol0?Goo00<07gooOol0;7oo000?Ool00`00Oomoo`02Ool00`0OOomoo`0ZOol00`0OOomo
o`0nOol00`0OOomoo`0/Ool00`0OOomoo`0mOol00`0OOomoo`0/Ool000moo`03001oogoo009oo`03
01moogoo02Yoo`0301moogoo03ioo`0301moogoo02aoo`0301moogoo03eoo`0301moogoo02aoo`00
3goo00<007ooOol00Woo00<07gooOol0:goo00<07gooOol0?Goo00<07gooOol0;Goo00<07gooOol0
?7oo00<07gooOol0;7oo000?Ool01000Oomoogoo0P0O;Goo00<07gooOol0?7oo00<07gooOol0;Woo
00<07gooOol0>goo00<07gooOol0;Goo000?Ool01@00Oomoogoo01l0;Woo00<07gooOol0?7oo00<0
7gooOol0;Woo00<07gooOol0>goo00<07gooOol0;Goo000?Ool20002Ool00`0OOomoo`0/Ool00`0O
Oomoo`0lOol00`0OOomoo`0^Ool00`0OOomoo`0kOol00`0OOomoo`0]Ool000moo`05001oogooOol0
7`0_Ool00`0OOomoo`0kOol00`0OOomoo`0_Ool00`0OOomoo`0jOol00`0OOomoo`0]Ool000moo`05
001oogooOol07`0_Ool00`0OOomoo`0kOol00`0OOomoo`0_Ool00`0OOomoo`0jOol00`0OOomoo`0]
Ool000moo`04001oogoo01l`Ool00`0OOomoo`0kOol00`0OOomoo`0_Ool00`0OOomoo`0jOol00`0O
Oomoo`0]Ool000moo`04001oogoo01l`Ool00`0OOomoo`0jOol00`0OOomoo`0`Ool00`0OOomoo`0i
Ool00`0OOomoo`0^Ool000moo`04001oogoo01l`Ool00`0OOomoo`0jOol00`0OOomoo`0`Ool00`0O
Oomoo`0iOol00`0OOomoo`0^Ool000moo`800003Ool07goo031oo`0301moogoo03Uoo`0301moogoo
031oo`0301moogoo03Uoo`0301moogoo02ioo`003goo00@007ooOol07c5oo`0301moogoo03Uoo`03
01moogoo031oo`0301moogoo03Uoo`0301moogoo02ioo`003goo00<007oo01l0<Woo00<07gooOol0
>Goo00<07gooOol0<Goo00<07gooOol0>7oo00<07gooOol0;Woo000?Ool00`00Ool07`0bOol00`0O
Oomoo`0iOol00`0OOomoo`0aOol00`0OOomoo`0hOol00`0OOomoo`0^Ool000Moo`D000=oo`03001o
o`0O039oo`0301moogoo03Uoo`0301moogoo035oo`0301moogoo03Qoo`0301moogoo02ioo`002Goo
00<007ooOol00goo00<007oo01l0<Woo00<07gooOol0>7oo00<07gooOol0<Woo00<07gooOol0>7oo
00<07gooOol0;Woo0009Ool00`00Oomoo`03Ool200000`0OOomoo`0aOol00`0OOomoo`0gOol00`0O
Oomoo`0bOol00`0OOomoo`0gOol00`0OOomoo`0_Ool00003Ool00000008000Aoo`03001oogoo00=o
o`03001oo`0O03=oo`0301moogoo03Moo`0301moogoo039oo`0301moogoo03Moo`0301moogoo02mo
o`002Goo00<007ooOol00goo00<007oo01l0<goo00<07gooOol0=goo00<07gooOol0<Woo00<07goo
Ool0=goo00<07gooOol0;goo0008Ool20005Ool00`00Ool07`0cOol00`0OOomoo`0gOol00`0OOomo
o`0bOol00`0OOomoo`0gOol00`0OOomoo`0_Ool000moo`0300007goo03=oo`0301moogoo03Moo`03
01moogoo039oo`0301moogoo03Moo`0301moogoo02moo`003goo00<0000OOol0<goo00<07gooOol0
=goo00<07gooOol0<Woo00<07gooOol0=goo00<07gooOol0;goo000?Ool00`0001moo`0cOol00`0O
Oomoo`0gOol00`0OOomoo`0cOol00`0OOomoo`0fOol00`0OOomoo`0_Ool000moo`0300007goo03=o
o`0301moogoo03Moo`0301moogoo03=oo`0301moogoo03Ioo`0301moogoo02moo`003goo00<0000O
Ool0=7oo00<07gooOol0=Woo00<07gooOol0<goo00<07gooOol0=Woo00<07gooOol0;goo000?Ool0
0`0001moo`0dOol00`0OOomoo`0fOol00`0OOomoo`0cOol00`0OOomoo`0fOol00`0OOomoo`0_Ool0
00moo`0300007goo03Aoo`0301moogoo03Ioo`0301moogoo03=oo`0301moogoo03Ioo`0301moogoo
02moo`003goo00<0000OOol0=7oo00<07gooOol0=Woo00<07gooOol0<goo00<07gooOol0=Woo00<0
7gooOol0;goo000?Ool00`0001moo`0dOol00`0OOomoo`0fOol00`0OOomoo`0cOol00`0OOomoo`0e
Ool00`0OOomoo`0`Ool000moo`0300007goo03Aoo`0301moogoo03Ioo`0301moogoo03=oo`0301mo
ogoo03Eoo`0301moogoo031oo`003goo00<0000OOol0=7oo00<07gooOol0=Woo00<07gooOol0<goo
00<07gooOol0=Goo00<07gooOol0<7oo000?Ool00`0001moo`0dOol00`0OOomoo`0eOol00`0OOomo
o`0dOol00`0OOomoo`0eOol00`0OOomoo`0`Ool000moo`0300007goo03Aoo`0301moogoo03Eoo`03
01moogoo03Aoo`0301moogoo03Eoo`0301moogoo031oo`003goo00<0000OOol0=7oo00<07gooOol0
=Goo00<07gooOol0=7oo00<07gooOol0=Goo00<07gooOol0<7oo000?Ool00`0001moo`0dOol00`0O
Oomoo`0eOol00`0OOomoo`0dOol00`0OOomoo`0eOol00`0OOomoo`0`Ool000moo`0301moogoo01Qo
o`@000=oo`8000Aoo`8000eoo`0301moogoo00Moo`<0009oo`8000Aoo`8001Aoo`<000Aoo`8000Ao
o`0301l007oo01Aoo`8000Aoo`8000Aoo`80019oo`0301l000000080009oo`8000Aoo`8000Aoo`80
00ioo`D00003Ool00000008000=oo`8000Aoo`80000301moogoo00]oo`D000=oo`<0009oo`8000Ao
o`80011oo`003goo00<07gooOol067oo00<007ooOol00goo00@007ooOol0009oo`04001oogoo000<
Ool00`0OOomoo`08Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo015oo`04001oogoo
0002Ool01000Oomoo`000Woo00@0000OOol001=oo`04001oogoo0002Ool01000Oomoo`000Woo00@0
07ooOol0015oo`0301moo`0000=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000mo
o`05001oogooOol00005Ool01000Oomoo`000Woo00@007ooOol07`moo`03001oogoo00Aoo`04001o
ogoo0002Ool01000Oomoo`000Woo00<007ooOol03Goo000?Ool00`0OOomoo`0IOol00`00Oomoo`02
Ool01000Oomoo`000Woo00@007ooOol000aoo`0301moogoo00Eoo`D00005Ool007ooOol00002Ool0
1000Oomoo`004goo00@007ooOol0009oo`04001oogoo0002Ool0100001moo`004goo00@007ooOol0
009oo`04001oogoo0002Ool01000Oomoo`004Goo00<07goo00000goo00@007ooOol0009oo`04001o
ogoo0002Ool01000Oomoo`003goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`04
001oogoo01l?Ool01000Oomoogoo1@0000Eoo`00Oomoo`00009oo`04001oogoo000?Ool000moo`03
01moogoo01Yoo`05001oogooOol00002Ool01000Oomoo`000Woo00<007ooOol02Woo00<07gooOol0
1Goo00@007ooOol0009oo`04001oogoo0002Ool01000Oomoo`004goo0`000goo00@007ooOol0009o
o`0400007goo000DOol20003Ool01000Oomoo`000Woo00@007ooOol0015oo`0301moo`0000=oo`04
001oogoo0002Ool01000Oomoo`000Woo00@007ooOol000moo`03001oogoo00=oo`05001oogooOol0
0002Ool01000Oomoo`000Woo00<07gooOol03Goo00D007ooOomoo`00009oo`04001oogoo0002Ool0
1000Oomoo`000Woo00<007ooOol03Goo000?Ool00`0OOomoo`0HOol01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogoo000<Ool00`0OOomoo`06Ool00`00Ool00002Ool01000Oomoo`000Woo00@0
07ooOol001Aoo`03001oogoo009oo`04001oogoo0002Ool0100001moo`004goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`004Goo00<07goo00000goo00@007ooOol0009oo`04001oogoo
0002Ool01000Oomoo`003goo00D007ooOomoo`00009oo`04001oogoo0002Ool01000Oomoo`000Woo
00<07gooOol03Goo00<007ooOol00Woo00<007oo00000Woo00@007ooOol0009oo`04001oogoo000?
Ool000moo`0301l007oo01Uoo`8000Aoo`8000Aoo`8000eoo`0301moogoo00Moo`8000=oo`8000Ao
o`8001Eoo`<000=oo`8000Aoo`0301l007oo01Aoo`8000Aoo`8000Aoo`8001=oo`0301l007oo00=o
o`8000Aoo`8000Aoo`8000moo`8000Aoo`8000Aoo`8000Aoo`80000301moogoo00aoo`8000Eoo`80
00=oo`8000Aoo`80011oo`003goo00<07gooOol0=7oo00<07gooOol0=Goo00<07gooOol0=Goo00<0
7gooOol0=7oo00<07gooOol0<7oo000?Ool00`00Oomoo`0dOol00`0OOomoo`0eOol00`0OOomoo`0e
Ool00`0OOomoo`0dOol00`0OOomoo`0`Ool000moo`03001oogoo03Eoo`0301moogoo03Aoo`0301mo
ogoo03Eoo`0301moogoo03Aoo`0301moogoo031oo`003goo00<007ooOol0=Goo00<07gooOol0=7oo
00<07gooOol0=Goo00<07gooOol0=7oo00<07gooOol0<7oo000?Ool00`00Oomoo`0eOol00`0OOomo
o`0dOol00`0OOomoo`0eOol00`0OOomoo`0dOol00`0OOomoo`0`Ool000Qoocl0000301l0000003@0
000301l0000003D0000301l0000003@0000301l00000030000003goo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Woo00@007oo
Ool07`Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001o
ogoo00Ioo`03001oogoo009oo`0501moogooOol00008Ool00`00Oomoo`05Ool00`00Oomoo`06Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`0O001oo`07Ool00`00Oomoo`05Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`0001moo`06Ool0
0`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool0
00moo`03001oogoo021oo`03001oogoo019oo`0301moogoo00aoo`03001oogoo021oo`03001oogoo
009oo`0301moogoo01]oo`03001oogoo01Moo`0301moogoo00Moo`03001oogoo021oo`03001oogoo
00Moo`0301moogoo01Ioo`03001oogoo01Moo`003goo00<007ooOol0=Goo00<07gooOol0=7oo00<0
7gooOol0=Goo00<07gooOol0=7oo00<07gooOol0<7oo000?Ool00`00Oomoo`0eOol00`0OOomoo`0d
Ool00`0OOomoo`0eOol00`0OOomoo`0dOol00`0OOomoo`0`Ool000moo`03001oogoo03Eoo`0301mo
ogoo03Aoo`0301moogoo03Eoo`0301moogoo03Aoo`0301moogoo031oo`003goo0P00=Woo00<07goo
Ool0=7oo00<07gooOol0=Goo00<07gooOol0=7oo00<07gooOol0<7oo000?Ool00`00Oomoo`0eOol0
0`0OOomoo`0dOol00`0OOomoo`0eOol00`0OOomoo`0dOol00`0OOomoo`0`Ool000moo`03001oogoo
03Eoo`0301moogoo03Aoo`0301moogoo03Eoo`0301moogoo03Aoo`0301moogoo031oo`003goo00<0
07ooOol0=Goo00<07gooOol0=7oo00<07gooOol0=Goo00<07gooOol0=7oo00<07gooOol0<7oo000?
Ool00`00Oomoo`0eOol00`0OOomoo`0dOol00`0OOomoo`0eOol00`0OOomoo`0dOol00`0OOomoo`0`
Ool000moo`03001oogoo03Eoo`0301moogoo03Aoo`0301moogoo03Eoo`0301moogoo03Aoo`0301mo
ogoo031oo`003goo0P00=Woo00<07gooOol0=7oo00<07gooOol0=Goo00<07gooOol0=7oo00<07goo
Ool0<7oo000?Ool00`00Oomoo`0eOol00`0OOomoo`0dOol00`0OOomoo`0eOol00`0OOomoo`0cOol0
0`0OOomoo`0aOol000moo`03001oogoo03Eoo`0301moogoo03Aoo`0301moogoo03Eoo`0301moogoo
03=oo`0301moogoo035oo`003goo00<007ooOol0=Goo00<07gooOol0=7oo00<07gooOol0=Goo00<0
7gooOol0<goo00<07gooOol0<Goo000?Ool00`00Oomoo`0eOol00`0OOomoo`0dOol00`0OOomoo`0e
Ool00`0OOomoo`0cOol00`0OOomoo`0aOol000moo`03001oogoo03Eoo`0301moogoo03Aoo`0301mo
ogoo03Eoo`0301moogoo03=oo`0301moogoo035oo`003goo0P00=Woo00<07gooOol0<goo00<07goo
Ool0=Woo00<07gooOol0<goo00<07gooOol0<Goo000?Ool00`00Oomoo`0eOol00`0OOomoo`0cOol0
0`0OOomoo`0fOol00`0OOomoo`0cOol00`0OOomoo`0aOol000moo`03001oogoo03Eoo`0301moogoo
03=oo`0301moogoo03Ioo`0301moogoo03=oo`0301moogoo035oo`003goo00<007ooOol0=Goo00<0
7gooOol0<goo00<07gooOol0=Woo00<07gooOol0<goo00<07gooOol0<Goo000?Ool00`00Oomoo`0e
Ool00`0OOomoo`0cOol00`0OOomoo`0fOol00`0OOomoo`0cOol00`0OOomoo`0aOol000moo`03001o
ogoo03Eoo`0301moogoo03=oo`0301moogoo03Moo`0301moogoo039oo`0301moogoo035oo`003goo
0P00=Woo00<07gooOol0<goo00<07gooOol0=goo00<07gooOol0<Woo00<07gooOol0<Goo000?Ool0
0`00Oomoo`0fOol00`0OOomoo`0bOol00`0OOomoo`0gOol00`0OOomoo`0bOol00`0OOomoo`0aOol0
00moo`03001oogoo03Ioo`0301moogoo039oo`0301moogoo03Moo`0301moogoo039oo`0301moogoo
035oo`003goo00<007ooOol0=Woo00<07gooOol0<Woo00<07gooOol0=goo00<07gooOol0<Woo00<0
7gooOol0<Goo0007Ool50003Ool00`00Oomoo`0fOol00`0OOomoo`0bOol00`0OOomoo`0gOol00`0O
Oomoo`0aOol00`0OOomoo`0bOol000Uoo`03001oogoo00=oo`03001oogoo03Ioo`0301moogoo035o
o`0301moogoo03Qoo`0301moogoo035oo`0301moogoo039oo`002Goo00<007ooOol00goo0`00=Woo
00<07gooOol0<Goo00<07gooOol0>7oo00<07gooOol0<Goo00<07gooOol0<Woo0009Ool00`00Oomo
o`03Ool00`00Oomoo`0fOol00`0OOomoo`0aOol00`0OOomoo`0hOol00`0OOomoo`0aOol00`0OOomo
o`0bOol000Uoo`03001oogoo00=oo`03001oogoo03Ioo`0301moogoo035oo`0301moogoo03Qoo`03
01moogoo035oo`0301moogoo039oo`0027oo0P001Goo00<007ooOol0=Woo00<07gooOol0<Goo00<0
7gooOol0>7oo00<07gooOol0<Goo00<07gooOol0<Woo000?Ool00`00Oomoo`0gOol00`0OOomoo`0`
Ool00`0OOomoo`0iOol00`0OOomoo`0`Ool00`0OOomoo`0bOol000moo`03001oogoo03Moo`0301mo
ogoo031oo`0301moogoo03Uoo`0301moogoo031oo`0301moogoo039oo`003goo0P00>7oo00<07goo
Ool0<7oo00<07gooOol0>Goo00<07gooOol0;goo00<07gooOol0<goo000?Ool00`00Oomoo`0gOol0
0`0OOomoo`0`Ool00`0OOomoo`0iOol00`0OOomoo`0_Ool00`0OOomoo`0cOol000moo`03001oogoo
03Moo`0301moogoo02moo`0301moogoo03Yoo`0301moogoo02moo`0301moogoo03=oo`003goo00<0
07ooOol0=goo00<07gooOol0;goo00<07gooOol0>Woo00<07gooOol0;goo00<07gooOol0<goo000?
Ool00`00Oomoo`0gOol00`0OOomoo`0_Ool00`0OOomoo`0kOol00`0OOomoo`0^Ool00`0OOomoo`0c
Ool000moo`03001oogoo03Moo`0301moogoo02moo`0301moogoo03]oo`0301moogoo02ioo`0301mo
ogoo03=oo`003goo0P00>Goo00<07gooOol0;Woo00<07gooOol0>goo00<07gooOol0;Goo00<07goo
Ool0=7oo000?Ool00`00Oomoo`0hOol00`0OOomoo`0^Ool00`0OOomoo`0kOol00`0OOomoo`0]Ool0
0`0OOomoo`0dOol000moo`03001oogoo03Qoo`0301moogoo02eoo`0301moogoo03aoo`0301moogoo
02eoo`0301moogoo03Aoo`003goo00<007ooOol0>7oo00<07gooOol0;Goo00<07gooOol0?7oo0P0O
;Woo00<07gooOol0=7oo000?Ool00`00Oomoo`0hOol00`0OOomoo`0]Ool00`0OOomoo`0mOol00`0O
Oomoo`0/Ool00`0OOomoo`0dOol000moo`03001oogoo03Uoo`0301moogoo02aoo`0301moogoo03eo
o`0301moogoo02]oo`0301moogoo03Eoo`003goo0P00>Woo00<07gooOol0:goo00<07gooOol0?Woo
00<07gooOol0:goo00<07gooOol0=Goo000?Ool00`00Oomoo`0iOol00`0OOomoo`0[Ool00`0OOomo
o`0nOol00`0OOomoo`0[Ool00`0OOomoo`0eOol000moo`03001oogoo03Uoo`0301moogoo02]oo`03
01moogoo03moo`0301moogoo02Uoo`807cMoo`003goo00<007ooOol0>Woo00<07gooOol0:Woo00<0
7gooOol0?goo00<07gooOol0:Goo00<07gooOol0=Woo000?Ool00`00Oomoo`0jOol00`0OOomoo`0Y
Ool201m1Ool00`0OOomoo`0YOol00`0OOomoo`0fOol000moo`03001oogoo03Yoo`0301moogoo02Uo
o`0301moogoo045oo`0301moogoo02Qoo`0301moogoo03Ioo`003goo0P00>goo00<07gooOol0:Goo
00<07gooOol0@Goo00<07gooOol09goo00<07gooOol0=goo000?Ool00`00Oomoo`0kOol00`0OOomo
o`0XOol00`0OOomoo`11Ool00`0OOomoo`0WOol00`0OOomoo`0gOol000moo`03001oogoo03]oo`03
01moogoo02Moo`0301moogoo049oo`807bQoo`0301moogoo03Moo`003goo00<007ooOol0>goo00<0
7gooOol09goo00<07gooOol0@goo00<07gooOol09Goo0P0O>Goo0007Ool40004Ool00`00Oomoo`0k
Ool201lXOol00`0OOomoo`13Ool00`0OOomoo`0UOol00`0OOomoo`0hOol000Moo`03001oogoo00Eo
o`03001oogoo03aoo`0301moogoo02Eoo`0301moogoo04Aoo`807bEoo`807cYoo`0027oo00<007oo
Ool017oo0`00?7oo00<07gooOol09Goo00<07gooOol0AGoo00<07gooOol08goo00<07gooOol0>Goo
0009Ool00`00Oomoo`03Ool00`00Oomoo`0mOol00`0OOomoo`0SOol201m7Ool201lTOol00`0OOomo
o`0iOol000Moo`04001oogoo0004Ool00`00Oomoo`0mOol00`0OOomoo`0SOol00`0OOomoo`17Ool0
0`0OOomoo`0QOol201lkOol000Qoo`8000Eoo`03001oogoo03eoo`807bAoo`0301moogoo04Moo`03
01moogoo025oo`0301moogoo03Yoo`003goo00<007ooOol0?Woo00<07gooOol08Goo0P0OBWoo00<0
7gooOol07goo0P0O?7oo000?Ool00`00Oomoo`0nOol00`0OOomoo`0QOol00`0OOomoo`19Ool00`0O
Oomoo`0OOol00`0OOomoo`0kOol000moo`80041oo`0301moogoo01moo`807d]oo`807amoo`807ceo
o`003goo00<007ooOol0?goo0P0O87oo00<07gooOol0Bgoo00<07gooOol07Goo00<07gooOol0?7oo
000?Ool00`00Oomoo`10Ool00`0OOomoo`0MOol201m>Ool00`0OOomoo`0KOol201lnOol000moo`03
001oogoo041oo`807aioo`0301moogoo04eoo`807aaoo`0301moogoo03eoo`003goo00<007ooOol0
@Goo00<07gooOol06goo0P0OD7oo00<07gooOol06Goo00<07gooOol0?Woo000?Ool00`00Oomoo`11
Ool201lKOol201mAOol201lIOol201m0Ool000moo`8004=oo`0301moogoo01Uoo`0301moogoo055o
o`807aMoo`807d5oo`003goo00<007ooOol0@goo00<07gooOol05goo0P0OE7oo0P0O5Woo00<07goo
Ool0@7oo000?Ool00`00Oomoo`13Ool201lGOol201mFOol00`0OOomoo`0COol201m2Ool000moo`03
001oogoo04Aoo`807aEoo`807eQoo`0301moogoo015oo`0301moogoo049oo`003goo00<007ooOol0
AGoo0P0O57oo00<07gooOol0F7oo0P0O47oo0P0OA7oo000?Ool00`00Oomoo`16Ool201lBOol00`0O
Oomoo`1JOol201l=Ool301m5Ool000moo`8004Qoo`807`moo`<07eeoo`807`]oo`807dMoo`003goo
00<007ooOol0B7oo0P0O3Goo0P0OHGoo0`0O1Goo100OB7oo000?Ool00`00Oomoo`19Ool301l:Ool2
01mTOol701m;Ool000moo`03001oogoo04]oo`<07`Eoo`<07kQoo`003goo00<007ooOol0CGoo1`0O
^Woo000?Ool00`00Oomoo`3oOol?Ool000moo`800?mooa1oo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-87.6451, -2.96858, 5.66255, \
0.033517}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["tbl4=Flatten[Chop[Table[{(Y[1,t]-Y[2,t])},{t,1,1500}]]];", "Input"],

Cell[CellGroupData[{

Cell["ListPlot[tbl4,PlotJoined->True,PlotStyle->RGBColor[0,1,1]]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000634921 -0.205152 0.111038 [
[.15079 .00442 -9 -9 ]
[.15079 .00442 9 0 ]
[.27778 .00442 -9 -9 ]
[.27778 .00442 9 0 ]
[.40476 .00442 -9 -9 ]
[.40476 .00442 9 0 ]
[.53175 .00442 -9 -9 ]
[.53175 .00442 9 0 ]
[.65873 .00442 -12 -9 ]
[.65873 .00442 12 0 ]
[.78571 .00442 -12 -9 ]
[.78571 .00442 12 0 ]
[.9127 .00442 -12 -9 ]
[.9127 .00442 12 0 ]
[.01131 .12796 -6 -4.5 ]
[.01131 .12796 0 4.5 ]
[.01131 .239 -6 -4.5 ]
[.01131 .239 0 4.5 ]
[.01131 .35004 -6 -4.5 ]
[.01131 .35004 0 4.5 ]
[.01131 .46107 -6 -4.5 ]
[.01131 .46107 0 4.5 ]
[.01131 .57211 -6 -4.5 ]
[.01131 .57211 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15079 .01692 m
.15079 .02317 L
s
[(200)] .15079 .00442 0 1 Mshowa
.27778 .01692 m
.27778 .02317 L
s
[(400)] .27778 .00442 0 1 Mshowa
.40476 .01692 m
.40476 .02317 L
s
[(600)] .40476 .00442 0 1 Mshowa
.53175 .01692 m
.53175 .02317 L
s
[(800)] .53175 .00442 0 1 Mshowa
.65873 .01692 m
.65873 .02317 L
s
[(1000)] .65873 .00442 0 1 Mshowa
.78571 .01692 m
.78571 .02317 L
s
[(1200)] .78571 .00442 0 1 Mshowa
.9127 .01692 m
.9127 .02317 L
s
[(1400)] .9127 .00442 0 1 Mshowa
.125 Mabswid
.05556 .01692 m
.05556 .02067 L
s
.0873 .01692 m
.0873 .02067 L
s
.11905 .01692 m
.11905 .02067 L
s
.18254 .01692 m
.18254 .02067 L
s
.21429 .01692 m
.21429 .02067 L
s
.24603 .01692 m
.24603 .02067 L
s
.30952 .01692 m
.30952 .02067 L
s
.34127 .01692 m
.34127 .02067 L
s
.37302 .01692 m
.37302 .02067 L
s
.43651 .01692 m
.43651 .02067 L
s
.46825 .01692 m
.46825 .02067 L
s
.5 .01692 m
.5 .02067 L
s
.56349 .01692 m
.56349 .02067 L
s
.59524 .01692 m
.59524 .02067 L
s
.62698 .01692 m
.62698 .02067 L
s
.69048 .01692 m
.69048 .02067 L
s
.72222 .01692 m
.72222 .02067 L
s
.75397 .01692 m
.75397 .02067 L
s
.81746 .01692 m
.81746 .02067 L
s
.84921 .01692 m
.84921 .02067 L
s
.88095 .01692 m
.88095 .02067 L
s
.94444 .01692 m
.94444 .02067 L
s
.97619 .01692 m
.97619 .02067 L
s
.25 Mabswid
0 .01692 m
1 .01692 L
s
.02381 .12796 m
.03006 .12796 L
s
[(3)] .01131 .12796 1 0 Mshowa
.02381 .239 m
.03006 .239 L
s
[(4)] .01131 .239 1 0 Mshowa
.02381 .35004 m
.03006 .35004 L
s
[(5)] .01131 .35004 1 0 Mshowa
.02381 .46107 m
.03006 .46107 L
s
[(6)] .01131 .46107 1 0 Mshowa
.02381 .57211 m
.03006 .57211 L
s
[(7)] .01131 .57211 1 0 Mshowa
.125 Mabswid
.02381 .03913 m
.02756 .03913 L
s
.02381 .06134 m
.02756 .06134 L
s
.02381 .08355 m
.02756 .08355 L
s
.02381 .10575 m
.02756 .10575 L
s
.02381 .15017 m
.02756 .15017 L
s
.02381 .17238 m
.02756 .17238 L
s
.02381 .19458 m
.02756 .19458 L
s
.02381 .21679 m
.02756 .21679 L
s
.02381 .26121 m
.02756 .26121 L
s
.02381 .28341 m
.02756 .28341 L
s
.02381 .30562 m
.02756 .30562 L
s
.02381 .32783 m
.02756 .32783 L
s
.02381 .37224 m
.02756 .37224 L
s
.02381 .39445 m
.02756 .39445 L
s
.02381 .41666 m
.02756 .41666 L
s
.02381 .43887 m
.02756 .43887 L
s
.02381 .48328 m
.02756 .48328 L
s
.02381 .50549 m
.02756 .50549 L
s
.02381 .5277 m
.02756 .5277 L
s
.02381 .54991 m
.02756 .54991 L
s
.02381 .59432 m
.02756 .59432 L
s
.02381 .61653 m
.02756 .61653 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 1 r
.5 Mabswid
.02444 .02803 m
.02508 .03932 L
.02571 .05679 L
.02635 .07479 L
.02698 .09184 L
.02762 .10769 L
.02825 .12242 L
.02889 .13615 L
.02952 .14901 L
.03016 .16111 L
.03079 .17254 L
.03143 .18338 L
.03206 .1937 L
.0327 .20355 L
.03333 .21297 L
.03397 .22202 L
.0346 .23071 L
.03524 .23908 L
.03587 .24716 L
.03651 .25497 L
.03714 .26252 L
.03778 .26984 L
.03841 .27694 L
.03905 .28384 L
.03968 .29054 L
.04032 .29706 L
.04095 .30341 L
.04159 .3096 L
.04222 .31564 L
.04286 .32153 L
.04349 .32728 L
.04413 .33289 L
.04476 .33838 L
.0454 .34375 L
.04603 .34901 L
.04667 .35415 L
.0473 .35919 L
.04794 .36412 L
.04857 .36895 L
.04921 .37369 L
.04984 .37834 L
.05048 .38289 L
.05111 .38736 L
.05175 .39175 L
.05238 .39606 L
.05302 .40029 L
.05365 .40444 L
.05429 .40852 L
.05492 .41252 L
.05556 .41646 L
Mistroke
.05619 .42033 L
.05683 .42413 L
.05746 .42786 L
.0581 .43154 L
.05873 .43515 L
.05937 .4387 L
.06 .44219 L
.06063 .44562 L
.06127 .449 L
.0619 .45232 L
.06254 .45559 L
.06317 .4588 L
.06381 .46196 L
.06444 .46507 L
.06508 .46813 L
.06571 .47114 L
.06635 .4741 L
.06698 .47701 L
.06762 .47988 L
.06825 .4827 L
.06889 .48547 L
.06952 .4882 L
.07016 .49089 L
.07079 .49353 L
.07143 .49612 L
.07206 .49868 L
.0727 .50119 L
.07333 .50366 L
.07397 .5061 L
.0746 .50849 L
.07524 .51084 L
.07587 .51315 L
.07651 .51542 L
.07714 .51766 L
.07778 .51985 L
.07841 .52201 L
.07905 .52413 L
.07968 .52622 L
.08032 .52826 L
.08095 .53028 L
.08159 .53225 L
.08222 .53419 L
.08286 .5361 L
.08349 .53797 L
.08413 .5398 L
.08476 .5416 L
.0854 .54337 L
.08603 .5451 L
.08667 .5468 L
.0873 .54847 L
Mistroke
.08794 .55011 L
.08857 .55171 L
.08921 .55328 L
.08984 .55481 L
.09048 .55632 L
.09111 .55779 L
.09175 .55923 L
.09238 .56064 L
.09302 .56201 L
.09365 .56336 L
.09429 .56468 L
.09492 .56596 L
.09556 .56722 L
.09619 .56844 L
.09683 .56963 L
.09746 .5708 L
.0981 .57193 L
.09873 .57303 L
.09937 .57411 L
.1 .57515 L
.10063 .57616 L
.10127 .57715 L
.1019 .5781 L
.10254 .57903 L
.10317 .57993 L
.10381 .5808 L
.10444 .58164 L
.10508 .58245 L
.10571 .58323 L
.10635 .58398 L
.10698 .58471 L
.10762 .5854 L
.10825 .58607 L
.10889 .58671 L
.10952 .58732 L
.11016 .58791 L
.11079 .58846 L
.11143 .58899 L
.11206 .58949 L
.1127 .58996 L
.11333 .59041 L
.11397 .59082 L
.1146 .59121 L
.11524 .59157 L
.11587 .5919 L
.11651 .59221 L
.11714 .59248 L
.11778 .59273 L
.11841 .59296 L
.11905 .59315 L
Mistroke
.11968 .59332 L
.12032 .59346 L
.12095 .59357 L
.12159 .59365 L
.12222 .59371 L
.12286 .59374 L
.12349 .59374 L
.12413 .59372 L
.12476 .59367 L
.1254 .59359 L
.12603 .59348 L
.12667 .59334 L
.1273 .59318 L
.12794 .59299 L
.12857 .59277 L
.12921 .59253 L
.12984 .59225 L
.13048 .59195 L
.13111 .59163 L
.13175 .59127 L
.13238 .59089 L
.13302 .59048 L
.13365 .59004 L
.13429 .58957 L
.13492 .58908 L
.13556 .58855 L
.13619 .588 L
.13683 .58743 L
.13746 .58682 L
.1381 .58618 L
.13873 .58552 L
.13937 .58483 L
.14 .58411 L
.14063 .58336 L
.14127 .58259 L
.1419 .58178 L
.14254 .58095 L
.14317 .58009 L
.14381 .5792 L
.14444 .57828 L
.14508 .57733 L
.14571 .57635 L
.14635 .57534 L
.14698 .57431 L
.14762 .57324 L
.14825 .57215 L
.14889 .57102 L
.14952 .56987 L
.15016 .56868 L
.15079 .56747 L
Mistroke
.15143 .56622 L
.15206 .56495 L
.1527 .56364 L
.15333 .5623 L
.15397 .56093 L
.1546 .55954 L
.15524 .55811 L
.15587 .55664 L
.15651 .55515 L
.15714 .55363 L
.15778 .55207 L
.15841 .55048 L
.15905 .54886 L
.15968 .54721 L
.16032 .54552 L
.16095 .5438 L
.16159 .54205 L
.16222 .54026 L
.16286 .53844 L
.16349 .53658 L
.16413 .53469 L
.16476 .53277 L
.1654 .53081 L
.16603 .52882 L
.16667 .52679 L
.1673 .52472 L
.16794 .52262 L
.16857 .52048 L
.16921 .5183 L
.16984 .51609 L
.17048 .51384 L
.17111 .51155 L
.17175 .50922 L
.17238 .50686 L
.17302 .50445 L
.17365 .502 L
.17429 .49951 L
.17492 .49699 L
.17556 .49442 L
.17619 .49181 L
.17683 .48915 L
.17746 .48645 L
.1781 .48371 L
.17873 .48093 L
.17937 .47809 L
.18 .47522 L
.18063 .47229 L
.18127 .46932 L
.1819 .4663 L
.18254 .46324 L
Mistroke
.18317 .46012 L
.18381 .45695 L
.18444 .45373 L
.18508 .45046 L
.18571 .44713 L
.18635 .44375 L
.18698 .44031 L
.18762 .43682 L
.18825 .43327 L
.18889 .42966 L
.18952 .42599 L
.19016 .42225 L
.19079 .41846 L
.19143 .41459 L
.19206 .41066 L
.1927 .40667 L
.19333 .4026 L
.19397 .39846 L
.1946 .39424 L
.19524 .38995 L
.19587 .38558 L
.19651 .38113 L
.19714 .3766 L
.19778 .37198 L
.19841 .36727 L
.19905 .36247 L
.19968 .35757 L
.20032 .35258 L
.20095 .34748 L
.20159 .34228 L
.20222 .33696 L
.20286 .33153 L
.20349 .32598 L
.20413 .3203 L
.20476 .31449 L
.2054 .30854 L
.20603 .30245 L
.20667 .29621 L
.2073 .28981 L
.20794 .28323 L
.20857 .27648 L
.20921 .26954 L
.20984 .2624 L
.21048 .25504 L
.21111 .24746 L
.21175 .23963 L
.21238 .23153 L
.21302 .22315 L
.21365 .21447 L
.21429 .20545 L
Mistroke
.21492 .19606 L
.21556 .18627 L
.21619 .17604 L
.21683 .16532 L
.21746 .15405 L
.2181 .14216 L
.21873 .12959 L
.21937 .11621 L
.22 .10193 L
.22063 .08659 L
.22127 .07001 L
.2219 .052 L
.22254 .03237 L
.22317 .01601 L
.22381 .01699 L
.22444 .01811 L
.22508 .03712 L
.22571 .06073 L
.22635 .08158 L
.22698 .10009 L
.22762 .11677 L
.22825 .132 L
.22889 .14605 L
.22952 .15912 L
.23016 .17136 L
.23079 .18289 L
.23143 .1938 L
.23206 .20416 L
.2327 .21404 L
.23333 .22348 L
.23397 .23253 L
.2346 .24123 L
.23524 .2496 L
.23587 .25767 L
.23651 .26548 L
.23714 .27302 L
.23778 .28034 L
.23841 .28743 L
.23905 .29431 L
.23968 .30101 L
.24032 .30752 L
.24095 .31386 L
.24159 .32003 L
.24222 .32606 L
.24286 .33194 L
.24349 .33767 L
.24413 .34328 L
.24476 .34876 L
.2454 .35412 L
.24603 .35936 L
Mistroke
.24667 .3645 L
.2473 .36952 L
.24794 .37445 L
.24857 .37927 L
.24921 .384 L
.24984 .38863 L
.25048 .39318 L
.25111 .39764 L
.25175 .40202 L
.25238 .40632 L
.25302 .41054 L
.25365 .41468 L
.25429 .41875 L
.25492 .42275 L
.25556 .42667 L
.25619 .43053 L
.25683 .43433 L
.25746 .43805 L
.2581 .44172 L
.25873 .44532 L
.25937 .44886 L
.26 .45234 L
.26063 .45577 L
.26127 .45914 L
.2619 .46245 L
.26254 .46571 L
.26317 .46891 L
.26381 .47206 L
.26444 .47516 L
.26508 .47822 L
.26571 .48122 L
.26635 .48417 L
.26698 .48707 L
.26762 .48993 L
.26825 .49274 L
.26889 .4955 L
.26952 .49822 L
.27016 .5009 L
.27079 .50353 L
.27143 .50612 L
.27206 .50867 L
.2727 .51117 L
.27333 .51363 L
.27397 .51605 L
.2746 .51843 L
.27524 .52078 L
.27587 .52308 L
.27651 .52534 L
.27714 .52756 L
.27778 .52975 L
Mistroke
.27841 .5319 L
.27905 .53401 L
.27968 .53608 L
.28032 .53812 L
.28095 .54012 L
.28159 .54208 L
.28222 .54401 L
.28286 .54591 L
.28349 .54776 L
.28413 .54959 L
.28476 .55138 L
.2854 .55313 L
.28603 .55485 L
.28667 .55654 L
.2873 .5582 L
.28794 .55982 L
.28857 .56141 L
.28921 .56296 L
.28984 .56449 L
.29048 .56598 L
.29111 .56744 L
.29175 .56886 L
.29238 .57026 L
.29302 .57162 L
.29365 .57295 L
.29429 .57426 L
.29492 .57553 L
.29556 .57677 L
.29619 .57798 L
.29683 .57915 L
.29746 .5803 L
.2981 .58142 L
.29873 .58251 L
.29937 .58357 L
.3 .5846 L
.30063 .58559 L
.30127 .58656 L
.3019 .5875 L
.30254 .58841 L
.30317 .58929 L
.30381 .59015 L
.30444 .59097 L
.30508 .59176 L
.30571 .59253 L
.30635 .59326 L
.30698 .59397 L
.30762 .59465 L
.30825 .5953 L
.30889 .59592 L
.30952 .59651 L
Mistroke
.31016 .59708 L
.31079 .59762 L
.31143 .59812 L
.31206 .5986 L
.3127 .59906 L
.31333 .59948 L
.31397 .59988 L
.3146 .60024 L
.31524 .60058 L
.31587 .6009 L
.31651 .60118 L
.31714 .60144 L
.31778 .60167 L
.31841 .60187 L
.31905 .60204 L
.31968 .60218 L
.32032 .6023 L
.32095 .60239 L
.32159 .60245 L
.32222 .60249 L
.32286 .60249 L
.32349 .60247 L
.32413 .60242 L
.32476 .60235 L
.3254 .60224 L
.32603 .60211 L
.32667 .60195 L
.3273 .60177 L
.32794 .60155 L
.32857 .60131 L
.32921 .60104 L
.32984 .60074 L
.33048 .60041 L
.33111 .60006 L
.33175 .59967 L
.33238 .59926 L
.33302 .59883 L
.33365 .59836 L
.33429 .59787 L
.33492 .59734 L
.33556 .59679 L
.33619 .59621 L
.33683 .59561 L
.33746 .59497 L
.3381 .59431 L
.33873 .59361 L
.33937 .59289 L
.34 .59214 L
.34063 .59136 L
.34127 .59056 L
Mistroke
.3419 .58972 L
.34254 .58886 L
.34317 .58796 L
.34381 .58704 L
.34444 .58609 L
.34508 .5851 L
.34571 .58409 L
.34635 .58305 L
.34698 .58198 L
.34762 .58088 L
.34825 .57975 L
.34889 .57859 L
.34952 .5774 L
.35016 .57618 L
.35079 .57493 L
.35143 .57364 L
.35206 .57233 L
.3527 .57099 L
.35333 .56961 L
.35397 .5682 L
.3546 .56677 L
.35524 .5653 L
.35587 .56379 L
.35651 .56226 L
.35714 .56069 L
.35778 .55909 L
.35841 .55746 L
.35905 .5558 L
.35968 .5541 L
.36032 .55237 L
.36095 .55061 L
.36159 .54881 L
.36222 .54698 L
.36286 .54511 L
.36349 .54321 L
.36413 .54127 L
.36476 .5393 L
.3654 .53729 L
.36603 .53525 L
.36667 .53317 L
.3673 .53105 L
.36794 .5289 L
.36857 .5267 L
.36921 .52448 L
.36984 .52221 L
.37048 .5199 L
.37111 .51756 L
.37175 .51517 L
.37238 .51275 L
.37302 .51028 L
Mistroke
.37365 .50778 L
.37429 .50523 L
.37492 .50264 L
.37556 .50001 L
.37619 .49733 L
.37683 .49462 L
.37746 .49185 L
.3781 .48904 L
.37873 .48619 L
.37937 .48329 L
.38 .48034 L
.38063 .47735 L
.38127 .4743 L
.3819 .47121 L
.38254 .46807 L
.38317 .46487 L
.38381 .46162 L
.38444 .45832 L
.38508 .45497 L
.38571 .45156 L
.38635 .44809 L
.38698 .44456 L
.38762 .44098 L
.38825 .43734 L
.38889 .43363 L
.38952 .42986 L
.39016 .42603 L
.39079 .42213 L
.39143 .41816 L
.39206 .41412 L
.3927 .41002 L
.39333 .40583 L
.39397 .40158 L
.3946 .39724 L
.39524 .39282 L
.39587 .38833 L
.39651 .38374 L
.39714 .37907 L
.39778 .37431 L
.39841 .36945 L
.39905 .3645 L
.39968 .35944 L
.40032 .35428 L
.40095 .34901 L
.40159 .34363 L
.40222 .33812 L
.40286 .3325 L
.40349 .32674 L
.40413 .32085 L
.40476 .31481 L
Mistroke
.4054 .30863 L
.40603 .30228 L
.40667 .29578 L
.4073 .28909 L
.40794 .28222 L
.40857 .27515 L
.40921 .26788 L
.40984 .26037 L
.41048 .25263 L
.41111 .24462 L
.41175 .23634 L
.41238 .22775 L
.41302 .21884 L
.41365 .20956 L
.41429 .19989 L
.41492 .18977 L
.41556 .17917 L
.41619 .16803 L
.41683 .15626 L
.41746 .14379 L
.4181 .13051 L
.41873 .11626 L
.41937 .10088 L
.42 .0841 L
.42063 .06559 L
.42127 .04479 L
.4219 .02076 L
.42254 .01589 L
.42317 .01695 L
.42381 .01855 L
.42444 .03886 L
.42508 .06233 L
.42571 .08305 L
.42635 .10143 L
.42698 .11802 L
.42762 .13317 L
.42825 .14715 L
.42889 .16017 L
.42952 .17236 L
.43016 .18385 L
.43079 .19472 L
.43143 .20505 L
.43206 .2149 L
.4327 .22431 L
.43333 .23334 L
.43397 .24202 L
.4346 .25037 L
.43524 .25843 L
.43587 .26622 L
.43651 .27375 L
Mistroke
.43714 .28105 L
.43778 .28813 L
.43841 .29501 L
.43905 .30169 L
.43968 .30819 L
.44032 .31452 L
.44095 .32069 L
.44159 .32671 L
.44222 .33258 L
.44286 .33831 L
.44349 .34391 L
.44413 .34939 L
.44476 .35474 L
.4454 .35998 L
.44603 .36511 L
.44667 .37013 L
.4473 .37505 L
.44794 .37987 L
.44857 .3846 L
.44921 .38923 L
.44984 .39378 L
.45048 .39823 L
.45111 .40261 L
.45175 .40691 L
.45238 .41112 L
.45302 .41526 L
.45365 .41933 L
.45429 .42333 L
.45492 .42725 L
.45556 .43111 L
.45619 .4349 L
.45683 .43863 L
.45746 .44229 L
.4581 .44589 L
.45873 .44944 L
.45937 .45292 L
.46 .45634 L
.46063 .45971 L
.46127 .46302 L
.4619 .46628 L
.46254 .46949 L
.46317 .47264 L
.46381 .47574 L
.46444 .47879 L
.46508 .48179 L
.46571 .48475 L
.46635 .48765 L
.46698 .49051 L
.46762 .49332 L
.46825 .49609 L
Mistroke
.46889 .49881 L
.46952 .50148 L
.47016 .50412 L
.47079 .50671 L
.47143 .50925 L
.47206 .51176 L
.4727 .51422 L
.47333 .51664 L
.47397 .51903 L
.4746 .52137 L
.47524 .52367 L
.47587 .52594 L
.47651 .52816 L
.47714 .53035 L
.47778 .5325 L
.47841 .53461 L
.47905 .53669 L
.47968 .53873 L
.48032 .54073 L
.48095 .5427 L
.48159 .54463 L
.48222 .54652 L
.48286 .54838 L
.48349 .55021 L
.48413 .552 L
.48476 .55376 L
.4854 .55548 L
.48603 .55717 L
.48667 .55883 L
.4873 .56045 L
.48794 .56204 L
.48857 .5636 L
.48921 .56513 L
.48984 .56662 L
.49048 .56808 L
.49111 .56951 L
.49175 .57091 L
.49238 .57228 L
.49302 .57361 L
.49365 .57492 L
.49429 .57619 L
.49492 .57743 L
.49556 .57865 L
.49619 .57983 L
.49683 .58098 L
.49746 .5821 L
.4981 .58319 L
.49873 .58425 L
.49937 .58528 L
.5 .58629 L
Mistroke
.50063 .58726 L
.50127 .5882 L
.5019 .58911 L
.50254 .59 L
.50317 .59085 L
.50381 .59168 L
.50444 .59248 L
.50508 .59324 L
.50571 .59398 L
.50635 .5947 L
.50698 .59538 L
.50762 .59603 L
.50825 .59666 L
.50889 .59725 L
.50952 .59782 L
.51016 .59836 L
.51079 .59887 L
.51143 .59936 L
.51206 .59981 L
.5127 .60024 L
.51333 .60064 L
.51397 .60101 L
.5146 .60136 L
.51524 .60167 L
.51587 .60196 L
.51651 .60222 L
.51714 .60246 L
.51778 .60266 L
.51841 .60284 L
.51905 .60299 L
.51968 .60311 L
.52032 .6032 L
.52095 .60327 L
.52159 .60331 L
.52222 .60332 L
.52286 .6033 L
.52349 .60326 L
.52413 .60319 L
.52476 .60309 L
.5254 .60296 L
.52603 .6028 L
.52667 .60262 L
.5273 .60241 L
.52794 .60217 L
.52857 .60191 L
.52921 .60161 L
.52984 .60129 L
.53048 .60094 L
.53111 .60056 L
.53175 .60016 L
Mistroke
.53238 .59973 L
.53302 .59927 L
.53365 .59878 L
.53429 .59826 L
.53492 .59771 L
.53556 .59714 L
.53619 .59654 L
.53683 .59591 L
.53746 .59525 L
.5381 .59456 L
.53873 .59385 L
.53937 .5931 L
.54 .59233 L
.54063 .59153 L
.54127 .5907 L
.5419 .58984 L
.54254 .58895 L
.54317 .58803 L
.54381 .58709 L
.54444 .58611 L
.54508 .58511 L
.54571 .58407 L
.54635 .58301 L
.54698 .58191 L
.54762 .58079 L
.54825 .57964 L
.54889 .57845 L
.54952 .57724 L
.55016 .57599 L
.55079 .57472 L
.55143 .57341 L
.55206 .57207 L
.5527 .57071 L
.55333 .56931 L
.55397 .56787 L
.5546 .56641 L
.55524 .56492 L
.55587 .56339 L
.55651 .56183 L
.55714 .56024 L
.55778 .55862 L
.55841 .55696 L
.55905 .55527 L
.55968 .55355 L
.56032 .5518 L
.56095 .55001 L
.56159 .54818 L
.56222 .54632 L
.56286 .54443 L
.56349 .5425 L
Mistroke
.56413 .54054 L
.56476 .53854 L
.5654 .53651 L
.56603 .53444 L
.56667 .53233 L
.5673 .53019 L
.56794 .52801 L
.56857 .52579 L
.56921 .52353 L
.56984 .52124 L
.57048 .5189 L
.57111 .51653 L
.57175 .51412 L
.57238 .51166 L
.57302 .50917 L
.57365 .50663 L
.57429 .50406 L
.57492 .50144 L
.57556 .49877 L
.57619 .49607 L
.57683 .49332 L
.57746 .49052 L
.5781 .48768 L
.57873 .4848 L
.57937 .48187 L
.58 .47888 L
.58063 .47586 L
.58127 .47278 L
.5819 .46965 L
.58254 .46647 L
.58317 .46324 L
.58381 .45996 L
.58444 .45662 L
.58508 .45322 L
.58571 .44978 L
.58635 .44627 L
.58698 .44271 L
.58762 .43908 L
.58825 .4354 L
.58889 .43165 L
.58952 .42784 L
.59016 .42396 L
.59079 .42002 L
.59143 .416 L
.59206 .41192 L
.5927 .40776 L
.59333 .40353 L
.59397 .39922 L
.5946 .39483 L
.59524 .39036 L
Mistroke
.59587 .38581 L
.59651 .38117 L
.59714 .37644 L
.59778 .37162 L
.59841 .3667 L
.59905 .36168 L
.59968 .35656 L
.60032 .35133 L
.60095 .34598 L
.60159 .34052 L
.60222 .33494 L
.60286 .32923 L
.60349 .32339 L
.60413 .31741 L
.60476 .31128 L
.6054 .305 L
.60603 .29855 L
.60667 .29194 L
.6073 .28514 L
.60794 .27815 L
.60857 .27095 L
.60921 .26353 L
.60984 .25588 L
.61048 .24798 L
.61111 .2398 L
.61175 .23133 L
.61238 .22254 L
.61302 .21341 L
.61365 .20389 L
.61429 .19395 L
.61492 .18354 L
.61556 .17262 L
.61619 .1611 L
.61683 .14891 L
.61746 .13595 L
.6181 .12209 L
.61873 .10717 L
.61937 .09096 L
.62 .07315 L
.62063 .05332 L
.62127 .0307 L
.6219 .01472 L
.62254 .01681 L
.62317 .01677 L
.62381 .02539 L
.62444 .04638 L
.62508 .06786 L
.62571 .08724 L
.62635 .10472 L
.62698 .12063 L
Mistroke
.62762 .13526 L
.62825 .14884 L
.62889 .16152 L
.62952 .17343 L
.63016 .18467 L
.63079 .19534 L
.63143 .20548 L
.63206 .21517 L
.6327 .22445 L
.63333 .23334 L
.63397 .2419 L
.6346 .25015 L
.63524 .2581 L
.63587 .2658 L
.63651 .27324 L
.63714 .28046 L
.63778 .28746 L
.63841 .29427 L
.63905 .30088 L
.63968 .30732 L
.64032 .31359 L
.64095 .3197 L
.64159 .32566 L
.64222 .33148 L
.64286 .33716 L
.64349 .34271 L
.64413 .34814 L
.64476 .35344 L
.6454 .35864 L
.64603 .36372 L
.64667 .3687 L
.6473 .37358 L
.64794 .37836 L
.64857 .38305 L
.64921 .38764 L
.64984 .39215 L
.65048 .39657 L
.65111 .40091 L
.65175 .40517 L
.65238 .40936 L
.65302 .41346 L
.65365 .4175 L
.65429 .42146 L
.65492 .42535 L
.65556 .42918 L
.65619 .43294 L
.65683 .43664 L
.65746 .44027 L
.6581 .44384 L
.65873 .44735 L
Mistroke
.65937 .45081 L
.66 .4542 L
.66063 .45754 L
.66127 .46083 L
.6619 .46406 L
.66254 .46723 L
.66317 .47036 L
.66381 .47343 L
.66444 .47646 L
.66508 .47943 L
.66571 .48236 L
.66635 .48524 L
.66698 .48807 L
.66762 .49086 L
.66825 .4936 L
.66889 .49629 L
.66952 .49894 L
.67016 .50155 L
.67079 .50411 L
.67143 .50664 L
.67206 .50912 L
.6727 .51156 L
.67333 .51396 L
.67397 .51631 L
.6746 .51863 L
.67524 .52091 L
.67587 .52315 L
.67651 .52535 L
.67714 .52752 L
.67778 .52964 L
.67841 .53173 L
.67905 .53378 L
.67968 .5358 L
.68032 .53778 L
.68095 .53972 L
.68159 .54163 L
.68222 .5435 L
.68286 .54534 L
.68349 .54714 L
.68413 .54891 L
.68476 .55065 L
.6854 .55235 L
.68603 .55402 L
.68667 .55565 L
.6873 .55725 L
.68794 .55882 L
.68857 .56036 L
.68921 .56186 L
.68984 .56333 L
.69048 .56477 L
Mistroke
.69111 .56618 L
.69175 .56755 L
.69238 .5689 L
.69302 .57021 L
.69365 .57149 L
.69429 .57274 L
.69492 .57396 L
.69556 .57515 L
.69619 .57631 L
.69683 .57744 L
.69746 .57854 L
.6981 .57961 L
.69873 .58065 L
.69937 .58166 L
.7 .58264 L
.70063 .58359 L
.70127 .58451 L
.7019 .5854 L
.70254 .58626 L
.70317 .58709 L
.70381 .5879 L
.70444 .58867 L
.70508 .58942 L
.70571 .59014 L
.70635 .59083 L
.70698 .59149 L
.70762 .59212 L
.70825 .59272 L
.70889 .59329 L
.70952 .59384 L
.71016 .59436 L
.71079 .59485 L
.71143 .59531 L
.71206 .59574 L
.7127 .59615 L
.71333 .59653 L
.71397 .59687 L
.7146 .5972 L
.71524 .59749 L
.71587 .59776 L
.71651 .59799 L
.71714 .5982 L
.71778 .59838 L
.71841 .59854 L
.71905 .59867 L
.71968 .59876 L
.72032 .59883 L
.72095 .59888 L
.72159 .59889 L
.72222 .59888 L
Mistroke
.72286 .59884 L
.72349 .59877 L
.72413 .59868 L
.72476 .59855 L
.7254 .5984 L
.72603 .59823 L
.72667 .59802 L
.7273 .59778 L
.72794 .59752 L
.72857 .59723 L
.72921 .59691 L
.72984 .59657 L
.73048 .59619 L
.73111 .59579 L
.73175 .59536 L
.73238 .59491 L
.73302 .59442 L
.73365 .59391 L
.73429 .59336 L
.73492 .59279 L
.73556 .59219 L
.73619 .59157 L
.73683 .59091 L
.73746 .59023 L
.7381 .58951 L
.73873 .58877 L
.73937 .588 L
.74 .5872 L
.74063 .58638 L
.74127 .58552 L
.7419 .58463 L
.74254 .58372 L
.74317 .58277 L
.74381 .5818 L
.74444 .5808 L
.74508 .57976 L
.74571 .5787 L
.74635 .57761 L
.74698 .57649 L
.74762 .57533 L
.74825 .57415 L
.74889 .57294 L
.74952 .5717 L
.75016 .57042 L
.75079 .56912 L
.75143 .56778 L
.75206 .56641 L
.7527 .56501 L
.75333 .56358 L
.75397 .56212 L
Mistroke
.7546 .56063 L
.75524 .5591 L
.75587 .55754 L
.75651 .55595 L
.75714 .55433 L
.75778 .55268 L
.75841 .55099 L
.75905 .54926 L
.75968 .54751 L
.76032 .54572 L
.76095 .54389 L
.76159 .54203 L
.76222 .54014 L
.76286 .53821 L
.76349 .53625 L
.76413 .53425 L
.76476 .53221 L
.7654 .53014 L
.76603 .52803 L
.76667 .52588 L
.7673 .5237 L
.76794 .52148 L
.76857 .51922 L
.76921 .51692 L
.76984 .51459 L
.77048 .51221 L
.77111 .50979 L
.77175 .50734 L
.77238 .50484 L
.77302 .5023 L
.77365 .49972 L
.77429 .4971 L
.77492 .49443 L
.77556 .49172 L
.77619 .48896 L
.77683 .48616 L
.77746 .48332 L
.7781 .48042 L
.77873 .47749 L
.77937 .4745 L
.78 .47146 L
.78063 .46838 L
.78127 .46524 L
.7819 .46205 L
.78254 .45881 L
.78317 .45552 L
.78381 .45217 L
.78444 .44877 L
.78508 .44531 L
.78571 .44179 L
Mistroke
.78635 .43822 L
.78698 .43458 L
.78762 .43089 L
.78825 .42712 L
.78889 .4233 L
.78952 .41941 L
.79016 .41545 L
.79079 .41142 L
.79143 .40732 L
.79206 .40314 L
.7927 .39889 L
.79333 .39457 L
.79397 .39016 L
.7946 .38567 L
.79524 .38109 L
.79587 .37643 L
.79651 .37168 L
.79714 .36683 L
.79778 .36188 L
.79841 .35683 L
.79905 .35168 L
.79968 .34642 L
.80032 .34104 L
.80095 .33555 L
.80159 .32993 L
.80222 .32418 L
.80286 .3183 L
.80349 .31227 L
.80413 .3061 L
.80476 .29977 L
.8054 .29327 L
.80603 .28659 L
.80667 .27973 L
.8073 .27268 L
.80794 .26541 L
.80857 .25792 L
.80921 .25018 L
.80984 .24219 L
.81048 .23392 L
.81111 .22535 L
.81175 .21646 L
.81238 .2072 L
.81302 .19755 L
.81365 .18746 L
.81429 .17689 L
.81492 .16578 L
.81556 .15406 L
.81619 .14164 L
.81683 .12843 L
.81746 .11427 L
Mistroke
.8181 .09902 L
.81873 .08243 L
.81937 .06417 L
.82 .04383 L
.82063 .02061 L
.82127 .01635 L
.8219 .01698 L
.82254 .02004 L
.82317 .03895 L
.82381 .0616 L
.82444 .08196 L
.82508 .10017 L
.82571 .11665 L
.82635 .13174 L
.82698 .14568 L
.82762 .15867 L
.82825 .17084 L
.82889 .18232 L
.82952 .19318 L
.83016 .2035 L
.83079 .21335 L
.83143 .22277 L
.83206 .23179 L
.8327 .24047 L
.83333 .24883 L
.83397 .25689 L
.8346 .26467 L
.83524 .27221 L
.83587 .27951 L
.83651 .28659 L
.83714 .29347 L
.83778 .30015 L
.83841 .30666 L
.83905 .31299 L
.83968 .31917 L
.84032 .32519 L
.84095 .33106 L
.84159 .3368 L
.84222 .3424 L
.84286 .34788 L
.84349 .35324 L
.84413 .35848 L
.84476 .36361 L
.8454 .36863 L
.84603 .37356 L
.84667 .37838 L
.8473 .38311 L
.84794 .38775 L
.84857 .3923 L
.84921 .39676 L
Mistroke
.84984 .40114 L
.85048 .40544 L
.85111 .40966 L
.85175 .4138 L
.85238 .41787 L
.85302 .42187 L
.85365 .4258 L
.85429 .42966 L
.85492 .43346 L
.85556 .43719 L
.85619 .44086 L
.85683 .44446 L
.85746 .44801 L
.8581 .45149 L
.85873 .45492 L
.85937 .45829 L
.86 .46161 L
.86063 .46487 L
.86127 .46808 L
.8619 .47124 L
.86254 .47434 L
.86317 .4774 L
.86381 .4804 L
.86444 .48336 L
.86508 .48627 L
.86571 .48913 L
.86635 .49195 L
.86698 .49472 L
.86762 .49744 L
.86825 .50012 L
.86889 .50276 L
.86952 .50536 L
.87016 .50791 L
.87079 .51042 L
.87143 .51289 L
.87206 .51531 L
.8727 .5177 L
.87333 .52005 L
.87397 .52236 L
.8746 .52462 L
.87524 .52686 L
.87587 .52905 L
.87651 .5312 L
.87714 .53332 L
.87778 .5354 L
.87841 .53744 L
.87905 .53945 L
.87968 .54142 L
.88032 .54336 L
.88095 .54526 L
Mistroke
.88159 .54713 L
.88222 .54896 L
.88286 .55076 L
.88349 .55252 L
.88413 .55425 L
.88476 .55594 L
.8854 .55761 L
.88603 .55924 L
.88667 .56083 L
.8873 .5624 L
.88794 .56393 L
.88857 .56543 L
.88921 .56689 L
.88984 .56833 L
.89048 .56973 L
.89111 .57111 L
.89175 .57245 L
.89238 .57376 L
.89302 .57504 L
.89365 .57629 L
.89429 .57751 L
.89492 .57869 L
.89556 .57985 L
.89619 .58098 L
.89683 .58208 L
.89746 .58314 L
.8981 .58418 L
.89873 .58519 L
.89937 .58617 L
.9 .58712 L
.90063 .58804 L
.90127 .58893 L
.9019 .58979 L
.90254 .59062 L
.90317 .59143 L
.90381 .5922 L
.90444 .59295 L
.90508 .59367 L
.90571 .59436 L
.90635 .59502 L
.90698 .59565 L
.90762 .59626 L
.90825 .59683 L
.90889 .59738 L
.90952 .5979 L
.91016 .59839 L
.91079 .59885 L
.91143 .59929 L
.91206 .5997 L
.9127 .60008 L
Mistroke
.91333 .60043 L
.91397 .60075 L
.9146 .60105 L
.91524 .60132 L
.91587 .60156 L
.91651 .60177 L
.91714 .60196 L
.91778 .60212 L
.91841 .60225 L
.91905 .60235 L
.91968 .60242 L
.92032 .60247 L
.92095 .60249 L
.92159 .60248 L
.92222 .60245 L
.92286 .60238 L
.92349 .60229 L
.92413 .60218 L
.92476 .60203 L
.9254 .60186 L
.92603 .60165 L
.92667 .60143 L
.9273 .60117 L
.92794 .60089 L
.92857 .60057 L
.92921 .60023 L
.92984 .59987 L
.93048 .59947 L
.93111 .59905 L
.93175 .5986 L
.93238 .59812 L
.93302 .59761 L
.93365 .59708 L
.93429 .59651 L
.93492 .59592 L
.93556 .5953 L
.93619 .59466 L
.93683 .59398 L
.93746 .59328 L
.9381 .59254 L
.93873 .59178 L
.93937 .59099 L
.94 .59017 L
.94063 .58932 L
.94127 .58845 L
.9419 .58754 L
.94254 .58661 L
.94317 .58564 L
.94381 .58465 L
.94444 .58363 L
Mistroke
.94508 .58258 L
.94571 .5815 L
.94635 .58038 L
.94698 .57924 L
.94762 .57807 L
.94825 .57687 L
.94889 .57564 L
.94952 .57438 L
.95016 .57308 L
.95079 .57176 L
.95143 .57041 L
.95206 .56902 L
.9527 .5676 L
.95333 .56616 L
.95397 .56468 L
.9546 .56316 L
.95524 .56162 L
.95587 .56005 L
.95651 .55844 L
.95714 .5568 L
.95778 .55512 L
.95841 .55342 L
.95905 .55168 L
.95968 .5499 L
.96032 .5481 L
.96095 .54625 L
.96159 .54438 L
.96222 .54247 L
.96286 .54052 L
.96349 .53854 L
.96413 .53653 L
.96476 .53447 L
.9654 .53238 L
.96603 .53026 L
.96667 .5281 L
.9673 .5259 L
.96794 .52366 L
.96857 .52139 L
.96921 .51907 L
.96984 .51672 L
.97048 .51433 L
.97111 .51189 L
.97175 .50942 L
.97238 .50691 L
.97302 .50435 L
.97365 .50176 L
.97429 .49912 L
.97492 .49644 L
.97556 .49371 L
.97619 .49094 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000YOol4
0003Ool20004Ool2000FOol30002Ool20004Ool2000COol30004Ool20004Ool2000EOol20004Ool2
0004Ool2000AOol50002Ool20004Ool20004Ool2000>Ool500000goo000000020003Ool20004Ool2
000=Ool50003Ool30002Ool20004Ool2000EOol002Uoo`03001oogoo00=oo`04001oogoo0002Ool0
1000Oomoo`005Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`0@Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000COol01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo000BOol01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`0=
Ool01@00Oomoogoo00001Goo00@007ooOol0009oo`04001oogoo000>Ool00`00Oomoo`04Ool01000
Oomoo`000Woo00@007ooOol0009oo`03001oogoo019oo`00:Woo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo000COol500001Goo001oogoo00000Woo00@007ooOol0019oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol001=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool0019oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo00eo
o`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`003Woo00@007ooOomo
o`D00005Ool007ooOol00002Ool01000Oomoo`0057oo000[Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`03001oogoo015oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0019oo`<0
00=oo`04001oogoo0002Ool01000Oomoo`0057oo0P000goo00@007ooOol0009oo`04001oogoo000B
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`0=Ool00`00
Oomoo`03Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00aoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo019oo`00:Goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`0057oo00<007oo00000Woo00@007ooOol0009oo`04001oogoo
000COol00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol001=oo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol0019oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo00eoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03
001oogoo00aoo`03001oogoo009oo`03001oo`00009oo`04001oogoo0002Ool01000Oomoo`0057oo
000ZOol20004Ool20004Ool2000FOol20003Ool20004Ool2000DOol30003Ool20004Ool2000EOol2
0004Ool20004Ool2000BOol20004Ool20004Ool20004Ool2000?Ool20004Ool20004Ool20004Ool2
000>Ool20005Ool20003Ool20004Ool2000EOol000ioo`03001oogoo0?mooa1oo`003Woo00<007oo
Ool0ogoo47oo000>Ool00`00Oomoo`3oOol@Ool000ioo`03001oogoo0?mooa1oo`003Woo00<007oo
Ool0XGoo00<3ogooOol0Jgoo0008Oolm00000`?o0000000c00020ole00000`?o0000000c00020ol`
0006Ool000ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03
001oogoo00Ioo`03001oogoo00Eoo`04001oogoo0ol5Ool00`00Oomoo`06Ool00`00Oomoo`05Ool0
0`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`02Ool20ol2Ool00`00Oomo
o`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomo
o`04Ool00`?o001oo`07Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomo
o`06Ool00`00Oomoo`05Ool00`000ol3o`06Ool00`00Oomoo`06Ool00`00Oomoo`05Ool00`00Oomo
o`06Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool000ioo`03001oogoo021oo`03001oogoo015oo`03
0omoogoo00aoo`03001oogoo01moo`03001oogoo009oo`83oaaoo`03001oogoo01Ioo`030omoogoo
00Moo`03001oogoo021oo`03001oogoo00Ioo`83oaMoo`03001oogoo01aoo`003Woo00<3ogooOol0
=7oo00<3ogooOol0<goo0P?o=Goo00<3ogooOol0<goo0P?o=Woo000>Ool00`?oOomoo`0dOol00`?o
Oomoo`0cOol20oleOol00`?oOomoo`0cOol20olfOol000ioo`030omoogoo03Aoo`030omoogoo03=o
o`83ocEoo`83ocAoo`83ocIoo`003Woo00<3o`00Ool0=7oo00<3ogooOol0<goo0P?o=Goo0P?o=7oo
0P?o=Woo000>Ool00`?oOomoo`0cOol20oleOol20oldOol00`?oOol3o`0dOol20olfOol000ioo`03
0omoogoo03=oo`83ocEoo`83ocAoo`030omoo`?o03Aoo`83ocIoo`003Woo00<000?oOol0<goo0P?o
=Goo0P?o=7oo00<3ogoo0ol0=7oo0P?o=Woo000>Ool00`000omoo`0cOol20oleOol20oldOol00`?o
Ool3o`0dOol20olfOol000ioo`030003ogoo03=oo`83ocEoo`83ocAoo`030omoo`?o03Aoo`83ocIo
o`003Woo00<000?oOol0<goo0P?o=Goo0P?o=7oo00<3ogoo0ol0=7oo0P?o=Woo000>Ool00`000omo
o`0cOol20oleOol20oldOol00`?oOol3o`0dOol20olfOol000ioo`030003ogoo03=oo`83ocEoo`83
ocAoo`030omoo`?o03Aoo`83ocIoo`003Woo00<000?oOol0<goo00<3ogoo0ol0=7oo0P?o=7oo00<3
ogoo0ol0=7oo0P?o=Woo000>Ool00`000omoo`0cOol00`?oOol3o`0dOol20oldOol00`?oOol3o`0d
Ool20olfOol000ioo`030003ogoo03=oo`030omoo`?o03Aoo`83ocAoo`030omoo`?o03Aoo`83ocIo
o`003Woo00<000?oOol0<goo00<3ogoo0ol0=7oo0P?o=7oo00<3ogoo0ol0=7oo0P?o=Woo000>Ool0
0`000omoo`0cOol00`?oOol3o`0dOol20oldOol00`?oOol3o`0dOol20olfOol000ioo`030003ogoo
03=oo`030omoo`?o03Aoo`83ocAoo`030omoo`?o03Aoo`83ocIoo`003Woo00<000?oOol0<goo00<3
ogoo0ol0<goo00<3ogoo0ol0=7oo00<3ogoo0ol0=7oo0P?o=Woo000>Ool00`000omoo`0cOol00`?o
Ool3o`0cOol00`?oOol3o`0dOol00`?oOol3o`0dOol20olfOol000ioo`030003ogoo03=oo`030omo
o`?o03=oo`030omoo`?o03Aoo`030omoo`?o03Aoo`83ocIoo`003Woo00<000?oOol0<goo00<3ogoo
0ol0<goo00<3ogoo0ol0=7oo00<3ogoo0ol0=7oo0P?o=Woo000>Ool00`000omoo`0cOol00`?oOol3
o`0cOol00`?oOol3o`0dOol00`?oOol3o`0cOol010?oOomoo`?o=Goo000>Ool00`000omoo`0cOol0
0`?oOol3o`0cOol00`?oOol3o`0dOol00`?oOol3o`0cOol010?oOomoo`?o=Goo000>Ool00`000omo
o`0cOol00`?oOol3o`0cOol00`?oOol3o`0dOol00`?oOol3o`0cOol010?oOomoo`?o=Goo0007Ool2
0005Ool00`000omoo`0cOol00`?oOol3o`0cOol00`?oOol3o`0dOol00`?oOol3o`0cOol010?oOomo
o`?o=Goo0006Ool01000Oomoo`0017oo00<000?oOol0<Woo00@3ogooOol3oc=oo`030omoo`?o03Ao
o`030omoo`?o03=oo`040omoogoo0oleOol000Qoo`03001oogoo00=oo`030003o`00039oo`040omo
ogoo0olcOol010?oOomoo`?o<goo00<3ogoo0ol0<goo00@3ogooOol3ocEoo`002Goo00<007ooOol0
0Woo00<007oo0ol0<Woo00@3ogooOol3oc=oo`040omoogoo0olcOol00`?oOol3o`0cOol010?oOomo
o`?o=Goo0006Ool01000Oomoo`0017oo00<007oo0ol0<Woo00@3ogooOol3oc=oo`040omoogoo0olc
Ool00`?oOol3o`0cOol010?oOomoo`?o=Goo0007Ool20005Ool00`00Ool3o`0bOol010?oOomoo`?o
<goo00@3ogooOol3oc=oo`030omoo`?o03=oo`040omoogoo0oleOol000ioo`03001oo`?o039oo`04
0omoogoo0olcOol010?oOomoo`?o<goo00@3ogooOol3oc9oo`040omoogoo0oleOol000ioo`03001o
o`?o039oo`040omoogoo0olcOol010?oOomoo`?o<Woo00D3ogooOomoo`?o039oo`040omoogoo0ole
Ool000ioo`8000030omoogoo031oo`040omoogoo0olcOol010?oOomoo`?o<Woo00D3ogooOomoo`?o
039oo`040omoogoo0oleOol000ioo`03001oo`?o039oo`040omoogoo0olcOol010?oOomoo`?o<Woo
00D3ogooOomoo`?o039oo`040omoogoo0oleOol000ioo`03001oo`?o039oo`040omoogoo0olcOol0
10?oOomoo`?o<Woo00D3ogooOomoo`?o039oo`040omoogoo0oleOol000ioo`03001oo`?o039oo`04
0omoogoo0olcOol010?oOomoo`?o<Woo00D3ogooOomoo`?o039oo`040omoogoo0oleOol000ioo`03
001oo`?o039oo`040omoogoo0olcOol010?oOomoo`?o<Woo00D3ogooOomoo`?o039oo`040omoogoo
0oleOol000ioo`03001oo`?o039oo`050omoogooOol3o`0bOol010?oOomoo`?o<Woo00D3ogooOomo
o`?o039oo`040omoogoo0oleOol000ioo`03001oo`?o039oo`050omoogooOol3o`0bOol010?oOomo
o`?o<Woo00D3ogooOomoo`?o039oo`040omoogoo0oleOol000ioo`8000030omoogoo031oo`050omo
ogooOol3o`0aOol01@?oOomoogoo0ol0<Woo00D3ogooOomoo`?o035oo`050omoogooOol3o`0eOol0
00ioo`03001oo`?o039oo`050omoogooOol3o`0aOol01@?oOomoogoo0ol0<Woo00D3ogooOomoo`?o
035oo`050omoogooOol3o`0eOol000ioo`03001oo`?o039oo`050omoogooOol3o`0aOol01@?oOomo
ogoo0ol0<Woo00D3ogooOomoo`?o035oo`050omoogooOol3o`0eOol000ioo`03001oo`?o039oo`05
0omoogooOol3o`0aOol01@?oOomoogoo0ol0<Woo00D3ogooOomoo`?o035oo`050omoogooOol3o`0e
Ool000ioo`03001oo`?o039oo`050omoogooOol3o`0aOol01@?oOomoogoo0ol0<Woo00D3ogooOomo
o`?o035oo`030omoogoo009oo`030omoogoo039oo`003Woo00<007oo0ol0<Goo00<3ogooOol00Woo
00<3ogooOol0;goo00<3ogooOol00Woo00<3ogooOol0;goo00D3ogooOomoo`?o035oo`030omoogoo
009oo`030omoogoo039oo`003Woo0P0000<3ogooOol0;goo00<3ogooOol00Woo00<3ogooOol0;goo
00<3ogooOol00Woo00<3ogooOol0;goo00D3ogooOomoo`?o035oo`030omoogoo009oo`030omoogoo
039oo`003Woo00@007ooOol3oc1oo`030omoogoo009oo`030omoogoo02moo`030omoogoo009oo`03
0omoogoo02moo`050omoogooOol3o`0aOol00`?oOomoo`02Ool00`?oOomoo`0bOol000ioo`04001o
ogoo0ol`Ool00`?oOomoo`02Ool00`?oOomoo`0_Ool00`?oOomoo`02Ool00`?oOomoo`0_Ool01@?o
Oomoogoo0ol0<Goo00<3ogooOol00Woo00<3ogooOol0<Woo000>Ool01000Oomoo`?o<7oo00<3ogoo
Ool00Woo00<3ogooOol0;goo00<3ogooOol00Woo00<3ogooOol0;goo00D3ogooOomoo`?o035oo`03
0omoogoo009oo`030omoogoo039oo`003Woo00@007ooOol3oc1oo`030omoogoo009oo`030omoogoo
02moo`030omoogoo009oo`030omoogoo02ioo`030omoogoo00=oo`030omoogoo02ioo`030omoogoo
009oo`030omoogoo039oo`003Woo00@007ooOol3oc1oo`030omoogoo009oo`030omoogoo02moo`03
0omoogoo009oo`030omoogoo02ioo`030omoogoo00=oo`030omoogoo02ioo`030omoogoo009oo`03
0omoogoo039oo`003Woo0P0000=oo`?oOol0;goo00<3ogooOol00Woo00<3ogooOol0;goo00<3ogoo
Ool00Woo00<3ogooOol0;Woo00<3ogooOol00goo00<3ogooOol0;Woo00<3ogooOol00Woo00<3ogoo
Ool0<Woo000>Ool01000Oomoo`?o<7oo00<3ogooOol00Woo00<3ogooOol0;goo00<3ogooOol00Woo
00<3ogooOol0;Woo00<3ogooOol00goo00<3ogooOol0;Woo00<3ogooOol00Woo00<3ogooOol0<Woo
000>Ool01000Oomoo`?o<7oo00<3ogooOol00Woo00<3ogooOol0;Woo00<3ogooOol00goo00<3ogoo
Ool0;Woo00<3ogooOol00goo00<3ogooOol0;Woo00<3ogooOol00Woo00<3ogooOol0<Woo000>Ool0
1000Oomoo`?o<7oo00<3ogooOol00goo00<3ogooOol0;Goo00<3ogooOol00goo00<3ogooOol0;Woo
00<3ogooOol00goo00<3ogooOol0;Goo00<3ogooOol00goo00<3ogooOol0<Woo0008Ool30003Ool0
1000Oomoo`?o<7oo00<3ogooOol00goo00<3ogooOol0;Goo00<3ogooOol00goo00<3ogooOol0;Woo
00<3ogooOol00goo00<3ogooOol0;Goo00<3ogooOol00goo00<3ogooOol0<Woo0009Ool00`00Oomo
o`02Ool01000Oomoo`?o<7oo00<3ogooOol00goo00<3ogooOol0;Goo00<3ogooOol00goo00<3ogoo
Ool0;Woo00<3ogooOol00goo00<3ogooOol0;Goo00<3ogooOol017oo00<3ogooOol0<Goo0006Ool5
0003Ool300000`?oOomoo`0^Ool00`?oOomoo`03Ool00`?oOomoo`0]Ool00`?oOomoo`03Ool00`?o
Oomoo`0^Ool00`?oOomoo`03Ool00`?oOomoo`0]Ool00`?oOomoo`04Ool00`?oOomoo`0aOol000Io
o`04001oogoo0004Ool01000Oomoo`?o;goo00<3ogooOol017oo00<3ogooOol0;Goo00<3ogooOol0
0goo00<3ogooOol0;Woo00<3ogooOol00goo00<3ogooOol0;Goo00<3ogooOol017oo00<3ogooOol0
<Goo0007Ool00`00Ool00004Ool01000Oomoo`?o;goo00<3ogooOol017oo00<3ogooOol0;Goo00<3
ogooOol017oo00<3ogooOol0;Goo00<3ogooOol00goo00<3ogooOol0;Goo00<3ogooOol017oo00<3
ogooOol0<Goo0008Ool20004Ool01@00Oomoogoo0ol0;Woo00<3ogooOol017oo00<3ogooOol0;Goo
00<3ogooOol017oo00<3ogooOol0;Goo00<3ogooOol00goo00<3ogooOol0;Goo00<3ogooOol017oo
00<3ogooOol0<Goo000>Ool01@00Oomoogoo0ol0;Woo00<3ogooOol017oo00<3ogooOol0;Goo00<3
ogooOol017oo00<3ogooOol0;Goo00<3ogooOol00goo00<3ogooOol0;Goo00<3ogooOol017oo00<3
ogooOol0<Goo000>Ool01@00Oomoogoo0ol0;Woo00<3ogooOol017oo00<3ogooOol0;Goo00<3ogoo
Ool017oo00<3ogooOol0;7oo00<3ogooOol017oo00<3ogooOol0;Goo00<3ogooOol017oo00<3ogoo
Ool0<Goo000>Ool20002Ool00`?oOomoo`0/Ool00`?oOomoo`04Ool00`?oOomoo`0]Ool00`?oOomo
o`04Ool00`?oOomoo`0/Ool00`?oOomoo`05Ool00`?oOomoo`0/Ool00`?oOomoo`04Ool00`?oOomo
o`0aOol000ioo`05001oogooOol3o`0^Ool00`?oOomoo`04Ool00`?oOomoo`0]Ool00`?oOomoo`04
Ool00`?oOomoo`0/Ool00`?oOomoo`05Ool00`?oOomoo`0/Ool00`?oOomoo`04Ool00`?oOomoo`0a
Ool000ioo`05001oogooOol3o`0^Ool00`?oOomoo`05Ool00`?oOomoo`0/Ool00`?oOomoo`04Ool0
0`?oOomoo`0/Ool00`?oOomoo`05Ool00`?oOomoo`0/Ool00`?oOomoo`04Ool00`?oOomoo`0aOol0
00ioo`05001oogooOol3o`0^Ool00`?oOomoo`05Ool00`?oOomoo`0[Ool00`?oOomoo`05Ool00`?o
Oomoo`0/Ool00`?oOomoo`05Ool00`?oOomoo`0/Ool00`?oOomoo`04Ool00`?oOomoo`0aOol000io
o`05001oogooOol3o`0^Ool00`?oOomoo`05Ool00`?oOomoo`0[Ool00`?oOomoo`05Ool00`?oOomo
o`0/Ool00`?oOomoo`05Ool00`?oOomoo`0[Ool00`?oOomoo`05Ool00`?oOomoo`0aOol000ioo`05
001oogooOol3o`0^Ool00`?oOomoo`05Ool00`?oOomoo`0[Ool00`?oOomoo`05Ool00`?oOomoo`0/
Ool00`?oOomoo`05Ool00`?oOomoo`0[Ool00`?oOomoo`05Ool00`?oOomoo`0aOol000ioo`80009o
o`030omoogoo02aoo`030omoogoo00Eoo`030omoogoo02]oo`030omoogoo00Eoo`030omoogoo02ao
o`030omoogoo00Eoo`030omoogoo02]oo`030omoogoo00Ioo`030omoogoo031oo`003Woo00D007oo
Oomoo`?o02eoo`030omoogoo00Ioo`030omoogoo02]oo`030omoogoo00Eoo`030omoogoo02aoo`03
0omoogoo00Eoo`030omoogoo02]oo`030omoogoo00Ioo`030omoogoo031oo`003Woo00D007ooOomo
o`?o02eoo`030omoogoo00Ioo`030omoogoo02]oo`030omoogoo00Ioo`030omoogoo02]oo`030omo
ogoo00Eoo`030omoogoo02]oo`030omoogoo00Ioo`030omoogoo031oo`003Woo00<007ooOol00Woo
00<3ogooOol0:Woo00<3ogooOol01Woo00<3ogooOol0:goo00<3ogooOol01Woo00<3ogooOol0:Woo
00<3ogooOol01Woo00<3ogooOol0:goo00<3ogooOol01Woo00<3ogooOol0<7oo000>Ool00`00Oomo
o`02Ool00`?oOomoo`0ZOol00`?oOomoo`06Ool00`?oOomoo`0[Ool00`?oOomoo`06Ool00`?oOomo
o`0ZOol00`?oOomoo`07Ool00`?oOomoo`0ZOol00`?oOomoo`06Ool00`?oOomoo`0`Ool000ioo`03
001oogoo009oo`030omoogoo02Yoo`030omoogoo00Ioo`030omoogoo02]oo`030omoogoo00Ioo`03
0omoogoo02Yoo`030omoogoo00Moo`030omoogoo02Yoo`030omoogoo00Ioo`030omoogoo031oo`00
3Woo0P000goo00<3ogooOol0:Woo00<3ogooOol01Woo00<3ogooOol0:goo00<3ogooOol01Woo00<3
ogooOol0:Woo00<3ogooOol01goo00<3ogooOol0:Woo00<3ogooOol01Woo00<3ogooOol0<7oo000>
Ool00`00Oomoo`02Ool00`?oOomoo`0ZOol00`?oOomoo`06Ool00`?oOomoo`0[Ool00`?oOomoo`06
Ool00`?oOomoo`0ZOol00`?oOomoo`07Ool00`?oOomoo`0ZOol00`?oOomoo`06Ool00`?oOomoo`0`
Ool000ioo`03001oogoo009oo`030omoogoo02Yoo`030omoogoo00Moo`030omoogoo02Uoo`030omo
ogoo00Moo`030omoogoo02Yoo`030omoogoo00Moo`030omoogoo02Yoo`030omoogoo00Ioo`030omo
ogoo031oo`003Woo00<007ooOol00Woo00<3ogooOol0:Goo00<3ogooOol027oo00<3ogooOol0:Goo
00<3ogooOol01goo00<3ogooOol0:Woo00<3ogooOol01goo00<3ogooOol0:Goo00<3ogooOol01goo
00<3ogooOol0<7oo000>Ool00`00Oomoo`02Ool00`?oOomoo`0YOol00`?oOomoo`08Ool00`?oOomo
o`0YOol00`?oOomoo`07Ool00`?oOomoo`0ZOol00`?oOomoo`07Ool00`?oOomoo`0YOol00`?oOomo
o`07Ool00`?oOomoo`0`Ool000ioo`03001oogoo00=oo`030omoogoo02Qoo`030omoogoo00Qoo`03
0omoogoo02Uoo`030omoogoo00Moo`030omoogoo02Yoo`030omoogoo00Moo`030omoogoo02Uoo`03
0omoogoo00Qoo`030omoogoo02moo`003Woo0P0017oo00<3ogooOol0:7oo00<3ogooOol027oo00<3
ogooOol0:Goo00<3ogooOol01goo00<3ogooOol0:Woo00<3ogooOol01goo00<3ogooOol0:Goo00<3
ogooOol027oo00<3ogooOol0;goo000>Ool00`00Oomoo`03Ool00`?oOomoo`0XOol00`?oOomoo`08
Ool00`?oOomoo`0YOol00`?oOomoo`08Ool00`?oOomoo`0XOol00`?oOomoo`08Ool00`?oOomoo`0Y
Ool00`?oOomoo`08Ool00`?oOomoo`0_Ool000ioo`03001oogoo00=oo`030omoogoo02Qoo`030omo
ogoo00Qoo`030omoogoo02Uoo`030omoogoo00Qoo`030omoogoo02Qoo`030omoogoo00Uoo`030omo
ogoo02Qoo`030omoogoo00Qoo`030omoogoo02moo`003Woo00<007ooOol00goo00<3ogooOol0:7oo
00<3ogooOol027oo00<3ogooOol0:Goo00<3ogooOol027oo00<3ogooOol0:7oo00<3ogooOol02Goo
00<3ogooOol0:7oo00<3ogooOol027oo00<3ogooOol0;goo0007Ool20005Ool00`00Oomoo`03Ool0
0`?oOomoo`0XOol00`?oOomoo`08Ool00`?oOomoo`0YOol00`?oOomoo`08Ool00`?oOomoo`0XOol0
0`?oOomoo`09Ool00`?oOomoo`0XOol00`?oOomoo`08Ool00`?oOomoo`0_Ool000Ioo`04001oogoo
0004Ool00`00Oomoo`03Ool00`?oOomoo`0XOol00`?oOomoo`09Ool00`?oOomoo`0WOol00`?oOomo
o`09Ool00`?oOomoo`0XOol00`?oOomoo`09Ool00`?oOomoo`0WOol00`?oOomoo`09Ool00`?oOomo
o`0_Ool000Uoo`03001oogoo009oo`<000=oo`030omoogoo02Moo`030omoogoo00Yoo`030omoogoo
02Moo`030omoogoo00Uoo`030omoogoo02Qoo`030omoogoo00Uoo`030omoogoo02Moo`030omoogoo
00Uoo`030omoogoo02moo`001goo0P001Goo00<007ooOol00goo00<3ogooOol09goo00<3ogooOol0
2Woo00<3ogooOol09goo00<3ogooOol02Goo00<3ogooOol0:7oo00<3ogooOol02Goo00<3ogooOol0
9goo00<3ogooOol02Goo00<3ogooOol0;goo0007Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`?o
Oomoo`0VOol00`?oOomoo`0:Ool00`?oOomoo`0WOol00`?oOomoo`0:Ool00`?oOomoo`0WOol00`?o
Oomoo`09Ool00`?oOomoo`0WOol00`?oOomoo`0:Ool00`?oOomoo`0^Ool000Moo`<000Aoo`03001o
ogoo00Aoo`030omoogoo02Ioo`030omoogoo00Yoo`030omoogoo02Moo`030omoogoo00Yoo`030omo
ogoo02Moo`030omoogoo00Uoo`030omoogoo02Moo`030omoogoo00Yoo`030omoogoo02ioo`003Woo
00<007ooOol017oo00<3ogooOol09Woo00<3ogooOol02Woo00<3ogooOol09goo00<3ogooOol02Woo
00<3ogooOol09Woo00<3ogooOol02Woo00<3ogooOol09goo00<3ogooOol02Woo00<3ogooOol0;Woo
000>Ool00`00Oomoo`04Ool00`?oOomoo`0VOol00`?oOomoo`0:Ool00`?oOomoo`0WOol00`?oOomo
o`0:Ool00`?oOomoo`0VOol00`?oOomoo`0;Ool00`?oOomoo`0VOol00`?oOomoo`0:Ool00`?oOomo
o`0^Ool000ioo`8000Eoo`030omoogoo02Ioo`030omoogoo00Yoo`030omoogoo02Ioo`030omoogoo
00]oo`030omoogoo02Ioo`030omoogoo00]oo`030omoogoo02Ioo`030omoogoo00Yoo`030omoogoo
02ioo`003Woo00<007ooOol017oo00<3ogooOol09Woo00<3ogooOol02Woo00<3ogooOol09Woo00<3
ogooOol02goo00<3ogooOol09Woo00<3ogooOol02goo00<3ogooOol09Goo00<3ogooOol02goo00<3
ogooOol0;Woo000>Ool00`00Oomoo`04Ool00`?oOomoo`0UOol00`?oOomoo`0<Ool00`?oOomoo`0U
Ool00`?oOomoo`0;Ool00`?oOomoo`0VOol00`?oOomoo`0;Ool00`?oOomoo`0UOol00`?oOomoo`0;
Ool00`?oOomoo`0^Ool000ioo`03001oogoo00Aoo`030omoogoo02Eoo`030omoogoo00aoo`030omo
ogoo02Eoo`030omoogoo00]oo`030omoogoo02Ioo`030omoogoo00]oo`030omoogoo02Eoo`030omo
ogoo00aoo`030omoogoo02eoo`003Woo00<007ooOol01Goo00<3ogooOol097oo00<3ogooOol037oo
00<3ogooOol09Goo00<3ogooOol02goo00<3ogooOol09Woo00<3ogooOol02goo00<3ogooOol09Goo
00<3ogooOol037oo00<3ogooOol0;Goo000>Ool00`00Oomoo`05Ool00`?oOomoo`0TOol00`?oOomo
o`0<Ool00`?oOomoo`0UOol00`?oOomoo`0<Ool00`?oOomoo`0UOol00`?oOomoo`0;Ool00`?oOomo
o`0UOol00`?oOomoo`0<Ool00`?oOomoo`0]Ool000ioo`8000Ioo`030omoogoo02Aoo`030omoogoo
00aoo`030omoogoo02Eoo`030omoogoo00aoo`030omoogoo02Aoo`030omoogoo00aoo`030omoogoo
02Eoo`030omoogoo00aoo`030omoogoo02eoo`003Woo00<007ooOol01Goo00<3ogooOol097oo00<3
ogooOol037oo00<3ogooOol09Goo00<3ogooOol037oo00<3ogooOol097oo00<3ogooOol03Goo00<3
ogooOol097oo00<3ogooOol037oo00<3ogooOol0;Goo000>Ool00`00Oomoo`05Ool00`?oOomoo`0T
Ool00`?oOomoo`0=Ool00`?oOomoo`0SOol00`?oOomoo`0=Ool00`?oOomoo`0TOol00`?oOomoo`0=
Ool00`?oOomoo`0TOol00`?oOomoo`0<Ool00`?oOomoo`0]Ool000ioo`03001oogoo00Eoo`030omo
ogoo02Aoo`030omoogoo00eoo`030omoogoo02=oo`030omoogoo00eoo`030omoogoo02Aoo`030omo
ogoo00eoo`030omoogoo02=oo`030omoogoo00eoo`030omoogoo02eoo`003Woo00<007ooOol01Goo
00<3ogooOol08goo00<3ogooOol03Woo00<3ogooOol08goo00<3ogooOol03Goo00<3ogooOol097oo
00<3ogooOol03Goo00<3ogooOol08goo00<3ogooOol03Woo00<3ogooOol0;7oo000>Ool00`00Oomo
o`06Ool00`?oOomoo`0ROol00`?oOomoo`0>Ool00`?oOomoo`0SOol00`?oOomoo`0=Ool00`?oOomo
o`0TOol00`?oOomoo`0=Ool00`?oOomoo`0SOol00`?oOomoo`0>Ool00`?oOomoo`0/Ool000ioo`80
00Moo`030omoogoo029oo`030omoogoo00ioo`030omoogoo02=oo`030omoogoo00ioo`030omoogoo
029oo`030omoogoo00ioo`030omoogoo02=oo`030omoogoo00ioo`030omoogoo02aoo`003Woo00<0
07ooOol01Woo00<3ogooOol08Woo00<3ogooOol03Woo00<3ogooOol08goo00<3ogooOol03Woo00<3
ogooOol08Woo00<3ogooOol03goo00<3ogooOol08Woo00<3ogooOol03Woo00<3ogooOol0;7oo000>
Ool00`00Oomoo`06Ool00`?oOomoo`0ROol00`?oOomoo`0>Ool00`?oOomoo`0SOol00`?oOomoo`0>
Ool00`?oOomoo`0ROol00`?oOomoo`0?Ool00`?oOomoo`0ROol00`?oOomoo`0>Ool00`?oOomoo`0/
Ool000ioo`03001oogoo00Ioo`030omoogoo025oo`030omoogoo011oo`030omoogoo025oo`030omo
ogoo00moo`030omoogoo029oo`030omoogoo00moo`030omoogoo025oo`030omoogoo00moo`030omo
ogoo02aoo`003Woo00<007ooOol01goo00<3ogooOol087oo00<3ogooOol047oo00<3ogooOol08Goo
00<3ogooOol03goo00<3ogooOol08Woo00<3ogooOol03goo00<3ogooOol08Goo00<3ogooOol03goo
00<3ogooOol0;7oo000>Ool00`00Oomoo`07Ool00`?oOomoo`0POol00`?oOomoo`0@Ool00`?oOomo
o`0QOol00`?oOomoo`0?Ool00`?oOomoo`0ROol00`?oOomoo`0?Ool00`?oOomoo`0QOol00`?oOomo
o`0@Ool00`?oOomoo`0[Ool000ioo`8000Qoo`030omoogoo021oo`030omoogoo011oo`030omoogoo
025oo`030omoogoo011oo`030omoogoo025oo`030omoogoo00moo`030omoogoo025oo`030omoogoo
011oo`030omoogoo02]oo`003Woo00<007ooOol01goo00<3ogooOol087oo00<3ogooOol047oo00<3
ogooOol08Goo00<3ogooOol047oo00<3ogooOol087oo00<3ogooOol04Goo00<3ogooOol087oo00<3
ogooOol047oo00<3ogooOol0:goo000>Ool00`00Oomoo`07Ool00`?oOomoo`0POol00`?oOomoo`0@
Ool00`?oOomoo`0QOol00`?oOomoo`0@Ool00`?oOomoo`0POol00`?oOomoo`0AOol00`?oOomoo`0O
Ool00`?oOomoo`0AOol00`?oOomoo`0[Ool000ioo`03001oogoo00Moo`030omoogoo01moo`030omo
ogoo019oo`030omoogoo01moo`030omoogoo015oo`030omoogoo021oo`030omoogoo015oo`030omo
ogoo01moo`030omoogoo015oo`030omoogoo02]oo`003Woo00<007ooOol027oo00<3ogooOol07Woo
00<3ogooOol04Woo00<3ogooOol07goo00<3ogooOol04Goo00<3ogooOol087oo00<3ogooOol04Goo
00<3ogooOol07goo00<3ogooOol04Goo00<3ogooOol0:goo0006Ool30005Ool00`00Oomoo`08Ool0
0`?oOomoo`0NOol00`?oOomoo`0BOol00`?oOomoo`0OOol00`?oOomoo`0BOol00`?oOomoo`0OOol0
0`?oOomoo`0AOol00`?oOomoo`0OOol00`?oOomoo`0BOol00`?oOomoo`0ZOol000Ioo`04001oogoo
0004Ool00`00Oomoo`08Ool00`?oOomoo`0NOol00`?oOomoo`0BOol00`?oOomoo`0OOol00`?oOomo
o`0BOol00`?oOomoo`0NOol00`?oOomoo`0BOol20olPOol00`?oOomoo`0BOol00`?oOomoo`0ZOol0
00Ioo`04001oogoo0004Ool30008Ool00`?oOomoo`0NOol00`?oOomoo`0BOol00`?oOomoo`0OOol0
0`?oOomoo`0BOol00`?oOomoo`0NOol00`?oOomoo`0COol00`?oOomoo`0NOol00`?oOomoo`0BOol0
0`?oOomoo`0ZOol000Ioo`<000Eoo`03001oogoo00Qoo`030omoogoo01eoo`030omoogoo01=oo`03
0omoogoo01ioo`030omoogoo01=oo`030omoogoo01ioo`030omoogoo01=oo`030omoogoo01eoo`03
0omoogoo01=oo`030omoogoo02Yoo`001goo00<007ooOol017oo00<007ooOol02Goo00<3ogooOol0
77oo00<3ogooOol057oo00<3ogooOol07Goo00<3ogooOol04goo00<3ogooOol07Woo00<3ogooOol0
4goo00<3ogooOol07Goo00<3ogooOol057oo00<3ogooOol0:Goo0007Ool30004Ool00`00Oomoo`09
Ool00`?oOomoo`0LOol00`?oOomoo`0DOol00`?oOomoo`0MOol00`?oOomoo`0COol00`?oOomoo`0N
Ool00`?oOomoo`0COol00`?oOomoo`0MOol00`?oOomoo`0DOol00`?oOomoo`0YOol000ioo`03001o
ogoo00Uoo`030omoogoo01aoo`030omoogoo01Aoo`030omoogoo01eoo`030omoogoo01Aoo`030omo
ogoo01aoo`83oaEoo`030omoogoo01eoo`030omoogoo01Aoo`030omoogoo02Uoo`003Woo00<007oo
Ool02Goo00<3ogooOol077oo00<3ogooOol057oo00<3ogooOol07Goo00<3ogooOol057oo00<3ogoo
Ool077oo00<3ogooOol05Goo00<3ogooOol077oo00<3ogooOol057oo00<3ogooOol0:Goo000>Ool2
000:Ool00`?oOomoo`0KOol00`?oOomoo`0FOol00`?oOomoo`0KOol00`?oOomoo`0EOol00`?oOomo
o`0LOol00`?oOomoo`0EOol00`?oOomoo`0KOol00`?oOomoo`0EOol00`?oOomoo`0YOol000ioo`03
001oogoo00Yoo`030omoogoo01Yoo`030omoogoo01Ioo`030omoogoo01]oo`030omoogoo01Eoo`03
0omoogoo01aoo`030omoogoo01Eoo`030omoogoo01]oo`030omoogoo01Ioo`030omoogoo02Qoo`00
3Woo00<007ooOol02Woo00<3ogooOol06Woo00<3ogooOol05Woo00<3ogooOol06goo00<3ogooOol0
5Goo0P?o77oo0P?o5goo0P?o77oo00<3ogooOol05Woo00<3ogooOol06goo00<3ogooOol02Woo000>
Ool00`00Oomoo`0:Ool00`?oOomoo`0IOol20olHOol00`?oOomoo`0KOol00`?oOomoo`0FOol00`?o
Oomoo`0JOol00`?oOomoo`0GOol00`?oOomoo`0JOol00`?oOomoo`0FOol00`?oOomoo`0JOol00`?o
Oomoo`0;Ool000ioo`03001oogoo00Yoo`030omoogoo01Uoo`030omoogoo01Moo`83oa]oo`030omo
ogoo01Moo`030omoogoo01Yoo`030omoogoo01Moo`030omoogoo01Uoo`030omoogoo01Moo`030omo
ogoo01Yoo`030omoogoo00]oo`003Woo00<007ooOol02goo00<3ogooOol067oo00<3ogooOol067oo
00<3ogooOol06Goo00<3ogooOol05goo00<3ogooOol06Woo00<3ogooOol05goo00<3ogooOol06Goo
00<3ogooOol05goo00<3ogooOol06Woo00<3ogooOol02goo000>Ool2000<Ool00`?oOomoo`0HOol0
0`?oOomoo`0HOol00`?oOomoo`0IOol00`?oOomoo`0GOol00`?oOomoo`0JOol00`?oOomoo`0GOol0
0`?oOomoo`0IOol00`?oOomoo`0HOol00`?oOomoo`0IOol00`?oOomoo`0;Ool000ioo`03001oogoo
00]oo`030omoogoo01Moo`83oaYoo`030omoogoo01Uoo`030omoogoo01Qoo`030omoogoo01Qoo`03
0omoogoo01Uoo`030omoogoo01Qoo`030omoogoo01Qoo`030omoogoo01Qoo`83o`eoo`003Woo00<0
07ooOol02goo0P?o67oo00<3ogooOol06Goo00<3ogooOol067oo0P?o6Woo00<3ogooOol067oo00<3
ogooOol06Goo00<3ogooOol05goo00<3ogooOol06Goo00<3ogooOol067oo00<3ogooOol037oo000>
Ool00`00Oomoo`0<Ool00`?oOomoo`0FOol00`?oOomoo`0JOol00`?oOomoo`0GOol00`?oOomoo`0I
Ool00`?oOomoo`0HOol00`?oOomoo`0IOol00`?oOomoo`0GOol00`?oOomoo`0IOol00`?oOomoo`0H
Ool00`?oOomoo`0<Ool000ioo`03001oogoo00aoo`030omoogoo01Ioo`030omoogoo01Yoo`030omo
ogoo01Moo`030omoogoo01Yoo`030omoogoo01Moo`030omoogoo01Uoo`030omoogoo01Moo`030omo
ogoo01Yoo`030omoogoo01Moo`030omoogoo00aoo`003Woo00<007ooOol037oo00<3ogooOol05Goo
00<3ogooOol06goo00<3ogooOol05goo00<3ogooOol06Woo00<3ogooOol05Woo00<3ogooOol06goo
00<3ogooOol05Goo0P?o77oo00<3ogooOol05Woo0P?o3Woo000>Ool2000>Ool00`?oOomoo`0DOol0
0`?oOomoo`0KOol20olGOol00`?oOomoo`0KOol00`?oOomoo`0FOol00`?oOomoo`0KOol00`?oOomo
o`0EOol00`?oOomoo`0KOol00`?oOomoo`0FOol00`?oOomoo`0=Ool000ioo`03001oogoo00eoo`03
0omoogoo01Aoo`030omoogoo01aoo`030omoogoo01Eoo`030omoogoo01]oo`030omoogoo01Ioo`03
0omoogoo01]oo`030omoogoo01Eoo`030omoogoo01]oo`83oaMoo`030omoogoo00eoo`003Woo00<0
07ooOol03Goo00<3ogooOol04goo0P?o7Woo00<3ogooOol05Goo00<3ogooOol077oo00<3ogooOol0
57oo0P?o7Woo00<3ogooOol057oo00<3ogooOol077oo00<3ogooOol057oo0P?o3goo000>Ool00`00
Oomoo`0=Ool20olDOol00`?oOomoo`0MOol20olEOol00`?oOomoo`0MOol00`?oOomoo`0DOol00`?o
Oomoo`0MOol00`?oOomoo`0COol00`?oOomoo`0MOol00`?oOomoo`0DOol00`?oOomoo`0>Ool000io
o`03001oogoo00ioo`030omoogoo019oo`030omoogoo01ioo`030omoogoo01=oo`030omoogoo01eo
o`030omoogoo01Aoo`030omoogoo01eoo`030omoogoo01=oo`030omoogoo01eoo`83oaEoo`030omo
ogoo00ioo`003Woo00<007ooOol03Woo0P?o4Woo00<3ogooOol07goo00<3ogooOol04goo00<3ogoo
Ool07Woo00<3ogooOol04Woo00<3ogooOol07goo00<3ogooOol04Woo00<3ogooOol07Woo00<3ogoo
Ool04Woo0P?o47oo000>Ool2000@Ool00`?oOomoo`0@Ool00`?oOomoo`0OOol20olCOol20olPOol0
0`?oOomoo`0BOol00`?oOomoo`0OOol00`?oOomoo`0AOol00`?oOomoo`0OOol00`?oOomoo`0BOol0
0`?oOomoo`0?Ool000ioo`03001oogoo00moo`030omoogoo00moo`83ob9oo`030omoogoo015oo`03
0omoogoo01moo`030omoogoo019oo`030omoogoo01moo`83oa9oo`030omoogoo01moo`83oa=oo`03
0omoogoo00moo`003Woo00<007ooOol03goo0P?o47oo00<3ogooOol08Goo00<3ogooOol04Goo00<3
ogooOol087oo00<3ogooOol047oo00<3ogooOol08Goo00<3ogooOol03goo0P?o8Woo00<3ogooOol0
47oo0P?o4Goo000>Ool00`00Oomoo`0@Ool00`?oOomoo`0>Ool00`?oOomoo`0QOol20olAOol00`?o
Oomoo`0QOol00`?oOomoo`0@Ool00`?oOomoo`0QOol00`?oOomoo`0?Ool00`?oOomoo`0QOol00`?o
Oomoo`0@Ool00`?oOomoo`0@Ool000Qoo`03001oogoo00=oo`03001oogoo011oo`83o`ioo`030omo
ogoo02=oo`030omoogoo00moo`030omoogoo025oo`83oa1oo`83ob=oo`83o`moo`83obAoo`030omo
ogoo00moo`030omoogoo011oo`0027oo00<007ooOol00goo00<007ooOol04Goo00<3ogooOol037oo
00<3ogooOol08goo0P?o3goo00<3ogooOol08goo00<3ogooOol03Woo00<3ogooOol08goo00<3ogoo
Ool03Goo00<3ogooOol08goo00<3ogooOol03Woo00<3ogooOol04Goo0008Ool00`00Oomoo`03Ool3
000AOol20ol<Ool00`?oOomoo`0UOol00`?oOomoo`0=Ool00`?oOomoo`0SOol20ol?Ool00`?oOomo
o`0SOol20ol=Ool20olUOol20ol?Ool00`?oOomoo`0AOol000Uoo`03001oogoo009oo`03001oogoo
019oo`030omoogoo00Uoo`83obMoo`83o`eoo`83obIoo`030omoogoo00aoo`030omoogoo02Eoo`03
0omoogoo00]oo`030omoogoo02Eoo`030omoogoo00aoo`030omoogoo019oo`001Woo00@007ooOol0
00Aoo`03001oogoo01=oo`030omoogoo00Qoo`030omoogoo02Moo`030omoogoo00]oo`030omoogoo
02Eoo`83o`aoo`83obMoo`83o`]oo`83obQoo`030omoogoo00Yoo`83oaAoo`001Woo100017oo00<0
07ooOol04goo0P?o27oo00<3ogooOol0:7oo0P?o2goo0P?o:7oo00<3ogooOol02Woo00<3ogooOol0
9goo0P?o2Woo00<3ogooOol09goo00<3ogooOol02Woo00<3ogooOol04goo000>Ool00`00Oomoo`0D
Ool20ol6Ool20ol[Ool00`?oOomoo`09Ool00`?oOomoo`0WOol20ol:Ool20olZOol00`?oOomoo`07
Ool00`?oOomoo`0YOol00`?oOomoo`08Ool20olEOol000ioo`03001oogoo01Eoo`83o`=oo`<3obeo
o`030omoogoo00Moo`030omoogoo02Uoo`030omoogoo00Moo`83obaoo`030omoogoo00Eoo`83ob]o
o`83o`Uoo`030omoogoo01Aoo`003Woo0P0067oo10?o;goo0P?o1goo00<3ogooOol0:goo0P?o1goo
00<3ogooOol0:goo0P?o1Goo0P?o;Goo0P?o1Woo0P?o5goo000>Ool00`00Oomoo`1;Ool20ol4Ool3
0ol^Ool20ol4Ool20ol`Ool60ol_Ool20ol4Ool20olHOol000ioo`03001oogoo04eoo`D3oc5oo`H3
ofMoo`H3oaUoo`003Woo00<007ooOol0ogoo47oo000>Ool00`00Oomoo`3oOol@Ool000ioo`03001o
ogoo0?mooa1oo`003Woo0P00ogoo4Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-84.1703, 1.59121, 5.75479, \
0.0329062}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["DR=.", "Input"],

Cell["\<\
For[i=1,i<1501,{DX = X[1,i-1] - X[2,i-1];
DY = Y[1,i-1] - Y[2,i-1];
DZ = Z[1,i-1] - Z[2,i-1];
DR[i] = (DX^2. + DY^2. + DZ^2.)^0.5;i++}];\
\>", "Input"],

Cell["tbl5=Chop[Table[DR[i],{i,1,1500}]];", "Input"],

Cell[CellGroupData[{

Cell["ListPlot[tbl5,PlotJoined->True,PlotStyle->RGBColor[1,0,0]]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000634921 -0.188922 0.101804 [
[.15079 .00219 -9 -9 ]
[.15079 .00219 9 0 ]
[.27778 .00219 -9 -9 ]
[.27778 .00219 9 0 ]
[.40476 .00219 -9 -9 ]
[.40476 .00219 9 0 ]
[.53175 .00219 -9 -9 ]
[.53175 .00219 9 0 ]
[.65873 .00219 -12 -9 ]
[.65873 .00219 12 0 ]
[.78571 .00219 -12 -9 ]
[.78571 .00219 12 0 ]
[.9127 .00219 -12 -9 ]
[.9127 .00219 12 0 ]
[.01131 .11649 -6 -4.5 ]
[.01131 .11649 0 4.5 ]
[.01131 .2183 -6 -4.5 ]
[.01131 .2183 0 4.5 ]
[.01131 .3201 -6 -4.5 ]
[.01131 .3201 0 4.5 ]
[.01131 .4219 -6 -4.5 ]
[.01131 .4219 0 4.5 ]
[.01131 .52371 -6 -4.5 ]
[.01131 .52371 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15079 .01469 m
.15079 .02094 L
s
[(200)] .15079 .00219 0 1 Mshowa
.27778 .01469 m
.27778 .02094 L
s
[(400)] .27778 .00219 0 1 Mshowa
.40476 .01469 m
.40476 .02094 L
s
[(600)] .40476 .00219 0 1 Mshowa
.53175 .01469 m
.53175 .02094 L
s
[(800)] .53175 .00219 0 1 Mshowa
.65873 .01469 m
.65873 .02094 L
s
[(1000)] .65873 .00219 0 1 Mshowa
.78571 .01469 m
.78571 .02094 L
s
[(1200)] .78571 .00219 0 1 Mshowa
.9127 .01469 m
.9127 .02094 L
s
[(1400)] .9127 .00219 0 1 Mshowa
.125 Mabswid
.05556 .01469 m
.05556 .01844 L
s
.0873 .01469 m
.0873 .01844 L
s
.11905 .01469 m
.11905 .01844 L
s
.18254 .01469 m
.18254 .01844 L
s
.21429 .01469 m
.21429 .01844 L
s
.24603 .01469 m
.24603 .01844 L
s
.30952 .01469 m
.30952 .01844 L
s
.34127 .01469 m
.34127 .01844 L
s
.37302 .01469 m
.37302 .01844 L
s
.43651 .01469 m
.43651 .01844 L
s
.46825 .01469 m
.46825 .01844 L
s
.5 .01469 m
.5 .01844 L
s
.56349 .01469 m
.56349 .01844 L
s
.59524 .01469 m
.59524 .01844 L
s
.62698 .01469 m
.62698 .01844 L
s
.69048 .01469 m
.69048 .01844 L
s
.72222 .01469 m
.72222 .01844 L
s
.75397 .01469 m
.75397 .01844 L
s
.81746 .01469 m
.81746 .01844 L
s
.84921 .01469 m
.84921 .01844 L
s
.88095 .01469 m
.88095 .01844 L
s
.94444 .01469 m
.94444 .01844 L
s
.97619 .01469 m
.97619 .01844 L
s
.25 Mabswid
0 .01469 m
1 .01469 L
s
.02381 .11649 m
.03006 .11649 L
s
[(3)] .01131 .11649 1 0 Mshowa
.02381 .2183 m
.03006 .2183 L
s
[(4)] .01131 .2183 1 0 Mshowa
.02381 .3201 m
.03006 .3201 L
s
[(5)] .01131 .3201 1 0 Mshowa
.02381 .4219 m
.03006 .4219 L
s
[(6)] .01131 .4219 1 0 Mshowa
.02381 .52371 m
.03006 .52371 L
s
[(7)] .01131 .52371 1 0 Mshowa
.125 Mabswid
.02381 .03505 m
.02756 .03505 L
s
.02381 .05541 m
.02756 .05541 L
s
.02381 .07577 m
.02756 .07577 L
s
.02381 .09613 m
.02756 .09613 L
s
.02381 .13685 m
.02756 .13685 L
s
.02381 .15721 m
.02756 .15721 L
s
.02381 .17757 m
.02756 .17757 L
s
.02381 .19793 m
.02756 .19793 L
s
.02381 .23866 m
.02756 .23866 L
s
.02381 .25902 m
.02756 .25902 L
s
.02381 .27938 m
.02756 .27938 L
s
.02381 .29974 m
.02756 .29974 L
s
.02381 .34046 m
.02756 .34046 L
s
.02381 .36082 m
.02756 .36082 L
s
.02381 .38118 m
.02756 .38118 L
s
.02381 .40154 m
.02756 .40154 L
s
.02381 .44226 m
.02756 .44226 L
s
.02381 .46263 m
.02756 .46263 L
s
.02381 .48299 m
.02756 .48299 L
s
.02381 .50335 m
.02756 .50335 L
s
.02381 .54407 m
.02756 .54407 L
s
.02381 .56443 m
.02756 .56443 L
s
.02381 .58479 m
.02756 .58479 L
s
.02381 .60515 m
.02756 .60515 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02444 .02487 m
.02508 .02546 L
.02571 .03755 L
.02635 .05564 L
.02698 .07406 L
.02762 .0914 L
.02825 .10743 L
.02889 .12226 L
.02952 .13605 L
.03016 .14893 L
.03079 .16103 L
.03143 .17244 L
.03206 .18324 L
.0327 .19351 L
.03333 .2033 L
.03397 .21266 L
.0346 .22164 L
.03524 .23025 L
.03587 .23855 L
.03651 .24655 L
.03714 .25427 L
.03778 .26174 L
.03841 .26898 L
.03905 .27599 L
.03968 .28281 L
.04032 .28942 L
.04095 .29586 L
.04159 .30213 L
.04222 .30823 L
.04286 .31418 L
.04349 .31999 L
.04413 .32565 L
.04476 .33119 L
.0454 .3366 L
.04603 .34188 L
.04667 .34706 L
.0473 .35212 L
.04794 .35708 L
.04857 .36193 L
.04921 .36669 L
.04984 .37135 L
.05048 .37592 L
.05111 .3804 L
.05175 .3848 L
.05238 .38911 L
.05302 .39335 L
.05365 .3975 L
.05429 .40158 L
.05492 .40559 L
.05556 .40953 L
Mistroke
.05619 .4134 L
.05683 .4172 L
.05746 .42093 L
.0581 .4246 L
.05873 .42821 L
.05937 .43175 L
.06 .43524 L
.06063 .43867 L
.06127 .44204 L
.0619 .44536 L
.06254 .44862 L
.06317 .45182 L
.06381 .45498 L
.06444 .45808 L
.06508 .46113 L
.06571 .46414 L
.06635 .46709 L
.06698 .47 L
.06762 .47285 L
.06825 .47567 L
.06889 .47843 L
.06952 .48115 L
.07016 .48383 L
.07079 .48647 L
.07143 .48906 L
.07206 .49161 L
.0727 .49411 L
.07333 .49658 L
.07397 .499 L
.0746 .50139 L
.07524 .50373 L
.07587 .50604 L
.07651 .5083 L
.07714 .51053 L
.07778 .51272 L
.07841 .51488 L
.07905 .51699 L
.07968 .51907 L
.08032 .52112 L
.08095 .52313 L
.08159 .5251 L
.08222 .52703 L
.08286 .52894 L
.08349 .5308 L
.08413 .53264 L
.08476 .53444 L
.0854 .5362 L
.08603 .53794 L
.08667 .53963 L
.0873 .5413 L
Mistroke
.08794 .54294 L
.08857 .54454 L
.08921 .54611 L
.08984 .54764 L
.09048 .54915 L
.09111 .55062 L
.09175 .55207 L
.09238 .55348 L
.09302 .55486 L
.09365 .55621 L
.09429 .55753 L
.09492 .55882 L
.09556 .56008 L
.09619 .56131 L
.09683 .5625 L
.09746 .56367 L
.0981 .56481 L
.09873 .56592 L
.09937 .56701 L
.1 .56806 L
.10063 .56908 L
.10127 .57007 L
.1019 .57104 L
.10254 .57198 L
.10317 .57288 L
.10381 .57376 L
.10444 .57461 L
.10508 .57544 L
.10571 .57623 L
.10635 .577 L
.10698 .57773 L
.10762 .57845 L
.10825 .57913 L
.10889 .57978 L
.10952 .58041 L
.11016 .58101 L
.11079 .58158 L
.11143 .58212 L
.11206 .58264 L
.1127 .58313 L
.11333 .58359 L
.11397 .58403 L
.1146 .58443 L
.11524 .58481 L
.11587 .58517 L
.11651 .58549 L
.11714 .58579 L
.11778 .58606 L
.11841 .58631 L
.11905 .58653 L
Mistroke
.11968 .58672 L
.12032 .58688 L
.12095 .58702 L
.12159 .58713 L
.12222 .58721 L
.12286 .58727 L
.12349 .58729 L
.12413 .5873 L
.12476 .58727 L
.1254 .58722 L
.12603 .58714 L
.12667 .58704 L
.1273 .5869 L
.12794 .58674 L
.12857 .58656 L
.12921 .58635 L
.12984 .58611 L
.13048 .58584 L
.13111 .58554 L
.13175 .58522 L
.13238 .58487 L
.13302 .5845 L
.13365 .5841 L
.13429 .58367 L
.13492 .58321 L
.13556 .58272 L
.13619 .58221 L
.13683 .58167 L
.13746 .58111 L
.1381 .58051 L
.13873 .57989 L
.13937 .57924 L
.14 .57857 L
.14063 .57786 L
.14127 .57713 L
.1419 .57637 L
.14254 .57558 L
.14317 .57476 L
.14381 .57392 L
.14444 .57305 L
.14508 .57215 L
.14571 .57122 L
.14635 .57026 L
.14698 .56927 L
.14762 .56826 L
.14825 .56721 L
.14889 .56614 L
.14952 .56503 L
.15016 .5639 L
.15079 .56274 L
Mistroke
.15143 .56155 L
.15206 .56033 L
.1527 .55908 L
.15333 .5578 L
.15397 .55649 L
.1546 .55515 L
.15524 .55378 L
.15587 .55238 L
.15651 .55095 L
.15714 .54948 L
.15778 .54799 L
.15841 .54646 L
.15905 .54491 L
.15968 .54332 L
.16032 .54169 L
.16095 .54004 L
.16159 .53836 L
.16222 .53664 L
.16286 .53489 L
.16349 .5331 L
.16413 .53128 L
.16476 .52943 L
.1654 .52754 L
.16603 .52562 L
.16667 .52367 L
.1673 .52168 L
.16794 .51965 L
.16857 .51759 L
.16921 .51549 L
.16984 .51336 L
.17048 .51119 L
.17111 .50898 L
.17175 .50674 L
.17238 .50445 L
.17302 .50213 L
.17365 .49977 L
.17429 .49737 L
.17492 .49493 L
.17556 .49245 L
.17619 .48993 L
.17683 .48737 L
.17746 .48477 L
.1781 .48212 L
.17873 .47943 L
.17937 .4767 L
.18 .47392 L
.18063 .4711 L
.18127 .46823 L
.1819 .46531 L
.18254 .46235 L
Mistroke
.18317 .45934 L
.18381 .45628 L
.18444 .45317 L
.18508 .45001 L
.18571 .44679 L
.18635 .44353 L
.18698 .44021 L
.18762 .43683 L
.18825 .4334 L
.18889 .42992 L
.18952 .42637 L
.19016 .42276 L
.19079 .4191 L
.19143 .41537 L
.19206 .41157 L
.1927 .40771 L
.19333 .40378 L
.19397 .39978 L
.1946 .39572 L
.19524 .39157 L
.19587 .38736 L
.19651 .38306 L
.19714 .37868 L
.19778 .37422 L
.19841 .36968 L
.19905 .36505 L
.19968 .36032 L
.20032 .35551 L
.20095 .35059 L
.20159 .34557 L
.20222 .34045 L
.20286 .33521 L
.20349 .32986 L
.20413 .32439 L
.20476 .3188 L
.2054 .31307 L
.20603 .30721 L
.20667 .3012 L
.2073 .29505 L
.20794 .28873 L
.20857 .28224 L
.20921 .27558 L
.20984 .26872 L
.21048 .26166 L
.21111 .25439 L
.21175 .24689 L
.21238 .23914 L
.21302 .23113 L
.21365 .22283 L
.21429 .21422 L
Mistroke
.21492 .20527 L
.21556 .19595 L
.21619 .18622 L
.21683 .17604 L
.21746 .16537 L
.2181 .15413 L
.21873 .14226 L
.21937 .12968 L
.22 .11628 L
.22063 .10194 L
.22127 .08649 L
.2219 .06976 L
.22254 .05154 L
.22317 .03167 L
.22381 .01478 L
.22444 .01475 L
.22508 .01686 L
.22571 .03764 L
.22635 .06214 L
.22698 .08355 L
.22762 .10245 L
.22825 .11939 L
.22889 .13481 L
.22952 .149 L
.23016 .16216 L
.23079 .17447 L
.23143 .18604 L
.23206 .19697 L
.2327 .20735 L
.23333 .21723 L
.23397 .22667 L
.2346 .23571 L
.23524 .24439 L
.23587 .25274 L
.23651 .26079 L
.23714 .26856 L
.23778 .27608 L
.23841 .28336 L
.23905 .29042 L
.23968 .29727 L
.24032 .30392 L
.24095 .31039 L
.24159 .31669 L
.24222 .32283 L
.24286 .32881 L
.24349 .33465 L
.24413 .34035 L
.24476 .34591 L
.2454 .35135 L
.24603 .35667 L
Mistroke
.24667 .36187 L
.2473 .36696 L
.24794 .37194 L
.24857 .37682 L
.24921 .38161 L
.24984 .38629 L
.25048 .39089 L
.25111 .39539 L
.25175 .39982 L
.25238 .40415 L
.25302 .40841 L
.25365 .41259 L
.25429 .41669 L
.25492 .42072 L
.25556 .42468 L
.25619 .42857 L
.25683 .43239 L
.25746 .43614 L
.2581 .43983 L
.25873 .44346 L
.25937 .44702 L
.26 .45053 L
.26063 .45397 L
.26127 .45736 L
.2619 .46069 L
.26254 .46397 L
.26317 .4672 L
.26381 .47037 L
.26444 .47348 L
.26508 .47655 L
.26571 .47957 L
.26635 .48254 L
.26698 .48546 L
.26762 .48833 L
.26825 .49115 L
.26889 .49393 L
.26952 .49667 L
.27016 .49935 L
.27079 .502 L
.27143 .5046 L
.27206 .50716 L
.2727 .50968 L
.27333 .51215 L
.27397 .51459 L
.2746 .51698 L
.27524 .51933 L
.27587 .52165 L
.27651 .52392 L
.27714 .52616 L
.27778 .52835 L
Mistroke
.27841 .53052 L
.27905 .53264 L
.27968 .53472 L
.28032 .53677 L
.28095 .53878 L
.28159 .54076 L
.28222 .5427 L
.28286 .54461 L
.28349 .54648 L
.28413 .54832 L
.28476 .55012 L
.2854 .55189 L
.28603 .55362 L
.28667 .55532 L
.2873 .55699 L
.28794 .55862 L
.28857 .56022 L
.28921 .56179 L
.28984 .56333 L
.29048 .56483 L
.29111 .56631 L
.29175 .56775 L
.29238 .56916 L
.29302 .57054 L
.29365 .57188 L
.29429 .5732 L
.29492 .57449 L
.29556 .57574 L
.29619 .57696 L
.29683 .57816 L
.29746 .57932 L
.2981 .58046 L
.29873 .58156 L
.29937 .58264 L
.3 .58368 L
.30063 .5847 L
.30127 .58568 L
.3019 .58664 L
.30254 .58757 L
.30317 .58847 L
.30381 .58934 L
.30444 .59018 L
.30508 .59099 L
.30571 .59177 L
.30635 .59253 L
.30698 .59326 L
.30762 .59395 L
.30825 .59462 L
.30889 .59527 L
.30952 .59588 L
Mistroke
.31016 .59647 L
.31079 .59702 L
.31143 .59755 L
.31206 .59806 L
.3127 .59853 L
.31333 .59898 L
.31397 .59939 L
.3146 .59979 L
.31524 .60015 L
.31587 .60048 L
.31651 .60079 L
.31714 .60107 L
.31778 .60133 L
.31841 .60155 L
.31905 .60175 L
.31968 .60192 L
.32032 .60207 L
.32095 .60218 L
.32159 .60227 L
.32222 .60233 L
.32286 .60236 L
.32349 .60237 L
.32413 .60235 L
.32476 .6023 L
.3254 .60223 L
.32603 .60212 L
.32667 .60199 L
.3273 .60184 L
.32794 .60165 L
.32857 .60144 L
.32921 .6012 L
.32984 .60093 L
.33048 .60064 L
.33111 .60031 L
.33175 .59996 L
.33238 .59959 L
.33302 .59918 L
.33365 .59875 L
.33429 .59829 L
.33492 .5978 L
.33556 .59728 L
.33619 .59674 L
.33683 .59617 L
.33746 .59557 L
.3381 .59494 L
.33873 .59429 L
.33937 .5936 L
.34 .59289 L
.34063 .59215 L
.34127 .59138 L
Mistroke
.3419 .59058 L
.34254 .58976 L
.34317 .5889 L
.34381 .58802 L
.34444 .58711 L
.34508 .58617 L
.34571 .5852 L
.34635 .5842 L
.34698 .58317 L
.34762 .58211 L
.34825 .58103 L
.34889 .57991 L
.34952 .57877 L
.35016 .57759 L
.35079 .57638 L
.35143 .57515 L
.35206 .57388 L
.3527 .57258 L
.35333 .57126 L
.35397 .5699 L
.3546 .56851 L
.35524 .56709 L
.35587 .56563 L
.35651 .56415 L
.35714 .56264 L
.35778 .56109 L
.35841 .55951 L
.35905 .5579 L
.35968 .55625 L
.36032 .55458 L
.36095 .55287 L
.36159 .55112 L
.36222 .54935 L
.36286 .54754 L
.36349 .54569 L
.36413 .54381 L
.36476 .5419 L
.3654 .53995 L
.36603 .53797 L
.36667 .53595 L
.3673 .53389 L
.36794 .5318 L
.36857 .52967 L
.36921 .52751 L
.36984 .5253 L
.37048 .52306 L
.37111 .52078 L
.37175 .51847 L
.37238 .51611 L
.37302 .51371 L
Mistroke
.37365 .51128 L
.37429 .5088 L
.37492 .50628 L
.37556 .50372 L
.37619 .50112 L
.37683 .49848 L
.37746 .49579 L
.3781 .49306 L
.37873 .49028 L
.37937 .48746 L
.38 .48459 L
.38063 .48168 L
.38127 .47871 L
.3819 .4757 L
.38254 .47264 L
.38317 .46953 L
.38381 .46637 L
.38444 .46316 L
.38508 .45989 L
.38571 .45657 L
.38635 .4532 L
.38698 .44977 L
.38762 .44628 L
.38825 .44273 L
.38889 .43913 L
.38952 .43546 L
.39016 .43173 L
.39079 .42793 L
.39143 .42407 L
.39206 .42015 L
.3927 .41615 L
.39333 .41208 L
.39397 .40794 L
.3946 .40372 L
.39524 .39943 L
.39587 .39505 L
.39651 .39059 L
.39714 .38605 L
.39778 .38142 L
.39841 .3767 L
.39905 .37189 L
.39968 .36697 L
.40032 .36196 L
.40095 .35684 L
.40159 .35161 L
.40222 .34627 L
.40286 .34081 L
.40349 .33522 L
.40413 .32951 L
.40476 .32366 L
Mistroke
.4054 .31766 L
.40603 .31152 L
.40667 .30522 L
.4073 .29875 L
.40794 .2921 L
.40857 .28527 L
.40921 .27824 L
.40984 .27099 L
.41048 .26352 L
.41111 .25581 L
.41175 .24783 L
.41238 .23957 L
.41302 .231 L
.41365 .2221 L
.41429 .21283 L
.41492 .20316 L
.41556 .19304 L
.41619 .18242 L
.41683 .17125 L
.41746 .15943 L
.4181 .14689 L
.41873 .13351 L
.41937 .11913 L
.42 .10357 L
.42063 .08656 L
.42127 .06773 L
.4219 .04651 L
.42254 .02197 L
.42317 .01474 L
.42381 .01472 L
.42444 .01748 L
.42508 .0395 L
.42571 .06385 L
.42635 .08511 L
.42698 .10387 L
.42762 .12072 L
.42825 .13606 L
.42889 .15017 L
.42952 .16328 L
.43016 .17554 L
.43079 .18707 L
.43143 .19797 L
.43206 .20831 L
.4327 .21817 L
.43333 .22758 L
.43397 .2366 L
.4346 .24526 L
.43524 .25359 L
.43587 .26162 L
.43651 .26938 L
Mistroke
.43714 .27689 L
.43778 .28415 L
.43841 .2912 L
.43905 .29804 L
.43968 .30468 L
.44032 .31115 L
.44095 .31744 L
.44159 .32357 L
.44222 .32955 L
.44286 .33538 L
.44349 .34107 L
.44413 .34663 L
.44476 .35206 L
.4454 .35738 L
.44603 .36258 L
.44667 .36766 L
.4473 .37264 L
.44794 .37752 L
.44857 .3823 L
.44921 .38699 L
.44984 .39158 L
.45048 .39608 L
.45111 .4005 L
.45175 .40484 L
.45238 .40909 L
.45302 .41327 L
.45365 .41737 L
.45429 .4214 L
.45492 .42536 L
.45556 .42925 L
.45619 .43307 L
.45683 .43682 L
.45746 .44051 L
.4581 .44414 L
.45873 .4477 L
.45937 .45121 L
.46 .45465 L
.46063 .45804 L
.46127 .46137 L
.4619 .46465 L
.46254 .46788 L
.46317 .47105 L
.46381 .47417 L
.46444 .47723 L
.46508 .48025 L
.46571 .48322 L
.46635 .48614 L
.46698 .48901 L
.46762 .49184 L
.46825 .49462 L
Mistroke
.46889 .49736 L
.46952 .50005 L
.47016 .50269 L
.47079 .5053 L
.47143 .50786 L
.47206 .51038 L
.4727 .51285 L
.47333 .51529 L
.47397 .51768 L
.4746 .52004 L
.47524 .52235 L
.47587 .52463 L
.47651 .52687 L
.47714 .52907 L
.47778 .53123 L
.47841 .53336 L
.47905 .53544 L
.47968 .53749 L
.48032 .53951 L
.48095 .54149 L
.48159 .54343 L
.48222 .54534 L
.48286 .54721 L
.48349 .54905 L
.48413 .55086 L
.48476 .55263 L
.4854 .55436 L
.48603 .55607 L
.48667 .55774 L
.4873 .55937 L
.48794 .56098 L
.48857 .56255 L
.48921 .56409 L
.48984 .5656 L
.49048 .56707 L
.49111 .56852 L
.49175 .56993 L
.49238 .57131 L
.49302 .57266 L
.49365 .57398 L
.49429 .57527 L
.49492 .57653 L
.49556 .57775 L
.49619 .57895 L
.49683 .58012 L
.49746 .58126 L
.4981 .58236 L
.49873 .58344 L
.49937 .58449 L
.5 .58551 L
Mistroke
.50063 .5865 L
.50127 .58746 L
.5019 .58839 L
.50254 .58929 L
.50317 .59016 L
.50381 .59101 L
.50444 .59182 L
.50508 .59261 L
.50571 .59337 L
.50635 .5941 L
.50698 .5948 L
.50762 .59548 L
.50825 .59612 L
.50889 .59674 L
.50952 .59733 L
.51016 .59789 L
.51079 .59842 L
.51143 .59893 L
.51206 .59941 L
.5127 .59986 L
.51333 .60028 L
.51397 .60068 L
.5146 .60104 L
.51524 .60138 L
.51587 .60169 L
.51651 .60198 L
.51714 .60224 L
.51778 .60247 L
.51841 .60267 L
.51905 .60284 L
.51968 .60299 L
.52032 .60311 L
.52095 .6032 L
.52159 .60327 L
.52222 .60331 L
.52286 .60332 L
.52349 .6033 L
.52413 .60326 L
.52476 .60319 L
.5254 .60309 L
.52603 .60296 L
.52667 .60281 L
.5273 .60263 L
.52794 .60242 L
.52857 .60219 L
.52921 .60192 L
.52984 .60163 L
.53048 .60132 L
.53111 .60097 L
.53175 .6006 L
Mistroke
.53238 .6002 L
.53302 .59977 L
.53365 .59932 L
.53429 .59883 L
.53492 .59832 L
.53556 .59778 L
.53619 .59722 L
.53683 .59662 L
.53746 .596 L
.5381 .59535 L
.53873 .59467 L
.53937 .59397 L
.54 .59323 L
.54063 .59247 L
.54127 .59168 L
.5419 .59086 L
.54254 .59001 L
.54317 .58913 L
.54381 .58822 L
.54444 .58729 L
.54508 .58633 L
.54571 .58533 L
.54635 .58431 L
.54698 .58326 L
.54762 .58218 L
.54825 .58107 L
.54889 .57993 L
.54952 .57876 L
.55016 .57756 L
.55079 .57633 L
.55143 .57507 L
.55206 .57378 L
.5527 .57246 L
.55333 .57111 L
.55397 .56972 L
.5546 .56831 L
.55524 .56687 L
.55587 .56539 L
.55651 .56388 L
.55714 .56234 L
.55778 .56077 L
.55841 .55917 L
.55905 .55753 L
.55968 .55586 L
.56032 .55416 L
.56095 .55243 L
.56159 .55066 L
.56222 .54885 L
.56286 .54702 L
.56349 .54515 L
Mistroke
.56413 .54324 L
.56476 .5413 L
.5654 .53933 L
.56603 .53732 L
.56667 .53527 L
.5673 .53319 L
.56794 .53107 L
.56857 .52892 L
.56921 .52672 L
.56984 .52449 L
.57048 .52222 L
.57111 .51992 L
.57175 .51757 L
.57238 .51519 L
.57302 .51276 L
.57365 .51029 L
.57429 .50779 L
.57492 .50524 L
.57556 .50265 L
.57619 .50002 L
.57683 .49734 L
.57746 .49462 L
.5781 .49186 L
.57873 .48905 L
.57937 .4862 L
.58 .4833 L
.58063 .48035 L
.58127 .47735 L
.5819 .47431 L
.58254 .47121 L
.58317 .46807 L
.58381 .46487 L
.58444 .46162 L
.58508 .45832 L
.58571 .45496 L
.58635 .45155 L
.58698 .44808 L
.58762 .44455 L
.58825 .44096 L
.58889 .43731 L
.58952 .4336 L
.59016 .42983 L
.59079 .42599 L
.59143 .42209 L
.59206 .41811 L
.5927 .41407 L
.59333 .40995 L
.59397 .40576 L
.5946 .40149 L
.59524 .39714 L
Mistroke
.59587 .39271 L
.59651 .3882 L
.59714 .3836 L
.59778 .37891 L
.59841 .37413 L
.59905 .36925 L
.59968 .36427 L
.60032 .35919 L
.60095 .354 L
.60159 .3487 L
.60222 .34328 L
.60286 .33774 L
.60349 .33208 L
.60413 .32628 L
.60476 .32034 L
.6054 .31425 L
.60603 .308 L
.60667 .3016 L
.6073 .29502 L
.60794 .28825 L
.60857 .2813 L
.60921 .27413 L
.60984 .26675 L
.61048 .25913 L
.61111 .25125 L
.61175 .2431 L
.61238 .23465 L
.61302 .22588 L
.61365 .21675 L
.61429 .20724 L
.61492 .19729 L
.61556 .18687 L
.61619 .17591 L
.61683 .16435 L
.61746 .1521 L
.6181 .13906 L
.61873 .12508 L
.61937 .10999 L
.62 .09357 L
.62063 .07548 L
.62127 .05527 L
.6219 .03216 L
.62254 .01485 L
.62317 .01483 L
.62381 .01474 L
.62444 .0245 L
.62508 .04661 L
.62571 .06877 L
.62635 .08859 L
.62698 .10637 L
Mistroke
.62762 .12249 L
.62825 .13727 L
.62889 .15093 L
.62952 .16367 L
.63016 .17562 L
.63079 .18688 L
.63143 .19755 L
.63206 .20769 L
.6327 .21736 L
.63333 .22661 L
.63397 .23547 L
.6346 .24399 L
.63524 .2522 L
.63587 .26012 L
.63651 .26776 L
.63714 .27516 L
.63778 .28233 L
.63841 .28929 L
.63905 .29604 L
.63968 .3026 L
.64032 .30899 L
.64095 .3152 L
.64159 .32126 L
.64222 .32717 L
.64286 .33293 L
.64349 .33856 L
.64413 .34405 L
.64476 .34943 L
.6454 .35468 L
.64603 .35982 L
.64667 .36486 L
.6473 .36978 L
.64794 .37461 L
.64857 .37934 L
.64921 .38397 L
.64984 .38852 L
.65048 .39297 L
.65111 .39735 L
.65175 .40164 L
.65238 .40585 L
.65302 .40998 L
.65365 .41404 L
.65429 .41803 L
.65492 .42194 L
.65556 .42579 L
.65619 .42957 L
.65683 .43328 L
.65746 .43693 L
.6581 .44052 L
.65873 .44405 L
Mistroke
.65937 .44752 L
.66 .45093 L
.66063 .45428 L
.66127 .45757 L
.6619 .46082 L
.66254 .46401 L
.66317 .46714 L
.66381 .47023 L
.66444 .47326 L
.66508 .47625 L
.66571 .47918 L
.66635 .48207 L
.66698 .48491 L
.66762 .4877 L
.66825 .49045 L
.66889 .49315 L
.66952 .49581 L
.67016 .49843 L
.67079 .501 L
.67143 .50353 L
.67206 .50602 L
.6727 .50847 L
.67333 .51087 L
.67397 .51324 L
.6746 .51556 L
.67524 .51785 L
.67587 .5201 L
.67651 .52231 L
.67714 .52448 L
.67778 .52661 L
.67841 .52871 L
.67905 .53077 L
.67968 .53279 L
.68032 .53478 L
.68095 .53673 L
.68159 .53864 L
.68222 .54053 L
.68286 .54237 L
.68349 .54418 L
.68413 .54596 L
.68476 .5477 L
.6854 .54941 L
.68603 .55109 L
.68667 .55273 L
.6873 .55435 L
.68794 .55592 L
.68857 .55747 L
.68921 .55898 L
.68984 .56046 L
.69048 .56191 L
Mistroke
.69111 .56333 L
.69175 .56472 L
.69238 .56608 L
.69302 .5674 L
.69365 .56869 L
.69429 .56996 L
.69492 .57119 L
.69556 .57239 L
.69619 .57357 L
.69683 .57471 L
.69746 .57582 L
.6981 .5769 L
.69873 .57796 L
.69937 .57898 L
.7 .57998 L
.70063 .58094 L
.70127 .58188 L
.7019 .58278 L
.70254 .58366 L
.70317 .58451 L
.70381 .58533 L
.70444 .58612 L
.70508 .58689 L
.70571 .58762 L
.70635 .58833 L
.70698 .58901 L
.70762 .58966 L
.70825 .59028 L
.70889 .59087 L
.70952 .59144 L
.71016 .59198 L
.71079 .59249 L
.71143 .59297 L
.71206 .59343 L
.7127 .59385 L
.71333 .59425 L
.71397 .59462 L
.7146 .59497 L
.71524 .59528 L
.71587 .59557 L
.71651 .59583 L
.71714 .59607 L
.71778 .59628 L
.71841 .59646 L
.71905 .59661 L
.71968 .59673 L
.72032 .59683 L
.72095 .5969 L
.72159 .59694 L
.72222 .59696 L
Mistroke
.72286 .59694 L
.72349 .5969 L
.72413 .59684 L
.72476 .59674 L
.7254 .59662 L
.72603 .59647 L
.72667 .5963 L
.7273 .59609 L
.72794 .59586 L
.72857 .59561 L
.72921 .59532 L
.72984 .59501 L
.73048 .59467 L
.73111 .5943 L
.73175 .5939 L
.73238 .59348 L
.73302 .59303 L
.73365 .59255 L
.73429 .59204 L
.73492 .59151 L
.73556 .59095 L
.73619 .59036 L
.73683 .58974 L
.73746 .58909 L
.7381 .58842 L
.73873 .58772 L
.73937 .58699 L
.74 .58623 L
.74063 .58544 L
.74127 .58462 L
.7419 .58378 L
.74254 .58291 L
.74317 .58201 L
.74381 .58107 L
.74444 .58012 L
.74508 .57913 L
.74571 .57811 L
.74635 .57706 L
.74698 .57599 L
.74762 .57488 L
.74825 .57374 L
.74889 .57258 L
.74952 .57138 L
.75016 .57016 L
.75079 .5689 L
.75143 .56762 L
.75206 .5663 L
.7527 .56495 L
.75333 .56357 L
.75397 .56216 L
Mistroke
.7546 .56072 L
.75524 .55925 L
.75587 .55775 L
.75651 .55621 L
.75714 .55464 L
.75778 .55305 L
.75841 .55141 L
.75905 .54975 L
.75968 .54805 L
.76032 .54632 L
.76095 .54455 L
.76159 .54276 L
.76222 .54092 L
.76286 .53906 L
.76349 .53715 L
.76413 .53522 L
.76476 .53325 L
.7654 .53124 L
.76603 .5292 L
.76667 .52712 L
.7673 .525 L
.76794 .52285 L
.76857 .52066 L
.76921 .51843 L
.76984 .51617 L
.77048 .51386 L
.77111 .51152 L
.77175 .50913 L
.77238 .50671 L
.77302 .50425 L
.77365 .50174 L
.77429 .4992 L
.77492 .49661 L
.77556 .49398 L
.77619 .4913 L
.77683 .48859 L
.77746 .48582 L
.7781 .48302 L
.77873 .48016 L
.77937 .47726 L
.78 .47431 L
.78063 .47132 L
.78127 .46827 L
.7819 .46518 L
.78254 .46203 L
.78317 .45883 L
.78381 .45558 L
.78444 .45228 L
.78508 .44892 L
.78571 .4455 L
Mistroke
.78635 .44203 L
.78698 .4385 L
.78762 .43491 L
.78825 .43126 L
.78889 .42754 L
.78952 .42377 L
.79016 .41992 L
.79079 .41601 L
.79143 .41203 L
.79206 .40798 L
.7927 .40385 L
.79333 .39965 L
.79397 .39537 L
.7946 .39102 L
.79524 .38658 L
.79587 .38205 L
.79651 .37744 L
.79714 .37274 L
.79778 .36794 L
.79841 .36305 L
.79905 .35805 L
.79968 .35295 L
.80032 .34774 L
.80095 .34242 L
.80159 .33698 L
.80222 .33142 L
.80286 .32572 L
.80349 .31989 L
.80413 .31392 L
.80476 .3078 L
.8054 .30152 L
.80603 .29507 L
.80667 .28845 L
.8073 .28164 L
.80794 .27464 L
.80857 .26742 L
.80921 .25997 L
.80984 .25229 L
.81048 .24434 L
.81111 .23611 L
.81175 .22757 L
.81238 .21871 L
.81302 .20948 L
.81365 .19985 L
.81429 .18977 L
.81492 .1792 L
.81556 .16808 L
.81619 .15633 L
.81683 .14387 L
.81746 .13058 L
Mistroke
.8181 .11632 L
.81873 .10092 L
.81937 .08412 L
.82 .06559 L
.82063 .04488 L
.82127 .02123 L
.8219 .01482 L
.82254 .01477 L
.82317 .01879 L
.82381 .03918 L
.82444 .06265 L
.82508 .08353 L
.82571 .1021 L
.82635 .11882 L
.82698 .13408 L
.82762 .14815 L
.82825 .16121 L
.82889 .17344 L
.82952 .18494 L
.83016 .19582 L
.83079 .20615 L
.83143 .21599 L
.83206 .22539 L
.8327 .2344 L
.83333 .24305 L
.83397 .25137 L
.8346 .25939 L
.83524 .26714 L
.83587 .27464 L
.83651 .2819 L
.83714 .28894 L
.83778 .29577 L
.83841 .30241 L
.83905 .30887 L
.83968 .31516 L
.84032 .32128 L
.84095 .32725 L
.84159 .33308 L
.84222 .33877 L
.84286 .34432 L
.84349 .34975 L
.84413 .35506 L
.84476 .36025 L
.8454 .36534 L
.84603 .37031 L
.84667 .37519 L
.8473 .37997 L
.84794 .38465 L
.84857 .38924 L
.84921 .39374 L
Mistroke
.84984 .39816 L
.85048 .40249 L
.85111 .40674 L
.85175 .41092 L
.85238 .41502 L
.85302 .41905 L
.85365 .423 L
.85429 .42689 L
.85492 .4307 L
.85556 .43446 L
.85619 .43815 L
.85683 .44177 L
.85746 .44533 L
.8581 .44884 L
.85873 .45228 L
.85937 .45567 L
.86 .459 L
.86063 .46228 L
.86127 .4655 L
.8619 .46868 L
.86254 .47179 L
.86317 .47486 L
.86381 .47788 L
.86444 .48085 L
.86508 .48377 L
.86571 .48664 L
.86635 .48947 L
.86698 .49225 L
.86762 .49499 L
.86825 .49768 L
.86889 .50032 L
.86952 .50293 L
.87016 .50549 L
.87079 .50801 L
.87143 .51049 L
.87206 .51292 L
.8727 .51532 L
.87333 .51768 L
.87397 .51999 L
.8746 .52227 L
.87524 .52451 L
.87587 .52671 L
.87651 .52888 L
.87714 .531 L
.87778 .53309 L
.87841 .53515 L
.87905 .53716 L
.87968 .53915 L
.88032 .54109 L
.88095 .543 L
Mistroke
.88159 .54488 L
.88222 .54672 L
.88286 .54853 L
.88349 .5503 L
.88413 .55204 L
.88476 .55375 L
.8854 .55542 L
.88603 .55706 L
.88667 .55867 L
.8873 .56024 L
.88794 .56178 L
.88857 .5633 L
.88921 .56477 L
.88984 .56622 L
.89048 .56764 L
.89111 .56902 L
.89175 .57038 L
.89238 .5717 L
.89302 .57299 L
.89365 .57426 L
.89429 .57549 L
.89492 .57669 L
.89556 .57786 L
.89619 .579 L
.89683 .58011 L
.89746 .5812 L
.8981 .58225 L
.89873 .58327 L
.89937 .58427 L
.9 .58523 L
.90063 .58617 L
.90127 .58708 L
.9019 .58796 L
.90254 .58881 L
.90317 .58963 L
.90381 .59042 L
.90444 .59119 L
.90508 .59192 L
.90571 .59263 L
.90635 .59331 L
.90698 .59396 L
.90762 .59459 L
.90825 .59518 L
.90889 .59575 L
.90952 .59629 L
.91016 .5968 L
.91079 .59729 L
.91143 .59775 L
.91206 .59817 L
.9127 .59858 L
Mistroke
.91333 .59895 L
.91397 .5993 L
.9146 .59962 L
.91524 .59991 L
.91587 .60017 L
.91651 .60041 L
.91714 .60062 L
.91778 .60081 L
.91841 .60096 L
.91905 .60109 L
.91968 .60119 L
.92032 .60126 L
.92095 .60131 L
.92159 .60133 L
.92222 .60132 L
.92286 .60129 L
.92349 .60123 L
.92413 .60114 L
.92476 .60102 L
.9254 .60088 L
.92603 .60071 L
.92667 .60051 L
.9273 .60028 L
.92794 .60003 L
.92857 .59975 L
.92921 .59944 L
.92984 .59911 L
.93048 .59874 L
.93111 .59835 L
.93175 .59794 L
.93238 .59749 L
.93302 .59702 L
.93365 .59652 L
.93429 .59599 L
.93492 .59544 L
.93556 .59485 L
.93619 .59424 L
.93683 .5936 L
.93746 .59294 L
.9381 .59224 L
.93873 .59152 L
.93937 .59077 L
.94 .58999 L
.94063 .58918 L
.94127 .58835 L
.9419 .58748 L
.94254 .58659 L
.94317 .58567 L
.94381 .58472 L
.94444 .58374 L
Mistroke
.94508 .58273 L
.94571 .58169 L
.94635 .58063 L
.94698 .57953 L
.94762 .5784 L
.94825 .57725 L
.94889 .57606 L
.94952 .57485 L
.95016 .5736 L
.95079 .57233 L
.95143 .57102 L
.95206 .56969 L
.9527 .56832 L
.95333 .56692 L
.95397 .56549 L
.9546 .56403 L
.95524 .56254 L
.95587 .56102 L
.95651 .55947 L
.95714 .55788 L
.95778 .55626 L
.95841 .55461 L
.95905 .55293 L
.95968 .55121 L
.96032 .54946 L
.96095 .54768 L
.96159 .54586 L
.96222 .54401 L
.96286 .54212 L
.96349 .5402 L
.96413 .53825 L
.96476 .53626 L
.9654 .53423 L
.96603 .53217 L
.96667 .53007 L
.9673 .52794 L
.96794 .52577 L
.96857 .52356 L
.96921 .52132 L
.96984 .51903 L
.97048 .51671 L
.97111 .51435 L
.97175 .51195 L
.97238 .50951 L
.97302 .50702 L
.97365 .5045 L
.97429 .50194 L
.97492 .49933 L
.97556 .49668 L
.97619 .49399 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000YOol4
0003Ool20004Ool2000FOol30002Ool20004Ool2000COol30004Ool20004Ool2000EOol20004Ool2
0004Ool2000AOol50002Ool20004Ool20004Ool2000=Ool500000goo000000020003Ool20004Ool2
000>Ool50003Ool30002Ool20004Ool2000EOol002Uoo`03001oogoo00=oo`04001oogoo0002Ool0
1000Oomoo`005Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`0@Ool01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo000COol01000Oomoo`000Woo00@007ooOol0009oo`04001o
ogoo000BOol01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`0<
Ool01@00Oomoogoo00001Goo00@007ooOol0009oo`04001oogoo000?Ool00`00Oomoo`04Ool01000
Oomoo`000Woo00@007ooOol0009oo`03001oogoo019oo`00:Woo00<007ooOol00Woo00@007ooOol0
009oo`04001oogoo000COol500001Goo001oogoo00000Woo00@007ooOol0019oo`04001oogoo0002
Ool01000Oomoo`000Woo00@007ooOol001=oo`04001oogoo0002Ool01000Oomoo`000Woo00@007oo
Ool0019oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo00ao
o`03001oogoo009oo`03001oogoo009oo`04001oogoo0002Ool01000Oomoo`003goo00@007ooOomo
o`D00005Ool007ooOol00002Ool01000Oomoo`0057oo000[Ool01@00Oomoogoo00000Woo00@007oo
Ool0009oo`03001oogoo015oo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0019oo`<0
00=oo`04001oogoo0002Ool01000Oomoo`0057oo0P000goo00@007ooOol0009oo`04001oogoo000B
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`04001oogoo0002Ool00`00Oomoo`0<Ool00`00
Oomoo`03Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo00eoo`05001oogooOol0
0002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo019oo`00:Goo00@007ooOol0009o
o`04001oogoo0002Ool01000Oomoo`0057oo00<007oo00000Woo00@007ooOol0009oo`04001oogoo
000COol00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol001=oo`04001oogoo0002Ool01000
Oomoo`000Woo00@007ooOol0019oo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oogoo00aoo`05001oogooOol00002Ool01000Oomoo`000Woo00@007ooOol0009oo`03
001oogoo00eoo`03001oogoo009oo`03001oo`00009oo`04001oogoo0002Ool01000Oomoo`0057oo
000ZOol20004Ool20004Ool2000FOol20003Ool20004Ool2000DOol30003Ool20004Ool2000EOol2
0004Ool20004Ool2000BOol20004Ool20004Ool20004Ool2000>Ool20004Ool20004Ool20004Ool2
000?Ool20005Ool20003Ool20004Ool2000EOol00?moob5oo`003goo00<007ooOol0ogoo3goo000?
Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0ogoo3goo0008
Oolm00000g`00000000d00000g`00000000c00000g`00000000c00000g`00000000_0006Ool000mo
o`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Io
o`03001oogoo00Ioo`03001oog`000Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eo
o`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo009oo`9l009oo`03001oogoo00Ioo`03001o
ogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03O000
07oo00Moo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001o
ogoo00Ioo`03001l07`000Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001o
ogoo00Eoo`03001oogoo00]oo`003goo00<007ooOol07goo00<007ooOol04Goo00=l07ooOol037oo
00<007ooOol07goo00<007ooOol00Woo0W`077oo00<007ooOol05Woo00=l07ooOol01goo00<007oo
Ool07goo00<007ooOol01goo0W`05goo00<007ooOol077oo000?Ool00g`0Oomoo`0cOol00g`0Oomo
o`0cOol2O00eOol00g`0Oomoo`0cOol2O00fOol000moo`03O01oogoo03=oo`9l03Aoo`9l03Eoo`03
O01oogoo03=oo`9l03Ioo`003goo00=l07ooOol0<goo0W`0=7oo0W`0=Goo00=l07ooOol0<goo0W`0
=Woo000?Ool00g`0001oo`0cOol2O00dOol2O00eOol2O00dOol2O00fOol000moo`03O01oogoo03=o
o`9l03Aoo`9l03Eoo`9l03Aoo`9l03Ioo`003goo00=l07ooOol0<goo0W`0=7oo0W`0=Goo0W`0=7oo
0W`0=Woo000?Ool00g`0Oomoo`0cOol2O00dOol2O00eOol2O00dOol2O00fOol000moo`03O01oogoo
03=oo`9l03Aoo`9l03Eoo`9l03Aoo`9l03Ioo`003goo00=l0000Ool0<goo0W`0=7oo0W`0=Goo0W`0
=7oo0W`0=Woo000?Ool00g`0Oomoo`0cOol2O00dOol2O00eOol2O00dOol2O00fOol000moo`03O01o
ogoo03=oo`9l03Aoo`9l03Eoo`9l03Aoo`9l03Ioo`003goo00=l07ooOol0<goo0W`0=7oo0W`0=7oo
00=l07ooO000=7oo0W`0=Woo000?Ool00g`0Oomoo`0cOol2O00dOol2O00dOol00g`0Ooml000dOol2
O00fOol000moo`03O01oogoo03=oo`9l03Aoo`9l03Aoo`03O01oog`003Aoo`9l03Ioo`003goo00=l
0000Ool0<goo0W`0=7oo0W`0=7oo00=l07ooO000=7oo0W`0=Woo000?Ool00g`0Oomoo`0bOol00g`0
Ooml000dOol2O00dOol00g`0Ooml000dOol2O00fOol000moo`03001l07oo039oo`03O01oog`003Ao
o`9l03Aoo`03O01oog`003Aoo`9l03Ioo`003goo00<007`0Ool0<Woo00=l07ooO000=7oo0W`0=7oo
00=l07ooO000=7oo0W`0=Woo000?Ool00`00O01oo`0bOol00g`0Ooml000dOol2O00dOol00g`0Ooml
000cOol00g`0Ooml000fOol000moo`03001l07oo039oo`03O01oog`003Aoo`03O01oog`003=oo`03
O01oog`003=oo`03O01oog`003Ioo`003goo00<007`0Ool0<Woo00=l07ooO000=7oo00=l07ooO000
<goo00=l07ooO000<goo00=l07ooO000=Woo000?Ool00`00O01oo`0bOol00g`0Ooml000dOol00g`0
Ooml000cOol00g`0Ooml000cOol00g`0Ooml000fOol000moo`03001l07oo039oo`03O01oog`003Ao
o`03O01oog`003=oo`03O01oog`003=oo`03O01oog`003Ioo`001goo0P001Woo00<007`0Ool0<Woo
00=l07ooO000<goo00Al07ooOoml03=oo`03O01oog`003=oo`03O01oog`003Ioo`001Woo00@007oo
Ool000Eoo`03001l07oo039oo`03O01oog`003=oo`04O01oogooO00cOol00g`0Ooml000cOol00g`0
Ooml000fOol000Qoo`03001oogoo00Aoo`03001l07oo039oo`03O01oog`003=oo`04O01oogooO00c
Ool00g`0Ooml000cOol00g`0Ooml000fOol000Uoo`03001oogoo00=oo`03001l07oo039oo`03O01o
og`003=oo`04O01oogooO00cOol00g`0Ooml000cOol00g`0Ooml000fOol000Ioo`04001oogoo0005
Ool00`00O01oo`0bOol00g`0Ooml000cOol017`0Oomoog`0<goo00=l07ooO000<goo00=l07ooO000
=Woo0007Ool20006Ool00`00O01oo`0bOol017`0Oomoog`0<Woo00Al07ooOoml03=oo`03O01oog`0
03=oo`04O01oogooO00eOol000moo`03001l07oo039oo`04O01oogooO00bOol017`0Oomoog`0<goo
00=l07ooO000<goo00Al07ooOoml03Eoo`003goo00<007`0Ool0<Woo00Al07ooOoml039oo`04O01o
ogooO00cOol00g`0Ooml000cOol017`0Oomoog`0=Goo000?Ool00`00O01oo`0bOol017`0Oomoog`0
<Woo00Al07ooOoml03=oo`03O01oog`003=oo`04O01oogooO00eOol000moo`03001l07oo039oo`04
O01oogooO00bOol017`0Oomoog`0<goo00Al07ooOoml039oo`04O01oogooO00eOol000moo`03001l
07oo039oo`04O01oogooO00bOol017`0Oomoog`0<Woo00El07ooOomoog`0039oo`04O01oogooO00e
Ool000moo`03001l07oo039oo`04O01oogooO00bOol017`0Oomoog`0<Woo00El07ooOomoog`0039o
o`04O01oogooO00eOol000moo`03001l07oo039oo`04O01oogooO00bOol017`0Oomoog`0<Woo00El
07ooOomoog`0039oo`04O01oogooO00eOol000moo`800003O01oogoo031oo`04O01oogooO00bOol0
17`0Oomoog`0<Woo00El07ooOomoog`0039oo`04O01oogooO00eOol000moo`03001oog`0035oo`05
O01oogooOoml000bOol017`0Oomoog`0<Woo00El07ooOomoog`0039oo`04O01oogooO00eOol000mo
o`03001oog`0035oo`05O01oogooOoml000bOol017`0Oomoog`0<Woo00El07ooOomoog`0039oo`04
O01oogooO00eOol000moo`03001oog`0035oo`05O01oogooOoml000bOol017`0Oomoog`0<Woo00El
07ooOomoog`0039oo`04O01oogooO00eOol000moo`03001oog`0035oo`05O01oogooOoml000bOol0
17`0Oomoog`0<Woo00El07ooOomoog`0039oo`04O01oogooO00eOol000moo`800003O01oogoo02mo
o`05O01oogooOoml000bOol017`0Oomoog`0<Woo00El07ooOomoog`0035oo`05O01oogooOoml000e
Ool000moo`03001oog`0035oo`05O01oogooOoml000bOol017`0Oomoog`0<Woo00El07ooOomoog`0
035oo`05O01oogooOoml000eOol000moo`03001oog`0035oo`05O01oogooOoml000bOol01G`0Oomo
ogooO000<Goo00El07ooOomoog`0035oo`05O01oogooOoml000eOol000moo`03001oog`0035oo`05
O01oogooOoml000bOol01G`0OomoogooO000<Goo00El07ooOomoog`0035oo`05O01oogooOoml000e
Ool000moo`03001oog`0035oo`05O01oogooOoml000aOol00g`0Oomoo`02Ool00g`0Oomoo`0_Ool0
1G`0OomoogooO000<Goo00El07ooOomoog`003Eoo`003goo00<007ooO000<Goo00El07ooOomoog`0
035oo`03O01oogoo009oo`03O01oogoo02moo`05O01oogooOoml000aOol01G`0OomoogooO000=Goo
000?Ool200000g`0Oomoo`0_Ool01G`0OomoogooO000<Goo00=l07ooOol00Woo00=l07ooOol0;goo
00El07ooOomoog`0035oo`05O01oogooOoml000eOol000moo`03001oog`0035oo`05O01oogooOoml
000aOol00g`0Oomoo`02Ool00g`0Oomoo`0_Ool01G`0OomoogooO000<Goo00=l07ooOol00Woo00=l
07ooOol0<Woo000?Ool00`00Ooml000aOol00g`0Oomoo`02Ool00g`0Oomoo`0^Ool00g`0Oomoo`02
Ool00g`0Oomoo`0_Ool01G`0OomoogooO000<Goo00=l07ooOol00Woo00=l07ooOol0<Woo0008Ool3
0004Ool00`00Ooml000aOol00g`0Oomoo`02Ool00g`0Oomoo`0^Ool00g`0Oomoo`02Ool00g`0Oomo
o`0_Ool01G`0OomoogooO000<Goo00=l07ooOol00Woo00=l07ooOol0<Woo0009Ool00`00Oomoo`03
Ool00`00Ooml000aOol00g`0Oomoo`02Ool00g`0Oomoo`0^Ool00g`0Oomoo`02Ool00g`0Oomoo`0^
Ool00g`0Oomoo`03Ool00g`0Oomoo`0^Ool00g`0Oomoo`02Ool00g`0Oomoo`0bOol000Ioo`D000Ao
o`800003Ooml07oo02moo`03O01oogoo009oo`03O01oogoo02ioo`03O01oogoo009oo`03O01oogoo
02ioo`03O01oogoo00=oo`03O01oogoo02ioo`03O01oogoo009oo`03O01oogoo039oo`001Woo00@0
07ooOol000Eoo`04001oogooO00_Ool00g`0Oomoo`03Ool00g`0Oomoo`0^Ool00g`0Oomoo`02Ool0
0g`0Oomoo`0^Ool00g`0Oomoo`03Ool00g`0Oomoo`0^Ool00g`0Oomoo`02Ool00g`0Oomoo`0bOol0
00Moo`03001oo`0000Eoo`04001oogooO00_Ool00g`0Oomoo`03Ool00g`0Oomoo`0^Ool00g`0Oomo
o`02Ool00g`0Oomoo`0^Ool00g`0Oomoo`03Ool00g`0Oomoo`0]Ool00g`0Oomoo`03Ool00g`0Oomo
o`0bOol000Qoo`8000Eoo`04001oogooO00_Ool00g`0Oomoo`03Ool00g`0Oomoo`0^Ool00g`0Oomo
o`02Ool00g`0Oomoo`0^Ool00g`0Oomoo`03Ool00g`0Oomoo`0]Ool00g`0Oomoo`03Ool00g`0Oomo
o`0bOol000moo`04001oogooO00_Ool00g`0Oomoo`03Ool00g`0Oomoo`0^Ool00g`0Oomoo`02Ool0
0g`0Oomoo`0^Ool00g`0Oomoo`03Ool00g`0Oomoo`0]Ool00g`0Oomoo`03Ool00g`0Oomoo`0bOol0
00moo`04001oogooO00_Ool00g`0Oomoo`03Ool00g`0Oomoo`0^Ool00g`0Oomoo`02Ool00g`0Oomo
o`0^Ool00g`0Oomoo`03Ool00g`0Oomoo`0]Ool00g`0Oomoo`03Ool00g`0Oomoo`0bOol000moo`80
0003Ooml07oo02ioo`03O01oogoo00=oo`03O01oogoo02ioo`03O01oogoo009oo`03O01oogoo02io
o`03O01oogoo00=oo`03O01oogoo02eoo`03O01oogoo00=oo`03O01oogoo039oo`003goo00@007oo
Ooml02moo`03O01oogoo00=oo`03O01oogoo02ioo`03O01oogoo00=oo`03O01oogoo02eoo`03O01o
ogoo00=oo`03O01oogoo02eoo`03O01oogoo00=oo`03O01oogoo039oo`003goo00@007ooOoml02mo
o`03O01oogoo00=oo`03O01oogoo02eoo`03O01oogoo00Aoo`03O01oogoo02eoo`03O01oogoo00=o
o`03O01oogoo02eoo`03O01oogoo00=oo`03O01oogoo039oo`003goo00@007ooOoml02moo`03O01o
ogoo00=oo`03O01oogoo02eoo`03O01oogoo00Aoo`03O01oogoo02eoo`03O01oogoo00=oo`03O01o
ogoo02eoo`03O01oogoo00Aoo`03O01oogoo035oo`003goo00@007ooOoml02moo`03O01oogoo00=o
o`03O01oogoo02eoo`03O01oogoo00Aoo`03O01oogoo02eoo`03O01oogoo00=oo`03O01oogoo02eo
o`03O01oogoo00Aoo`03O01oogoo035oo`003goo00@007ooOoml02moo`03O01oogoo00Aoo`03O01o
ogoo02aoo`03O01oogoo00Aoo`03O01oogoo02eoo`03O01oogoo00Aoo`03O01oogoo02aoo`03O01o
ogoo00Aoo`03O01oogoo035oo`003goo0P0000=oog`0Ool0;Woo00=l07ooOol017oo00=l07ooOol0
;7oo00=l07ooOol017oo00=l07ooOol0;Goo00=l07ooOol017oo00=l07ooOol0;7oo00=l07ooOol0
17oo00=l07ooOol0<Goo000?Ool01@00OomoogooO000;Goo00=l07ooOol01Goo00=l07ooOol0;7oo
00=l07ooOol017oo00=l07ooOol0;7oo00=l07ooOol01Goo00=l07ooOol0;7oo00=l07ooOol017oo
00=l07ooOol0<Goo000?Ool01@00OomoogooO000;Goo00=l07ooOol01Goo00=l07ooOol0;7oo00=l
07ooOol017oo00=l07ooOol0;7oo00=l07ooOol01Goo00=l07ooOol0;7oo00=l07ooOol017oo00=l
07ooOol0<Goo000?Ool01@00OomoogooO000;Goo00=l07ooOol01Goo00=l07ooOol0;7oo00=l07oo
Ool017oo00=l07ooOol0;7oo00=l07ooOol01Goo00=l07ooOol0:goo00=l07ooOol01Goo00=l07oo
Ool0<Goo000?Ool01@00OomoogooO000;Goo00=l07ooOol01Goo00=l07ooOol0;7oo00=l07ooOol0
17oo00=l07ooOol0;7oo00=l07ooOol01Goo00=l07ooOol0:goo00=l07ooOol01Goo00=l07ooOol0
<Goo000?Ool20002Ool00g`0Oomoo`0[Ool00g`0Oomoo`05Ool00g`0Oomoo`0/Ool00g`0Oomoo`04
Ool00g`0Oomoo`0/Ool00g`0Oomoo`05Ool00g`0Oomoo`0[Ool00g`0Oomoo`05Ool00g`0Oomoo`0a
Ool000moo`05001oogooOoml000]Ool00g`0Oomoo`05Ool00g`0Oomoo`0/Ool00g`0Oomoo`04Ool0
0g`0Oomoo`0/Ool00g`0Oomoo`05Ool00g`0Oomoo`0[Ool00g`0Oomoo`05Ool00g`0Oomoo`0aOol0
00moo`05001oogooOoml000]Ool00g`0Oomoo`05Ool00g`0Oomoo`0/Ool00g`0Oomoo`05Ool00g`0
Oomoo`0[Ool00g`0Oomoo`05Ool00g`0Oomoo`0[Ool00g`0Oomoo`05Ool00g`0Oomoo`0aOol000mo
o`05001oogooOoml000]Ool00g`0Oomoo`05Ool00g`0Oomoo`0[Ool00g`0Oomoo`06Ool00g`0Oomo
o`0[Ool00g`0Oomoo`05Ool00g`0Oomoo`0[Ool00g`0Oomoo`05Ool00g`0Oomoo`0aOol000moo`05
001oogooOoml000]Ool00g`0Oomoo`05Ool00g`0Oomoo`0[Ool00g`0Oomoo`06Ool00g`0Oomoo`0[
Ool00g`0Oomoo`05Ool00g`0Oomoo`0[Ool00g`0Oomoo`06Ool00g`0Oomoo`0`Ool000moo`05001o
ogooOoml000/Ool00g`0Oomoo`06Ool00g`0Oomoo`0[Ool00g`0Oomoo`06Ool00g`0Oomoo`0[Ool0
0g`0Oomoo`05Ool00g`0Oomoo`0[Ool00g`0Oomoo`06Ool00g`0Oomoo`0`Ool000moo`80009oo`03
O01oogoo02Yoo`03O01oogoo00Moo`03O01oogoo02Yoo`03O01oogoo00Ioo`03O01oogoo02]oo`03
O01oogoo00Ioo`03O01oogoo02Yoo`03O01oogoo00Ioo`03O01oogoo031oo`003goo00<007ooOol0
0Woo00=l07ooOol0:Goo00=l07ooOol01goo00=l07ooOol0:Woo00=l07ooOol01Woo00=l07ooOol0
:Woo00=l07ooOol01goo00=l07ooOol0:Woo00=l07ooOol01Woo00=l07ooOol0<7oo000?Ool00`00
Oomoo`02Ool00g`0Oomoo`0YOol00g`0Oomoo`07Ool00g`0Oomoo`0ZOol00g`0Oomoo`06Ool00g`0
Oomoo`0ZOol00g`0Oomoo`07Ool00g`0Oomoo`0ZOol00g`0Oomoo`06Ool00g`0Oomoo`0`Ool000Mo
o`8000Ioo`03001oogoo009oo`03O01oogoo02Uoo`03O01oogoo00Moo`03O01oogoo02Yoo`03O01o
ogoo00Ioo`03O01oogoo02Yoo`03O01oogoo00Moo`03O01oogoo02Uoo`03O01oogoo00Moo`03O01o
ogoo031oo`001Woo00@007ooOol000Eoo`03001oogoo009oo`03O01oogoo02Uoo`03O01oogoo00Mo
o`03O01oogoo02Yoo`03O01oogoo00Ioo`03O01oogoo02Yoo`03O01oogoo00Moo`03O01oogoo02Uo
o`03O01oogoo00Moo`03O01oogoo031oo`002Goo00<007ooOol00goo0P000goo00=l07ooOol0:Goo
00=l07ooOol01goo00=l07ooOol0:Woo00=l07ooOol01Woo00=l07ooOol0:Woo00=l07ooOol01goo
00=l07ooOol0:Goo00=l07ooOol01goo00=l07ooOol0<7oo0007Ool20006Ool00`00Oomoo`02Ool0
0g`0Oomoo`0YOol00g`0Oomoo`07Ool00g`0Oomoo`0YOol00g`0Oomoo`08Ool00g`0Oomoo`0YOol0
0g`0Oomoo`07Ool00g`0Oomoo`0YOol00g`0Oomoo`07Ool00g`0Oomoo`0`Ool000Moo`03001oogoo
00Eoo`03001oogoo009oo`03O01oogoo02Uoo`03O01oogoo00Moo`03O01oogoo02Uoo`03O01oogoo
00Qoo`03O01oogoo02Uoo`03O01oogoo00Moo`03O01oogoo02Uoo`03O01oogoo00Moo`03O01oogoo
031oo`001goo0`001Goo00<007ooOol00Woo00=l07ooOol0:Goo00=l07ooOol01goo00=l07ooOol0
:Goo00=l07ooOol027oo00=l07ooOol0:Goo00=l07ooOol01goo00=l07ooOol0:Goo00=l07ooOol0
27oo00=l07ooOol0;goo000?Ool00`00Oomoo`02Ool00g`0Oomoo`0XOol00g`0Oomoo`09Ool00g`0
Oomoo`0XOol00g`0Oomoo`08Ool00g`0Oomoo`0YOol00g`0Oomoo`07Ool00g`0Oomoo`0YOol00g`0
Oomoo`08Ool00g`0Oomoo`0_Ool000moo`03001oogoo009oo`03O01oogoo02Qoo`03O01oogoo00Uo
o`03O01oogoo02Qoo`03O01oogoo00Qoo`03O01oogoo02Uoo`03O01oogoo00Qoo`03O01oogoo02Qo
o`03O01oogoo00Qoo`03O01oogoo02moo`003goo0P0017oo00=l07ooOol09goo00=l07ooOol02Goo
00=l07ooOol0:7oo00=l07ooOol027oo00=l07ooOol0:7oo00=l07ooOol02Goo00=l07ooOol0:7oo
00=l07ooOol027oo00=l07ooOol0;goo000?Ool00`00Oomoo`03Ool00g`0Oomoo`0WOol00g`0Oomo
o`09Ool00g`0Oomoo`0XOol00g`0Oomoo`08Ool00g`0Oomoo`0XOol00g`0Oomoo`09Ool00g`0Oomo
o`0WOol00g`0Oomoo`09Ool00g`0Oomoo`0_Ool000moo`03001oogoo00=oo`03O01oogoo02Moo`03
O01oogoo00Uoo`03O01oogoo02Qoo`03O01oogoo00Qoo`03O01oogoo02Qoo`03O01oogoo00Uoo`03
O01oogoo02Moo`03O01oogoo00Uoo`03O01oogoo02moo`003goo00<007ooOol00goo00=l07ooOol0
9goo00=l07ooOol02Goo00=l07ooOol0:7oo00=l07ooOol027oo00=l07ooOol0:7oo00=l07ooOol0
2Goo00=l07ooOol09goo00=l07ooOol02Goo00=l07ooOol0;goo000?Ool00`00Oomoo`03Ool00g`0
Oomoo`0WOol00g`0Oomoo`09Ool00g`0Oomoo`0WOol00g`0Oomoo`0:Ool00g`0Oomoo`0WOol00g`0
Oomoo`09Ool00g`0Oomoo`0WOol00g`0Oomoo`09Ool00g`0Oomoo`0_Ool000moo`8000Aoo`03O01o
ogoo02Moo`03O01oogoo00Uoo`03O01oogoo02Moo`03O01oogoo00Yoo`03O01oogoo02Moo`03O01o
ogoo00Uoo`03O01oogoo02Moo`03O01oogoo00Uoo`03O01oogoo02moo`003goo00<007ooOol00goo
00=l07ooOol09Woo00=l07ooOol02Woo00=l07ooOol09goo00=l07ooOol02Woo00=l07ooOol09goo
00=l07ooOol02Goo00=l07ooOol09goo00=l07ooOol02Woo00=l07ooOol0;Woo000?Ool00`00Oomo
o`04Ool00g`0Oomoo`0UOol00g`0Oomoo`0;Ool00g`0Oomoo`0VOol00g`0Oomoo`0:Ool00g`0Oomo
o`0VOol00g`0Oomoo`0;Ool00g`0Oomoo`0VOol00g`0Oomoo`0:Ool00g`0Oomoo`0^Ool000moo`03
001oogoo00Aoo`03O01oogoo02Eoo`03O01oogoo00]oo`03O01oogoo02Ioo`03O01oogoo00Yoo`03
O01oogoo02Ioo`03O01oogoo00]oo`03O01oogoo02Eoo`03O01oogoo00]oo`03O01oogoo02ioo`00
3goo00<007ooOol017oo00=l07ooOol09Goo00=l07ooOol02goo00=l07ooOol09Woo00=l07ooOol0
2Woo00=l07ooOol09Woo00=l07ooOol02goo00=l07ooOol09Goo00=l07ooOol02goo00=l07ooOol0
;Woo000?Ool00`00Oomoo`04Ool00g`0Oomoo`0UOol00g`0Oomoo`0;Ool00g`0Oomoo`0VOol00g`0
Oomoo`0:Ool00g`0Oomoo`0VOol00g`0Oomoo`0;Ool00g`0Oomoo`0UOol00g`0Oomoo`0;Ool00g`0
Oomoo`0^Ool000moo`8000Eoo`03O01oogoo02Eoo`03O01oogoo00]oo`03O01oogoo02Ioo`03O01o
ogoo00Yoo`03O01oogoo02Ioo`03O01oogoo00]oo`03O01oogoo02Eoo`03O01oogoo00]oo`03O01o
ogoo02ioo`003goo00<007ooOol017oo00=l07ooOol09Goo00=l07ooOol02goo00=l07ooOol09Goo
00=l07ooOol037oo00=l07ooOol09Goo00=l07ooOol02goo00=l07ooOol09Goo00=l07ooOol02goo
00=l07ooOol0;Woo000?Ool00`00Oomoo`04Ool00g`0Oomoo`0UOol00g`0Oomoo`0;Ool00g`0Oomo
o`0UOol00g`0Oomoo`0<Ool00g`0Oomoo`0UOol00g`0Oomoo`0;Ool00g`0Oomoo`0UOol00g`0Oomo
o`0<Ool00g`0Oomoo`0]Ool000moo`03001oogoo00Eoo`03O01oogoo02=oo`03O01oogoo00aoo`03
O01oogoo02Eoo`03O01oogoo00aoo`03O01oogoo02Eoo`03O01oogoo00]oo`03O01oogoo02Eoo`03
O01oogoo00aoo`03O01oogoo02eoo`003goo00<007ooOol01Goo00=l07ooOol08goo00=l07ooOol0
3Goo00=l07ooOol097oo00=l07ooOol037oo00=l07ooOol097oo00=l07ooOol03Goo00=l07ooOol0
97oo00=l07ooOol037oo00=l07ooOol0;Goo000?Ool20006Ool00g`0Oomoo`0SOol00g`0Oomoo`0=
Ool00g`0Oomoo`0TOol00g`0Oomoo`0<Ool00g`0Oomoo`0TOol00g`0Oomoo`0=Ool00g`0Oomoo`0S
Ool00g`0Oomoo`0=Ool00g`0Oomoo`0]Ool000moo`03001oogoo00Eoo`03O01oogoo02=oo`03O01o
ogoo00eoo`03O01oogoo02Aoo`03O01oogoo00aoo`03O01oogoo02Aoo`03O01oogoo00eoo`03O01o
ogoo02=oo`03O01oogoo00eoo`03O01oogoo02eoo`003goo00<007ooOol01Goo00=l07ooOol08goo
00=l07ooOol03Goo00=l07ooOol097oo00=l07ooOol037oo00=l07ooOol097oo00=l07ooOol03Goo
00=l07ooOol08goo00=l07ooOol03Goo00=l07ooOol0;Goo000?Ool00`00Oomoo`05Ool00g`0Oomo
o`0ROol00g`0Oomoo`0>Ool00g`0Oomoo`0SOol00g`0Oomoo`0=Ool00g`0Oomoo`0TOol00g`0Oomo
o`0=Ool00g`0Oomoo`0SOol00g`0Oomoo`0=Ool00g`0Oomoo`0]Ool000Ioo`<000Ioo`03001oogoo
00Eoo`03O01oogoo029oo`03O01oogoo00ioo`03O01oogoo02=oo`03O01oogoo00ioo`03O01oogoo
02=oo`03O01oogoo00eoo`03O01oogoo02=oo`03O01oogoo00ioo`03O01oogoo02aoo`001Woo00@0
07ooOol000Eoo`03001oogoo00Ioo`03O01oogoo025oo`03O01oogoo00ioo`03O01oogoo02=oo`03
O01oogoo00ioo`03O01oogoo02=oo`03O01oogoo00ioo`03O01oogoo029oo`03O01oogoo00ioo`03
O01oogoo02aoo`001Woo00@007ooOol000Eoo`8000Moo`03O01oogoo025oo`03O01oogoo00moo`03
O01oogoo029oo`03O01oogoo00ioo`03O01oogoo029oo`03O01oogoo00moo`03O01oogoo025oo`03
O01oogoo00moo`03O01oogoo02aoo`001Woo0`001Woo00<007ooOol01Woo00=l07ooOol08Goo00=l
07ooOol03goo00=l07ooOol08Woo00=l07ooOol03Woo00=l07ooOol08Woo00=l07ooOol03goo00=l
07ooOol08Goo00=l07ooOol03goo00=l07ooOol0;7oo0007Ool00`00Oomoo`05Ool00`00Oomoo`06
Ool00g`0Oomoo`0QOol00g`0Oomoo`0?Ool00g`0Oomoo`0ROol00g`0Oomoo`0>Ool00g`0Oomoo`0R
Ool00g`0Oomoo`0?Ool00g`0Oomoo`0QOol00g`0Oomoo`0?Ool00g`0Oomoo`0/Ool000Moo`<000Eo
o`03001oogoo00Ioo`03O01oogoo021oo`03O01oogoo011oo`03O01oogoo029oo`03O01oogoo00mo
o`03O01oogoo025oo`03O01oogoo00moo`03O01oogoo025oo`03O01oogoo00moo`03O01oogoo02ao
o`003goo00<007ooOol01Woo00=l07ooOol087oo00=l07ooOol047oo00=l07ooOol08Goo00=l07oo
Ool047oo00=l07ooOol08Goo00=l07ooOol03goo00=l07ooOol08Goo00=l07ooOol047oo00=l07oo
Ool0:goo000?Ool00`00Oomoo`07Ool00g`0Oomoo`0OOol00g`0Oomoo`0@Ool00g`0Oomoo`0QOol0
0g`0Oomoo`0@Ool00g`0Oomoo`0QOol00g`0Oomoo`0@Ool00g`0Oomoo`0POol00g`0Oomoo`0@Ool0
0g`0Oomoo`0[Ool000moo`8000Qoo`03O01oogoo01moo`03O01oogoo015oo`03O01oogoo021oo`03
O01oogoo011oo`03O01oogoo021oo`03O01oogoo015oo`03O01oogoo01moo`9l019oo`03O01oogoo
02]oo`003goo00<007ooOol01goo00=l07ooOol07goo00=l07ooOol04Goo00=l07ooOol087oo00=l
07ooOol047oo00=l07ooOol087oo00=l07ooOol04Goo00=l07ooOol07goo00=l07ooOol04Goo00=l
07ooOol0:goo000?Ool00`00Oomoo`07Ool00g`0Oomoo`0OOol00g`0Oomoo`0AOol00g`0Oomoo`0P
Ool00g`0Oomoo`0@Ool00g`0Oomoo`0POol00g`0Oomoo`0AOol00g`0Oomoo`0OOol00g`0Oomoo`0A
Ool00g`0Oomoo`0[Ool000moo`03001oogoo00Qoo`03O01oogoo01eoo`03O01oogoo019oo`03O01o
ogoo01moo`03O01oogoo019oo`03O01oogoo01moo`03O01oogoo015oo`03O01oogoo01moo`03O01o
ogoo015oo`03O01oogoo02]oo`003goo00<007ooOol027oo00=l07ooOol07Goo00=l07ooOol04Woo
00=l07ooOol07goo00=l07ooOol04Woo00=l07ooOol07goo00=l07ooOol04Goo00=l07ooOol07goo
00=l07ooOol04Woo00=l07ooOol0:Woo000?Ool20009Ool00g`0Oomoo`0MOol00g`0Oomoo`0COol0
0g`0Oomoo`0NOol00g`0Oomoo`0BOol00g`0Oomoo`0NOol00g`0Oomoo`0COol00g`0Oomoo`0NOol0
0g`0Oomoo`0BOol00g`0Oomoo`0ZOol000moo`03001oogoo00Qoo`03O01oogoo01eoo`03O01oogoo
01=oo`03O01oogoo01ioo`03O01oogoo019oo`03O01oogoo01ioo`03O01oogoo01=oo`03O01oogoo
01eoo`03O01oogoo01=oo`03O01oogoo02Yoo`003goo00<007ooOol027oo00=l07ooOol077oo0W`0
5Goo00=l07ooOol07Woo00=l07ooOol04Woo00=l07ooOol07Woo00=l07ooOol04goo00=l07ooOol0
7Goo00=l07ooOol04goo00=l07ooOol0:Woo000?Ool00`00Oomoo`09Ool00g`0Oomoo`0KOol00g`0
Oomoo`0DOol00g`0Oomoo`0MOol00g`0Oomoo`0DOol00g`0Oomoo`0MOol00g`0Oomoo`0COol00g`0
Oomoo`0MOol00g`0Oomoo`0COol00g`0Oomoo`0ZOol000moo`03001oogoo00Uoo`03O01oogoo01]o
o`03O01oogoo01Aoo`03O01oogoo01eoo`03O01oogoo01Aoo`03O01oogoo01eoo`03O01oogoo01=o
o`03O01oogoo01eoo`03O01oogoo01Aoo`03O01oogoo02Uoo`003goo00<007ooOol02Goo00=l07oo
Ool06goo00=l07ooOol05Goo00=l07ooOol077oo00=l07ooOol057oo00=l07ooOol077oo00=l07oo
Ool05Goo00=l07ooOol06goo00=l07ooOol05Goo00=l07ooOol0:Goo000?Ool2000:Ool00g`0Oomo
o`0KOol00g`0Oomoo`0EOol00g`0Oomoo`0LOol00g`0Oomoo`0DOol00g`0Oomoo`0LOol00g`0Oomo
o`0EOol00g`0Oomoo`0KOol00g`0Oomoo`0EOol00g`0Oomoo`0YOol000moo`03001oogoo00Uoo`9l
01]oo`03O01oogoo01Ioo`03O01oogoo01aoo`03O01oogoo01Aoo`03O01oogoo01aoo`03O01oogoo
01Eoo`03O01oogoo01]oo`03O01oogoo01Eoo`03O01oogoo02Uoo`003goo00<007ooOol02Woo00=l
07ooOol06Goo00=l07ooOol05Woo00=l07ooOol06goo00=l07ooOol05Woo00=l07ooOol06goo00=l
07ooOol05Goo0W`077oo00=l07ooOol05Woo00=l07ooOol0:7oo000?Ool00`00Oomoo`0:Ool00g`0
Oomoo`0IOol00g`0Oomoo`0FOol2O00LOol00g`0Oomoo`0FOol00g`0Oomoo`0KOol00g`0Oomoo`0F
Ool00g`0Oomoo`0IOol2O00HOol00g`0Oomoo`0JOol00g`0Oomoo`0;Ool000moo`03001oogoo00Yo
o`03O01oogoo01Qoo`9l01Uoo`03O01oogoo01Yoo`03O01oogoo01Ioo`03O01oogoo01Yoo`03O01o
ogoo01Moo`03O01oogoo01Uoo`03O01oogoo01Moo`03O01oogoo01Yoo`03O01oogoo00]oo`003goo
0P002goo0W`06Goo00=l07ooOol067oo00=l07ooOol06Woo00=l07ooOol05Woo00=l07ooOol06Woo
00=l07ooOol05goo00=l07ooOol06Goo00=l07ooOol05goo00=l07ooOol06Woo00=l07ooOol02goo
000?Ool00`00Oomoo`0;Ool00g`0Oomoo`0GOol00g`0Oomoo`0HOol00g`0Oomoo`0IOol00g`0Oomo
o`0GOol2O00KOol00g`0Oomoo`0GOol00g`0Oomoo`0IOol00g`0Oomoo`0GOol2O00JOol2O00=Ool0
00moo`03001oogoo00]oo`03O01oogoo01Moo`03O01oogoo01Qoo`03O01oogoo01Uoo`03O01oogoo
01Qoo`03O01oogoo01Uoo`03O01oogoo01Qoo`03O01oogoo01Moo`9l01Yoo`03O01oogoo01Qoo`03
O01oogoo00aoo`003goo00<007ooOol02goo00=l07ooOol05Woo00=l07ooOol06Woo00=l07ooOol0
67oo00=l07ooOol067oo00=l07ooOol067oo00=l07ooOol06Goo00=l07ooOol05goo00=l07ooOol0
6Goo00=l07ooOol067oo00=l07ooOol037oo0008Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00g`0
Oomoo`0EOol00g`0Oomoo`0JOol00g`0Oomoo`0GOol2O00JOol00g`0Oomoo`0HOol00g`0Oomoo`0I
Ool00g`0Oomoo`0GOol00g`0Oomoo`0IOol00g`0Oomoo`0HOol00g`0Oomoo`0<Ool000Qoo`03001o
ogoo00Aoo`03001oogoo00aoo`03O01oogoo01Eoo`03O01oogoo01Yoo`03O01oogoo01Moo`03O01o
ogoo01Yoo`03O01oogoo01Moo`03O01oogoo01Uoo`9l01Qoo`03O01oogoo01Uoo`9l01Qoo`9l00io
o`0027oo00<007ooOol017oo0P003Goo00=l07ooOol057oo0W`07Goo00=l07ooOol05Woo00=l07oo
Ool06Woo00=l07ooOol05goo00=l07ooOol06Woo00=l07ooOol05Goo0W`077oo00=l07ooOol05Woo
00=l07ooOol03Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00g`0Oomoo`0COol00g`0Oomo
o`0LOol00g`0Oomoo`0FOol00g`0Oomoo`0JOol00g`0Oomoo`0FOol00g`0Oomoo`0KOol00g`0Oomo
o`0EOol00g`0Oomoo`0KOol00g`0Oomoo`0FOol00g`0Oomoo`0=Ool000Ioo`04001oogoo0005Ool0
0`00Oomoo`0=Ool00g`0Oomoo`0COol00g`0Oomoo`0LOol00g`0Oomoo`0EOol00g`0Oomoo`0KOol2
O00GOol00g`0Oomoo`0KOol00g`0Oomoo`0EOol00g`0Oomoo`0KOol00g`0Oomoo`0FOol00g`0Oomo
o`0=Ool000Ioo`@000Eoo`03001oogoo00eoo`03O01oogoo019oo`9l01ioo`9l01Ioo`03O01oogoo
01aoo`03O01oogoo01Aoo`9l01ioo`03O01oogoo01=oo`03O01oogoo01eoo`03O01oogoo01Aoo`03
O01oogoo00ioo`003goo00<007ooOol03Woo00=l07ooOol04Goo00=l07ooOol07Woo00=l07ooOol0
57oo00=l07ooOol077oo00=l07ooOol057oo00=l07ooOol07Goo00=l07ooOol04goo00=l07ooOol0
7Goo00=l07ooOol057oo00=l07ooOol03Woo000?Ool2000?Ool00g`0Oomoo`0AOol00g`0Oomoo`0N
Ool00g`0Oomoo`0COol2O00NOol00g`0Oomoo`0DOol00g`0Oomoo`0MOol00g`0Oomoo`0COol00g`0
Oomoo`0MOol00g`0Oomoo`0DOol00g`0Oomoo`0>Ool000moo`03001oogoo00ioo`9l015oo`03O01o
ogoo01moo`9l01Aoo`03O01oogoo01ioo`03O01oogoo01=oo`03O01oogoo01ioo`03O01oogoo015o
o`03O01oogoo01moo`03O01oogoo019oo`03O01oogoo00moo`003goo00<007ooOol03goo00=l07oo
Ool03goo00=l07ooOol087oo00=l07ooOol04Woo00=l07ooOol07Woo00=l07ooOol04Woo00=l07oo
Ool07goo00=l07ooOol04Goo00=l07ooOol07goo00=l07ooOol04Woo00=l07ooOol03goo000?Ool0
0`00Oomoo`0?Ool00g`0Oomoo`0>Ool2O00ROol00g`0Oomoo`0AOol2O00POol00g`0Oomoo`0BOol0
0g`0Oomoo`0OOol2O00BOol00g`0Oomoo`0OOol2O00BOol2O00AOol000moo`03001oogoo011oo`03
O01oogoo00eoo`03O01oogoo025oo`9l019oo`03O01oogoo021oo`03O01oogoo011oo`9l029oo`03
O01oogoo00moo`03O01oogoo025oo`03O01oogoo011oo`03O01oogoo011oo`003goo00<007ooOol0
47oo0W`03Goo0W`097oo00=l07ooOol047oo00=l07ooOol087oo00=l07ooOol047oo00=l07ooOol0
8Goo00=l07ooOol03goo00=l07ooOol08Goo00=l07ooOol047oo00=l07ooOol047oo000?Ool2000B
Ool00g`0Oomoo`0;Ool00g`0Oomoo`0SOol00g`0Oomoo`0?Ool00g`0Oomoo`0ROol00g`0Oomoo`0?
Ool00g`0Oomoo`0ROol00g`0Oomoo`0=Ool2O00SOol2O00@Ool00g`0Oomoo`0AOol000moo`03001o
ogoo015oo`9l00]oo`9l02Ioo`03O01oogoo00ioo`03O01oogoo029oo`03O01oogoo00ioo`9l02Ao
o`03O01oogoo00eoo`03O01oogoo02=oo`03O01oogoo00ioo`03O01oogoo015oo`003goo00<007oo
Ool04Woo00=l07ooOol027oo0W`09goo00=l07ooOol03Goo00=l07ooOol08goo0W`03goo00=l07oo
Ool097oo00=l07ooOol02goo0W`09Goo0W`03Woo0W`04goo000?Ool00`00Oomoo`0COol00g`0Oomo
o`07Ool00g`0Oomoo`0WOol00g`0Oomoo`0<Ool00g`0Oomoo`0TOol00g`0Oomoo`0<Ool00g`0Oomo
o`0UOol00g`0Oomoo`0;Ool00g`0Oomoo`0UOol00g`0Oomoo`0<Ool00g`0Oomoo`0BOol000moo`03
001oogoo01=oo`9l00Moo`03O01oogoo02Qoo`03O01oogoo00]oo`03O01oogoo02Eoo`9l00eoo`03
O01oogoo02Ioo`03O01oogoo00Uoo`03O01oogoo02Ioo`9l00aoo`9l01Aoo`003goo0P005Goo0g`0
0goo0W`0;7oo00=l07ooOol02Woo00=l07ooOol09Woo00=l07ooOol02Woo00=l07ooOol09goo0W`0
2Goo0W`0:Goo00=l07ooOol02Goo0W`05Goo000?Ool00`00Oomoo`0FOol5O00]Ool2O00:Ool00g`0
Oomoo`0WOol2O00:Ool2O00ZOol2O007Ool2O00[Ool00g`0Oomoo`08Ool00g`0Oomoo`0DOol000mo
o`03001oogoo04Uoo`03O01oogoo00Moo`9l02Yoo`9l00Uoo`03O01oogoo02Yoo`9l00Eoo`9l02ao
o`9l00Qoo`9l01Ioo`003goo00<007ooOol0BWoo0W`01Woo0W`0;7oo0W`01goo0W`0;Goo0g`00Woo
0W`0;Woo0W`01Woo0W`05goo000?Ool00`00Oomoo`1;Ool2O004Ool2O00^Ool2O005Ool2O00`Ool3
O00aOol3O003Ool2O00HOol000moo`03001oogoo04aoo`Il031oo`Il06Qoo`Al01Yoo`003goo0P00
ogoo47oo000?Ool00`00Oomoo`3oOol?Ool000moo`03001oogoo0?moo`moo`003goo00<007ooOol0
ogoo3goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-87.2343, 1.55303, 5.7757, \
0.0360213}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Two Spheres in a Simple Shear Flow of a Newtonian fluid. ", \
"Subsubtitle",
  Background->RGBColor[1, 1, 0.658824]],

Cell["<<Graphics`Graphics3D`", "Input"],

Cell["X[1]=1.05;Y[1]=0;Z[1]=0;X[2]=-1.05;Y[2]=0;Z[2]=0;", "Input"],

Cell["dt=0.1;", "Input"],

Cell["NSPH=2;NDIM=6 NSPH;Ng=3 NSPH;NX5=5 NSPH; ", "Input"],

Cell[CellGroupData[{

Cell["s=OpenRead[\"C:\\\\TwoSpheresShearFlow\\\\data1.m\"]", "Input"],

Cell[BoxData[
    \(InputStream["C:\\TwoSpheresShearFlow\\data1.m", 8]\)], "Output"]
}, Open  ]],

Cell["Off[General::\"spell1\"];", "Input"],

Cell["\<\
For[i=1,i<48,{RSS[i]=Read[s,Real];
X11AS[i]=Read[s,Real];
X12AS[i]=Read[s,Real];
Y11AS[i]=Read[s,Real];
Y12AS[i]=Read[s,Real];
Y11BS[i]=Read[s,Real];
Y12BS[i]=Read[s,Real];
X11CS[i]=Read[s,Real];
X12CS[i]=Read[s,Real];
Y11CS[i]=Read[s,Real];
Y12CS[i]=Read[s,Real];i++}]\
\>", "Input"],

Cell[CellGroupData[{

Cell["s=OpenRead[\"C:\\\\TwoSpheresShearFlow\\\\data2.m\"]", "Input"],

Cell[BoxData[
    \(InputStream["C:\\TwoSpheresShearFlow\\data2.m", 9]\)], "Output"]
}, Open  ]],

Cell["\<\
For[i=1,i<48,{RSS[i]=Read[s,Real];
Y11MS[i]=Read[s,Real];
Y12MS[i]=Read[s,Real];
X11MS[i]=Read[s,Real];
Z11MS[i]=Read[s,Real];
X12GS[i]=Read[s,Real];
Y11HS[i]=Read[s,Real];
Y12HS[i]=Read[s,Real];
Y12GS[i]=Read[s,Real];
X11GS[i]=Read[s,Real];
X12MS[i]=Read[s,Real];
Z12MS[i]=Read[s,Real];
Y11GS[i]=Read[s,Real];i++}]\
\>", "Input"],

Cell["\<\
X[1,0]=X[1];Y[1,0]=Y[1];Z[1,0]=Z[1];
X[2,0]=X[2];Y[2,0]=Y[2];Z[2,0]=Z[2];\
\>", "Input"],

Cell["WT=0.;", "Input"],

Cell["G=-10;", "Input"],

Cell[CellGroupData[{

Cell["\<\
For[t=1,t<151,{<<\"C:\\\\TwoSpheresShearFlow\\\\VEL5.m\";
X[1,t]=X[1,t-1]+USS[1]*dt;Y[1,t]=Y[1,t-1]+USS[2]*dt;Z[1,t]=Z[1,t-1]+USS[3]*dt;\
X[2,t]=X[2,t-1]+USS[4]*dt;Y[2,t]=Y[2,t-1]+USS[5]*dt;Z[2,t]=Z[2,t-1]+USS[6]*dt;\
Print[t];t++}]\
\>", "Input"],

Cell[BoxData[
    \(1\)], "Print"],

Cell[BoxData[
    \(2\)], "Print"],

Cell[BoxData[
    \(3\)], "Print"],

Cell[BoxData[
    \(4\)], "Print"],

Cell[BoxData[
    \(5\)], "Print"],

Cell[BoxData[
    \(6\)], "Print"],

Cell[BoxData[
    \(7\)], "Print"],

Cell[BoxData[
    \(8\)], "Print"],

Cell[BoxData[
    \(9\)], "Print"],

Cell[BoxData[
    \(10\)], "Print"],

Cell[BoxData[
    \(11\)], "Print"],

Cell[BoxData[
    \(12\)], "Print"],

Cell[BoxData[
    \(13\)], "Print"],

Cell[BoxData[
    \(14\)], "Print"],

Cell[BoxData[
    \(15\)], "Print"],

Cell[BoxData[
    \(16\)], "Print"],

Cell[BoxData[
    \(17\)], "Print"],

Cell[BoxData[
    \(18\)], "Print"],

Cell[BoxData[
    \(19\)], "Print"],

Cell[BoxData[
    \(20\)], "Print"],

Cell[BoxData[
    \(21\)], "Print"],

Cell[BoxData[
    \(22\)], "Print"],

Cell[BoxData[
    \(23\)], "Print"],

Cell[BoxData[
    \(24\)], "Print"],

Cell[BoxData[
    \(25\)], "Print"],

Cell[BoxData[
    \(26\)], "Print"],

Cell[BoxData[
    \(27\)], "Print"],

Cell[BoxData[
    \(28\)], "Print"],

Cell[BoxData[
    \(29\)], "Print"],

Cell[BoxData[
    \(30\)], "Print"],

Cell[BoxData[
    \(31\)], "Print"],

Cell[BoxData[
    \(32\)], "Print"],

Cell[BoxData[
    \(33\)], "Print"],

Cell[BoxData[
    \(34\)], "Print"],

Cell[BoxData[
    \(35\)], "Print"],

Cell[BoxData[
    \(36\)], "Print"],

Cell[BoxData[
    \(37\)], "Print"],

Cell[BoxData[
    \(38\)], "Print"],

Cell[BoxData[
    \(39\)], "Print"],

Cell[BoxData[
    \(40\)], "Print"],

Cell[BoxData[
    \(41\)], "Print"],

Cell[BoxData[
    \(42\)], "Print"],

Cell[BoxData[
    \(43\)], "Print"],

Cell[BoxData[
    \(44\)], "Print"],

Cell[BoxData[
    \(45\)], "Print"],

Cell[BoxData[
    \(46\)], "Print"],

Cell[BoxData[
    \(47\)], "Print"],

Cell[BoxData[
    \(48\)], "Print"],

Cell[BoxData[
    \(49\)], "Print"],

Cell[BoxData[
    \(50\)], "Print"],

Cell[BoxData[
    \(51\)], "Print"],

Cell[BoxData[
    \(52\)], "Print"],

Cell[BoxData[
    \(53\)], "Print"],

Cell[BoxData[
    \(54\)], "Print"],

Cell[BoxData[
    \(55\)], "Print"],

Cell[BoxData[
    \(56\)], "Print"],

Cell[BoxData[
    \(57\)], "Print"],

Cell[BoxData[
    \(58\)], "Print"],

Cell[BoxData[
    \(59\)], "Print"],

Cell[BoxData[
    \(60\)], "Print"],

Cell[BoxData[
    \(61\)], "Print"],

Cell[BoxData[
    \(62\)], "Print"],

Cell[BoxData[
    \(63\)], "Print"],

Cell[BoxData[
    \(64\)], "Print"],

Cell[BoxData[
    \(65\)], "Print"],

Cell[BoxData[
    \(66\)], "Print"],

Cell[BoxData[
    \(67\)], "Print"],

Cell[BoxData[
    \(68\)], "Print"],

Cell[BoxData[
    \(69\)], "Print"],

Cell[BoxData[
    \(70\)], "Print"],

Cell[BoxData[
    \(71\)], "Print"],

Cell[BoxData[
    \(72\)], "Print"],

Cell[BoxData[
    \(73\)], "Print"],

Cell[BoxData[
    \(74\)], "Print"],

Cell[BoxData[
    \(75\)], "Print"],

Cell[BoxData[
    \(76\)], "Print"],

Cell[BoxData[
    \(77\)], "Print"],

Cell[BoxData[
    \(78\)], "Print"],

Cell[BoxData[
    \(79\)], "Print"],

Cell[BoxData[
    \(80\)], "Print"],

Cell[BoxData[
    \(81\)], "Print"],

Cell[BoxData[
    \(82\)], "Print"],

Cell[BoxData[
    \(83\)], "Print"],

Cell[BoxData[
    \(84\)], "Print"],

Cell[BoxData[
    \(85\)], "Print"],

Cell[BoxData[
    \(86\)], "Print"],

Cell[BoxData[
    \(87\)], "Print"],

Cell[BoxData[
    \(88\)], "Print"],

Cell[BoxData[
    \(89\)], "Print"],

Cell[BoxData[
    \(90\)], "Print"],

Cell[BoxData[
    \(91\)], "Print"],

Cell[BoxData[
    \(92\)], "Print"],

Cell[BoxData[
    \(93\)], "Print"],

Cell[BoxData[
    \(94\)], "Print"],

Cell[BoxData[
    \(95\)], "Print"],

Cell[BoxData[
    \(96\)], "Print"],

Cell[BoxData[
    \(97\)], "Print"],

Cell[BoxData[
    \(98\)], "Print"],

Cell[BoxData[
    \(99\)], "Print"],

Cell[BoxData[
    \(100\)], "Print"],

Cell[BoxData[
    \(101\)], "Print"],

Cell[BoxData[
    \(102\)], "Print"],

Cell[BoxData[
    \(103\)], "Print"],

Cell[BoxData[
    \(104\)], "Print"],

Cell[BoxData[
    \(105\)], "Print"],

Cell[BoxData[
    \(106\)], "Print"],

Cell[BoxData[
    \(107\)], "Print"],

Cell[BoxData[
    \(108\)], "Print"],

Cell[BoxData[
    \(109\)], "Print"],

Cell[BoxData[
    \(110\)], "Print"],

Cell[BoxData[
    \(111\)], "Print"],

Cell[BoxData[
    \(112\)], "Print"],

Cell[BoxData[
    \(113\)], "Print"],

Cell[BoxData[
    \(114\)], "Print"],

Cell[BoxData[
    \(115\)], "Print"],

Cell[BoxData[
    \(116\)], "Print"],

Cell[BoxData[
    \(117\)], "Print"],

Cell[BoxData[
    \(118\)], "Print"],

Cell[BoxData[
    \(119\)], "Print"],

Cell[BoxData[
    \(120\)], "Print"],

Cell[BoxData[
    \(121\)], "Print"],

Cell[BoxData[
    \(122\)], "Print"],

Cell[BoxData[
    \(123\)], "Print"],

Cell[BoxData[
    \(124\)], "Print"],

Cell[BoxData[
    \(125\)], "Print"],

Cell[BoxData[
    \(126\)], "Print"],

Cell[BoxData[
    \(127\)], "Print"],

Cell[BoxData[
    \(128\)], "Print"],

Cell[BoxData[
    \(129\)], "Print"],

Cell[BoxData[
    \(130\)], "Print"],

Cell[BoxData[
    \(131\)], "Print"],

Cell[BoxData[
    \(132\)], "Print"],

Cell[BoxData[
    \(133\)], "Print"],

Cell[BoxData[
    \(134\)], "Print"],

Cell[BoxData[
    \(135\)], "Print"],

Cell[BoxData[
    \(136\)], "Print"],

Cell[BoxData[
    \(137\)], "Print"],

Cell[BoxData[
    \(138\)], "Print"],

Cell[BoxData[
    \(139\)], "Print"],

Cell[BoxData[
    \(140\)], "Print"],

Cell[BoxData[
    \(141\)], "Print"],

Cell[BoxData[
    \(142\)], "Print"],

Cell[BoxData[
    \(143\)], "Print"],

Cell[BoxData[
    \(144\)], "Print"],

Cell[BoxData[
    \(145\)], "Print"],

Cell[BoxData[
    \(146\)], "Print"],

Cell[BoxData[
    \(147\)], "Print"],

Cell[BoxData[
    \(148\)], "Print"],

Cell[BoxData[
    \(149\)], "Print"],

Cell[BoxData[
    \(150\)], "Print"]
}, Open  ]],

Cell["\<\
plt[i_]:=Show[Graphics[{{RGBColor[1,0,0],PointSize[0.05],Point[{X[1,i],Y[1,i]}\
]},{RGBColor[0,0,1],PointSize[0.05],Point[{X[2,i],Y[2,i]}]}}],AspectRatio->1,\
PlotRange->{{-5,5},{-10,10}},Frame->True]\
\>", "Input"],

Cell["<<Graphics`Animation`", "Input"],

Cell[CellGroupData[{

Cell["Animate[plt[n],{n,1,150,10}]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.5 0.05 [
[.1 -0.0125 -6 -9 ]
[.1 -0.0125 6 0 ]
[.3 -0.0125 -6 -9 ]
[.3 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7 -0.0125 -3 -9 ]
[.7 -0.0125 3 0 ]
[.9 -0.0125 -3 -9 ]
[.9 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -24 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-4)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-2)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(2)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(4)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-7.5)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-5)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-2.5)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(2.5)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(5)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(7.5)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(10)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
.1 .99375 m
.1 1 L
s
.3 .99375 m
.3 1 L
s
.5 .99375 m
.5 1 L
s
.7 .99375 m
.7 1 L
s
.9 .99375 m
.9 1 L
s
.125 Mabswid
.15 .99625 m
.15 1 L
s
.2 .99625 m
.2 1 L
s
.25 .99625 m
.25 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.45 .99625 m
.45 1 L
s
.55 .99625 m
.55 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.75 .99625 m
.75 1 L
s
.8 .99625 m
.8 1 L
s
.85 .99625 m
.85 1 L
s
.05 .99625 m
.05 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.605 .50393 Mdot
0 0 1 r
.395 .49607 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000hOol3000_Ool4000^Ool2
000`Ool4000bOol3000IOol003Uoo`03001oogoo02ioo`03001oogoo02ioo`04001oogoo000_Ool0
0`00Oomoo`0dOol00`00Oomoo`0HOol003Ioo`D0031oo`03001oogoo02eoo`04001oogoo000`Ool0
0`00Oomoo`0`Ool5000IOol0031oo`@0009oo`04001oogoo000ZOol40004Ool00`00Oomoo`0/Ool0
1000Oomoo`00<Goo00<007ooOol0;goo00@007ooOol001Yoo`00=goo00<007oo0000<7oo00@007oo
Ool002eoo`04001oogoo000_Ool01000Oomoo`00<Goo00<007oo00006Woo000hOol2000aOol2000_
Ool2000aOol2000cOol2000JOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
000KOooo00050001Ool001]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`40005oo`006goo00<007ooOol05goo00<007ooOol0<Goo00<007oo
Ool0<Goo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol05goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool000Uoo`03001oogoo009oo`8000Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`002Goo00<007ooOol01goo00@007ooOol000Aoo`03001oogoo
0?moo`5oo`40005oo`002Goo00<007ooOol02Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0000
0goo000000020005Ool00`00Oomoo`07Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`04
001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`@000Uoo`<000Ao
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80
005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`004goo00@007ooOol0
00Aoo`03001oogoo0?moo`5oo`40005oo`005Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo000=
Ool40003Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool001Aoo`03001oogoo00Aoo`03001oogoo
0?moo`5oo`40005oo`0057oo0`0017oo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool0
01]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`001goo10000goo0P0017oo0P001Goo
00<007ooOol0ogoo0Goo0@000Goo0007Ool00`00Oomoo`09Ool01000Oomoo`0017oo00<007ooOol0
ogoo0Goo0@000Goo0008Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool2003oOol1Ool20001Ool00003
Ool00000008000Aoo`03001oogoo00Qoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`001goo00@0
07ooOol000Uoo`03001oogoo00Aoo`03001oogoo0?moo`5oo`40005oo`0027oo0P002Woo0`0017oo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo
0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool1
0001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo
0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo
00<007ooOol0H7oo1P0OVWoo0@000Goo000KOol00`00Oomoo`1OOol801nIOol10001Ool001]oo`03
001oogoo05ioo`X07bmoo`Il06=oo`40005oo`006goo00<007ooOol0GGoo300O;Goo27`0HWoo0@00
0Goo000DOol20005Ool00`00Oomoo`1MOol<01l/Ool:O01QOol10001Ool001=oo`04001oogoo0004
Ool00`00Oomoo`1MOol<01l[Ool<O01POol10001Ool001=oo`04001oogoo0004Ool2001NOol<01l[
Ool<O01OOol20001Ool001=oo`04001oogoo0004Ool00`00Oomoo`1MOol<01l[Ool<O01POol10001
Ool001=oo`04001oogoo0004Ool00`00Oomoo`1MOol<01l[Ool<O01POol10001Ool001Aoo`8000Eo
o`03001oogoo05ioo`X07baoo`al061oo`40005oo`006goo00<007ooOol0Ggoo200O;Goo37`0H7oo
0@000Goo000KOol00`00Oomoo`1POol601l_Ool:O01QOol10001Ool001]oo`8009Moo`Ql065oo`80
005oo`006goo00<007ooOol0Ugoo1W`0Hgoo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P00
0Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo
0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool000Moo`@000=oo`80
00Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`001goo00<007ooOol02Goo00@007ooOol000Ao
o`03001oogoo0?moo`5oo`40005oo`0027oo00<007ooOol02goo00<007ooOol00Woo0P00ogoo0Goo
0P000Goo0009Ool00`00Oomoo`08Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`04001o
ogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3oOol1Ool10001Ool000Qoo`8000Yoo`<000Aoo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`0057oo0P001Goo00<007ooOol0ogoo
0Goo0@000Goo000COol01000Oomoo`0017oo00<007ooOol0ogoo0Goo0@000Goo000FOol00`00Oomo
o`02Ool2003oOol1Ool20001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`0057oo00<0
07ooOol017oo00<007ooOol0ogoo0Goo0@000Goo000DOol30004Ool00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2
003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001o
ogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo0009Ool0
0`00Oomoo`02Ool20004Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool000Uoo`03001oogoo00Mo
o`04001oogoo0004Ool00`00Oomoo`3oOol1Ool10001Ool000Uoo`03001oogoo00Yoo`03001oogoo
009oo`800?moo`5oo`80005oo`002Woo00<007ooOol01goo0P001Goo00<007ooOol0ogoo0Goo0@00
0Goo0007Ool01000Oomoo`002Goo00<007ooOol017oo00<007ooOol0ogoo0Goo0@000Goo0007Ool4
0009Ool30004Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001o
ogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool000eoo`D0009o
o`8000Eoo`03001oogoo01Moo`03001oogoo035oo`03001oogoo035oo`03001oogoo031oo`03001o
ogoo035oo`03001oogoo01Moo`40005oo`003goo00D007ooOomoo`00009oo`03001oogoo009oo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`40
005oo`003goo00D007ooOomoo`00009oo`03001oogoo009oool000D0005oo`003goo00D007ooOomo
o`00009oo`03001oogoo0?moo`Qoo`003goo00D007ooOomoo`00009oo`03001oogoo0?moo`Qoo`00
3Woo0P0017oo0P00ogoo2goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.04945, -11.3526, 0.0385168, \
0.0770336}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.5 0.05 [
[.1 -0.0125 -6 -9 ]
[.1 -0.0125 6 0 ]
[.3 -0.0125 -6 -9 ]
[.3 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7 -0.0125 -3 -9 ]
[.7 -0.0125 3 0 ]
[.9 -0.0125 -3 -9 ]
[.9 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -24 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-4)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-2)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(2)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(4)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-7.5)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-5)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-2.5)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(2.5)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(5)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(7.5)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(10)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
.1 .99375 m
.1 1 L
s
.3 .99375 m
.3 1 L
s
.5 .99375 m
.5 1 L
s
.7 .99375 m
.7 1 L
s
.9 .99375 m
.9 1 L
s
.125 Mabswid
.15 .99625 m
.15 1 L
s
.2 .99625 m
.2 1 L
s
.25 .99625 m
.25 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.45 .99625 m
.45 1 L
s
.55 .99625 m
.55 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.75 .99625 m
.75 1 L
s
.8 .99625 m
.8 1 L
s
.85 .99625 m
.85 1 L
s
.05 .99625 m
.05 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.67021 .5254 Mdot
0 0 1 r
.32979 .4746 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000hOol3000_Ool4000^Ool2
000`Ool4000bOol3000IOol003Uoo`03001oogoo02ioo`03001oogoo02ioo`04001oogoo000_Ool0
0`00Oomoo`0dOol00`00Oomoo`0HOol003Ioo`D0031oo`03001oogoo02eoo`04001oogoo000`Ool0
0`00Oomoo`0`Ool5000IOol0031oo`@0009oo`04001oogoo000ZOol40004Ool00`00Oomoo`0/Ool0
1000Oomoo`00<Goo00<007ooOol0;goo00@007ooOol001Yoo`00=goo00<007oo0000<7oo00@007oo
Ool002eoo`04001oogoo000_Ool01000Oomoo`00<Goo00<007oo00006Woo000hOol2000aOol2000_
Ool2000aOol2000cOol2000JOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
000KOooo00050001Ool001]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`40005oo`006goo00<007ooOol05goo00<007ooOol0<Goo00<007oo
Ool0<Goo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol05goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool000Uoo`03001oogoo009oo`8000Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`002Goo00<007ooOol01goo00@007ooOol000Aoo`03001oogoo
0?moo`5oo`40005oo`002Goo00<007ooOol02Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0000
0goo000000020005Ool00`00Oomoo`07Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`04
001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`@000Uoo`<000Ao
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80
005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`004goo00@007ooOol0
00Aoo`03001oogoo0?moo`5oo`40005oo`005Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo000=
Ool40003Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool001Aoo`03001oogoo00Aoo`03001oogoo
0?moo`5oo`40005oo`0057oo0`0017oo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool0
01]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`001goo10000goo0P0017oo0P001Goo
00<007ooOol0ogoo0Goo0@000Goo0007Ool00`00Oomoo`09Ool01000Oomoo`0017oo00<007ooOol0
ogoo0Goo0@000Goo0008Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool2003oOol1Ool20001Ool00003
Ool00000008000Aoo`03001oogoo00Qoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`001goo00@0
07ooOol000Uoo`03001oogoo00Aoo`03001oogoo0?moo`5oo`40005oo`0027oo0P002Woo0`0017oo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo
0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool1
0001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0Cgoo1P0OZgoo0@000Goo000KOol0
0`00Oomoo`1>Ool801nZOol10001Ool001]oo`03001oogoo04eoo`X07jUoo`40005oo`006goo00<0
07ooOol0C7oo300OZ7oo0@000Goo000KOol00`00Oomoo`1<Ool<01nXOol10001Ool001]oo`8004eo
o``07jMoo`80005oo`006goo00<007ooOol0C7oo300OZ7oo0@000Goo000KOol00`00Oomoo`1<Ool<
01nXOol10001Ool001]oo`03001oogoo04aoo``07jQoo`40005oo`006goo00<007ooOol0CGoo2P0O
ZGoo0@000Goo000DOol20005Ool00`00Oomoo`1>Ool801nZOol10001Ool001=oo`04001oogoo0004
Ool00`00Oomoo`1?Ool601n[Ool10001Ool001=oo`04001oogoo0004Ool2003oOol1Ool20001Ool0
01=oo`04001oogoo0004Ool00`00Oomoo`2XOol6O01BOol10001Ool001=oo`04001oogoo0004Ool0
0`00Oomoo`2WOol8O01AOol10001Ool001Aoo`8000Eoo`03001oogoo0:Ioo`Yl051oo`40005oo`00
6goo00<007ooOol0YGoo37`0Cgoo0@000Goo000KOol00`00Oomoo`2UOol<O01?Ool10001Ool001]o
o`800:Ioo`al04ioo`80005oo`006goo00<007ooOol0YGoo37`0Cgoo0@000Goo000KOol00`00Oomo
o`2UOol<O01?Ool10001Ool001]oo`03001oogoo0:Eoo`al04moo`40005oo`006goo00<007ooOol0
YWoo2W`0D7oo0@000Goo000KOol00`00Oomoo`2WOol8O01AOol10001Ool001]oo`03001oogoo0:Qo
o`Il059oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P00
0Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool000Moo`@000=oo`8000Aoo`8000Eoo`03001oogoo0?moo`5oo`40005o
o`001goo00<007ooOol02Goo00@007ooOol000Aoo`03001oogoo0?moo`5oo`40005oo`0027oo00<0
07ooOol02goo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0009Ool00`00Oomoo`08Ool20005Ool0
0`00Oomoo`3oOol1Ool10001Ool000Moo`04001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3o
Ool1Ool10001Ool000Qoo`8000Yoo`<000Aoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`0057oo0P001Goo00<007ooOol0ogoo0Goo0@000Goo000COol01000Oomoo`0017oo00<0
07ooOol0ogoo0Goo0@000Goo000FOol00`00Oomoo`02Ool2003oOol1Ool20001Ool001Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`0057oo00<007ooOol017oo00<007ooOol0ogoo0Goo0@000Goo
000DOol30004Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo0009Ool00`00Oomoo`02Ool20004Ool20005Ool00`00Oomo
o`3oOol1Ool10001Ool000Uoo`03001oogoo00Moo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool1
0001Ool000Uoo`03001oogoo00Yoo`03001oogoo009oo`800?moo`5oo`80005oo`002Woo00<007oo
Ool01goo0P001Goo00<007ooOol0ogoo0Goo0@000Goo0007Ool01000Oomoo`002Goo00<007ooOol0
17oo00<007ooOol0ogoo0Goo0@000Goo0007Ool40009Ool30004Ool00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001o
ogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool000eoo`D0009oo`8000Eoo`03001oogoo01Moo`03001oogoo035o
o`03001oogoo035oo`03001oogoo031oo`03001oogoo035oo`03001oogoo01Moo`40005oo`003goo
00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`40005oo`003goo00D007ooOomoo`00009oo`03001o
ogoo009oool000D0005oo`003goo00D007ooOomoo`00009oo`03001oogoo0?moo`Qoo`003goo00D0
07ooOomoo`00009oo`03001oogoo0?moo`Qoo`003Woo0P0017oo0P00ogoo2goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.04945, -11.3526, 0.0385168, \
0.0770336}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.5 0.05 [
[.1 -0.0125 -6 -9 ]
[.1 -0.0125 6 0 ]
[.3 -0.0125 -6 -9 ]
[.3 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7 -0.0125 -3 -9 ]
[.7 -0.0125 3 0 ]
[.9 -0.0125 -3 -9 ]
[.9 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -24 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-4)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-2)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(2)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(4)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-7.5)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-5)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-2.5)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(2.5)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(5)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(7.5)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(10)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
.1 .99375 m
.1 1 L
s
.3 .99375 m
.3 1 L
s
.5 .99375 m
.5 1 L
s
.7 .99375 m
.7 1 L
s
.9 .99375 m
.9 1 L
s
.125 Mabswid
.15 .99625 m
.15 1 L
s
.2 .99625 m
.2 1 L
s
.25 .99625 m
.25 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.45 .99625 m
.45 1 L
s
.55 .99625 m
.55 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.75 .99625 m
.75 1 L
s
.8 .99625 m
.8 1 L
s
.85 .99625 m
.85 1 L
s
.05 .99625 m
.05 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.71117 .53419 Mdot
0 0 1 r
.28883 .46581 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000hOol3000_Ool4000^Ool2
000`Ool4000bOol3000IOol003Uoo`03001oogoo02ioo`03001oogoo02ioo`04001oogoo000_Ool0
0`00Oomoo`0dOol00`00Oomoo`0HOol003Ioo`D0031oo`03001oogoo02eoo`04001oogoo000`Ool0
0`00Oomoo`0`Ool5000IOol0031oo`@0009oo`04001oogoo000ZOol40004Ool00`00Oomoo`0/Ool0
1000Oomoo`00<Goo00<007ooOol0;goo00@007ooOol001Yoo`00=goo00<007oo0000<7oo00@007oo
Ool002eoo`04001oogoo000_Ool01000Oomoo`00<Goo00<007oo00006Woo000hOol2000aOol2000_
Ool2000aOol2000cOol2000JOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
000KOooo00050001Ool001]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`40005oo`006goo00<007ooOol05goo00<007ooOol0<Goo00<007oo
Ool0<Goo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol05goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool000Uoo`03001oogoo009oo`8000Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`002Goo00<007ooOol01goo00@007ooOol000Aoo`03001oogoo
0?moo`5oo`40005oo`002Goo00<007ooOol02Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0000
0goo000000020005Ool00`00Oomoo`07Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`04
001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`@000Uoo`<000Ao
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80
005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`004goo00@007ooOol0
00Aoo`03001oogoo0?moo`5oo`40005oo`005Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo000=
Ool40003Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool001Aoo`03001oogoo00Aoo`03001oogoo
0?moo`5oo`40005oo`0057oo0`0017oo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool0
01]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`001goo10000goo0P0017oo0P001Goo
00<007ooOol0ogoo0Goo0@000Goo0007Ool00`00Oomoo`09Ool01000Oomoo`0017oo00<007ooOol0
ogoo0Goo0@000Goo0008Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool2003oOol1Ool20001Ool00003
Ool00000008000Aoo`03001oogoo00Qoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`001goo00@0
07ooOol000Uoo`03001oogoo00Aoo`03001oogoo0?moo`5oo`40005oo`0027oo0P002Woo0`0017oo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo
0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`15Ool601ne
Ool10001Ool001]oo`8004Eoo`P07k=oo`80005oo`006goo00<007ooOol0@goo2P0O/goo0@000Goo
000KOol00`00Oomoo`12Ool<01nbOol10001Ool001]oo`03001oogoo049oo``07k9oo`40005oo`00
6goo00<007ooOol0@Woo300O/Woo0@000Goo000KOol00`00Oomoo`12Ool<01nbOol10001Ool001]o
o`8004=oo``07k5oo`80005oo`006goo00<007ooOol0@Woo300O/Woo0@000Goo000KOol00`00Oomo
o`13Ool:01ncOol10001Ool001]oo`03001oogoo04Aoo`P07kAoo`40005oo`006goo00<007ooOol0
AGoo1P0O]Goo0@000Goo000DOol20005Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo
0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool2003oOol1Ool20001Ool0
01=oo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool00`00
Oomoo`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0/Woo1W`0B7oo0@000Goo000KOol00`00Oomoo`2aOol8O017Ool10001Ool001]oo`800;5oo`Yl
04Eoo`80005oo`006goo00<007ooOol0[goo37`0AGoo0@000Goo000KOol00`00Oomoo`2_Ool<O015
Ool10001Ool001]oo`03001oogoo0:moo`al04Eoo`40005oo`006goo00<007ooOol0[goo37`0AGoo
0@000Goo000KOol00`00Oomoo`2_Ool<O015Ool10001Ool001]oo`03001oogoo0:moo`al04Eoo`40
005oo`006goo0P00/Goo2W`0AGoo0P000Goo000KOol00`00Oomoo`2aOol8O017Ool10001Ool001]o
o`03001oogoo0;9oo`Il04Qoo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P00
0Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool000Moo`@000=oo`8000Aoo`8000Eoo`03001oogoo0?moo`5oo`40005o
o`001goo00<007ooOol02Goo00@007ooOol000Aoo`03001oogoo0?moo`5oo`40005oo`0027oo00<0
07ooOol02goo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0009Ool00`00Oomoo`08Ool20005Ool0
0`00Oomoo`3oOol1Ool10001Ool000Moo`04001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3o
Ool1Ool10001Ool000Qoo`8000Yoo`<000Aoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`0057oo0P001Goo00<007ooOol0ogoo0Goo0@000Goo000COol01000Oomoo`0017oo00<0
07ooOol0ogoo0Goo0@000Goo000FOol00`00Oomoo`02Ool2003oOol1Ool20001Ool001Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`0057oo00<007ooOol017oo00<007ooOol0ogoo0Goo0@000Goo
000DOol30004Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo0009Ool00`00Oomoo`02Ool20004Ool20005Ool00`00Oomo
o`3oOol1Ool10001Ool000Uoo`03001oogoo00Moo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool1
0001Ool000Uoo`03001oogoo00Yoo`03001oogoo009oo`800?moo`5oo`80005oo`002Woo00<007oo
Ool01goo0P001Goo00<007ooOol0ogoo0Goo0@000Goo0007Ool01000Oomoo`002Goo00<007ooOol0
17oo00<007ooOol0ogoo0Goo0@000Goo0007Ool40009Ool30004Ool00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001o
ogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool000eoo`D0009oo`8000Eoo`03001oogoo01Moo`03001oogoo035o
o`03001oogoo035oo`03001oogoo031oo`03001oogoo035oo`03001oogoo01Moo`40005oo`003goo
00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`40005oo`003goo00D007ooOomoo`00009oo`03001o
ogoo009oool000D0005oo`003goo00D007ooOomoo`00009oo`03001oogoo0?moo`Qoo`003goo00D0
07ooOomoo`00009oo`03001oogoo0?moo`Qoo`003Woo0P0017oo0P00ogoo2goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.04945, -11.3526, 0.0385168, \
0.0770336}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.5 0.05 [
[.1 -0.0125 -6 -9 ]
[.1 -0.0125 6 0 ]
[.3 -0.0125 -6 -9 ]
[.3 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7 -0.0125 -3 -9 ]
[.7 -0.0125 3 0 ]
[.9 -0.0125 -3 -9 ]
[.9 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -24 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-4)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-2)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(2)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(4)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-7.5)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-5)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-2.5)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(2.5)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(5)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(7.5)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(10)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
.1 .99375 m
.1 1 L
s
.3 .99375 m
.3 1 L
s
.5 .99375 m
.5 1 L
s
.7 .99375 m
.7 1 L
s
.9 .99375 m
.9 1 L
s
.125 Mabswid
.15 .99625 m
.15 1 L
s
.2 .99625 m
.2 1 L
s
.25 .99625 m
.25 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.45 .99625 m
.45 1 L
s
.55 .99625 m
.55 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.75 .99625 m
.75 1 L
s
.8 .99625 m
.8 1 L
s
.85 .99625 m
.85 1 L
s
.05 .99625 m
.05 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.74116 .54025 Mdot
0 0 1 r
.25884 .45975 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000hOol3000_Ool4000^Ool2
000`Ool4000bOol3000IOol003Uoo`03001oogoo02ioo`03001oogoo02ioo`04001oogoo000_Ool0
0`00Oomoo`0dOol00`00Oomoo`0HOol003Ioo`D0031oo`03001oogoo02eoo`04001oogoo000`Ool0
0`00Oomoo`0`Ool5000IOol0031oo`@0009oo`04001oogoo000ZOol40004Ool00`00Oomoo`0/Ool0
1000Oomoo`00<Goo00<007ooOol0;goo00@007ooOol001Yoo`00=goo00<007oo0000<7oo00@007oo
Ool002eoo`04001oogoo000_Ool01000Oomoo`00<Goo00<007oo00006Woo000hOol2000aOol2000_
Ool2000aOol2000cOol2000JOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
000KOooo00050001Ool001]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`40005oo`006goo00<007ooOol05goo00<007ooOol0<Goo00<007oo
Ool0<Goo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol05goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool000Uoo`03001oogoo009oo`8000Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`002Goo00<007ooOol01goo00@007ooOol000Aoo`03001oogoo
0?moo`5oo`40005oo`002Goo00<007ooOol02Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0000
0goo000000020005Ool00`00Oomoo`07Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`04
001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`@000Uoo`<000Ao
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80
005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`004goo00@007ooOol0
00Aoo`03001oogoo0?moo`5oo`40005oo`005Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo000=
Ool40003Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool001Aoo`03001oogoo00Aoo`03001oogoo
0?moo`5oo`40005oo`0057oo0`0017oo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool0
01]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`001goo10000goo0P0017oo0P001Goo
00<007ooOol0ogoo0Goo0@000Goo0007Ool00`00Oomoo`09Ool01000Oomoo`0017oo00<007ooOol0
ogoo0Goo0@000Goo0008Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool2003oOol1Ool20001Ool00003
Ool00000008000Aoo`03001oogoo00Qoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`001goo00@0
07ooOol000Uoo`03001oogoo00Aoo`03001oogoo0?moo`5oo`40005oo`0027oo0P002Woo0`0017oo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo
0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
03eoo`H07keoo`40005oo`006goo00<007ooOol0?7oo200O_7oo0@000Goo000KOol00`00Oomoo`0k
Ool:01nkOol10001Ool001]oo`8003]oo``07kUoo`80005oo`006goo00<007ooOol0>Woo300O^Woo
0@000Goo000KOol00`00Oomoo`0jOol<01njOol10001Ool001]oo`03001oogoo03Yoo``07kYoo`40
005oo`006goo00<007ooOol0>Woo300O^Woo0@000Goo000KOol00`00Oomoo`0jOol<01njOol10001
Ool001]oo`8003aoo`X07kYoo`80005oo`006goo00<007ooOol0?7oo200O_7oo0@000Goo000KOol0
0`00Oomoo`0mOol601nmOol10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000DOol20005Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo
0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool2003oOol1Ool20001Ool0
01=oo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool00`00
Oomoo`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`2jOol6O010Ool10001Ool001]oo`800;Yoo`Ql03io
o`80005oo`006goo00<007ooOol0^7oo2W`0?Woo0@000Goo000KOol00`00Oomoo`2gOol<O00mOol1
0001Ool001]oo`03001oogoo0;Moo`al03eoo`40005oo`006goo00<007ooOol0]goo37`0?Goo0@00
0Goo000KOol00`00Oomoo`2gOol<O00mOol10001Ool001]oo`03001oogoo0;Moo`al03eoo`40005o
o`006goo0P00^7oo37`0?7oo0P000Goo000KOol00`00Oomoo`2hOol:O00nOol10001Ool001]oo`03
001oogoo0;Uoo`Ql03moo`40005oo`006goo00<007ooOol0^Woo1W`0@7oo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P00
0Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool000Moo`@000=oo`8000Aoo`8000Eoo`03001oogoo0?moo`5oo`40005o
o`001goo00<007ooOol02Goo00@007ooOol000Aoo`03001oogoo0?moo`5oo`40005oo`0027oo00<0
07ooOol02goo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0009Ool00`00Oomoo`08Ool20005Ool0
0`00Oomoo`3oOol1Ool10001Ool000Moo`04001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3o
Ool1Ool10001Ool000Qoo`8000Yoo`<000Aoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`0057oo0P001Goo00<007ooOol0ogoo0Goo0@000Goo000COol01000Oomoo`0017oo00<0
07ooOol0ogoo0Goo0@000Goo000FOol00`00Oomoo`02Ool2003oOol1Ool20001Ool001Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`0057oo00<007ooOol017oo00<007ooOol0ogoo0Goo0@000Goo
000DOol30004Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo0009Ool00`00Oomoo`02Ool20004Ool20005Ool00`00Oomo
o`3oOol1Ool10001Ool000Uoo`03001oogoo00Moo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool1
0001Ool000Uoo`03001oogoo00Yoo`03001oogoo009oo`800?moo`5oo`80005oo`002Woo00<007oo
Ool01goo0P001Goo00<007ooOol0ogoo0Goo0@000Goo0007Ool01000Oomoo`002Goo00<007ooOol0
17oo00<007ooOol0ogoo0Goo0@000Goo0007Ool40009Ool30004Ool00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001o
ogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool000eoo`D0009oo`8000Eoo`03001oogoo01Moo`03001oogoo035o
o`03001oogoo035oo`03001oogoo031oo`03001oogoo035oo`03001oogoo01Moo`40005oo`003goo
00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`40005oo`003goo00D007ooOomoo`00009oo`03001o
ogoo009oool000D0005oo`003goo00D007ooOomoo`00009oo`03001oogoo0?moo`Qoo`003goo00D0
07ooOomoo`00009oo`03001oogoo0?moo`Qoo`003Woo0P0017oo0P00ogoo2goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.04945, -11.3526, 0.0385168, \
0.0770336}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.5 0.05 [
[.1 -0.0125 -6 -9 ]
[.1 -0.0125 6 0 ]
[.3 -0.0125 -6 -9 ]
[.3 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7 -0.0125 -3 -9 ]
[.7 -0.0125 3 0 ]
[.9 -0.0125 -3 -9 ]
[.9 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -24 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-4)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-2)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(2)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(4)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-7.5)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-5)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-2.5)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(2.5)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(5)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(7.5)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(10)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
.1 .99375 m
.1 1 L
s
.3 .99375 m
.3 1 L
s
.5 .99375 m
.5 1 L
s
.7 .99375 m
.7 1 L
s
.9 .99375 m
.9 1 L
s
.125 Mabswid
.15 .99625 m
.15 1 L
s
.2 .99625 m
.2 1 L
s
.25 .99625 m
.25 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.45 .99625 m
.45 1 L
s
.55 .99625 m
.55 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.75 .99625 m
.75 1 L
s
.8 .99625 m
.8 1 L
s
.85 .99625 m
.85 1 L
s
.05 .99625 m
.05 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.76543 .54504 Mdot
0 0 1 r
.23457 .45496 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000hOol3000_Ool4000^Ool2
000`Ool4000bOol3000IOol003Uoo`03001oogoo02ioo`03001oogoo02ioo`04001oogoo000_Ool0
0`00Oomoo`0dOol00`00Oomoo`0HOol003Ioo`D0031oo`03001oogoo02eoo`04001oogoo000`Ool0
0`00Oomoo`0`Ool5000IOol0031oo`@0009oo`04001oogoo000ZOol40004Ool00`00Oomoo`0/Ool0
1000Oomoo`00<Goo00<007ooOol0;goo00@007ooOol001Yoo`00=goo00<007oo0000<7oo00@007oo
Ool002eoo`04001oogoo000_Ool01000Oomoo`00<Goo00<007oo00006Woo000hOol2000aOol2000_
Ool2000aOol2000cOol2000JOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
000KOooo00050001Ool001]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`40005oo`006goo00<007ooOol05goo00<007ooOol0<Goo00<007oo
Ool0<Goo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol05goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool000Uoo`03001oogoo009oo`8000Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`002Goo00<007ooOol01goo00@007ooOol000Aoo`03001oogoo
0?moo`5oo`40005oo`002Goo00<007ooOol02Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0000
0goo000000020005Ool00`00Oomoo`07Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`04
001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`@000Uoo`<000Ao
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80
005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`004goo00@007ooOol0
00Aoo`03001oogoo0?moo`5oo`40005oo`005Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo000=
Ool40003Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool001Aoo`03001oogoo00Aoo`03001oogoo
0?moo`5oo`40005oo`0057oo0`0017oo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool0
01]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`001goo10000goo0P0017oo0P001Goo
00<007ooOol0ogoo0Goo0@000Goo0007Ool00`00Oomoo`09Ool01000Oomoo`0017oo00<007ooOol0
ogoo0Goo0@000Goo0008Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool2003oOol1Ool20001Ool00003
Ool00000008000Aoo`03001oogoo00Qoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`001goo00@0
07ooOol000Uoo`03001oogoo00Aoo`03001oogoo0?moo`5oo`40005oo`0027oo0P002Woo0`0017oo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo
0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`0gOol601o3Ool10001Ool001]oo`03001o
ogoo03Ioo`P07l9oo`40005oo`006goo00<007ooOol0=Goo2P0O`Goo0@000Goo000KOol00`00Oomo
o`0dOol<01o0Ool10001Ool001]oo`8003Eoo``07kmoo`80005oo`006goo00<007ooOol0=7oo300O
`7oo0@000Goo000KOol00`00Oomoo`0dOol<01o0Ool10001Ool001]oo`03001oogoo03Aoo``07l1o
o`40005oo`006goo00<007ooOol0=7oo300O`7oo0@000Goo000KOol00`00Oomoo`0eOol:01o1Ool1
0001Ool001]oo`8003Moo`P07l5oo`80005oo`006goo00<007ooOol0=goo1P0O`goo0@000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000DOol20005Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo
0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool2003oOol1Ool20001Ool0
01=oo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool00`00
Oomoo`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005o
o`006goo00<007ooOol0`Goo1W`0>Goo0@000Goo000KOol00`00Oomoo`30Ool8O00hOol10001Ool0
01]oo`03001oogoo0;moo`Yl03Moo`40005oo`006goo00<007ooOol0_Woo37`0=Woo0@000Goo000K
Ool00`00Oomoo`2nOol<O00fOol10001Ool001]oo`03001oogoo0;ioo`al03Ioo`40005oo`006goo
0P00_goo37`0=Goo0P000Goo000KOol00`00Oomoo`2nOol<O00fOol10001Ool001]oo`03001oogoo
0;ioo`al03Ioo`40005oo`006goo00<007ooOol0_goo2W`0=goo0@000Goo000KOol00`00Oomoo`30
Ool8O00hOol10001Ool001]oo`03001oogoo0<5oo`Il03Uoo`40005oo`006goo0P00ogoo0Goo0P00
0Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool000Moo`@000=oo`8000Aoo`8000Eoo`03001oogoo0?moo`5oo`40005o
o`001goo00<007ooOol02Goo00@007ooOol000Aoo`03001oogoo0?moo`5oo`40005oo`0027oo00<0
07ooOol02goo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0009Ool00`00Oomoo`08Ool20005Ool0
0`00Oomoo`3oOol1Ool10001Ool000Moo`04001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3o
Ool1Ool10001Ool000Qoo`8000Yoo`<000Aoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`0057oo0P001Goo00<007ooOol0ogoo0Goo0@000Goo000COol01000Oomoo`0017oo00<0
07ooOol0ogoo0Goo0@000Goo000FOol00`00Oomoo`02Ool2003oOol1Ool20001Ool001Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`0057oo00<007ooOol017oo00<007ooOol0ogoo0Goo0@000Goo
000DOol30004Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo0009Ool00`00Oomoo`02Ool20004Ool20005Ool00`00Oomo
o`3oOol1Ool10001Ool000Uoo`03001oogoo00Moo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool1
0001Ool000Uoo`03001oogoo00Yoo`03001oogoo009oo`800?moo`5oo`80005oo`002Woo00<007oo
Ool01goo0P001Goo00<007ooOol0ogoo0Goo0@000Goo0007Ool01000Oomoo`002Goo00<007ooOol0
17oo00<007ooOol0ogoo0Goo0@000Goo0007Ool40009Ool30004Ool00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001o
ogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool000eoo`D0009oo`8000Eoo`03001oogoo01Moo`03001oogoo035o
o`03001oogoo035oo`03001oogoo031oo`03001oogoo035oo`03001oogoo01Moo`40005oo`003goo
00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`40005oo`003goo00D007ooOomoo`00009oo`03001o
ogoo009oool000D0005oo`003goo00D007ooOomoo`00009oo`03001oogoo0?moo`Qoo`003goo00D0
07ooOomoo`00009oo`03001oogoo0?moo`Qoo`003Woo0P0017oo0P00ogoo2goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.04945, -11.3526, 0.0385168, \
0.0770336}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.5 0.05 [
[.1 -0.0125 -6 -9 ]
[.1 -0.0125 6 0 ]
[.3 -0.0125 -6 -9 ]
[.3 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7 -0.0125 -3 -9 ]
[.7 -0.0125 3 0 ]
[.9 -0.0125 -3 -9 ]
[.9 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -24 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-4)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-2)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(2)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(4)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-7.5)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-5)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-2.5)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(2.5)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(5)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(7.5)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(10)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
.1 .99375 m
.1 1 L
s
.3 .99375 m
.3 1 L
s
.5 .99375 m
.5 1 L
s
.7 .99375 m
.7 1 L
s
.9 .99375 m
.9 1 L
s
.125 Mabswid
.15 .99625 m
.15 1 L
s
.2 .99625 m
.2 1 L
s
.25 .99625 m
.25 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.45 .99625 m
.45 1 L
s
.55 .99625 m
.55 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.75 .99625 m
.75 1 L
s
.8 .99625 m
.8 1 L
s
.85 .99625 m
.85 1 L
s
.05 .99625 m
.05 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.78609 .54906 Mdot
0 0 1 r
.21391 .45094 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000hOol3000_Ool4000^Ool2
000`Ool4000bOol3000IOol003Uoo`03001oogoo02ioo`03001oogoo02ioo`04001oogoo000_Ool0
0`00Oomoo`0dOol00`00Oomoo`0HOol003Ioo`D0031oo`03001oogoo02eoo`04001oogoo000`Ool0
0`00Oomoo`0`Ool5000IOol0031oo`@0009oo`04001oogoo000ZOol40004Ool00`00Oomoo`0/Ool0
1000Oomoo`00<Goo00<007ooOol0;goo00@007ooOol001Yoo`00=goo00<007oo0000<7oo00@007oo
Ool002eoo`04001oogoo000_Ool01000Oomoo`00<Goo00<007oo00006Woo000hOol2000aOol2000_
Ool2000aOol2000cOol2000JOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
000KOooo00050001Ool001]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`40005oo`006goo00<007ooOol05goo00<007ooOol0<Goo00<007oo
Ool0<Goo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol05goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool000Uoo`03001oogoo009oo`8000Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`002Goo00<007ooOol01goo00@007ooOol000Aoo`03001oogoo
0?moo`5oo`40005oo`002Goo00<007ooOol02Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0000
0goo000000020005Ool00`00Oomoo`07Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`04
001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`@000Uoo`<000Ao
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80
005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`004goo00@007ooOol0
00Aoo`03001oogoo0?moo`5oo`40005oo`005Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo000=
Ool40003Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool001Aoo`03001oogoo00Aoo`03001oogoo
0?moo`5oo`40005oo`0057oo0`0017oo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool0
01]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`001goo10000goo0P0017oo0P001Goo
00<007ooOol0ogoo0Goo0@000Goo0007Ool00`00Oomoo`09Ool01000Oomoo`0017oo00<007ooOol0
ogoo0Goo0@000Goo0008Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool2003oOol1Ool20001Ool00003
Ool00000008000Aoo`03001oogoo00Qoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`001goo00@0
07ooOol000Uoo`03001oogoo00Aoo`03001oogoo0?moo`5oo`40005oo`0027oo0P002Woo0`0017oo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo
0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo
00<007ooOol0<Goo1P0ObGoo0@000Goo000KOol00`00Oomoo`0`Ool801o8Ool10001Ool001]oo`03
001oogoo02moo`X07lMoo`40005oo`006goo00<007ooOol0;Woo300OaWoo0@000Goo000KOol00`00
Oomoo`0^Ool<01o6Ool10001Ool001]oo`8002moo``07lEoo`80005oo`006goo00<007ooOol0;Woo
300OaWoo0@000Goo000KOol00`00Oomoo`0^Ool<01o6Ool10001Ool001]oo`03001oogoo02ioo``0
7lIoo`40005oo`006goo00<007ooOol0;goo2P0Oagoo0@000Goo000KOol00`00Oomoo`0`Ool801o8
Ool10001Ool001]oo`80039oo`H07lQoo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000DOol20005Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo
0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool2003oOol1Ool20001Ool0
01=oo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool00`00
Oomoo`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005o
o`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`36Ool6O00dOol10001Ool001]o
o`03001oogoo0<Eoo`Ql03=oo`40005oo`006goo00<007ooOol0a7oo2W`0<Woo0@000Goo000KOol0
0`00Oomoo`33Ool<O00aOol10001Ool001]oo`03001oogoo0<=oo`al035oo`40005oo`006goo0P00
a7oo37`0<7oo0P000Goo000KOol00`00Oomoo`33Ool<O00aOol10001Ool001]oo`03001oogoo0<=o
o`al035oo`40005oo`006goo00<007ooOol0`goo37`0<Goo0@000Goo000KOol00`00Oomoo`34Ool:
O00bOol10001Ool001]oo`03001oogoo0<Eoo`Ql03=oo`40005oo`006goo0P00agoo1W`0<goo0P00
0Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool000Moo`@000=oo`8000Aoo`8000Eoo`03001oogoo0?moo`5oo`40005o
o`001goo00<007ooOol02Goo00@007ooOol000Aoo`03001oogoo0?moo`5oo`40005oo`0027oo00<0
07ooOol02goo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0009Ool00`00Oomoo`08Ool20005Ool0
0`00Oomoo`3oOol1Ool10001Ool000Moo`04001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3o
Ool1Ool10001Ool000Qoo`8000Yoo`<000Aoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`0057oo0P001Goo00<007ooOol0ogoo0Goo0@000Goo000COol01000Oomoo`0017oo00<0
07ooOol0ogoo0Goo0@000Goo000FOol00`00Oomoo`02Ool2003oOol1Ool20001Ool001Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`0057oo00<007ooOol017oo00<007ooOol0ogoo0Goo0@000Goo
000DOol30004Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo0009Ool00`00Oomoo`02Ool20004Ool20005Ool00`00Oomo
o`3oOol1Ool10001Ool000Uoo`03001oogoo00Moo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool1
0001Ool000Uoo`03001oogoo00Yoo`03001oogoo009oo`800?moo`5oo`80005oo`002Woo00<007oo
Ool01goo0P001Goo00<007ooOol0ogoo0Goo0@000Goo0007Ool01000Oomoo`002Goo00<007ooOol0
17oo00<007ooOol0ogoo0Goo0@000Goo0007Ool40009Ool30004Ool00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001o
ogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool000eoo`D0009oo`8000Eoo`03001oogoo01Moo`03001oogoo035o
o`03001oogoo035oo`03001oogoo031oo`03001oogoo035oo`03001oogoo01Moo`40005oo`003goo
00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`40005oo`003goo00D007ooOomoo`00009oo`03001o
ogoo009oool000D0005oo`003goo00D007ooOomoo`00009oo`03001oogoo0?moo`Qoo`003goo00D0
07ooOomoo`00009oo`03001oogoo0?moo`Qoo`003Woo0P0017oo0P00ogoo2goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.04945, -11.3526, 0.0385168, \
0.0770336}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.5 0.05 [
[.1 -0.0125 -6 -9 ]
[.1 -0.0125 6 0 ]
[.3 -0.0125 -6 -9 ]
[.3 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7 -0.0125 -3 -9 ]
[.7 -0.0125 3 0 ]
[.9 -0.0125 -3 -9 ]
[.9 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -24 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-4)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-2)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(2)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(4)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-7.5)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-5)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-2.5)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(2.5)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(5)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(7.5)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(10)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
.1 .99375 m
.1 1 L
s
.3 .99375 m
.3 1 L
s
.5 .99375 m
.5 1 L
s
.7 .99375 m
.7 1 L
s
.9 .99375 m
.9 1 L
s
.125 Mabswid
.15 .99625 m
.15 1 L
s
.2 .99625 m
.2 1 L
s
.25 .99625 m
.25 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.45 .99625 m
.45 1 L
s
.55 .99625 m
.55 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.75 .99625 m
.75 1 L
s
.8 .99625 m
.8 1 L
s
.85 .99625 m
.85 1 L
s
.05 .99625 m
.05 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.80424 .55255 Mdot
0 0 1 r
.19576 .44745 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000hOol3000_Ool4000^Ool2
000`Ool4000bOol3000IOol003Uoo`03001oogoo02ioo`03001oogoo02ioo`04001oogoo000_Ool0
0`00Oomoo`0dOol00`00Oomoo`0HOol003Ioo`D0031oo`03001oogoo02eoo`04001oogoo000`Ool0
0`00Oomoo`0`Ool5000IOol0031oo`@0009oo`04001oogoo000ZOol40004Ool00`00Oomoo`0/Ool0
1000Oomoo`00<Goo00<007ooOol0;goo00@007ooOol001Yoo`00=goo00<007oo0000<7oo00@007oo
Ool002eoo`04001oogoo000_Ool01000Oomoo`00<Goo00<007oo00006Woo000hOol2000aOol2000_
Ool2000aOol2000cOol2000JOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
000KOooo00050001Ool001]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`40005oo`006goo00<007ooOol05goo00<007ooOol0<Goo00<007oo
Ool0<Goo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol05goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool000Uoo`03001oogoo009oo`8000Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`002Goo00<007ooOol01goo00@007ooOol000Aoo`03001oogoo
0?moo`5oo`40005oo`002Goo00<007ooOol02Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0000
0goo000000020005Ool00`00Oomoo`07Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`04
001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`@000Uoo`<000Ao
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80
005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`004goo00@007ooOol0
00Aoo`03001oogoo0?moo`5oo`40005oo`005Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo000=
Ool40003Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool001Aoo`03001oogoo00Aoo`03001oogoo
0?moo`5oo`40005oo`0057oo0`0017oo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool0
01]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`001goo10000goo0P0017oo0P001Goo
00<007ooOol0ogoo0Goo0@000Goo0007Ool00`00Oomoo`09Ool01000Oomoo`0017oo00<007ooOol0
ogoo0Goo0@000Goo0008Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool2003oOol1Ool20001Ool00003
Ool00000008000Aoo`03001oogoo00Qoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`001goo00@0
07ooOol000Uoo`03001oogoo00Aoo`03001oogoo0?moo`5oo`40005oo`0027oo0P002Woo0`0017oo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo
0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo02eoo`H07leoo`40005oo`00
6goo00<007ooOol0;7oo200Oc7oo0@000Goo000KOol00`00Oomoo`0[Ool:01o;Ool10001Ool001]o
o`03001oogoo02Yoo``07lYoo`40005oo`006goo00<007ooOol0:Woo300ObWoo0@000Goo000KOol0
0`00Oomoo`0ZOol<01o:Ool10001Ool001]oo`8002]oo``07lUoo`80005oo`006goo00<007ooOol0
:Woo300ObWoo0@000Goo000KOol00`00Oomoo`0ZOol<01o:Ool10001Ool001]oo`03001oogoo02]o
o`X07l]oo`40005oo`006goo00<007ooOol0;7oo200Oc7oo0@000Goo000KOol00`00Oomoo`0]Ool6
01o=Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000DOol20005Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo
0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool2003oOol1Ool20001Ool0
01=oo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool00`00
Oomoo`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005o
o`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3;Ool6O00_Ool10001Ool001]o
o`03001oogoo0<Yoo`Ql02ioo`40005oo`006goo00<007ooOol0bGoo2W`0;Goo0@000Goo000KOol0
0`00Oomoo`38Ool<O00/Ool10001Ool001]oo`03001oogoo0<Qoo`al02aoo`40005oo`006goo0P00
bGoo37`0:goo0P000Goo000KOol00`00Oomoo`38Ool<O00/Ool10001Ool001]oo`03001oogoo0<Qo
o`al02aoo`40005oo`006goo00<007ooOol0b7oo37`0;7oo0@000Goo000KOol00`00Oomoo`39Ool:
O00]Ool10001Ool001]oo`03001oogoo0<Yoo`Ql02ioo`40005oo`006goo0P00c7oo1W`0;Woo0P00
0Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool000Moo`@000=oo`8000Aoo`8000Eoo`03001oogoo0?moo`5oo`40005o
o`001goo00<007ooOol02Goo00@007ooOol000Aoo`03001oogoo0?moo`5oo`40005oo`0027oo00<0
07ooOol02goo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0009Ool00`00Oomoo`08Ool20005Ool0
0`00Oomoo`3oOol1Ool10001Ool000Moo`04001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3o
Ool1Ool10001Ool000Qoo`8000Yoo`<000Aoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`0057oo0P001Goo00<007ooOol0ogoo0Goo0@000Goo000COol01000Oomoo`0017oo00<0
07ooOol0ogoo0Goo0@000Goo000FOol00`00Oomoo`02Ool2003oOol1Ool20001Ool001Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`0057oo00<007ooOol017oo00<007ooOol0ogoo0Goo0@000Goo
000DOol30004Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo0009Ool00`00Oomoo`02Ool20004Ool20005Ool00`00Oomo
o`3oOol1Ool10001Ool000Uoo`03001oogoo00Moo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool1
0001Ool000Uoo`03001oogoo00Yoo`03001oogoo009oo`800?moo`5oo`80005oo`002Woo00<007oo
Ool01goo0P001Goo00<007ooOol0ogoo0Goo0@000Goo0007Ool01000Oomoo`002Goo00<007ooOol0
17oo00<007ooOol0ogoo0Goo0@000Goo0007Ool40009Ool30004Ool00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001o
ogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool000eoo`D0009oo`8000Eoo`03001oogoo01Moo`03001oogoo035o
o`03001oogoo035oo`03001oogoo031oo`03001oogoo035oo`03001oogoo01Moo`40005oo`003goo
00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`40005oo`003goo00D007ooOomoo`00009oo`03001o
ogoo009oool000D0005oo`003goo00D007ooOomoo`00009oo`03001oogoo0?moo`Qoo`003goo00D0
07ooOomoo`00009oo`03001oogoo0?moo`Qoo`003Woo0P0017oo0P00ogoo2goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.04945, -11.3526, 0.0385168, \
0.0770336}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.5 0.05 [
[.1 -0.0125 -6 -9 ]
[.1 -0.0125 6 0 ]
[.3 -0.0125 -6 -9 ]
[.3 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7 -0.0125 -3 -9 ]
[.7 -0.0125 3 0 ]
[.9 -0.0125 -3 -9 ]
[.9 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -24 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-4)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-2)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(2)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(4)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-7.5)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-5)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-2.5)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(2.5)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(5)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(7.5)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(10)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
.1 .99375 m
.1 1 L
s
.3 .99375 m
.3 1 L
s
.5 .99375 m
.5 1 L
s
.7 .99375 m
.7 1 L
s
.9 .99375 m
.9 1 L
s
.125 Mabswid
.15 .99625 m
.15 1 L
s
.2 .99625 m
.2 1 L
s
.25 .99625 m
.25 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.45 .99625 m
.45 1 L
s
.55 .99625 m
.55 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.75 .99625 m
.75 1 L
s
.8 .99625 m
.8 1 L
s
.85 .99625 m
.85 1 L
s
.05 .99625 m
.05 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.82052 .55567 Mdot
0 0 1 r
.17948 .44433 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000hOol3000_Ool4000^Ool2
000`Ool4000bOol3000IOol003Uoo`03001oogoo02ioo`03001oogoo02ioo`04001oogoo000_Ool0
0`00Oomoo`0dOol00`00Oomoo`0HOol003Ioo`D0031oo`03001oogoo02eoo`04001oogoo000`Ool0
0`00Oomoo`0`Ool5000IOol0031oo`@0009oo`04001oogoo000ZOol40004Ool00`00Oomoo`0/Ool0
1000Oomoo`00<Goo00<007ooOol0;goo00@007ooOol001Yoo`00=goo00<007oo0000<7oo00@007oo
Ool002eoo`04001oogoo000_Ool01000Oomoo`00<Goo00<007oo00006Woo000hOol2000aOol2000_
Ool2000aOol2000cOol2000JOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
000KOooo00050001Ool001]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`40005oo`006goo00<007ooOol05goo00<007ooOol0<Goo00<007oo
Ool0<Goo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol05goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool000Uoo`03001oogoo009oo`8000Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`002Goo00<007ooOol01goo00@007ooOol000Aoo`03001oogoo
0?moo`5oo`40005oo`002Goo00<007ooOol02Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0000
0goo000000020005Ool00`00Oomoo`07Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`04
001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`@000Uoo`<000Ao
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80
005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`004goo00@007ooOol0
00Aoo`03001oogoo0?moo`5oo`40005oo`005Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo000=
Ool40003Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool001Aoo`03001oogoo00Aoo`03001oogoo
0?moo`5oo`40005oo`0057oo0`0017oo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool0
01]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`001goo10000goo0P0017oo0P001Goo
00<007ooOol0ogoo0Goo0@000Goo0007Ool00`00Oomoo`09Ool01000Oomoo`0017oo00<007ooOol0
ogoo0Goo0@000Goo0008Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool2003oOol1Ool20001Ool00003
Ool00000008000Aoo`03001oogoo00Qoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`001goo00@0
07ooOol000Uoo`03001oogoo00Aoo`03001oogoo0?moo`5oo`40005oo`0027oo0P002Woo0`0017oo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo
0Goo0@000Goo000KOol2000YOol601oAOol20001Ool001]oo`03001oogoo02Moo`P07m5oo`40005o
o`006goo00<007ooOol09Woo2P0Od7oo0@000Goo000KOol00`00Oomoo`0UOol<01o?Ool10001Ool0
01]oo`03001oogoo02Eoo``07lmoo`40005oo`006goo00<007ooOol09Goo300Ocgoo0@000Goo000K
Ool00`00Oomoo`0UOol<01o?Ool10001Ool001]oo`8002Ioo``07lioo`80005oo`006goo00<007oo
Ool09Goo300Ocgoo0@000Goo000KOol00`00Oomoo`0VOol:01o@Ool10001Ool001]oo`03001oogoo
02Moo`P07m5oo`40005oo`006goo00<007ooOol0:7oo1P0OdWoo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000DOol20005Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo
0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool2003oOol1Ool20001Ool0
01=oo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool00`00
Oomoo`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005o
o`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0<moo`Il02]oo`40005oo`006goo00<007ooOol0cWoo27`0:Woo0@000Goo000KOol00`00
Oomoo`3=Ool:O00YOol10001Ool001]oo`03001oogoo0<aoo`al02Qoo`40005oo`006goo0P00cGoo
37`09goo0P000Goo000KOol00`00Oomoo`3<Ool<O00XOol10001Ool001]oo`03001oogoo0<aoo`al
02Qoo`40005oo`006goo00<007ooOol0c7oo37`0:7oo0@000Goo000KOol00`00Oomoo`3<Ool<O00X
Ool10001Ool001]oo`03001oogoo0<eoo`Yl02Uoo`40005oo`006goo0P00cgoo27`0:Goo0P000Goo
000KOol00`00Oomoo`3?Ool6O00[Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool000Moo`@000=oo`8000Aoo`8000Eoo`03001oogoo0?moo`5oo`40005o
o`001goo00<007ooOol02Goo00@007ooOol000Aoo`03001oogoo0?moo`5oo`40005oo`0027oo00<0
07ooOol02goo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0009Ool00`00Oomoo`08Ool20005Ool0
0`00Oomoo`3oOol1Ool10001Ool000Moo`04001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3o
Ool1Ool10001Ool000Qoo`8000Yoo`<000Aoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`0057oo0P001Goo00<007ooOol0ogoo0Goo0@000Goo000COol01000Oomoo`0017oo00<0
07ooOol0ogoo0Goo0@000Goo000FOol00`00Oomoo`02Ool2003oOol1Ool20001Ool001Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`0057oo00<007ooOol017oo00<007ooOol0ogoo0Goo0@000Goo
000DOol30004Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo0009Ool00`00Oomoo`02Ool20004Ool20005Ool00`00Oomo
o`3oOol1Ool10001Ool000Uoo`03001oogoo00Moo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool1
0001Ool000Uoo`03001oogoo00Yoo`03001oogoo009oo`800?moo`5oo`80005oo`002Woo00<007oo
Ool01goo0P001Goo00<007ooOol0ogoo0Goo0@000Goo0007Ool01000Oomoo`002Goo00<007ooOol0
17oo00<007ooOol0ogoo0Goo0@000Goo0007Ool40009Ool30004Ool00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001o
ogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool000eoo`D0009oo`8000Eoo`03001oogoo01Moo`03001oogoo035o
o`03001oogoo035oo`03001oogoo031oo`03001oogoo035oo`03001oogoo01Moo`40005oo`003goo
00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`40005oo`003goo00D007ooOomoo`00009oo`03001o
ogoo009oool000D0005oo`003goo00D007ooOomoo`00009oo`03001oogoo0?moo`Qoo`003goo00D0
07ooOomoo`00009oo`03001oogoo0?moo`Qoo`003Woo0P0017oo0P00ogoo2goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.04945, -11.3526, 0.0385168, \
0.0770336}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.5 0.05 [
[.1 -0.0125 -6 -9 ]
[.1 -0.0125 6 0 ]
[.3 -0.0125 -6 -9 ]
[.3 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7 -0.0125 -3 -9 ]
[.7 -0.0125 3 0 ]
[.9 -0.0125 -3 -9 ]
[.9 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -24 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-4)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-2)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(2)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(4)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-7.5)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-5)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-2.5)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(2.5)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(5)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(7.5)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(10)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
.1 .99375 m
.1 1 L
s
.3 .99375 m
.3 1 L
s
.5 .99375 m
.5 1 L
s
.7 .99375 m
.7 1 L
s
.9 .99375 m
.9 1 L
s
.125 Mabswid
.15 .99625 m
.15 1 L
s
.2 .99625 m
.2 1 L
s
.25 .99625 m
.25 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.45 .99625 m
.45 1 L
s
.55 .99625 m
.55 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.75 .99625 m
.75 1 L
s
.8 .99625 m
.8 1 L
s
.85 .99625 m
.85 1 L
s
.05 .99625 m
.05 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.83535 .55849 Mdot
0 0 1 r
.16465 .44151 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000hOol3000_Ool4000^Ool2
000`Ool4000bOol3000IOol003Uoo`03001oogoo02ioo`03001oogoo02ioo`04001oogoo000_Ool0
0`00Oomoo`0dOol00`00Oomoo`0HOol003Ioo`D0031oo`03001oogoo02eoo`04001oogoo000`Ool0
0`00Oomoo`0`Ool5000IOol0031oo`@0009oo`04001oogoo000ZOol40004Ool00`00Oomoo`0/Ool0
1000Oomoo`00<Goo00<007ooOol0;goo00@007ooOol001Yoo`00=goo00<007oo0000<7oo00@007oo
Ool002eoo`04001oogoo000_Ool01000Oomoo`00<Goo00<007oo00006Woo000hOol2000aOol2000_
Ool2000aOol2000cOol2000JOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
000KOooo00050001Ool001]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`40005oo`006goo00<007ooOol05goo00<007ooOol0<Goo00<007oo
Ool0<Goo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol05goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool000Uoo`03001oogoo009oo`8000Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`002Goo00<007ooOol01goo00@007ooOol000Aoo`03001oogoo
0?moo`5oo`40005oo`002Goo00<007ooOol02Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0000
0goo000000020005Ool00`00Oomoo`07Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`04
001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`@000Uoo`<000Ao
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80
005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`004goo00@007ooOol0
00Aoo`03001oogoo0?moo`5oo`40005oo`005Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo000=
Ool40003Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool001Aoo`03001oogoo00Aoo`03001oogoo
0?moo`5oo`40005oo`0057oo0`0017oo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool0
01]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`001goo10000goo0P0017oo0P001Goo
00<007ooOol0ogoo0Goo0@000Goo0007Ool00`00Oomoo`09Ool01000Oomoo`0017oo00<007ooOol0
ogoo0Goo0@000Goo0008Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool2003oOol1Ool20001Ool00003
Ool00000008000Aoo`03001oogoo00Qoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`001goo00@0
07ooOol000Uoo`03001oogoo00Aoo`03001oogoo0?moo`5oo`40005oo`0027oo0P002Woo0`0017oo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo
0Goo0@000Goo000KOol2000VOol601oDOol20001Ool001]oo`03001oogoo02Aoo`P07mAoo`40005o
o`006goo00<007ooOol08goo2P0Odgoo0@000Goo000KOol00`00Oomoo`0ROol<01oBOol10001Ool0
01]oo`03001oogoo029oo``07m9oo`40005oo`006goo00<007ooOol08Woo300OdWoo0@000Goo000K
Ool00`00Oomoo`0ROol<01oBOol10001Ool001]oo`8002=oo``07m5oo`80005oo`006goo00<007oo
Ool08Woo300OdWoo0@000Goo000KOol00`00Oomoo`0SOol:01oCOol10001Ool001]oo`03001oogoo
02Aoo`P07mAoo`40005oo`006goo00<007ooOol09Goo1P0OeGoo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000DOol20005Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo
0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool2003oOol1Ool20001Ool0
01=oo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool00`00
Oomoo`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005o
o`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0dgoo1W`09goo0@000Goo000KOol00`00Oomo
o`3BOol8O00VOol10001Ool001]oo`03001oogoo0=5oo`Yl02Eoo`40005oo`006goo0P00dGoo37`0
8goo0P000Goo000KOol00`00Oomoo`3@Ool<O00TOol10001Ool001]oo`03001oogoo0=1oo`al02Ao
o`40005oo`006goo00<007ooOol0d7oo37`097oo0@000Goo000KOol00`00Oomoo`3@Ool<O00TOol1
0001Ool001]oo`03001oogoo0=1oo`al02Aoo`40005oo`006goo0P00dWoo2W`097oo0P000Goo000K
Ool00`00Oomoo`3BOol8O00VOol10001Ool001]oo`03001oogoo0==oo`Il02Moo`40005oo`006goo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool000Moo`@000=oo`8000Aoo`8000Eoo`03001oogoo0?moo`5oo`40005o
o`001goo00<007ooOol02Goo00@007ooOol000Aoo`03001oogoo0?moo`5oo`40005oo`0027oo00<0
07ooOol02goo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0009Ool00`00Oomoo`08Ool20005Ool0
0`00Oomoo`3oOol1Ool10001Ool000Moo`04001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3o
Ool1Ool10001Ool000Qoo`8000Yoo`<000Aoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`0057oo0P001Goo00<007ooOol0ogoo0Goo0@000Goo000COol01000Oomoo`0017oo00<0
07ooOol0ogoo0Goo0@000Goo000FOol00`00Oomoo`02Ool2003oOol1Ool20001Ool001Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`0057oo00<007ooOol017oo00<007ooOol0ogoo0Goo0@000Goo
000DOol30004Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo0009Ool00`00Oomoo`02Ool20004Ool20005Ool00`00Oomo
o`3oOol1Ool10001Ool000Uoo`03001oogoo00Moo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool1
0001Ool000Uoo`03001oogoo00Yoo`03001oogoo009oo`800?moo`5oo`80005oo`002Woo00<007oo
Ool01goo0P001Goo00<007ooOol0ogoo0Goo0@000Goo0007Ool01000Oomoo`002Goo00<007ooOol0
17oo00<007ooOol0ogoo0Goo0@000Goo0007Ool40009Ool30004Ool00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001o
ogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool000eoo`D0009oo`8000Eoo`03001oogoo01Moo`03001oogoo035o
o`03001oogoo035oo`03001oogoo031oo`03001oogoo035oo`03001oogoo01Moo`40005oo`003goo
00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`40005oo`003goo00D007ooOomoo`00009oo`03001o
ogoo009oool000D0005oo`003goo00D007ooOomoo`00009oo`03001oogoo0?moo`Qoo`003goo00D0
07ooOomoo`00009oo`03001oogoo0?moo`Qoo`003Woo0P0017oo0P00ogoo2goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.04945, -11.3526, 0.0385168, \
0.0770336}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.5 0.05 [
[.1 -0.0125 -6 -9 ]
[.1 -0.0125 6 0 ]
[.3 -0.0125 -6 -9 ]
[.3 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7 -0.0125 -3 -9 ]
[.7 -0.0125 3 0 ]
[.9 -0.0125 -3 -9 ]
[.9 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -24 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-4)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-2)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(2)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(4)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-7.5)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-5)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-2.5)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(2.5)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(5)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(7.5)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(10)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
.1 .99375 m
.1 1 L
s
.3 .99375 m
.3 1 L
s
.5 .99375 m
.5 1 L
s
.7 .99375 m
.7 1 L
s
.9 .99375 m
.9 1 L
s
.125 Mabswid
.15 .99625 m
.15 1 L
s
.2 .99625 m
.2 1 L
s
.25 .99625 m
.25 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.45 .99625 m
.45 1 L
s
.55 .99625 m
.55 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.75 .99625 m
.75 1 L
s
.8 .99625 m
.8 1 L
s
.85 .99625 m
.85 1 L
s
.05 .99625 m
.05 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.84902 .56108 Mdot
0 0 1 r
.15098 .43892 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000hOol3000_Ool4000^Ool2
000`Ool4000bOol3000IOol003Uoo`03001oogoo02ioo`03001oogoo02ioo`04001oogoo000_Ool0
0`00Oomoo`0dOol00`00Oomoo`0HOol003Ioo`D0031oo`03001oogoo02eoo`04001oogoo000`Ool0
0`00Oomoo`0`Ool5000IOol0031oo`@0009oo`04001oogoo000ZOol40004Ool00`00Oomoo`0/Ool0
1000Oomoo`00<Goo00<007ooOol0;goo00@007ooOol001Yoo`00=goo00<007oo0000<7oo00@007oo
Ool002eoo`04001oogoo000_Ool01000Oomoo`00<Goo00<007oo00006Woo000hOol2000aOol2000_
Ool2000aOol2000cOol2000JOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
000KOooo00050001Ool001]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`40005oo`006goo00<007ooOol05goo00<007ooOol0<Goo00<007oo
Ool0<Goo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol05goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool000Uoo`03001oogoo009oo`8000Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`002Goo00<007ooOol01goo00@007ooOol000Aoo`03001oogoo
0?moo`5oo`40005oo`002Goo00<007ooOol02Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0000
0goo000000020005Ool00`00Oomoo`07Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`04
001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`@000Uoo`<000Ao
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80
005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`004goo00@007ooOol0
00Aoo`03001oogoo0?moo`5oo`40005oo`005Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo000=
Ool40003Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool001Aoo`03001oogoo00Aoo`03001oogoo
0?moo`5oo`40005oo`0057oo0`0017oo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool0
01]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`001goo10000goo0P0017oo0P001Goo
00<007ooOol0ogoo0Goo0@000Goo0007Ool00`00Oomoo`09Ool01000Oomoo`0017oo00<007ooOol0
ogoo0Goo0@000Goo0008Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool2003oOol1Ool20001Ool00003
Ool00000008000Aoo`03001oogoo00Qoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`001goo00@0
07ooOol000Uoo`03001oogoo00Aoo`03001oogoo0?moo`5oo`40005oo`0027oo0P002Woo0`0017oo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol08Goo
1P0OfGoo0@000Goo000KOol2000QOol801oGOol20001Ool001]oo`03001oogoo01moo`X07mMoo`40
005oo`006goo00<007ooOol07Woo300OeWoo0@000Goo000KOol00`00Oomoo`0NOol<01oFOol10001
Ool001]oo`03001oogoo01ioo``07mIoo`40005oo`006goo00<007ooOol07Woo300OeWoo0@000Goo
000KOol00`00Oomoo`0NOol<01oFOol10001Ool001]oo`8001moo``07mEoo`80005oo`006goo00<0
07ooOol07goo2P0Oegoo0@000Goo000KOol00`00Oomoo`0POol801oHOol10001Ool001]oo`03001o
ogoo025oo`H07mUoo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000DOol20005Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo
0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool2003oOol1Ool20001Ool0
01=oo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool00`00
Oomoo`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005o
o`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3F
Ool6O00TOol10001Ool001]oo`03001oogoo0=Eoo`Ql02=oo`40005oo`006goo0P00eGoo2W`08Goo
0P000Goo000KOol00`00Oomoo`3COol<O00QOol10001Ool001]oo`03001oogoo0==oo`al025oo`40
005oo`006goo00<007ooOol0dgoo37`08Goo0@000Goo000KOol00`00Oomoo`3COol<O00QOol10001
Ool001]oo`03001oogoo0==oo`al025oo`40005oo`006goo0P00e7oo37`087oo0P000Goo000KOol0
0`00Oomoo`3DOol:O00ROol10001Ool001]oo`03001oogoo0=Eoo`Ql02=oo`40005oo`006goo00<0
07ooOol0eWoo1W`097oo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool000Moo`@000=oo`8000Aoo`8000Eoo`03001oogoo0?moo`5oo`40005o
o`001goo00<007ooOol02Goo00@007ooOol000Aoo`03001oogoo0?moo`5oo`40005oo`0027oo00<0
07ooOol02goo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0009Ool00`00Oomoo`08Ool20005Ool0
0`00Oomoo`3oOol1Ool10001Ool000Moo`04001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3o
Ool1Ool10001Ool000Qoo`8000Yoo`<000Aoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`0057oo0P001Goo00<007ooOol0ogoo0Goo0@000Goo000COol01000Oomoo`0017oo00<0
07ooOol0ogoo0Goo0@000Goo000FOol00`00Oomoo`02Ool2003oOol1Ool20001Ool001Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`0057oo00<007ooOol017oo00<007ooOol0ogoo0Goo0@000Goo
000DOol30004Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo0009Ool00`00Oomoo`02Ool20004Ool20005Ool00`00Oomo
o`3oOol1Ool10001Ool000Uoo`03001oogoo00Moo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool1
0001Ool000Uoo`03001oogoo00Yoo`03001oogoo009oo`800?moo`5oo`80005oo`002Woo00<007oo
Ool01goo0P001Goo00<007ooOol0ogoo0Goo0@000Goo0007Ool01000Oomoo`002Goo00<007ooOol0
17oo00<007ooOol0ogoo0Goo0@000Goo0007Ool40009Ool30004Ool00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001o
ogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool000eoo`D0009oo`8000Eoo`03001oogoo01Moo`03001oogoo035o
o`03001oogoo035oo`03001oogoo031oo`03001oogoo035oo`03001oogoo01Moo`40005oo`003goo
00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`40005oo`003goo00D007ooOomoo`00009oo`03001o
ogoo009oool000D0005oo`003goo00D007ooOomoo`00009oo`03001oogoo0?moo`Qoo`003goo00D0
07ooOomoo`00009oo`03001oogoo0?moo`Qoo`003Woo0P0017oo0P00ogoo2goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.04945, -11.3526, 0.0385168, \
0.0770336}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.5 0.05 [
[.1 -0.0125 -6 -9 ]
[.1 -0.0125 6 0 ]
[.3 -0.0125 -6 -9 ]
[.3 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7 -0.0125 -3 -9 ]
[.7 -0.0125 3 0 ]
[.9 -0.0125 -3 -9 ]
[.9 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -24 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-4)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-2)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(2)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(4)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-7.5)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-5)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-2.5)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(2.5)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(5)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(7.5)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(10)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
.1 .99375 m
.1 1 L
s
.3 .99375 m
.3 1 L
s
.5 .99375 m
.5 1 L
s
.7 .99375 m
.7 1 L
s
.9 .99375 m
.9 1 L
s
.125 Mabswid
.15 .99625 m
.15 1 L
s
.2 .99625 m
.2 1 L
s
.25 .99625 m
.25 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.45 .99625 m
.45 1 L
s
.55 .99625 m
.55 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.75 .99625 m
.75 1 L
s
.8 .99625 m
.8 1 L
s
.85 .99625 m
.85 1 L
s
.05 .99625 m
.05 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.86172 .56347 Mdot
0 0 1 r
.13828 .43653 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000hOol3000_Ool4000^Ool2
000`Ool4000bOol3000IOol003Uoo`03001oogoo02ioo`03001oogoo02ioo`04001oogoo000_Ool0
0`00Oomoo`0dOol00`00Oomoo`0HOol003Ioo`D0031oo`03001oogoo02eoo`04001oogoo000`Ool0
0`00Oomoo`0`Ool5000IOol0031oo`@0009oo`04001oogoo000ZOol40004Ool00`00Oomoo`0/Ool0
1000Oomoo`00<Goo00<007ooOol0;goo00@007ooOol001Yoo`00=goo00<007oo0000<7oo00@007oo
Ool002eoo`04001oogoo000_Ool01000Oomoo`00<Goo00<007oo00006Woo000hOol2000aOol2000_
Ool2000aOol2000cOol2000JOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
000KOooo00050001Ool001]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`40005oo`006goo00<007ooOol05goo00<007ooOol0<Goo00<007oo
Ool0<Goo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol05goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool000Uoo`03001oogoo009oo`8000Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`002Goo00<007ooOol01goo00@007ooOol000Aoo`03001oogoo
0?moo`5oo`40005oo`002Goo00<007ooOol02Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0000
0goo000000020005Ool00`00Oomoo`07Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`04
001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`@000Uoo`<000Ao
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80
005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`004goo00@007ooOol0
00Aoo`03001oogoo0?moo`5oo`40005oo`005Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo000=
Ool40003Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool001Aoo`03001oogoo00Aoo`03001oogoo
0?moo`5oo`40005oo`0057oo0`0017oo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool0
01]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`001goo10000goo0P0017oo0P001Goo
00<007ooOol0ogoo0Goo0@000Goo0007Ool00`00Oomoo`09Ool01000Oomoo`0017oo00<007ooOol0
ogoo0Goo0@000Goo0008Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool2003oOol1Ool20001Ool00003
Ool00000008000Aoo`03001oogoo00Qoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`001goo00@0
07ooOol000Uoo`03001oogoo00Aoo`03001oogoo0?moo`5oo`40005oo`0027oo0P002Woo0`0017oo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo01ioo`H07maoo`40005oo`006goo00<007ooOol0
7Goo200Ofgoo0@000Goo000KOol2000MOol:01oIOol20001Ool001]oo`03001oogoo01]oo``07mUo
o`40005oo`006goo00<007ooOol06goo300OfGoo0@000Goo000KOol00`00Oomoo`0KOol<01oIOol1
0001Ool001]oo`03001oogoo01]oo``07mUoo`40005oo`006goo00<007ooOol06goo300OfGoo0@00
0Goo000KOol00`00Oomoo`0KOol<01oIOol10001Ool001]oo`8001eoo`X07mUoo`80005oo`006goo
00<007ooOol07Goo200Ofgoo0@000Goo000KOol00`00Oomoo`0NOol601oLOol10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000DOol20005Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo
0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool2003oOol1Ool20001Ool0
01=oo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool00`00
Oomoo`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005o
o`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3J
Ool6O00POol10001Ool001]oo`03001oogoo0=Uoo`Ql01moo`40005oo`006goo0P00fGoo2W`07Goo
0P000Goo000KOol00`00Oomoo`3GOol<O00MOol10001Ool001]oo`03001oogoo0=Moo`al01eoo`40
005oo`006goo00<007ooOol0egoo37`07Goo0@000Goo000KOol00`00Oomoo`3GOol<O00MOol10001
Ool001]oo`03001oogoo0=Moo`al01eoo`40005oo`006goo0P00f7oo37`077oo0P000Goo000KOol0
0`00Oomoo`3HOol:O00NOol10001Ool001]oo`03001oogoo0=Uoo`Ql01moo`40005oo`006goo00<0
07ooOol0fWoo1W`087oo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool000Moo`@000=oo`8000Aoo`8000Eoo`03001oogoo0?moo`5oo`40005o
o`001goo00<007ooOol02Goo00@007ooOol000Aoo`03001oogoo0?moo`5oo`40005oo`0027oo00<0
07ooOol02goo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0009Ool00`00Oomoo`08Ool20005Ool0
0`00Oomoo`3oOol1Ool10001Ool000Moo`04001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3o
Ool1Ool10001Ool000Qoo`8000Yoo`<000Aoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`0057oo0P001Goo00<007ooOol0ogoo0Goo0@000Goo000COol01000Oomoo`0017oo00<0
07ooOol0ogoo0Goo0@000Goo000FOol00`00Oomoo`02Ool2003oOol1Ool20001Ool001Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`0057oo00<007ooOol017oo00<007ooOol0ogoo0Goo0@000Goo
000DOol30004Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo0009Ool00`00Oomoo`02Ool20004Ool20005Ool00`00Oomo
o`3oOol1Ool10001Ool000Uoo`03001oogoo00Moo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool1
0001Ool000Uoo`03001oogoo00Yoo`03001oogoo009oo`800?moo`5oo`80005oo`002Woo00<007oo
Ool01goo0P001Goo00<007ooOol0ogoo0Goo0@000Goo0007Ool01000Oomoo`002Goo00<007ooOol0
17oo00<007ooOol0ogoo0Goo0@000Goo0007Ool40009Ool30004Ool00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001o
ogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool000eoo`D0009oo`8000Eoo`03001oogoo01Moo`03001oogoo035o
o`03001oogoo035oo`03001oogoo031oo`03001oogoo035oo`03001oogoo01Moo`40005oo`003goo
00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`40005oo`003goo00D007ooOomoo`00009oo`03001o
ogoo009oool000D0005oo`003goo00D007ooOomoo`00009oo`03001oogoo0?moo`Qoo`003goo00D0
07ooOomoo`00009oo`03001oogoo0?moo`Qoo`003Woo0P0017oo0P00ogoo2goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.04945, -11.3526, 0.0385168, \
0.0770336}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.5 0.05 [
[.1 -0.0125 -6 -9 ]
[.1 -0.0125 6 0 ]
[.3 -0.0125 -6 -9 ]
[.3 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7 -0.0125 -3 -9 ]
[.7 -0.0125 3 0 ]
[.9 -0.0125 -3 -9 ]
[.9 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -24 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-4)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-2)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(2)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(4)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-7.5)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-5)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-2.5)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(2.5)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(5)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(7.5)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(10)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
.1 .99375 m
.1 1 L
s
.3 .99375 m
.3 1 L
s
.5 .99375 m
.5 1 L
s
.7 .99375 m
.7 1 L
s
.9 .99375 m
.9 1 L
s
.125 Mabswid
.15 .99625 m
.15 1 L
s
.2 .99625 m
.2 1 L
s
.25 .99625 m
.25 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.45 .99625 m
.45 1 L
s
.55 .99625 m
.55 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.75 .99625 m
.75 1 L
s
.8 .99625 m
.8 1 L
s
.85 .99625 m
.85 1 L
s
.05 .99625 m
.05 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.87361 .56571 Mdot
0 0 1 r
.12639 .43429 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000hOol3000_Ool4000^Ool2
000`Ool4000bOol3000IOol003Uoo`03001oogoo02ioo`03001oogoo02ioo`04001oogoo000_Ool0
0`00Oomoo`0dOol00`00Oomoo`0HOol003Ioo`D0031oo`03001oogoo02eoo`04001oogoo000`Ool0
0`00Oomoo`0`Ool5000IOol0031oo`@0009oo`04001oogoo000ZOol40004Ool00`00Oomoo`0/Ool0
1000Oomoo`00<Goo00<007ooOol0;goo00@007ooOol001Yoo`00=goo00<007oo0000<7oo00@007oo
Ool002eoo`04001oogoo000_Ool01000Oomoo`00<Goo00<007oo00006Woo000hOol2000aOol2000_
Ool2000aOol2000cOol2000JOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
000KOooo00050001Ool001]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`40005oo`006goo00<007ooOol05goo00<007ooOol0<Goo00<007oo
Ool0<Goo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol05goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool000Uoo`03001oogoo009oo`8000Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`002Goo00<007ooOol01goo00@007ooOol000Aoo`03001oogoo
0?moo`5oo`40005oo`002Goo00<007ooOol02Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0000
0goo000000020005Ool00`00Oomoo`07Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`04
001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`@000Uoo`<000Ao
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80
005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`004goo00@007ooOol0
00Aoo`03001oogoo0?moo`5oo`40005oo`005Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo000=
Ool40003Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool001Aoo`03001oogoo00Aoo`03001oogoo
0?moo`5oo`40005oo`0057oo0`0017oo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool0
01]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`001goo10000goo0P0017oo0P001Goo
00<007ooOol0ogoo0Goo0@000Goo0007Ool00`00Oomoo`09Ool01000Oomoo`0017oo00<007ooOol0
ogoo0Goo0@000Goo0008Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool2003oOol1Ool20001Ool00003
Ool00000008000Aoo`03001oogoo00Qoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`001goo00@0
07ooOol000Uoo`03001oogoo00Aoo`03001oogoo0?moo`5oo`40005oo`0027oo0P002Woo0`0017oo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo01]oo`H07mmoo`40005oo`006goo00<007ooOol0
6Woo200OgWoo0@000Goo000KOol2000JOol:01oLOol20001Ool001]oo`03001oogoo01Qoo``07mao
o`40005oo`006goo00<007ooOol067oo300Og7oo0@000Goo000KOol00`00Oomoo`0HOol<01oLOol1
0001Ool001]oo`03001oogoo01Qoo``07maoo`40005oo`006goo00<007ooOol067oo300Og7oo0@00
0Goo000KOol00`00Oomoo`0HOol<01oLOol10001Ool001]oo`8001Yoo`X07maoo`80005oo`006goo
00<007ooOol06Woo200OgWoo0@000Goo000KOol00`00Oomoo`0KOol601oOOol10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000DOol20005Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo
0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool2003oOol1Ool20001Ool0
01=oo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool00`00
Oomoo`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005o
o`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0=eoo`Il01eoo`40005oo`006goo0P00gGoo27`06goo0P00
0Goo000KOol00`00Oomoo`3KOol:O00KOol10001Ool001]oo`03001oogoo0=Yoo`al01Yoo`40005o
o`006goo00<007ooOol0fWoo37`06Woo0@000Goo000KOol00`00Oomoo`3JOol<O00JOol10001Ool0
01]oo`03001oogoo0=Yoo`al01Yoo`40005oo`006goo0P00fgoo37`06Goo0P000Goo000KOol00`00
Oomoo`3JOol<O00JOol10001Ool001]oo`03001oogoo0=]oo`Yl01]oo`40005oo`006goo00<007oo
Ool0g7oo27`077oo0@000Goo000KOol00`00Oomoo`3MOol6O00MOol10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool000Moo`@000=oo`8000Aoo`8000Eoo`03001oogoo0?moo`5oo`40005o
o`001goo00<007ooOol02Goo00@007ooOol000Aoo`03001oogoo0?moo`5oo`40005oo`0027oo00<0
07ooOol02goo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0009Ool00`00Oomoo`08Ool20005Ool0
0`00Oomoo`3oOol1Ool10001Ool000Moo`04001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3o
Ool1Ool10001Ool000Qoo`8000Yoo`<000Aoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`0057oo0P001Goo00<007ooOol0ogoo0Goo0@000Goo000COol01000Oomoo`0017oo00<0
07ooOol0ogoo0Goo0@000Goo000FOol00`00Oomoo`02Ool2003oOol1Ool20001Ool001Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`0057oo00<007ooOol017oo00<007ooOol0ogoo0Goo0@000Goo
000DOol30004Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo0009Ool00`00Oomoo`02Ool20004Ool20005Ool00`00Oomo
o`3oOol1Ool10001Ool000Uoo`03001oogoo00Moo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool1
0001Ool000Uoo`03001oogoo00Yoo`03001oogoo009oo`800?moo`5oo`80005oo`002Woo00<007oo
Ool01goo0P001Goo00<007ooOol0ogoo0Goo0@000Goo0007Ool01000Oomoo`002Goo00<007ooOol0
17oo00<007ooOol0ogoo0Goo0@000Goo0007Ool40009Ool30004Ool00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001o
ogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool000eoo`D0009oo`8000Eoo`03001oogoo01Moo`03001oogoo035o
o`03001oogoo035oo`03001oogoo031oo`03001oogoo035oo`03001oogoo01Moo`40005oo`003goo
00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`40005oo`003goo00D007ooOomoo`00009oo`03001o
ogoo009oool000D0005oo`003goo00D007ooOomoo`00009oo`03001oogoo0?moo`Qoo`003goo00D0
07ooOomoo`00009oo`03001oogoo0?moo`Qoo`003Woo0P0017oo0P00ogoo2goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.04945, -11.3526, 0.0385168, \
0.0770336}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.5 0.05 [
[.1 -0.0125 -6 -9 ]
[.1 -0.0125 6 0 ]
[.3 -0.0125 -6 -9 ]
[.3 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7 -0.0125 -3 -9 ]
[.7 -0.0125 3 0 ]
[.9 -0.0125 -3 -9 ]
[.9 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -24 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-4)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-2)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(2)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(4)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-7.5)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-5)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-2.5)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(2.5)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(5)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(7.5)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(10)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
.1 .99375 m
.1 1 L
s
.3 .99375 m
.3 1 L
s
.5 .99375 m
.5 1 L
s
.7 .99375 m
.7 1 L
s
.9 .99375 m
.9 1 L
s
.125 Mabswid
.15 .99625 m
.15 1 L
s
.2 .99625 m
.2 1 L
s
.25 .99625 m
.25 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.45 .99625 m
.45 1 L
s
.55 .99625 m
.55 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.75 .99625 m
.75 1 L
s
.8 .99625 m
.8 1 L
s
.85 .99625 m
.85 1 L
s
.05 .99625 m
.05 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.88481 .56782 Mdot
0 0 1 r
.11519 .43218 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000hOol3000_Ool4000^Ool2
000`Ool4000bOol3000IOol003Uoo`03001oogoo02ioo`03001oogoo02ioo`04001oogoo000_Ool0
0`00Oomoo`0dOol00`00Oomoo`0HOol003Ioo`D0031oo`03001oogoo02eoo`04001oogoo000`Ool0
0`00Oomoo`0`Ool5000IOol0031oo`@0009oo`04001oogoo000ZOol40004Ool00`00Oomoo`0/Ool0
1000Oomoo`00<Goo00<007ooOol0;goo00@007ooOol001Yoo`00=goo00<007oo0000<7oo00@007oo
Ool002eoo`04001oogoo000_Ool01000Oomoo`00<Goo00<007oo00006Woo000hOol2000aOol2000_
Ool2000aOol2000cOol2000JOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
000KOooo00050001Ool001]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`40005oo`006goo00<007ooOol05goo00<007ooOol0<Goo00<007oo
Ool0<Goo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol05goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool000Uoo`03001oogoo009oo`8000Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`002Goo00<007ooOol01goo00@007ooOol000Aoo`03001oogoo
0?moo`5oo`40005oo`002Goo00<007ooOol02Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0000
0goo000000020005Ool00`00Oomoo`07Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`04
001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`@000Uoo`<000Ao
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80
005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`004goo00@007ooOol0
00Aoo`03001oogoo0?moo`5oo`40005oo`005Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo000=
Ool40003Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool001Aoo`03001oogoo00Aoo`03001oogoo
0?moo`5oo`40005oo`0057oo0`0017oo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool0
01]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`001goo10000goo0P0017oo0P001Goo
00<007ooOol0ogoo0Goo0@000Goo0007Ool00`00Oomoo`09Ool01000Oomoo`0017oo00<007ooOol0
ogoo0Goo0@000Goo0008Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool2003oOol1Ool20001Ool00003
Ool00000008000Aoo`03001oogoo00Qoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`001goo00@0
07ooOol000Uoo`03001oogoo00Aoo`03001oogoo0?moo`5oo`40005oo`0027oo0P002Woo0`0017oo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`0HOol601oROol10001Ool001]oo`03001oogoo01Moo`P07n5oo`40005oo`006goo00<007oo
Ool05Woo2P0Oh7oo0@000Goo000KOol2000FOol<01oNOol20001Ool001]oo`03001oogoo01Eoo``0
7mmoo`40005oo`006goo00<007ooOol05Goo300Oggoo0@000Goo000KOol00`00Oomoo`0EOol<01oO
Ool10001Ool001]oo`03001oogoo01Eoo``07mmoo`40005oo`006goo00<007ooOol05Goo300Oggoo
0@000Goo000KOol00`00Oomoo`0FOol:01oPOol10001Ool001]oo`8001Qoo`P07n1oo`80005oo`00
6goo00<007ooOol067oo1P0OhWoo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000DOol20005Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo
0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool2003oOol1Ool20001Ool0
01=oo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool00`00
Oomoo`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005o
o`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0>1oo`Il01Yoo`40005oo`006goo0P00h7oo27`067oo0P00
0Goo000KOol00`00Oomoo`3NOol:O00HOol10001Ool001]oo`03001oogoo0=eoo`al01Moo`40005o
o`006goo00<007ooOol0gGoo37`05goo0@000Goo000KOol00`00Oomoo`3MOol<O00GOol10001Ool0
01]oo`03001oogoo0=eoo`al01Moo`40005oo`006goo0P00gWoo37`05Woo0P000Goo000KOol00`00
Oomoo`3MOol<O00GOol10001Ool001]oo`03001oogoo0=ioo`Yl01Qoo`40005oo`006goo00<007oo
Ool0ggoo27`06Goo0@000Goo000KOol00`00Oomoo`3POol6O00JOol10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool000Moo`@000=oo`8000Aoo`8000Eoo`03001oogoo0?moo`5oo`40005o
o`001goo00<007ooOol02Goo00@007ooOol000Aoo`03001oogoo0?moo`5oo`40005oo`0027oo00<0
07ooOol02goo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0009Ool00`00Oomoo`08Ool20005Ool0
0`00Oomoo`3oOol1Ool10001Ool000Moo`04001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3o
Ool1Ool10001Ool000Qoo`8000Yoo`<000Aoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`0057oo0P001Goo00<007ooOol0ogoo0Goo0@000Goo000COol01000Oomoo`0017oo00<0
07ooOol0ogoo0Goo0@000Goo000FOol00`00Oomoo`02Ool2003oOol1Ool20001Ool001Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`0057oo00<007ooOol017oo00<007ooOol0ogoo0Goo0@000Goo
000DOol30004Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo0009Ool00`00Oomoo`02Ool20004Ool20005Ool00`00Oomo
o`3oOol1Ool10001Ool000Uoo`03001oogoo00Moo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool1
0001Ool000Uoo`03001oogoo00Yoo`03001oogoo009oo`800?moo`5oo`80005oo`002Woo00<007oo
Ool01goo0P001Goo00<007ooOol0ogoo0Goo0@000Goo0007Ool01000Oomoo`002Goo00<007ooOol0
17oo00<007ooOol0ogoo0Goo0@000Goo0007Ool40009Ool30004Ool00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001o
ogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool000eoo`D0009oo`8000Eoo`03001oogoo01Moo`03001oogoo035o
o`03001oogoo035oo`03001oogoo031oo`03001oogoo035oo`03001oogoo01Moo`40005oo`003goo
00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`40005oo`003goo00D007ooOomoo`00009oo`03001o
ogoo009oool000D0005oo`003goo00D007ooOomoo`00009oo`03001oogoo0?moo`Qoo`003goo00D0
07ooOomoo`00009oo`03001oogoo0?moo`Qoo`003Woo0P0017oo0P00ogoo2goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.04945, -11.3526, 0.0385168, \
0.0770336}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.5 0.05 [
[.1 -0.0125 -6 -9 ]
[.1 -0.0125 6 0 ]
[.3 -0.0125 -6 -9 ]
[.3 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7 -0.0125 -3 -9 ]
[.7 -0.0125 3 0 ]
[.9 -0.0125 -3 -9 ]
[.9 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -24 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-4)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-2)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(2)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(4)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-7.5)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-5)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-2.5)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(2.5)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(5)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(7.5)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(10)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
.1 .99375 m
.1 1 L
s
.3 .99375 m
.3 1 L
s
.5 .99375 m
.5 1 L
s
.7 .99375 m
.7 1 L
s
.9 .99375 m
.9 1 L
s
.125 Mabswid
.15 .99625 m
.15 1 L
s
.2 .99625 m
.2 1 L
s
.25 .99625 m
.25 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.45 .99625 m
.45 1 L
s
.55 .99625 m
.55 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.75 .99625 m
.75 1 L
s
.8 .99625 m
.8 1 L
s
.85 .99625 m
.85 1 L
s
.05 .99625 m
.05 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.89542 .56981 Mdot
0 0 1 r
.10458 .43019 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000hOol3000_Ool4000^Ool2
000`Ool4000bOol3000IOol003Uoo`03001oogoo02ioo`03001oogoo02ioo`04001oogoo000_Ool0
0`00Oomoo`0dOol00`00Oomoo`0HOol003Ioo`D0031oo`03001oogoo02eoo`04001oogoo000`Ool0
0`00Oomoo`0`Ool5000IOol0031oo`@0009oo`04001oogoo000ZOol40004Ool00`00Oomoo`0/Ool0
1000Oomoo`00<Goo00<007ooOol0;goo00@007ooOol001Yoo`00=goo00<007oo0000<7oo00@007oo
Ool002eoo`04001oogoo000_Ool01000Oomoo`00<Goo00<007oo00006Woo000hOol2000aOol2000_
Ool2000aOol2000cOol2000JOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
000KOooo00050001Ool001]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`40005oo`006goo00<007ooOol05goo00<007ooOol0<Goo00<007oo
Ool0<Goo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol05goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool000Uoo`03001oogoo009oo`8000Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`002Goo00<007ooOol01goo00@007ooOol000Aoo`03001oogoo
0?moo`5oo`40005oo`002Goo00<007ooOol02Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0000
0goo000000020005Ool00`00Oomoo`07Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`04
001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`@000Uoo`<000Ao
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80
005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`004goo00@007ooOol0
00Aoo`03001oogoo0?moo`5oo`40005oo`005Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo000=
Ool40003Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool001Aoo`03001oogoo00Aoo`03001oogoo
0?moo`5oo`40005oo`0057oo0`0017oo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool0
01]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`001goo10000goo0P0017oo0P001Goo
00<007ooOol0ogoo0Goo0@000Goo0007Ool00`00Oomoo`09Ool01000Oomoo`0017oo00<007ooOol0
ogoo0Goo0@000Goo0008Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool2003oOol1Ool20001Ool00003
Ool00000008000Aoo`03001oogoo00Qoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`001goo00@0
07ooOol000Uoo`03001oogoo00Aoo`03001oogoo0?moo`5oo`40005oo`0027oo0P002Woo0`0017oo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`0EOol601oUOol10001Ool001]oo`03001oogoo01Aoo`P07nAoo`40005oo`006goo00<007oo
Ool04goo2P0Ohgoo0@000Goo000KOol2000COol<01oQOol20001Ool001]oo`03001oogoo019oo``0
7n9oo`40005oo`006goo00<007ooOol04Woo300OhWoo0@000Goo000KOol00`00Oomoo`0BOol<01oR
Ool10001Ool001]oo`03001oogoo019oo``07n9oo`40005oo`006goo00<007ooOol04Woo300OhWoo
0@000Goo000KOol00`00Oomoo`0COol:01oSOol10001Ool001]oo`8001Eoo`P07n=oo`80005oo`00
6goo00<007ooOol05Goo1P0OiGoo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000DOol20005Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo
0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool2003oOol1Ool20001Ool0
01=oo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool00`00
Oomoo`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005o
o`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00hgoo1W`05goo0P000Goo
000KOol00`00Oomoo`3QOol8O00GOol10001Ool001]oo`03001oogoo0>1oo`Yl01Ioo`40005oo`00
6goo00<007ooOol0ggoo37`05Goo0@000Goo000KOol00`00Oomoo`3OOol<O00EOol10001Ool001]o
o`03001oogoo0=moo`al01Eoo`40005oo`006goo0P00h7oo37`057oo0P000Goo000KOol00`00Oomo
o`3OOol<O00EOol10001Ool001]oo`03001oogoo0=moo`al01Eoo`40005oo`006goo00<007ooOol0
h7oo2W`05Woo0@000Goo000KOol00`00Oomoo`3QOol8O00GOol10001Ool001]oo`03001oogoo0>9o
o`Il01Qoo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool000Moo`@000=oo`8000Aoo`8000Eoo`03001oogoo0?moo`5oo`40005o
o`001goo00<007ooOol02Goo00@007ooOol000Aoo`03001oogoo0?moo`5oo`40005oo`0027oo00<0
07ooOol02goo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0009Ool00`00Oomoo`08Ool20005Ool0
0`00Oomoo`3oOol1Ool10001Ool000Moo`04001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3o
Ool1Ool10001Ool000Qoo`8000Yoo`<000Aoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`0057oo0P001Goo00<007ooOol0ogoo0Goo0@000Goo000COol01000Oomoo`0017oo00<0
07ooOol0ogoo0Goo0@000Goo000FOol00`00Oomoo`02Ool2003oOol1Ool20001Ool001Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`0057oo00<007ooOol017oo00<007ooOol0ogoo0Goo0@000Goo
000DOol30004Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo0009Ool00`00Oomoo`02Ool20004Ool20005Ool00`00Oomo
o`3oOol1Ool10001Ool000Uoo`03001oogoo00Moo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool1
0001Ool000Uoo`03001oogoo00Yoo`03001oogoo009oo`800?moo`5oo`80005oo`002Woo00<007oo
Ool01goo0P001Goo00<007ooOol0ogoo0Goo0@000Goo0007Ool01000Oomoo`002Goo00<007ooOol0
17oo00<007ooOol0ogoo0Goo0@000Goo0007Ool40009Ool30004Ool00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001o
ogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool000eoo`D0009oo`8000Eoo`03001oogoo01Moo`03001oogoo035o
o`03001oogoo035oo`03001oogoo031oo`03001oogoo035oo`03001oogoo01Moo`40005oo`003goo
00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`40005oo`003goo00D007ooOomoo`00009oo`03001o
ogoo009oool000D0005oo`003goo00D007ooOomoo`00009oo`03001oogoo0?moo`Qoo`003goo00D0
07ooOomoo`00009oo`03001oogoo0?moo`Qoo`003Woo0P0017oo0P00ogoo2goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.04945, -11.3526, 0.0385168, \
0.0770336}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.1 0.5 0.05 [
[.1 -0.0125 -6 -9 ]
[.1 -0.0125 6 0 ]
[.3 -0.0125 -6 -9 ]
[.3 -0.0125 6 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7 -0.0125 -3 -9 ]
[.7 -0.0125 3 0 ]
[.9 -0.0125 -3 -9 ]
[.9 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .125 -24 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -12 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -24 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -18 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -6 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -18 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.1 0 m
.1 .00625 L
s
[(-4)] .1 -0.0125 0 1 Mshowa
.3 0 m
.3 .00625 L
s
[(-2)] .3 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7 0 m
.7 .00625 L
s
[(2)] .7 -0.0125 0 1 Mshowa
.9 0 m
.9 .00625 L
s
[(4)] .9 -0.0125 0 1 Mshowa
.125 Mabswid
.15 0 m
.15 .00375 L
s
.2 0 m
.2 .00375 L
s
.25 0 m
.25 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.45 0 m
.45 .00375 L
s
.55 0 m
.55 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.75 0 m
.75 .00375 L
s
.8 0 m
.8 .00375 L
s
.85 0 m
.85 .00375 L
s
.05 0 m
.05 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .125 m
.00625 .125 L
s
[(-7.5)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-5)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-2.5)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(2.5)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(5)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(7.5)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(10)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
.1 .99375 m
.1 1 L
s
.3 .99375 m
.3 1 L
s
.5 .99375 m
.5 1 L
s
.7 .99375 m
.7 1 L
s
.9 .99375 m
.9 1 L
s
.125 Mabswid
.15 .99625 m
.15 1 L
s
.2 .99625 m
.2 1 L
s
.25 .99625 m
.25 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.45 .99625 m
.45 1 L
s
.55 .99625 m
.55 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.75 .99625 m
.75 1 L
s
.8 .99625 m
.8 1 L
s
.85 .99625 m
.85 1 L
s
.05 .99625 m
.05 1 L
s
.95 .99625 m
.95 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.05 w
.90549 .57169 Mdot
0 0 1 r
.09451 .42831 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000hOol3000_Ool4000^Ool2
000`Ool4000bOol3000IOol003Uoo`03001oogoo02ioo`03001oogoo02ioo`04001oogoo000_Ool0
0`00Oomoo`0dOol00`00Oomoo`0HOol003Ioo`D0031oo`03001oogoo02eoo`04001oogoo000`Ool0
0`00Oomoo`0`Ool5000IOol0031oo`@0009oo`04001oogoo000ZOol40004Ool00`00Oomoo`0/Ool0
1000Oomoo`00<Goo00<007ooOol0;goo00@007ooOol001Yoo`00=goo00<007oo0000<7oo00@007oo
Ool002eoo`04001oogoo000_Ool01000Oomoo`00<Goo00<007oo00006Woo000hOol2000aOol2000_
Ool2000aOol2000cOol2000JOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
000KOooo00050001Ool001]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Yoo`03001oogoo00Yoo`40005oo`006goo00<007ooOol05goo00<007ooOol0<Goo00<007oo
Ool0<Goo00<007ooOol0<7oo00<007ooOol0<Goo00<007ooOol05goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool000Uoo`03001oogoo009oo`8000Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`002Goo00<007ooOol01goo00@007ooOol000Aoo`03001oogoo
0?moo`5oo`40005oo`002Goo00<007ooOol02Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0000
0goo000000020005Ool00`00Oomoo`07Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`04
001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3oOol1Ool10001Ool000Moo`@000Uoo`<000Ao
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80
005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo
000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<0
07ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]o
o`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomo
o`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`004goo00@007ooOol0
00Aoo`03001oogoo0?moo`5oo`40005oo`005Woo00<007ooOol00Woo0P00ogoo0Goo0P000Goo000=
Ool40003Ool20005Ool00`00Oomoo`3oOol1Ool10001Ool001Aoo`03001oogoo00Aoo`03001oogoo
0?moo`5oo`40005oo`0057oo0`0017oo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool0
01]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`001goo10000goo0P0017oo0P001Goo
00<007ooOol0ogoo0Goo0@000Goo0007Ool00`00Oomoo`09Ool01000Oomoo`0017oo00<007ooOol0
ogoo0Goo0@000Goo0008Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool2003oOol1Ool20001Ool00003
Ool00000008000Aoo`03001oogoo00Qoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`001goo00@0
07ooOol000Uoo`03001oogoo00Aoo`03001oogoo0?moo`5oo`40005oo`0027oo0P002Woo0`0017oo
00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo
0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol04Woo1P0Oj7oo0@000Goo000KOol0
0`00Oomoo`0AOol801oWOol10001Ool001]oo`03001oogoo011oo`X07nIoo`40005oo`006goo00<0
07ooOol03goo300OiGoo0@000Goo000KOol2000@Ool<01oTOol20001Ool001]oo`03001oogoo00mo
o``07nEoo`40005oo`006goo00<007ooOol03goo300OiGoo0@000Goo000KOol00`00Oomoo`0?Ool<
01oUOol10001Ool001]oo`03001oogoo00moo``07nEoo`40005oo`006goo00<007ooOol047oo2P0O
iWoo0@000Goo000KOol00`00Oomoo`0AOol801oWOol10001Ool001]oo`8001=oo`H07nMoo`80005o
o`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000DOol20005Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo
0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool2003oOol1Ool20001Ool0
01=oo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool10001Ool001=oo`04001oogoo0004Ool00`00
Oomoo`3oOol1Ool10001Ool001Aoo`8000Eoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005o
o`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00iWoo1W`057oo0P000Goo
000KOol00`00Oomoo`3TOol8O00DOol10001Ool001]oo`03001oogoo0>=oo`Yl01=oo`40005oo`00
6goo00<007ooOol0hWoo37`04Woo0@000Goo000KOol00`00Oomoo`3ROol<O00BOol10001Ool001]o
o`03001oogoo0>9oo`al019oo`40005oo`006goo0P00hgoo37`04Goo0P000Goo000KOol00`00Oomo
o`3ROol<O00BOol10001Ool001]oo`03001oogoo0>9oo`al019oo`40005oo`006goo00<007ooOol0
hgoo2W`04goo0@000Goo000KOol00`00Oomoo`3TOol8O00DOol10001Ool001]oo`03001oogoo0>Eo
o`Il01Eoo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool0
01]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00
Oomoo`3oOol1Ool10001Ool000Moo`@000=oo`8000Aoo`8000Eoo`03001oogoo0?moo`5oo`40005o
o`001goo00<007ooOol02Goo00@007ooOol000Aoo`03001oogoo0?moo`5oo`40005oo`0027oo00<0
07ooOol02goo00<007ooOol00Woo0P00ogoo0Goo0P000Goo0009Ool00`00Oomoo`08Ool20005Ool0
0`00Oomoo`3oOol1Ool10001Ool000Moo`04001oogoo0009Ool00`00Oomoo`04Ool00`00Oomoo`3o
Ool1Ool10001Ool000Qoo`8000Yoo`<000Aoo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000K
Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03
001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3o
Ool1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@00
0Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007oo
Ool0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5o
o`40005oo`0057oo0P001Goo00<007ooOol0ogoo0Goo0@000Goo000COol01000Oomoo`0017oo00<0
07ooOol0ogoo0Goo0@000Goo000FOol00`00Oomoo`02Ool2003oOol1Ool20001Ool001Aoo`8000Eo
o`03001oogoo0?moo`5oo`40005oo`0057oo00<007ooOol017oo00<007ooOol0ogoo0Goo0@000Goo
000DOol30004Ool00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol2003oOol1Ool20001Ool001]oo`03001oogoo0?mo
o`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo0009Ool00`00Oomoo`02Ool20004Ool20005Ool00`00Oomo
o`3oOol1Ool10001Ool000Uoo`03001oogoo00Moo`04001oogoo0004Ool00`00Oomoo`3oOol1Ool1
0001Ool000Uoo`03001oogoo00Yoo`03001oogoo009oo`800?moo`5oo`80005oo`002Woo00<007oo
Ool01goo0P001Goo00<007ooOol0ogoo0Goo0@000Goo0007Ool01000Oomoo`002Goo00<007ooOol0
17oo00<007ooOol0ogoo0Goo0@000Goo0007Ool40009Ool30004Ool00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`800?moo`5oo`80005oo`006goo00<007ooOol0ogoo0Goo
0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`800?mo
o`5oo`80005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo
0P000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001oogoo0?moo`5oo`40005oo`00
6goo00<007ooOol0ogoo0Goo0@000Goo000KOol00`00Oomoo`3oOol1Ool10001Ool001]oo`03001o
ogoo0?moo`5oo`40005oo`006goo0P00ogoo0Goo0P000Goo000KOol00`00Oomoo`3oOol1Ool10001
Ool001]oo`03001oogoo0?moo`5oo`40005oo`006goo00<007ooOol0ogoo0Goo0@000Goo000KOol0
0`00Oomoo`3oOol1Ool10001Ool000eoo`D0009oo`8000Eoo`03001oogoo01Moo`03001oogoo035o
o`03001oogoo035oo`03001oogoo031oo`03001oogoo035oo`03001oogoo01Moo`40005oo`003goo
00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`40005oo`003goo00D007ooOomoo`00009oo`03001o
ogoo009oool000D0005oo`003goo00D007ooOomoo`00009oo`03001oogoo0?moo`Qoo`003goo00D0
07ooOomoo`00009oo`03001oogoo0?moo`Qoo`003Woo0P0017oo0P00ogoo2goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-6.04945, -11.3526, 0.0385168, \
0.0770336}}]
}, Open  ]],

Cell["tbl1=Chop[Table[{(Y[1,t]-Y[2,t]),X[1,t]-X[2,t]},{t,1,150}]];", "Input"],

Cell[CellGroupData[{

Cell["ListPlot[tbl1,PlotJoined->True,PlotStyle->RGBColor[0,1,0]]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.324762 -0.185193 0.0951946 [
[.18619 -0.0073 -9 -9 ]
[.18619 -0.0073 9 0 ]
[.34857 -0.0073 -3 -9 ]
[.34857 -0.0073 3 0 ]
[.51095 -0.0073 -9 -9 ]
[.51095 -0.0073 9 0 ]
[.67333 -0.0073 -3 -9 ]
[.67333 -0.0073 3 0 ]
[.83572 -0.0073 -9 -9 ]
[.83572 -0.0073 9 0 ]
[.9981 -0.0073 -3 -9 ]
[.9981 -0.0073 3 0 ]
[.01131 .10039 -6 -4.5 ]
[.01131 .10039 0 4.5 ]
[.01131 .19558 -6 -4.5 ]
[.01131 .19558 0 4.5 ]
[.01131 .29078 -6 -4.5 ]
[.01131 .29078 0 4.5 ]
[.01131 .38597 -6 -4.5 ]
[.01131 .38597 0 4.5 ]
[.01131 .48117 -6 -4.5 ]
[.01131 .48117 0 4.5 ]
[.01131 .57636 -6 -4.5 ]
[.01131 .57636 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18619 .0052 m
.18619 .01145 L
s
[(0.5)] .18619 -0.0073 0 1 Mshowa
.34857 .0052 m
.34857 .01145 L
s
[(1)] .34857 -0.0073 0 1 Mshowa
.51095 .0052 m
.51095 .01145 L
s
[(1.5)] .51095 -0.0073 0 1 Mshowa
.67333 .0052 m
.67333 .01145 L
s
[(2)] .67333 -0.0073 0 1 Mshowa
.83572 .0052 m
.83572 .01145 L
s
[(2.5)] .83572 -0.0073 0 1 Mshowa
.9981 .0052 m
.9981 .01145 L
s
[(3)] .9981 -0.0073 0 1 Mshowa
.125 Mabswid
.05629 .0052 m
.05629 .00895 L
s
.08876 .0052 m
.08876 .00895 L
s
.12124 .0052 m
.12124 .00895 L
s
.15371 .0052 m
.15371 .00895 L
s
.21867 .0052 m
.21867 .00895 L
s
.25114 .0052 m
.25114 .00895 L
s
.28362 .0052 m
.28362 .00895 L
s
.3161 .0052 m
.3161 .00895 L
s
.38105 .0052 m
.38105 .00895 L
s
.41352 .0052 m
.41352 .00895 L
s
.446 .0052 m
.446 .00895 L
s
.47848 .0052 m
.47848 .00895 L
s
.54343 .0052 m
.54343 .00895 L
s
.57591 .0052 m
.57591 .00895 L
s
.60838 .0052 m
.60838 .00895 L
s
.64086 .0052 m
.64086 .00895 L
s
.70581 .0052 m
.70581 .00895 L
s
.73829 .0052 m
.73829 .00895 L
s
.77076 .0052 m
.77076 .00895 L
s
.80324 .0052 m
.80324 .00895 L
s
.86819 .0052 m
.86819 .00895 L
s
.90067 .0052 m
.90067 .00895 L
s
.93314 .0052 m
.93314 .00895 L
s
.96562 .0052 m
.96562 .00895 L
s
.25 Mabswid
0 .0052 m
1 .0052 L
s
.02381 .10039 m
.03006 .10039 L
s
[(3)] .01131 .10039 1 0 Mshowa
.02381 .19558 m
.03006 .19558 L
s
[(4)] .01131 .19558 1 0 Mshowa
.02381 .29078 m
.03006 .29078 L
s
[(5)] .01131 .29078 1 0 Mshowa
.02381 .38597 m
.03006 .38597 L
s
[(6)] .01131 .38597 1 0 Mshowa
.02381 .48117 m
.03006 .48117 L
s
[(7)] .01131 .48117 1 0 Mshowa
.02381 .57636 m
.03006 .57636 L
s
[(8)] .01131 .57636 1 0 Mshowa
.125 Mabswid
.02381 .02423 m
.02756 .02423 L
s
.02381 .04327 m
.02756 .04327 L
s
.02381 .06231 m
.02756 .06231 L
s
.02381 .08135 m
.02756 .08135 L
s
.02381 .11943 m
.02756 .11943 L
s
.02381 .13847 m
.02756 .13847 L
s
.02381 .15751 m
.02756 .15751 L
s
.02381 .17655 m
.02756 .17655 L
s
.02381 .21462 m
.02756 .21462 L
s
.02381 .23366 m
.02756 .23366 L
s
.02381 .2527 m
.02756 .2527 L
s
.02381 .27174 m
.02756 .27174 L
s
.02381 .30982 m
.02756 .30982 L
s
.02381 .32886 m
.02756 .32886 L
s
.02381 .3479 m
.02756 .3479 L
s
.02381 .36693 m
.02756 .36693 L
s
.02381 .40501 m
.02756 .40501 L
s
.02381 .42405 m
.02756 .42405 L
s
.02381 .44309 m
.02756 .44309 L
s
.02381 .46213 m
.02756 .46213 L
s
.02381 .50021 m
.02756 .50021 L
s
.02381 .51925 m
.02756 .51925 L
s
.02381 .53829 m
.02756 .53829 L
s
.02381 .55732 m
.02756 .55732 L
s
.02381 .5954 m
.02756 .5954 L
s
.02381 .61444 m
.02756 .61444 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 0 r
.5 Mabswid
.07481 .01472 m
.12717 .0244 L
.17117 .03938 L
.20668 .05483 L
.23626 .06947 L
.2616 .08308 L
.28386 .09573 L
.30376 .10753 L
.32181 .11859 L
.33839 .12901 L
.35373 .13886 L
.36804 .14821 L
.38148 .15712 L
.39415 .16563 L
.40617 .17379 L
.4176 .18162 L
.42851 .18916 L
.43895 .19643 L
.44897 .20346 L
.45861 .21026 L
.46791 .21685 L
.47689 .22325 L
.48557 .22947 L
.49399 .23552 L
.50215 .24141 L
.51008 .24716 L
.5178 .25276 L
.52531 .25824 L
.53263 .26359 L
.53977 .26883 L
.54674 .27395 L
.55355 .27897 L
.56021 .28389 L
.56673 .28871 L
.57311 .29345 L
.57937 .29809 L
.5855 .30265 L
.59151 .30714 L
.59742 .31155 L
.60322 .31588 L
.60891 .32015 L
.61451 .32435 L
.62001 .32848 L
.62543 .33255 L
.63076 .33656 L
.636 .34052 L
.64117 .34441 L
.64625 .34826 L
.65127 .35205 L
.65621 .35579 L
Mistroke
.66109 .35949 L
.66589 .36313 L
.67064 .36673 L
.67532 .37029 L
.67993 .3738 L
.6845 .37727 L
.689 .3807 L
.69345 .38409 L
.69784 .38745 L
.70219 .39076 L
.70648 .39404 L
.71073 .39729 L
.71492 .4005 L
.71907 .40367 L
.72318 .40682 L
.72724 .40993 L
.73126 .41301 L
.73524 .41607 L
.73918 .41909 L
.74307 .42208 L
.74693 .42505 L
.75075 .42798 L
.75454 .43089 L
.75829 .43378 L
.762 .43664 L
.76568 .43947 L
.76932 .44228 L
.77294 .44507 L
.77652 .44783 L
.78007 .45057 L
.78358 .45328 L
.78707 .45598 L
.79053 .45865 L
.79396 .4613 L
.79737 .46393 L
.80074 .46654 L
.80409 .46913 L
.80741 .4717 L
.8107 .47425 L
.81397 .47679 L
.81722 .4793 L
.82044 .4818 L
.82363 .48427 L
.8268 .48673 L
.82995 .48918 L
.83308 .4916 L
.83618 .49401 L
.83926 .4964 L
.84232 .49878 L
.84536 .50114 L
Mistroke
.84838 .50348 L
.85137 .50581 L
.85435 .50813 L
.85731 .51043 L
.86024 .51271 L
.86316 .51498 L
.86606 .51724 L
.86894 .51948 L
.8718 .52171 L
.87465 .52392 L
.87747 .52613 L
.88028 .52832 L
.88307 .53049 L
.88585 .53265 L
.8886 .5348 L
.89135 .53694 L
.89407 .53907 L
.89678 .54118 L
.89947 .54328 L
.90215 .54537 L
.90481 .54745 L
.90746 .54952 L
.91009 .55157 L
.91271 .55362 L
.91531 .55565 L
.9179 .55768 L
.92048 .55969 L
.92304 .56169 L
.92558 .56368 L
.92812 .56566 L
.93064 .56763 L
.93314 .56959 L
.93564 .57155 L
.93812 .57349 L
.94059 .57542 L
.94304 .57734 L
.94549 .57926 L
.94792 .58116 L
.95034 .58305 L
.95274 .58494 L
.95514 .58682 L
.95752 .58868 L
.9599 .59054 L
.96226 .59239 L
.96461 .59423 L
.96694 .59607 L
.96927 .59789 L
.97159 .59971 L
.97389 .60152 L
.97619 .60332 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000dOol2
0004Ool20004Ool2000SOol5000POol50002Ool20004Ool2000SOol4000QOol40003Ool20004Ool2
000TOol2000:Ool003=oo`04001oogoo0008Ool01000Oomoo`0097oo00<007ooOol08Woo00<007oo
Ool01goo00@007ooOol0029oo`03001oogoo029oo`03001oogoo00Uoo`04001oogoo000ROol01000
Oomoo`002Goo000cOol01000Oomoo`002goo00<007ooOol08Woo00<007ooOol08Woo00<007ooOol0
2Woo00<007ooOol08Goo00<007ooOol08Woo00<007ooOol02goo00<007ooOol08Woo00<007ooOol0
27oo000cOol01000Oomoo`002Goo0P009Goo00<007ooOol08Woo00<007ooOol027oo0P009Goo00<0
07ooOol08Woo00<007ooOol027oo0P009Woo00<007ooOol01goo000cOol01000Oomoo`002Goo00<0
07ooOol097oo00<007ooOol08Woo00<007ooOol027oo00<007ooOol08Woo00@007ooOol0025oo`04
001oogoo0009Ool00`00Oomoo`0ROol01000Oomoo`002Goo000dOol2000:Ool3000SOol2000SOol2
000:Ool3000SOol2000SOol2000:Ool3000SOol2000:Ool00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`003goo00<007ooOol0ogoo3goo0009Oooo000?0009Ool000moo`03001oogoo00Ioo`03
001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03
001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03
001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03
001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Ioo`03
001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03
001oogoo00Ioo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Qoo`00
3goo00<007ooOol02goo0`?P6goo00<007ooOol0:Goo00<007ooOol0:7oo00<007ooOol0:Goo00<0
07ooOol0:7oo00<007ooOol0:Goo00<007ooOol027oo000?Ool00`00Oomoo`0>Ool40n3lOol000mo
o`03001oogoo019oo`D3h?Moo`003goo0P0067oo10?Plgoo000?Ool00`00Oomoo`0KOol30n3`Ool0
00moo`03001oogoo01ioo`<3h>eoo`003goo00<007ooOol08Goo0`?PjWoo000?Ool00`00Oomoo`0T
Ool30n3WOol000moo`8002Qoo`83h>Eoo`003goo00<007ooOol0:Goo0P?Phgoo000?Ool00`00Oomo
o`0[Ool20n3QOol000moo`03001oogoo02eoo`83h=moo`003goo00<007ooOol0;goo0P?PgGoo000?
Ool2000bOol20n3KOol000moo`03001oogoo03=oo`83h=Uoo`003goo00<007ooOol0=Goo0P?Pegoo
000?Ool00`00Oomoo`0gOol20n3EOol000moo`03001oogoo03Uoo`83h==oo`003goo0P00?7oo0P?P
dGoo000?Ool00`00Oomoo`0mOol00`?POomoo`3>Ool000moo`03001oogoo03ioo`83h<ioo`0027oo
0P001Goo00<007ooOol0@7oo0P?Pc7oo0007Ool01000Oomoo`0017oo00<007ooOol0@Woo0P?PbWoo
0009Ool00`00Oomoo`03Ool30014Ool20n38Ool000Yoo`03001oogoo009oo`03001oogoo04Ioo`83
h<Ioo`001goo00@007ooOol000Aoo`03001oogoo04Qoo`83h<Aoo`0027oo0P001Goo00<007ooOol0
BWoo00<3h7ooOol0`Goo000?Ool00`00Oomoo`1;Ool20n31Ool000moo`03001oogoo04eoo`030n1o
ogoo0;ioo`003goo0P00Cgoo0P?P_Woo000?Ool00`00Oomoo`1@Ool20n2lOol000moo`03001oogoo
059oo`030n1oogoo0;Uoo`003goo00<007ooOol0Dgoo00<3h7ooOol0^7oo000?Ool00`00Oomoo`1D
Ool20n2hOol000moo`8005Moo`030n1oogoo0;Eoo`003goo00<007ooOol0Egoo0P?P]Goo000?Ool0
0`00Oomoo`1IOol20n2cOol000moo`03001oogoo05]oo`030n1oogoo0;1oo`003goo00<007ooOol0
G7oo00<3h7ooOol0[goo000?Ool2001NOol00`?POomoo`2^Ool000moo`03001oogoo05ioo`83h:io
o`003goo00<007ooOol0H7oo0P?P[7oo000?Ool00`00Oomoo`1ROol20n2ZOol000moo`03001oogoo
06Aoo`030n1oogoo0:Moo`003goo0P00IWoo0P?PYgoo000?Ool00`00Oomoo`1WOol00`?POomoo`2T
Ool000moo`03001oogoo06Qoo`83h:Aoo`002Goo0`000goo00<007ooOol0JWoo00<3h7ooOol0XGoo
000:Ool00`00Oomoo`02Ool00`00Oomoo`1[Ool20n2QOol000Moo`D000=oo`<006eoo`030n1oogoo
09ioo`001goo00@007ooOol000Aoo`03001oogoo06ioo`83h9ioo`0027oo00<007oo000017oo00<0
07ooOol0L7oo00<3h7ooOol0Vgoo0009Ool20004Ool00`00Oomoo`1aOol00`?POomoo`2JOol000mo
o`03001oogoo079oo`030n1oogoo09Uoo`003goo0P00M7oo0P?PVGoo000?Ool00`00Oomoo`1eOol0
0`?POomoo`2FOol000moo`03001oogoo07Ioo`83h9Ioo`003goo00<007ooOol0N7oo00<3h7ooOol0
Tgoo000?Ool00`00Oomoo`1iOol00`?POomoo`2BOol000moo`8007]oo`83h99oo`003goo00<007oo
Ool0O7oo00<3h7ooOol0Sgoo000?Ool00`00Oomoo`1mOol20n2?Ool000moo`03001oogoo07moo`03
0n1oogoo08aoo`003goo00<007ooOol0P7oo00<3h7ooOol0Rgoo000?Ool20022Ool20n2;Ool000mo
o`03001oogoo08=oo`030n1oogoo08Qoo`003goo00<007ooOol0Q7oo00<3h7ooOol0Qgoo000?Ool0
0`00Oomoo`25Ool20n27Ool000moo`03001oogoo08Moo`030n1oogoo08Aoo`003goo0P00RGoo00<3
h7ooOol0Pgoo000?Ool00`00Oomoo`29Ool20n23Ool000moo`03001oogoo08]oo`83h85oo`003goo
00<007ooOol0SGoo00<3h7ooOol0OWoo0008Ool20005Ool00`00Oomoo`2=Ool00`?POomoo`1nOol0
00Moo`04001oogoo0004Ool00`00Oomoo`2>Ool20n1nOol000Yoo`03001oogoo009oo`<0091oo`83
h7aoo`0027oo0P001Goo00<007ooOol0TWoo00<3h7ooOol0NGoo0008Ool00`00Oomoo`04Ool00`00
Oomoo`2COol00`?POomoo`1hOol000Qoo`<000Aoo`03001oogoo09Aoo`030n1oogoo07Moo`003goo
00<007ooOol0UGoo0P?PMgoo000?Ool2002HOol00`?POomoo`1dOol000moo`03001oogoo09Qoo`83
h7Aoo`003goo00<007ooOol0VWoo00<3h7ooOol0LGoo000?Ool00`00Oomoo`2KOol00`?POomoo`1`
Ool000moo`03001oogoo09aoo`030n1oogoo06moo`003goo0P00WWoo00<3h7ooOol0KWoo000?Ool0
0`00Oomoo`2NOol20n1^Ool000moo`03001oogoo0:1oo`030n1oogoo06]oo`003goo00<007ooOol0
XGoo0P?PJgoo000?Ool00`00Oomoo`2SOol00`?POomoo`1XOol000moo`800:Eoo`83h6Qoo`003goo
00<007ooOol0YWoo00<3h7ooOol0IGoo000?Ool00`00Oomoo`2WOol00`?POomoo`1TOol000moo`03
001oogoo0:Qoo`83h6Aoo`003goo00<007ooOol0ZWoo00<3h7ooOol0HGoo000?Ool2002/Ool00`?P
Oomoo`1POol000moo`03001oogoo0:aoo`030n1oogoo05moo`003goo00<007ooOol0[Goo0P?PGgoo
0007Ool30005Ool00`00Oomoo`2_Ool00`?POomoo`1LOol000Moo`04001oogoo0004Ool00`00Oomo
o`2`Ool00`?POomoo`1KOol000Moo`04001oogoo0004Ool3002aOol00`?POomoo`1JOol000Moo`<0
00Eoo`03001oogoo0;9oo`<3h5Uoo`0027oo00<007ooOol017oo00<007ooOol0]Goo00<3h7ooOol0
EWoo0008Ool30004Ool00`00Oomoo`2fOol00`?POomoo`1EOol000moo`03001oogoo0;Moo`030n1o
ogoo05Aoo`003goo0P00^Goo00<3h7ooOol0Dgoo000?Ool00`00Oomoo`2iOol00`?POomoo`1BOol0
00moo`03001oogoo0;Yoo`83h59oo`003goo00<007ooOol0_7oo00<3h7ooOol0Cgoo000?Ool00`00
Oomoo`2mOol00`?POomoo`1>Ool000moo`800;moo`83h4ioo`003goo00<007ooOol0`7oo0P?PC7oo
000?Ool00`00Oomoo`32Ool00`?POomoo`19Ool000moo`03001oogoo0<=oo`030n1oogoo04Qoo`00
3goo00<007ooOol0a7oo00<3h7ooOol0Agoo000?Ool00`00Oomoo`35Ool20n17Ool000moo`800<Qo
o`030n1oogoo04Aoo`003goo00<007ooOol0agoo00<3h7ooOol0A7oo000?Ool00`00Oomoo`38Ool2
0n14Ool000moo`03001oogoo0<Yoo`030n1oogoo045oo`003goo00<007ooOol0bgoo0P?P@Goo000?
Ool2003>Ool00`?POomoo`0nOol000moo`03001oogoo0<ioo`030n1oogoo03eoo`003goo00<007oo
Ool0cgoo0P?P?Goo0009Ool00`00Oomoo`03Ool00`00Oomoo`3AOol00`?POomoo`0jOol000Uoo`03
001oogoo00=oo`03001oogoo0=9oo`030n1oogoo03Uoo`002Goo00<007ooOol00goo0`00dgoo00<3
h7ooOol0>7oo000:Ool00`00Oomoo`02Ool00`00Oomoo`3DOol20n0hOol000Moo`04001oogoo0004
Ool00`00Oomoo`3FOol00`?POomoo`0eOol000Moo`@000Aoo`03001oogoo0=Moo`83h3Eoo`003goo
00<007ooOol0f7oo0P?P=7oo000?Ool2003KOol00`?POomoo`0aOol000moo`03001oogoo0=]oo`83
h35oo`003goo00<007ooOol0g7oo00<3h7ooOol0;goo000?Ool00`00Oomoo`3MOol20n0_Ool000mo
o`03001oogoo0=moo`83h2eoo`003goo0P00hGoo00<3h7ooOol0:goo000?Ool00`00Oomoo`3QOol2
0n0[Ool000moo`03001oogoo0>=oo`030n1oogoo02Qoo`003goo00<007ooOol0i7oo00<3h7ooOol0
9goo000?Ool00`00Oomoo`3UOol20n0WOol000moo`800>Moo`83h2Ioo`003goo00<007ooOol0j7oo
0P?P97oo000?Ool00`00Oomoo`3YOol00`?POomoo`0ROol000moo`03001oogoo0>Yoo`83h29oo`00
3goo00<007ooOol0jgoo0P?P8Goo000?Ool2003^Ool00`?POomoo`0NOol000moo`03001oogoo0>io
o`83h1ioo`003goo00<007ooOol0l7oo00<3h7ooOol06goo0008Ool20005Ool00`00Oomoo`3aOol2
0n0KOol000Moo`04001oogoo0004Ool00`00Oomoo`3bOol00`?POomoo`0IOol000Moo`04001oogoo
0004Ool3003cOol20n0IOol000Qoo`8000Eoo`03001oogoo0?Aoo`83h1Qoo`001goo00@007ooOol0
00Aoo`03001oogoo0?Ioo`030n1oogoo01Eoo`0027oo0P001Goo00<007ooOol0mgoo00<3h7ooOol0
57oo000?Ool00`00Oomoo`3hOol20n0DOol000moo`800?Yoo`83h1=oo`003goo00<007ooOol0ngoo
00<3h7ooOol047oo000?Ool00`00Oomoo`3lOol20n0@Ool000moo`03001oogoo0?eoo`030n1oogoo
00ioo`003goo00<007ooOol0ogoo3goo000?Ool00`00Oomoo`3oOol?Ool000moo`800?mooa1oo`00
\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.181764, 1.51665, \
0.0114657, 0.0391159}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["tbl2=Chop[Table[{(X[1,t]-X[2,t]),Z[1,t]-Z[2,t]},{t,1,150}]];", "Input"],

Cell[CellGroupData[{

Cell["ListPlot[tbl2,PlotJoined->True,PlotStyle->RGBColor[1,1,0]]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.299649 0.154028 0.309017 0.294302 [
[.16243 .29652 -3 -9 ]
[.16243 .29652 3 0 ]
[.31646 .29652 -3 -9 ]
[.31646 .29652 3 0 ]
[.47049 .29652 -3 -9 ]
[.47049 .29652 3 0 ]
[.62452 .29652 -3 -9 ]
[.62452 .29652 3 0 ]
[.77855 .29652 -3 -9 ]
[.77855 .29652 3 0 ]
[.93257 .29652 -3 -9 ]
[.93257 .29652 3 0 ]
[-0.00409 .01472 -12 -4.5 ]
[-0.00409 .01472 0 4.5 ]
[-0.00409 .16187 -24 -4.5 ]
[-0.00409 .16187 0 4.5 ]
[-0.00409 .45617 -18 -4.5 ]
[-0.00409 .45617 0 4.5 ]
[-0.00409 .60332 -6 -4.5 ]
[-0.00409 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16243 .30902 m
.16243 .31527 L
s
[(3)] .16243 .29652 0 1 Mshowa
.31646 .30902 m
.31646 .31527 L
s
[(4)] .31646 .29652 0 1 Mshowa
.47049 .30902 m
.47049 .31527 L
s
[(5)] .47049 .29652 0 1 Mshowa
.62452 .30902 m
.62452 .31527 L
s
[(6)] .62452 .29652 0 1 Mshowa
.77855 .30902 m
.77855 .31527 L
s
[(7)] .77855 .29652 0 1 Mshowa
.93257 .30902 m
.93257 .31527 L
s
[(8)] .93257 .29652 0 1 Mshowa
.125 Mabswid
.03921 .30902 m
.03921 .31277 L
s
.07002 .30902 m
.07002 .31277 L
s
.10082 .30902 m
.10082 .31277 L
s
.13163 .30902 m
.13163 .31277 L
s
.19324 .30902 m
.19324 .31277 L
s
.22405 .30902 m
.22405 .31277 L
s
.25485 .30902 m
.25485 .31277 L
s
.28566 .30902 m
.28566 .31277 L
s
.34727 .30902 m
.34727 .31277 L
s
.37807 .30902 m
.37807 .31277 L
s
.40888 .30902 m
.40888 .31277 L
s
.43969 .30902 m
.43969 .31277 L
s
.5013 .30902 m
.5013 .31277 L
s
.5321 .30902 m
.5321 .31277 L
s
.56291 .30902 m
.56291 .31277 L
s
.59371 .30902 m
.59371 .31277 L
s
.65532 .30902 m
.65532 .31277 L
s
.68613 .30902 m
.68613 .31277 L
s
.71694 .30902 m
.71694 .31277 L
s
.74774 .30902 m
.74774 .31277 L
s
.80935 .30902 m
.80935 .31277 L
s
.84016 .30902 m
.84016 .31277 L
s
.87096 .30902 m
.87096 .31277 L
s
.90177 .30902 m
.90177 .31277 L
s
.96338 .30902 m
.96338 .31277 L
s
.99419 .30902 m
.99419 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.00841 .01472 m
.01466 .01472 L
s
[(-1)] -0.00409 .01472 1 0 Mshowa
.00841 .16187 m
.01466 .16187 L
s
[(-0.5)] -0.00409 .16187 1 0 Mshowa
.00841 .45617 m
.01466 .45617 L
s
[(0.5)] -0.00409 .45617 1 0 Mshowa
.00841 .60332 m
.01466 .60332 L
s
[(1)] -0.00409 .60332 1 0 Mshowa
.125 Mabswid
.00841 .04415 m
.01216 .04415 L
s
.00841 .07358 m
.01216 .07358 L
s
.00841 .10301 m
.01216 .10301 L
s
.00841 .13244 m
.01216 .13244 L
s
.00841 .1913 m
.01216 .1913 L
s
.00841 .22073 m
.01216 .22073 L
s
.00841 .25016 m
.01216 .25016 L
s
.00841 .27959 m
.01216 .27959 L
s
.00841 .33845 m
.01216 .33845 L
s
.00841 .36788 m
.01216 .36788 L
s
.00841 .39731 m
.01216 .39731 L
s
.00841 .42674 m
.01216 .42674 L
s
.00841 .4856 m
.01216 .4856 L
s
.00841 .51503 m
.01216 .51503 L
s
.00841 .54446 m
.01216 .54446 L
s
.00841 .57389 m
.01216 .57389 L
s
.25 Mabswid
.00841 0 m
.00841 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 1 0 r
.5 Mabswid
.02381 .30902 m
.03947 .30902 L
.06372 .30902 L
.08871 .30902 L
.1124 .30902 L
.13442 .30902 L
.15489 .30902 L
.17399 .30902 L
.19189 .30902 L
.20874 .30902 L
.22468 .30902 L
.23981 .30902 L
.25422 .30902 L
.26799 .30902 L
.28119 .30902 L
.29386 .30902 L
.30606 .30902 L
.31783 .30902 L
.3292 .30902 L
.34021 .30902 L
.35087 .30902 L
.36123 .30902 L
.37129 .30902 L
.38108 .30902 L
.39061 .30902 L
.39991 .30902 L
.40898 .30902 L
.41784 .30902 L
.4265 .30902 L
.43497 .30902 L
.44326 .30902 L
.45138 .30902 L
.45934 .30902 L
.46715 .30902 L
.4748 .30902 L
.48232 .30902 L
.48971 .30902 L
.49696 .30902 L
.50409 .30902 L
.51111 .30902 L
.51801 .30902 L
.5248 .30902 L
.53149 .30902 L
.53808 .30902 L
.54457 .30902 L
.55097 .30902 L
.55727 .30902 L
.56349 .30902 L
.56963 .30902 L
.57568 .30902 L
Mistroke
.58166 .30902 L
.58756 .30902 L
.59338 .30902 L
.59914 .30902 L
.60482 .30902 L
.61044 .30902 L
.61599 .30902 L
.62148 .30902 L
.6269 .30902 L
.63227 .30902 L
.63757 .30902 L
.64282 .30902 L
.64802 .30902 L
.65316 .30902 L
.65825 .30902 L
.66328 .30902 L
.66827 .30902 L
.67321 .30902 L
.6781 .30902 L
.68294 .30902 L
.68774 .30902 L
.69249 .30902 L
.6972 .30902 L
.70187 .30902 L
.7065 .30902 L
.71108 .30902 L
.71563 .30902 L
.72013 .30902 L
.7246 .30902 L
.72903 .30902 L
.73343 .30902 L
.73779 .30902 L
.74211 .30902 L
.7464 .30902 L
.75066 .30902 L
.75488 .30902 L
.75907 .30902 L
.76323 .30902 L
.76736 .30902 L
.77146 .30902 L
.77552 .30902 L
.77956 .30902 L
.78357 .30902 L
.78755 .30902 L
.7915 .30902 L
.79543 .30902 L
.79933 .30902 L
.8032 .30902 L
.80704 .30902 L
.81086 .30902 L
Mistroke
.81465 .30902 L
.81842 .30902 L
.82217 .30902 L
.82589 .30902 L
.82959 .30902 L
.83326 .30902 L
.83691 .30902 L
.84054 .30902 L
.84414 .30902 L
.84773 .30902 L
.85129 .30902 L
.85483 .30902 L
.85835 .30902 L
.86185 .30902 L
.86533 .30902 L
.86879 .30902 L
.87223 .30902 L
.87565 .30902 L
.87905 .30902 L
.88243 .30902 L
.88579 .30902 L
.88914 .30902 L
.89247 .30902 L
.89577 .30902 L
.89907 .30902 L
.90234 .30902 L
.90559 .30902 L
.90883 .30902 L
.91206 .30902 L
.91526 .30902 L
.91845 .30902 L
.92162 .30902 L
.92478 .30902 L
.92792 .30902 L
.93105 .30902 L
.93416 .30902 L
.93725 .30902 L
.94033 .30902 L
.9434 .30902 L
.94645 .30902 L
.94949 .30902 L
.95251 .30902 L
.95552 .30902 L
.95851 .30902 L
.96149 .30902 L
.96446 .30902 L
.96741 .30902 L
.97035 .30902 L
.97328 .30902 L
.97619 .30902 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000KOol00`00Oomoo`3oOol3
Ool001]oo`03001oogoo0?moo`=oo`004goo1@000goo00<007ooOol0ogoo0goo000EOol00`00Oomo
o`03Ool00`00Oomoo`3oOol3Ool001Eoo`03001oogoo00=oo`800?moo`Aoo`003Goo100017oo00<0
07ooOol00goo00<007ooOol0ogoo0goo000EOol00`00Oomoo`03Ool00`00Oomoo`3oOol3Ool001Ao
o`8000Eoo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3
Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol2003oOol4Ool001]o
o`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]o
o`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]o
o`800?moo`Aoo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001o
ogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001o
ogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol2003oOol4Ool001]oo`03001oogoo0?mo
o`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?mo
o`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?mo
o`=oo`006goo0P00ogoo17oo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`00
6goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool000Qoo`8000Aoo`8000Aoo`8000Eo
o`03001oogoo0?moo`=oo`001goo00@007ooOol000Qoo`04001oogoo0004Ool00`00Oomoo`3oOol3
Ool000Moo`04001oogoo000;Ool00`00Oomoo`02Ool2003oOol4Ool00003Ool000000080009oo`04
001oogoo0009Ool20005Ool00`00Oomoo`3oOol3Ool000Moo`04001oogoo0009Ool00`00Oomoo`04
Ool00`00Oomoo`3oOol3Ool000Qoo`8000Yoo`<000Aoo`03001oogoo0?moo`=oo`006goo00<007oo
Ool0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007oo
Ool0ogoo0goo000KOol2003oOol4Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo
0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo
0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo0P00ogoo17oo000K
Ool00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000K
Ool00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000K
Ool00`00Oomoo`3oOol3Ool001]oo`800?moo`Aoo`006goo00<007ooOol0ogoo0goo000KOol00`00
Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol097oo0P009goo0`009Goo
0P009Goo0`009goo00<007ooOol09Goo0P004Woo000KOol00`00Oomoo`0SOol01000Oomoo`009goo
00<007ooOol08goo00@007ooOol002Aoo`04001oogoo000VOol00`00Oomoo`0TOol01000Oomoo`00
4Goo000KOol00`00Oomoo`0UOol00`00Oomoo`0SOol5000WOol00`00Oomoo`0ROol01000Oomoo`00
9Woo00<007ooOol097oo00@007ooOol0015oo`006goo0P009goo00<007ooOol08Woo00@007ooOol0
02Ioo`8002Eoo`<002Qoo`03001oogoo02Aoo`80019oo`006goo00<007ooOol08goo00@007ooOol0
02Eoo`03001oo`0002Ioo`03001oogoo02Eoo`03001oogoo02Aoo`04001oogoo000UOol01000Oomo
o`004Goo000KOol00`00Oomoo`0TOol2000WOol2000VOol3000UOol3000TOol4000VOol2000BOol0
01]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool0
01]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000IOol6003jOn07000001]oo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo00Eoo`40005oo`5oo`006goo00<007ooOol09Goo00<007ooOol09Goo
00<007ooOol09Woo00<007ooOol09Goo00<007ooOol09Goo00<007ooOol09Woo00<007ooOol047oo
000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo
000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo0P00ogoo17oo000KOol0
0`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol0
0`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol2
003oOol4Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomo
o`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomo
o`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo0P00ogoo17oo000KOol00`00Oomoo`3oOol3
Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3
Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3
Ool001]oo`800?moo`Aoo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]o
o`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool000Qo
o`8000Aoo`8000Aoo`8000Eoo`03001oogoo0?moo`=oo`001goo00@007ooOol000Qoo`04001oogoo
0004Ool00`00Oomoo`3oOol3Ool000Moo`04001oogoo000;Ool00`00Oomoo`02Ool2003oOol4Ool0
00Moo`04001oogoo0009Ool20005Ool00`00Oomoo`3oOol3Ool000Moo`04001oogoo0009Ool00`00
Oomoo`04Ool00`00Oomoo`3oOol3Ool000Qoo`8000Yoo`<000Aoo`03001oogoo0?moo`=oo`006goo
00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo
0P00ogoo17oo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007oo
Ool0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007oo
Ool0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`800?moo`Aoo`006goo00<007ooOol0ogoo
0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo
0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo
0goo000KOol2003oOol4Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000K
Ool00`00Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000K
Ool00`00Oomoo`3oOol3Ool001]oo`800?moo`Aoo`006goo00<007ooOol0ogoo0goo000KOol00`00
Oomoo`3oOol3Ool001]oo`03001oogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00
Oomoo`3oOol3Ool001=oo`D000=oo`03001oogoo0?moo`=oo`005Goo00<007ooOol00goo00<007oo
Ool0ogoo0goo000EOol00`00Oomoo`03Ool2003oOol4Ool001Eoo`03001oogoo00=oo`03001oogoo
0?moo`=oo`005Goo00<007ooOol00goo00<007ooOol0ogoo0goo000DOol20005Ool00`00Oomoo`3o
Ool3Ool001]oo`03001oogoo0?moo`=oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {1.32395, -1.14766, \
0.0247869, 0.0129726}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["tbl3=Flatten[Chop[Table[{(X[1,t]-X[2,t])},{t,1,150}]]];", "Input"],

Cell[CellGroupData[{

Cell["ListPlot[tbl3,PlotJoined->True,PlotStyle->RGBColor[0,0,1]]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00634921 -0.185193 0.0951946 [
[.15079 -0.0073 -6 -9 ]
[.15079 -0.0073 6 0 ]
[.27778 -0.0073 -6 -9 ]
[.27778 -0.0073 6 0 ]
[.40476 -0.0073 -6 -9 ]
[.40476 -0.0073 6 0 ]
[.53175 -0.0073 -6 -9 ]
[.53175 -0.0073 6 0 ]
[.65873 -0.0073 -9 -9 ]
[.65873 -0.0073 9 0 ]
[.78571 -0.0073 -9 -9 ]
[.78571 -0.0073 9 0 ]
[.9127 -0.0073 -9 -9 ]
[.9127 -0.0073 9 0 ]
[.01131 .10039 -6 -4.5 ]
[.01131 .10039 0 4.5 ]
[.01131 .19558 -6 -4.5 ]
[.01131 .19558 0 4.5 ]
[.01131 .29078 -6 -4.5 ]
[.01131 .29078 0 4.5 ]
[.01131 .38597 -6 -4.5 ]
[.01131 .38597 0 4.5 ]
[.01131 .48117 -6 -4.5 ]
[.01131 .48117 0 4.5 ]
[.01131 .57636 -6 -4.5 ]
[.01131 .57636 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15079 .0052 m
.15079 .01145 L
s
[(20)] .15079 -0.0073 0 1 Mshowa
.27778 .0052 m
.27778 .01145 L
s
[(40)] .27778 -0.0073 0 1 Mshowa
.40476 .0052 m
.40476 .01145 L
s
[(60)] .40476 -0.0073 0 1 Mshowa
.53175 .0052 m
.53175 .01145 L
s
[(80)] .53175 -0.0073 0 1 Mshowa
.65873 .0052 m
.65873 .01145 L
s
[(100)] .65873 -0.0073 0 1 Mshowa
.78571 .0052 m
.78571 .01145 L
s
[(120)] .78571 -0.0073 0 1 Mshowa
.9127 .0052 m
.9127 .01145 L
s
[(140)] .9127 -0.0073 0 1 Mshowa
.125 Mabswid
.05556 .0052 m
.05556 .00895 L
s
.0873 .0052 m
.0873 .00895 L
s
.11905 .0052 m
.11905 .00895 L
s
.18254 .0052 m
.18254 .00895 L
s
.21429 .0052 m
.21429 .00895 L
s
.24603 .0052 m
.24603 .00895 L
s
.30952 .0052 m
.30952 .00895 L
s
.34127 .0052 m
.34127 .00895 L
s
.37302 .0052 m
.37302 .00895 L
s
.43651 .0052 m
.43651 .00895 L
s
.46825 .0052 m
.46825 .00895 L
s
.5 .0052 m
.5 .00895 L
s
.56349 .0052 m
.56349 .00895 L
s
.59524 .0052 m
.59524 .00895 L
s
.62698 .0052 m
.62698 .00895 L
s
.69048 .0052 m
.69048 .00895 L
s
.72222 .0052 m
.72222 .00895 L
s
.75397 .0052 m
.75397 .00895 L
s
.81746 .0052 m
.81746 .00895 L
s
.84921 .0052 m
.84921 .00895 L
s
.88095 .0052 m
.88095 .00895 L
s
.94444 .0052 m
.94444 .00895 L
s
.97619 .0052 m
.97619 .00895 L
s
.25 Mabswid
0 .0052 m
1 .0052 L
s
.02381 .10039 m
.03006 .10039 L
s
[(3)] .01131 .10039 1 0 Mshowa
.02381 .19558 m
.03006 .19558 L
s
[(4)] .01131 .19558 1 0 Mshowa
.02381 .29078 m
.03006 .29078 L
s
[(5)] .01131 .29078 1 0 Mshowa
.02381 .38597 m
.03006 .38597 L
s
[(6)] .01131 .38597 1 0 Mshowa
.02381 .48117 m
.03006 .48117 L
s
[(7)] .01131 .48117 1 0 Mshowa
.02381 .57636 m
.03006 .57636 L
s
[(8)] .01131 .57636 1 0 Mshowa
.125 Mabswid
.02381 .02423 m
.02756 .02423 L
s
.02381 .04327 m
.02756 .04327 L
s
.02381 .06231 m
.02756 .06231 L
s
.02381 .08135 m
.02756 .08135 L
s
.02381 .11943 m
.02756 .11943 L
s
.02381 .13847 m
.02756 .13847 L
s
.02381 .15751 m
.02756 .15751 L
s
.02381 .17655 m
.02756 .17655 L
s
.02381 .21462 m
.02756 .21462 L
s
.02381 .23366 m
.02756 .23366 L
s
.02381 .2527 m
.02756 .2527 L
s
.02381 .27174 m
.02756 .27174 L
s
.02381 .30982 m
.02756 .30982 L
s
.02381 .32886 m
.02756 .32886 L
s
.02381 .3479 m
.02756 .3479 L
s
.02381 .36693 m
.02756 .36693 L
s
.02381 .40501 m
.02756 .40501 L
s
.02381 .42405 m
.02756 .42405 L
s
.02381 .44309 m
.02756 .44309 L
s
.02381 .46213 m
.02756 .46213 L
s
.02381 .50021 m
.02756 .50021 L
s
.02381 .51925 m
.02756 .51925 L
s
.02381 .53829 m
.02756 .53829 L
s
.02381 .55732 m
.02756 .55732 L
s
.02381 .5954 m
.02756 .5954 L
s
.02381 .61444 m
.02756 .61444 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.03016 .01472 m
.03651 .0244 L
.04286 .03938 L
.04921 .05483 L
.05556 .06947 L
.0619 .08308 L
.06825 .09573 L
.0746 .10753 L
.08095 .11859 L
.0873 .12901 L
.09365 .13886 L
.1 .14821 L
.10635 .15712 L
.1127 .16563 L
.11905 .17379 L
.1254 .18162 L
.13175 .18916 L
.1381 .19643 L
.14444 .20346 L
.15079 .21026 L
.15714 .21685 L
.16349 .22325 L
.16984 .22947 L
.17619 .23552 L
.18254 .24141 L
.18889 .24716 L
.19524 .25276 L
.20159 .25824 L
.20794 .26359 L
.21429 .26883 L
.22063 .27395 L
.22698 .27897 L
.23333 .28389 L
.23968 .28871 L
.24603 .29345 L
.25238 .29809 L
.25873 .30265 L
.26508 .30714 L
.27143 .31155 L
.27778 .31588 L
.28413 .32015 L
.29048 .32435 L
.29683 .32848 L
.30317 .33255 L
.30952 .33656 L
.31587 .34052 L
.32222 .34441 L
.32857 .34826 L
.33492 .35205 L
.34127 .35579 L
Mistroke
.34762 .35949 L
.35397 .36313 L
.36032 .36673 L
.36667 .37029 L
.37302 .3738 L
.37937 .37727 L
.38571 .3807 L
.39206 .38409 L
.39841 .38745 L
.40476 .39076 L
.41111 .39404 L
.41746 .39729 L
.42381 .4005 L
.43016 .40367 L
.43651 .40682 L
.44286 .40993 L
.44921 .41301 L
.45556 .41607 L
.4619 .41909 L
.46825 .42208 L
.4746 .42505 L
.48095 .42798 L
.4873 .43089 L
.49365 .43378 L
.5 .43664 L
.50635 .43947 L
.5127 .44228 L
.51905 .44507 L
.5254 .44783 L
.53175 .45057 L
.5381 .45328 L
.54444 .45598 L
.55079 .45865 L
.55714 .4613 L
.56349 .46393 L
.56984 .46654 L
.57619 .46913 L
.58254 .4717 L
.58889 .47425 L
.59524 .47679 L
.60159 .4793 L
.60794 .4818 L
.61429 .48427 L
.62063 .48673 L
.62698 .48918 L
.63333 .4916 L
.63968 .49401 L
.64603 .4964 L
.65238 .49878 L
.65873 .50114 L
Mistroke
.66508 .50348 L
.67143 .50581 L
.67778 .50813 L
.68413 .51043 L
.69048 .51271 L
.69683 .51498 L
.70317 .51724 L
.70952 .51948 L
.71587 .52171 L
.72222 .52392 L
.72857 .52613 L
.73492 .52832 L
.74127 .53049 L
.74762 .53265 L
.75397 .5348 L
.76032 .53694 L
.76667 .53907 L
.77302 .54118 L
.77937 .54328 L
.78571 .54537 L
.79206 .54745 L
.79841 .54952 L
.80476 .55157 L
.81111 .55362 L
.81746 .55565 L
.82381 .55768 L
.83016 .55969 L
.83651 .56169 L
.84286 .56368 L
.84921 .56566 L
.85556 .56763 L
.8619 .56959 L
.86825 .57155 L
.8746 .57349 L
.88095 .57542 L
.8873 .57734 L
.89365 .57926 L
.9 .58116 L
.90635 .58305 L
.9127 .58494 L
.91905 .58682 L
.9254 .58868 L
.93175 .59054 L
.9381 .59239 L
.94444 .59423 L
.95079 .59607 L
.95714 .59789 L
.96349 .59971 L
.96984 .60152 L
.97619 .60332 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000^Ool4
0003Ool2000KOol30002Ool2000IOol30004Ool2000JOol20004Ool2000FOol50002Ool20004Ool2
000COol500000goo000000020003Ool2000COol50003Ool30002Ool2000JOol002ioo`03001oogoo
00=oo`04001oogoo000KOol01000Oomoo`000Woo00<007ooOol05Woo00@007ooOol0009oo`04001o
ogoo000HOol01000Oomoo`000Woo00@007ooOol001Moo`05001oogooOol00002Ool01000Oomoo`00
0Woo00<007ooOol04Woo00D007ooOomoo`0000Eoo`04001oogoo000DOol00`00Oomoo`04Ool01000
Oomoo`000Woo00<007ooOol05goo000_Ool00`00Oomoo`02Ool01000Oomoo`0067oo1@0000Eoo`00
Oomoo`0001Qoo`04001oogoo0002Ool01000Oomoo`0067oo00@007ooOol0009oo`04001oogoo000G
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo019oo`03001oogoo009oo`03001o
ogoo009oo`04001oogoo000DOol01000Oomoogoo1@0000Eoo`00Oomoo`0001Uoo`00<7oo00D007oo
Oomoo`00009oo`03001oogoo01Ioo`04001oogoo0002Ool01000Oomoo`0067oo0`000goo00@007oo
Ool001Uoo`8000=oo`04001oogoo000GOol01@00Oomoogoo00000Woo00@007ooOol0009oo`03001o
ogoo019oo`03001oogoo00=oo`05001oogooOol00002Ool00`00Oomoo`0BOol01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo01Moo`00;Woo00@007ooOol0009oo`04001oogoo000IOol0
0`00Ool00002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol001Qoo`04001oogoo0002
Ool01000Oomoo`005goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`0BOol01@00
Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo019oo`03001oogoo009oo`03001oo`00009o
o`04001oogoo000IOol002moo`8000Aoo`8001]oo`8000=oo`8001Yoo`<000=oo`8001Yoo`8000Ao
o`8001Moo`8000Aoo`8000Aoo`8001Aoo`8000Aoo`8000Aoo`8001Aoo`8000Eoo`8000=oo`8001Yo
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000AOol00`00Oomoo`3oOol=Ool000Yoool0
00l000Qoo`004Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol01Goo00<007ooOol03Goo000AOol00`0001moo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0NOol0015oo`03001oo`0O0?moo`eoo`004Goo00<007oo01l0ogoo3Goo000AOol200000goo01mo
o`3oOol;Ool0015oo`05001oogooOol07`3oOol;Ool0015oo`05001oogooOol07`3oOol;Ool0015o
o`03001oogoo009oo`0301moogoo0?moo`Qoo`004Goo00<007ooOol00Woo00<07gooOol0ogoo27oo
000AOol20003Ool00`0OOomoo`3oOol8Ool0015oo`03001oogoo00=oo`0301moogoo0?moo`Moo`00
4Goo00<007ooOol00goo00<07gooOol0ogoo1goo000AOol00`00Oomoo`03Ool00`0OOomoo`3oOol7
Ool0015oo`03001oogoo00Aoo`0301moogoo0?moo`Ioo`004Goo0P001Goo00<07gooOol0ogoo1Woo
000AOol00`00Oomoo`05Ool00`0OOomoo`3oOol5Ool0015oo`03001oogoo00Eoo`0301moogoo0?mo
o`Eoo`004Goo00<007ooOol01Woo00<07gooOol0ogoo17oo000AOol00`00Oomoo`06Ool00`0OOomo
o`3oOol4Ool0015oo`8000Qoo`0301moogoo0?moo`=oo`004Goo00<007ooOol01goo00<07gooOol0
ogoo0goo000AOol00`00Oomoo`08Ool00`0OOomoo`3oOol2Ool000Uoo`8000Ioo`03001oogoo00Qo
o`0301moogoo0?moo`9oo`0027oo00@007ooOol000Eoo`03001oogoo00Uoo`0301moogoo0?moo`5o
o`002Woo00<007ooOol017oo0P002Woo00<07gooOol0ogoo0Goo000;Ool00`00Oomoo`03Ool00`00
Oomoo`0:Ool00`0OOomoo`3oOol000Qoo`04001oogoo0005Ool00`00Oomoo`0:Ool00`0OOomoo`3o
Ool000Uoo`8000Ioo`03001oogoo00]oo`0301moogoo0?ioo`004Goo00<007ooOol02goo00<07goo
Ool0oWoo000AOol00`00Oomoo`0<Ool00`0OOomoo`3mOol0015oo`8000ioo`0301moogoo0?aoo`00
4Goo00<007ooOol03Goo00<07gooOol0o7oo000AOol00`00Oomoo`0>Ool00`0OOomoo`3kOol0015o
o`03001oogoo00ioo`0301moogoo0?]oo`004Goo00<007ooOol03goo00<07gooOol0nWoo000AOol2
000@Ool00`0OOomoo`3jOol0015oo`03001oogoo011oo`0301moogoo0?Uoo`004Goo00<007ooOol0
4Goo00<07gooOol0n7oo000AOol00`00Oomoo`0BOol00`0OOomoo`3gOol0015oo`03001oogoo019o
o`0301moogoo0?Moo`004Goo0P0057oo00<07gooOol0mWoo000AOol00`00Oomoo`0DOol00`0OOomo
o`3eOol0015oo`03001oogoo01Aoo`0301moogoo0?Eoo`004Goo00<007ooOol05Goo00<07gooOol0
m7oo000AOol00`00Oomoo`0FOol00`0OOomoo`3cOol0015oo`8001Qoo`0301moogoo0?9oo`004Goo
00<007ooOol067oo00<07gooOol0lGoo000AOol00`00Oomoo`0IOol00`0OOomoo`3`Ool000Yoo`<0
00Aoo`03001oogoo01Yoo`0301moogoo0>moo`002goo00<007ooOol00goo00<007ooOol06goo00<0
7gooOol0kWoo0008Ool50004Ool2000LOol00`0OOomoo`3^Ool000Qoo`04001oogoo0005Ool00`00
Oomoo`0LOol00`0OOomoo`3]Ool000Uoo`03001oo`0000Eoo`03001oogoo01eoo`0301moogoo0>ao
o`002Woo0P001Goo00<007ooOol07Woo00<07gooOol0jgoo000AOol00`00Oomoo`0OOol00`0OOomo
o`3ZOol0015oo`80025oo`0301moogoo0>Uoo`004Goo00<007ooOol087oo00<07gooOol0jGoo000A
Ool00`00Oomoo`0QOol201oYOol0015oo`03001oogoo02=oo`0301moogoo0>Ioo`004Goo00<007oo
Ool097oo00<07gooOol0iGoo000AOol2000VOol00`0OOomoo`3TOol0015oo`03001oogoo02Ioo`03
01moogoo0>=oo`004Goo00<007ooOol09goo00<07gooOol0hWoo000AOol00`00Oomoo`0XOol00`0O
Oomoo`3QOol0015oo`03001oogoo02Uoo`0301moogoo0>1oo`004Goo0P00:goo0P0Oh7oo000AOol0
0`00Oomoo`0/Ool00`0OOomoo`3MOol0015oo`03001oogoo02aoo`0301moogoo0=eoo`004Goo00<0
07ooOol0;Goo0P0OgGoo000AOol00`00Oomoo`0_Ool00`0OOomoo`3JOol0015oo`80035oo`0301mo
ogoo0=Uoo`004Goo00<007ooOol0<Goo00<07gooOol0f7oo000AOol00`00Oomoo`0bOol201oHOol0
015oo`03001oogoo03Aoo`0301moogoo0=Eoo`002Goo0P001Woo00<007ooOol0=Goo00<07gooOol0
e7oo0008Ool01000Oomoo`001Goo00<007ooOol0=Woo0P0Oe7oo000;Ool00`00Oomoo`03Ool2000i
Ool00`0OOomoo`3AOol000Uoo`8000Ioo`03001oogoo03Uoo`0301moogoo0=1oo`002Goo00<007oo
Ool01Goo00<007ooOol0>Woo00<07gooOol0cgoo0009Ool30005Ool00`00Oomoo`0kOol201o?Ool0
015oo`03001oogoo03eoo`0301moogoo0<aoo`004Goo0P00?goo0P0Oc7oo000AOol00`00Oomoo`10
Ool201o:Ool0015oo`03001oogoo049oo`807lQoo`004Goo00<007ooOol0A7oo00<07gooOol0aGoo
000AOol00`00Oomoo`14Ool00`0OOomoo`35Ool0015oo`8004Ioo`807lEoo`004Goo00<007ooOol0
Agoo0P0O`goo000AOol00`00Oomoo`19Ool00`0OOomoo`30Ool0015oo`03001oogoo04Yoo`807l1o
o`004Goo00<007ooOol0C7oo0P0O_Woo000AOol2001?Ool00`0OOomoo`2kOol0015oo`03001oogoo
04moo`807k]oo`004Goo00<007ooOol0DGoo0P0O^Goo000AOol00`00Oomoo`1COol201ngOol0015o
o`03001oogoo05Eoo`0301moogoo0;Aoo`004Goo0P00Egoo0P0O]7oo000AOol00`00Oomoo`1HOol2
01nbOol0015oo`03001oogoo05Yoo`0301moogoo0:moo`0027oo0`001Woo00<007ooOol0Fgoo0P0O
[goo0008Ool01000Oomoo`001Goo00<007ooOol0GGoo0P0O[Goo0008Ool01000Oomoo`001Goo0P00
H7oo00<07gooOol0ZWoo0008Ool30006Ool00`00Oomoo`1POol401nXOol000Uoo`03001oogoo00Eo
o`03001oogoo06Aoo`807jIoo`002Goo0`001Goo00<007ooOol0IWoo00<07gooOol0Xgoo000AOol0
0`00Oomoo`1WOol201nSOol0015oo`8006Yoo`807j5oo`004Goo00<007ooOol0Jgoo00<07gooOol0
WWoo000AOol00`00Oomoo`1/Ool401nLOol0015oo`03001oogoo071oo`807iYoo`004Goo00<007oo
Ool0LWoo00<07gooOol0Ugoo000AOol2001dOol201nGOol0015oo`03001oogoo07Eoo`<07iAoo`00
4Goo00<007ooOol0N7oo0P0OTWoo000AOol00`00Oomoo`1jOol201n@Ool0015oo`03001oogoo07ao
o`0301moogoo08eoo`004Goo00<007ooOol0OGoo100ORgoo000AOol20022Ool201n9Ool0015oo`03
001oogoo08=oo`0301moogoo08Ioo`004Goo00<007ooOol0Q7oo100OQ7oo000AOol00`00Oomoo`28
Ool00`0OOomoo`21Ool0015oo`03001oogoo08Uoo`@07gmoo`004Goo0P00SWoo0P0OOGoo000AOol0
0`00Oomoo`2?Ool00`0OOomoo`1jOol0015oo`03001oogoo091oo`@07gQoo`002Woo00<007ooOol0
17oo00<007ooOol0U7oo00<07gooOol0MGoo000:Ool00`00Oomoo`04Ool00`00Oomoo`2EOol401mc
Ool000Yoo`03001oogoo00Aoo`8009Yoo`0301moogoo071oo`002goo00<007ooOol00goo00<007oo
Ool0VWoo100OKWoo0008Ool01000Oomoo`001Goo00<007ooOol0WWoo0P0OK7oo0008Ool40005Ool0
0`00Oomoo`2POol301mYOol0015oo`03001oogoo0:=oo`<07fIoo`004Goo0P00Ygoo0P0OI7oo000A
Ool00`00Oomoo`2XOol401mPOol0015oo`03001oogoo0:aoo`0301moogoo05eoo`004Goo00<007oo
Ool0[Goo100OFgoo000AOol00`00Oomoo`2aOol301mHOol0015oo`800;Eoo`807eIoo`004Goo00<0
07ooOol0]Woo0`0ODgoo000AOol00`00Oomoo`2iOol401m?Ool0015oo`03001oogoo0;eoo`0301mo
ogoo04aoo`004Goo00<007ooOol0_Woo100OBWoo000AOol20033Ool301m7Ool0015oo`03001oogoo
0<Eoo`@07d=oo`004Goo00<007ooOol0bGoo00<07gooOol0@7oo000AOol00`00Oomoo`3:Ool401ln
Ool0015oo`03001oogoo0<ioo`<07c]oo`004Goo0P00dWoo0`0O>7oo000AOol00`00Oomoo`3DOol4
01ldOol0015oo`03001oogoo0=Qoo`<07c5oo`002Goo0P001Woo00<007ooOol0fgoo100O;Goo0008
Ool01000Oomoo`001Goo00<007ooOol0ggoo00<07gooOol0:Woo0008Ool01000Oomoo`001Goo0P00
hGoo100O:7oo0009Ool20006Ool00`00Oomoo`3TOol301lUOol000Qoo`04001oogoo0005Ool00`00
Oomoo`3WOol401lQOol000Uoo`8000Ioo`03001oogoo0>]oo`<07aioo`004Goo00<007ooOol0kWoo
0`0O6goo000AOol2003bOol401lGOol0015oo`03001oogoo0?Eoo`<07aAoo`004Goo00<007ooOol0
n7oo100O47oo000AOol00`00Oomoo`3lOol00`0OOomoo`0=Ool0015oo`03001oogoo0?moo`eoo`00
4Goo00<007ooOol0ogoo3Goo000AOol2003oOol>Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-10.0273, 1.51665, 0.586471, \
0.0391159}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["tbl4=Flatten[Chop[Table[{(Y[1,t]-Y[2,t])},{t,1,150}]]];", "Input"],

Cell[CellGroupData[{

Cell["ListPlot[tbl4,PlotJoined->True,PlotStyle->RGBColor[0,1,1]]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00634921 0.0147151 0.200714 [
[.15079 .00222 -6 -9 ]
[.15079 .00222 6 0 ]
[.27778 .00222 -6 -9 ]
[.27778 .00222 6 0 ]
[.40476 .00222 -6 -9 ]
[.40476 .00222 6 0 ]
[.53175 .00222 -6 -9 ]
[.53175 .00222 6 0 ]
[.65873 .00222 -9 -9 ]
[.65873 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.9127 .00222 -9 -9 ]
[.9127 .00222 9 0 ]
[.01131 .11507 -18 -4.5 ]
[.01131 .11507 0 4.5 ]
[.01131 .21543 -6 -4.5 ]
[.01131 .21543 0 4.5 ]
[.01131 .31579 -18 -4.5 ]
[.01131 .31579 0 4.5 ]
[.01131 .41614 -6 -4.5 ]
[.01131 .41614 0 4.5 ]
[.01131 .5165 -18 -4.5 ]
[.01131 .5165 0 4.5 ]
[.01131 .61686 -6 -4.5 ]
[.01131 .61686 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15079 .01472 m
.15079 .02097 L
s
[(20)] .15079 .00222 0 1 Mshowa
.27778 .01472 m
.27778 .02097 L
s
[(40)] .27778 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(60)] .40476 .00222 0 1 Mshowa
.53175 .01472 m
.53175 .02097 L
s
[(80)] .53175 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(100)] .65873 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(120)] .78571 .00222 0 1 Mshowa
.9127 .01472 m
.9127 .02097 L
s
[(140)] .9127 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.18254 .01472 m
.18254 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.34127 .01472 m
.34127 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.81746 .01472 m
.81746 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11507 m
.03006 .11507 L
s
[(0.5)] .01131 .11507 1 0 Mshowa
.02381 .21543 m
.03006 .21543 L
s
[(1)] .01131 .21543 1 0 Mshowa
.02381 .31579 m
.03006 .31579 L
s
[(1.5)] .01131 .31579 1 0 Mshowa
.02381 .41614 m
.03006 .41614 L
s
[(2)] .01131 .41614 1 0 Mshowa
.02381 .5165 m
.03006 .5165 L
s
[(2.5)] .01131 .5165 1 0 Mshowa
.02381 .61686 m
.03006 .61686 L
s
[(3)] .01131 .61686 1 0 Mshowa
.125 Mabswid
.02381 .03479 m
.02756 .03479 L
s
.02381 .05486 m
.02756 .05486 L
s
.02381 .07493 m
.02756 .07493 L
s
.02381 .095 m
.02756 .095 L
s
.02381 .13514 m
.02756 .13514 L
s
.02381 .15521 m
.02756 .15521 L
s
.02381 .17529 m
.02756 .17529 L
s
.02381 .19536 m
.02756 .19536 L
s
.02381 .2355 m
.02756 .2355 L
s
.02381 .25557 m
.02756 .25557 L
s
.02381 .27564 m
.02756 .27564 L
s
.02381 .29571 m
.02756 .29571 L
s
.02381 .33586 m
.02756 .33586 L
s
.02381 .35593 m
.02756 .35593 L
s
.02381 .376 m
.02756 .376 L
s
.02381 .39607 m
.02756 .39607 L
s
.02381 .43621 m
.02756 .43621 L
s
.02381 .45629 m
.02756 .45629 L
s
.02381 .47636 m
.02756 .47636 L
s
.02381 .49643 m
.02756 .49643 L
s
.02381 .53657 m
.02756 .53657 L
s
.02381 .55664 m
.02756 .55664 L
s
.02381 .57671 m
.02756 .57671 L
s
.02381 .59679 m
.02756 .59679 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 1 1 r
.5 Mabswid
.03016 .04623 m
.03651 .0786 L
.04286 .10579 L
.04921 .12773 L
.05556 .14602 L
.0619 .16168 L
.06825 .17543 L
.0746 .18773 L
.08095 .19889 L
.0873 .20913 L
.09365 .21862 L
.1 .22746 L
.10635 .23577 L
.1127 .2436 L
.11905 .25103 L
.1254 .25809 L
.13175 .26483 L
.1381 .27129 L
.14444 .27748 L
.15079 .28344 L
.15714 .28918 L
.16349 .29473 L
.16984 .3001 L
.17619 .3053 L
.18254 .31035 L
.18889 .31525 L
.19524 .32002 L
.20159 .32466 L
.20794 .32918 L
.21429 .33359 L
.22063 .3379 L
.22698 .34211 L
.23333 .34623 L
.23968 .35026 L
.24603 .3542 L
.25238 .35807 L
.25873 .36186 L
.26508 .36558 L
.27143 .36922 L
.27778 .37281 L
.28413 .37633 L
.29048 .37979 L
.29683 .38319 L
.30317 .38654 L
.30952 .38983 L
.31587 .39307 L
.32222 .39626 L
.32857 .39941 L
.33492 .40251 L
.34127 .40556 L
Mistroke
.34762 .40857 L
.35397 .41154 L
.36032 .41448 L
.36667 .41737 L
.37302 .42022 L
.37937 .42304 L
.38571 .42583 L
.39206 .42858 L
.39841 .43129 L
.40476 .43398 L
.41111 .43663 L
.41746 .43925 L
.42381 .44185 L
.43016 .44441 L
.43651 .44695 L
.44286 .44946 L
.44921 .45194 L
.45556 .4544 L
.4619 .45684 L
.46825 .45924 L
.4746 .46163 L
.48095 .46399 L
.4873 .46633 L
.49365 .46865 L
.5 .47094 L
.50635 .47322 L
.5127 .47547 L
.51905 .4777 L
.5254 .47991 L
.53175 .48211 L
.5381 .48428 L
.54444 .48644 L
.55079 .48858 L
.55714 .4907 L
.56349 .4928 L
.56984 .49488 L
.57619 .49695 L
.58254 .49901 L
.58889 .50104 L
.59524 .50306 L
.60159 .50507 L
.60794 .50706 L
.61429 .50903 L
.62063 .51099 L
.62698 .51294 L
.63333 .51487 L
.63968 .51679 L
.64603 .51869 L
.65238 .52058 L
.65873 .52246 L
Mistroke
.66508 .52433 L
.67143 .52618 L
.67778 .52802 L
.68413 .52984 L
.69048 .53166 L
.69683 .53346 L
.70317 .53525 L
.70952 .53703 L
.71587 .5388 L
.72222 .54056 L
.72857 .54231 L
.73492 .54404 L
.74127 .54577 L
.74762 .54748 L
.75397 .54919 L
.76032 .55088 L
.76667 .55257 L
.77302 .55424 L
.77937 .5559 L
.78571 .55756 L
.79206 .5592 L
.79841 .56084 L
.80476 .56247 L
.81111 .56409 L
.81746 .56569 L
.82381 .56729 L
.83016 .56889 L
.83651 .57047 L
.84286 .57204 L
.84921 .57361 L
.85556 .57517 L
.8619 .57671 L
.86825 .57826 L
.8746 .57979 L
.88095 .58131 L
.8873 .58283 L
.89365 .58434 L
.9 .58585 L
.90635 .58734 L
.9127 .58883 L
.91905 .59031 L
.9254 .59178 L
.93175 .59325 L
.9381 .59471 L
.94444 .59616 L
.95079 .5976 L
.95714 .59904 L
.96349 .60047 L
.96984 .6019 L
.97619 .60332 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000eOol4
0003Ool2000JOol30002Ool2000IOol30004Ool2000JOol20004Ool2000FOol50002Ool20004Ool2
000BOol500000goo000000020003Ool2000COol50003Ool30002Ool2000EOol003Eoo`03001oogoo
00=oo`04001oogoo000JOol01000Oomoo`000Woo00<007ooOol05Woo00@007ooOol0009oo`04001o
ogoo000HOol01000Oomoo`000Woo00@007ooOol001Moo`05001oogooOol00002Ool01000Oomoo`00
0Woo00<007ooOol04Goo00D007ooOomoo`0000Eoo`04001oogoo000DOol00`00Oomoo`04Ool01000
Oomoo`000Woo00<007ooOol04Woo000fOol00`00Oomoo`02Ool01000Oomoo`005goo1@0000Eoo`00
Oomoo`0001Qoo`04001oogoo0002Ool01000Oomoo`0067oo00@007ooOol0009oo`04001oogoo000G
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo015oo`03001oogoo009oo`03001o
ogoo009oo`04001oogoo000DOol01000Oomoogoo1@0000Eoo`00Oomoo`0001Aoo`00=goo00D007oo
Oomoo`00009oo`03001oogoo01Eoo`04001oogoo0002Ool01000Oomoo`0067oo0`000goo00@007oo
Ool001Uoo`8000=oo`04001oogoo000GOol01@00Oomoogoo00000Woo00@007ooOol0009oo`03001o
ogoo015oo`03001oogoo00=oo`05001oogooOol00002Ool00`00Oomoo`0BOol01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo019oo`00=Goo00@007ooOol0009oo`04001oogoo000HOol0
0`00Ool00002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol001Qoo`04001oogoo0002
Ool01000Oomoo`005goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`0AOol01@00
Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo019oo`03001oogoo009oo`03001oo`00009o
o`04001oogoo000DOol003Ioo`8000Aoo`8001Yoo`8000=oo`8001Yoo`<000=oo`8001Yoo`8000Ao
o`8001Moo`8000Aoo`8000Aoo`8001=oo`8000Aoo`8000Aoo`8001Aoo`8000Eoo`8000=oo`8001Eo
o`00ogoo8Goo000HOol00`00Oomoo`3oOol6Ool001Qoo`03001oogoo0?moo`Ioo`0067oo00<007oo
Ool0ogoo1Woo000HOol00`00Oomoo`3oOol6Ool0019oool000/000Aoo`0067oo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol027oo
000HOol00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0OOol00`00Oomoo`0NOol00`00Oomoo`0OOol00`00Oomoo`0IOol001Qoo`03001oogoo0?moo`Io
o`0067oo00<007ooOol0ogoo1Woo000HOol2003oOol7Ool001Qoo`03001oogoo0?moo`Ioo`0067oo
00<007ooOol0ogoo1Woo000HOol00`00Ool3o`3oOol6Ool001Qoo`03001oo`?o0?moo`Ioo`0067oo
00<007oo0ol0ogoo1Woo000HOol200000`?oOomoo`3oOol4Ool001Qoo`03001oo`?o0?moo`Ioo`00
67oo00@007ooOol3oomoo`Eoo`0067oo00@007ooOol3oomoo`Eoo`0067oo00@007ooOol3oomoo`Eo
o`0067oo0P0000=oo`?oOol0ogoo17oo000HOol01000Oomoo`?oogoo1Goo000HOol01000Oomoo`?o
ogoo1Goo000HOol01@00Oomoogoo0ol0ogoo17oo000HOol01@00Oomoogoo0ol0ogoo17oo000HOol2
0002Ool00`?oOomoo`3oOol2Ool001Qoo`05001oogooOol3o`3oOol4Ool001Qoo`03001oogoo009o
o`030omoogoo0?moo`5oo`0067oo00<007ooOol00Woo00<3ogooOol0ogoo0Goo0005Ool20004Ool2
0004Ool20005Ool00`00Oomoo`02Ool00`?oOomoo`3oOol1Ool000Aoo`04001oogoo0008Ool01000
Oomoo`0017oo00<007ooOol00goo00<3ogooOol0ogoo0004Ool01000Oomoo`002goo00<007ooOol0
0Woo0`000goo00<3ogooOol0ogoo0004Ool01000Oomoo`002Goo0P001Goo00<007ooOol00goo00<3
ogooOol0ogoo0004Ool01000Oomoo`002Goo00<007ooOol017oo00<007ooOol017oo00<3ogooOol0
oWoo0005Ool2000:Ool30004Ool00`00Oomoo`04Ool00`?oOomoo`3nOol001Qoo`03001oogoo00Ao
o`030omoogoo0?ioo`0067oo0P001Goo00<3ogooOol0oWoo000HOol00`00Oomoo`05Ool00`?oOomo
o`3mOol001Qoo`03001oogoo00Eoo`030omoogoo0?eoo`0067oo00<007ooOol01Goo00<3ogooOol0
oGoo000HOol00`00Oomoo`06Ool00`?oOomoo`3lOol001Qoo`8000Moo`030omoogoo0?aoo`0067oo
00<007ooOol01goo00<3ogooOol0ngoo000HOol00`00Oomoo`07Ool00`?oOomoo`3kOol001Qoo`03
001oogoo00Qoo`030omoogoo0?Yoo`0067oo00<007ooOol027oo00<3ogooOol0nWoo000HOol00`00
Oomoo`09Ool00`?oOomoo`3iOol001Qoo`8000Yoo`030omoogoo0?Uoo`0067oo00<007ooOol02Goo
00<3ogooOol0nGoo000HOol00`00Oomoo`0:Ool00`?oOomoo`3hOol001Qoo`03001oogoo00Yoo`03
0omoogoo0?Qoo`0067oo00<007ooOol02goo00<3ogooOol0mgoo000HOol2000<Ool00`?oOomoo`3g
Ool001Qoo`03001oogoo00aoo`030omoogoo0?Ioo`0067oo00<007ooOol03Goo00<3ogooOol0mGoo
000@Ool50003Ool00`00Oomoo`0=Ool00`?oOomoo`3eOol0019oo`03001oogoo00=oo`03001oogoo
00ioo`030omoogoo0?Aoo`004Woo00<007ooOol00goo0`003goo00<3ogooOol0lgoo000BOol00`00
Oomoo`03Ool00`00Oomoo`0?Ool00`?oOomoo`3cOol0019oo`03001oogoo00=oo`03001oogoo011o
o`030omoogoo0?9oo`004Goo0P001Goo00<007ooOol04Goo00<3ogooOol0lGoo000HOol00`00Oomo
o`0BOol00`?oOomoo`3`Ool001Qoo`03001oogoo019oo`030omoogoo0?1oo`0067oo0P0057oo00<3
ogooOol0kgoo000HOol00`00Oomoo`0DOol00`?oOomoo`3^Ool001Qoo`03001oogoo01Eoo`030omo
ogoo0>eoo`0067oo00<007ooOol05Woo00<3ogooOol0k7oo000HOol00`00Oomoo`0FOol00`?oOomo
o`3/Ool001Qoo`8001Qoo`030omoogoo0>]oo`0067oo00<007ooOol067oo00<3ogooOol0jWoo000H
Ool00`00Oomoo`0IOol20ooZOol001Qoo`03001oogoo01]oo`030omoogoo0>Moo`0067oo00<007oo
Ool06goo00<3ogooOol0igoo000HOol2000MOol00`?oOomoo`3VOol001Qoo`03001oogoo01eoo`03
0omoogoo0>Eoo`0067oo00<007ooOol07Woo0P?oiGoo000HOol00`00Oomoo`0POol00`?oOomoo`3R
Ool001Qoo`03001oogoo021oo`030omoogoo0>9oo`0067oo00<007ooOol08Goo0P?ohWoo000HOol2
000TOol00`?oOomoo`3OOol001Qoo`03001oogoo02Aoo`030omoogoo0=ioo`0067oo00<007ooOol0
9Goo00<3ogooOol0gGoo0004Ool50002Ool20004Ool20005Ool00`00Oomoo`0VOol20ooMOol000Io
o`03001oogoo00Moo`04001oogoo0004Ool00`00Oomoo`0XOol00`?oOomoo`3JOol000Ioo`03001o
ogoo00Yoo`03001oogoo009oo`<002Uoo`030omoogoo0=Uoo`001Woo00<007ooOol027oo0P001Goo
00<007ooOol0:Woo00<3ogooOol0f7oo0006Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomo
o`0[Ool20ooHOol000Eoo`8000Yoo`<000Aoo`03001oogoo02eoo`030omoogoo0=Eoo`0067oo00<0
07ooOol0;Woo00<3ogooOol0e7oo000HOol2000`Ool20ooDOol001Qoo`03001oogoo035oo`030omo
ogoo0=5oo`0067oo00<007ooOol0<Woo0P?odGoo000HOol00`00Oomoo`0dOol20oo?Ool001Qoo`03
001oogoo03Ioo`030omoogoo0<aoo`0067oo00<007ooOol0=goo0P?oc7oo000HOol2000jOol20oo:
Ool001Qoo`03001oogoo03]oo`030omoogoo0<Moo`0067oo00<007ooOol0?7oo0P?oagoo000HOol0
0`00Oomoo`0nOol20oo5Ool001Qoo`03001oogoo041oo`030omoogoo0<9oo`0067oo0P00@Woo0P?o
`Woo000HOol00`00Oomoo`13Ool20oo0Ool001Qoo`03001oogoo04Eoo`030omoogoo0;eoo`0067oo
00<007ooOol0AWoo0P?o_Goo000HOol00`00Oomoo`18Ool40oniOol001Qoo`8004eoo`030omoogoo
0;Ioo`0067oo00<007ooOol0CGoo0P?o]Woo000HOol00`00Oomoo`1?Ool20ondOol001Qoo`03001o
ogoo055oo`030omoogoo0;5oo`0047oo100017oo00<007ooOol0DWoo10?o[goo000@Ool00`00Oomo
o`05Ool00`00Oomoo`1FOol00`?oOomoo`2/Ool0015oo`03001oogoo00Aoo`<005Moo`83ojaoo`00
4Woo00<007ooOol00goo00<007ooOol0FGoo0`?oZGoo000@Ool01000Oomoo`0017oo00<007ooOol0
G7oo0P?oYgoo000AOol20005Ool00`00Oomoo`1NOol20onUOol001Qoo`03001oogoo061oo`<3oj9o
o`0067oo0P00I7oo0P?oX7oo000HOol00`00Oomoo`1UOol30onMOol001Qoo`03001oogoo06Qoo`83
oi]oo`0067oo00<007ooOol0JWoo0`?oV7oo000HOol00`00Oomoo`1]Ool20onFOol001Qoo`80071o
o`<3oi=oo`0067oo00<007ooOol0LWoo0P?oTGoo000HOol00`00Oomoo`1dOol30on>Ool001Qoo`03
001oogoo07Moo`83ohaoo`0067oo00<007ooOol0NGoo0`?oRGoo000HOol00`00Oomoo`1lOol40on5
Ool001Qoo`80085oo`83oh=oo`0067oo00<007ooOol0PWoo0`?oP7oo000HOol00`00Oomoo`25Ool3
0ommOol001Qoo`03001oogoo08Qoo`@3ogUoo`0067oo00<007ooOol0S7oo00<3ogooOol0MWoo000H
Ool2002>Ool40omdOol001Qoo`03001oogoo095oo`<3og5oo`0067oo00<007ooOol0U7oo10?oKGoo
0004Ool40003Ool20004Ool20005Ool00`00Oomoo`2HOol30omZOol000Aoo`03001oogoo00Uoo`04
001oogoo0004Ool00`00Oomoo`2KOol30omWOol000Eoo`03001oogoo00]oo`03001oogoo009oo`<0
09ioo`@3of=oo`001Woo00<007ooOol027oo0P001Goo00<007ooOol0XWoo0`?oH7oo0004Ool01000
Oomoo`002Goo00<007ooOol017oo00<007ooOol0YGoo0`?oGGoo0005Ool2000:Ool30004Ool00`00
Oomoo`2XOol40omIOol001Qoo`03001oogoo0:aoo`<3oeIoo`0067oo00<007ooOol0[goo10?oDWoo
000HOol2002dOol30om?Ool001Qoo`03001oogoo0;Ioo`<3odaoo`0067oo00<007ooOol0^Goo10?o
B7oo000HOol00`00Oomoo`2mOol50om3Ool001Qoo`03001oogoo0<9oo`<3od1oo`0067oo0P00aWoo
0`?o?Goo000HOol00`00Oomoo`38Ool40oliOol001Qoo`03001oogoo0<aoo`D3ocAoo`0067oo00<0
07ooOol0dGoo0`?o<Goo000HOol00`00Oomoo`3DOol50ol/Ool001Qoo`800=Yoo`@3obQoo`0067oo
00<007ooOol0gGoo0`?o9Goo000HOol00`00Oomoo`3POol50olPOol001Qoo`03001oogoo0>Eoo`@3
oaaoo`0067oo00<007ooOol0jGoo1@?o5goo000HOol00`00Oomoo`3^Ool50olBOol001Qoo`800?Ao
o`<3o`moo`0067oo00<007ooOol0mWoo1@?o2Woo000HOol00`00Oomoo`3oOol6Ool0015oo`8000Eo
o`03001oogoo0?moo`Ioo`0047oo00@007ooOol000Aoo`03001oogoo0?moo`Ioo`004Woo00<007oo
Ool00goo0`00ogoo1Woo000COol00`00Oomoo`3oOol;Ool0011oo`04001oogoo003oOol=Ool0015o
o`800?moo`ioo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-14.4376, -0.2309, 0.592316, \
0.0187368}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["DR=.", "Input"],

Cell["\<\
For[i=1,i<151,{DX = X[1,i-1] - X[2,i-1];
DY = Y[1,i-1] - Y[2,i-1];
DZ = Z[1,i-1] - Z[2,i-1];
DR[i] = (DX^2. + DY^2. + DZ^2.)^0.5;i++}];\
\>", "Input"],

Cell["tbl5=Chop[Table[DR[i],{i,1,150}]];", "Input"],

Cell[CellGroupData[{

Cell["ListPlot[tbl5,PlotJoined->True,PlotStyle->RGBColor[1,0,0]]", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00634921 -0.170692 0.0882892 [
[.15079 -0.00661 -6 -9 ]
[.15079 -0.00661 6 0 ]
[.27778 -0.00661 -6 -9 ]
[.27778 -0.00661 6 0 ]
[.40476 -0.00661 -6 -9 ]
[.40476 -0.00661 6 0 ]
[.53175 -0.00661 -6 -9 ]
[.53175 -0.00661 6 0 ]
[.65873 -0.00661 -9 -9 ]
[.65873 -0.00661 9 0 ]
[.78571 -0.00661 -9 -9 ]
[.78571 -0.00661 9 0 ]
[.9127 -0.00661 -9 -9 ]
[.9127 -0.00661 9 0 ]
[.01131 .09418 -6 -4.5 ]
[.01131 .09418 0 4.5 ]
[.01131 .18246 -6 -4.5 ]
[.01131 .18246 0 4.5 ]
[.01131 .27075 -6 -4.5 ]
[.01131 .27075 0 4.5 ]
[.01131 .35904 -6 -4.5 ]
[.01131 .35904 0 4.5 ]
[.01131 .44733 -6 -4.5 ]
[.01131 .44733 0 4.5 ]
[.01131 .53562 -6 -4.5 ]
[.01131 .53562 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15079 .00589 m
.15079 .01214 L
s
[(20)] .15079 -0.00661 0 1 Mshowa
.27778 .00589 m
.27778 .01214 L
s
[(40)] .27778 -0.00661 0 1 Mshowa
.40476 .00589 m
.40476 .01214 L
s
[(60)] .40476 -0.00661 0 1 Mshowa
.53175 .00589 m
.53175 .01214 L
s
[(80)] .53175 -0.00661 0 1 Mshowa
.65873 .00589 m
.65873 .01214 L
s
[(100)] .65873 -0.00661 0 1 Mshowa
.78571 .00589 m
.78571 .01214 L
s
[(120)] .78571 -0.00661 0 1 Mshowa
.9127 .00589 m
.9127 .01214 L
s
[(140)] .9127 -0.00661 0 1 Mshowa
.125 Mabswid
.05556 .00589 m
.05556 .00964 L
s
.0873 .00589 m
.0873 .00964 L
s
.11905 .00589 m
.11905 .00964 L
s
.18254 .00589 m
.18254 .00964 L
s
.21429 .00589 m
.21429 .00964 L
s
.24603 .00589 m
.24603 .00964 L
s
.30952 .00589 m
.30952 .00964 L
s
.34127 .00589 m
.34127 .00964 L
s
.37302 .00589 m
.37302 .00964 L
s
.43651 .00589 m
.43651 .00964 L
s
.46825 .00589 m
.46825 .00964 L
s
.5 .00589 m
.5 .00964 L
s
.56349 .00589 m
.56349 .00964 L
s
.59524 .00589 m
.59524 .00964 L
s
.62698 .00589 m
.62698 .00964 L
s
.69048 .00589 m
.69048 .00964 L
s
.72222 .00589 m
.72222 .00964 L
s
.75397 .00589 m
.75397 .00964 L
s
.81746 .00589 m
.81746 .00964 L
s
.84921 .00589 m
.84921 .00964 L
s
.88095 .00589 m
.88095 .00964 L
s
.94444 .00589 m
.94444 .00964 L
s
.97619 .00589 m
.97619 .00964 L
s
.25 Mabswid
0 .00589 m
1 .00589 L
s
.02381 .09418 m
.03006 .09418 L
s
[(3)] .01131 .09418 1 0 Mshowa
.02381 .18246 m
.03006 .18246 L
s
[(4)] .01131 .18246 1 0 Mshowa
.02381 .27075 m
.03006 .27075 L
s
[(5)] .01131 .27075 1 0 Mshowa
.02381 .35904 m
.03006 .35904 L
s
[(6)] .01131 .35904 1 0 Mshowa
.02381 .44733 m
.03006 .44733 L
s
[(7)] .01131 .44733 1 0 Mshowa
.02381 .53562 m
.03006 .53562 L
s
[(8)] .01131 .53562 1 0 Mshowa
.125 Mabswid
.02381 .02354 m
.02756 .02354 L
s
.02381 .0412 m
.02756 .0412 L
s
.02381 .05886 m
.02756 .05886 L
s
.02381 .07652 m
.02756 .07652 L
s
.02381 .11183 m
.02756 .11183 L
s
.02381 .12949 m
.02756 .12949 L
s
.02381 .14715 m
.02756 .14715 L
s
.02381 .16481 m
.02756 .16481 L
s
.02381 .20012 m
.02756 .20012 L
s
.02381 .21778 m
.02756 .21778 L
s
.02381 .23544 m
.02756 .23544 L
s
.02381 .2531 m
.02756 .2531 L
s
.02381 .28841 m
.02756 .28841 L
s
.02381 .30607 m
.02756 .30607 L
s
.02381 .32373 m
.02756 .32373 L
s
.02381 .34139 m
.02756 .34139 L
s
.02381 .3767 m
.02756 .3767 L
s
.02381 .39436 m
.02756 .39436 L
s
.02381 .41202 m
.02756 .41202 L
s
.02381 .42967 m
.02756 .42967 L
s
.02381 .46499 m
.02756 .46499 L
s
.02381 .48265 m
.02756 .48265 L
s
.02381 .50031 m
.02756 .50031 L
s
.02381 .51796 m
.02756 .51796 L
s
.02381 .55328 m
.02756 .55328 L
s
.02381 .57094 m
.02756 .57094 L
s
.02381 .58859 m
.02756 .58859 L
s
.02381 .60625 m
.02756 .60625 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.03016 .01472 m
.03651 .01523 L
.04286 .02571 L
.04921 .04141 L
.05556 .0574 L
.0619 .07245 L
.06825 .08638 L
.0746 .09927 L
.08095 .11126 L
.0873 .12247 L
.09365 .13301 L
.1 .14295 L
.10635 .15238 L
.1127 .16134 L
.11905 .1699 L
.1254 .1781 L
.13175 .18596 L
.1381 .19352 L
.14444 .20081 L
.15079 .20784 L
.15714 .21465 L
.16349 .22125 L
.16984 .22765 L
.17619 .23386 L
.18254 .23991 L
.18889 .24579 L
.19524 .25153 L
.20159 .25712 L
.20794 .26258 L
.21429 .26792 L
.22063 .27314 L
.22698 .27825 L
.23333 .28325 L
.23968 .28815 L
.24603 .29296 L
.25238 .29767 L
.25873 .3023 L
.26508 .30684 L
.27143 .3113 L
.27778 .31569 L
.28413 .32 L
.29048 .32425 L
.29683 .32842 L
.30317 .33254 L
.30952 .33658 L
.31587 .34057 L
.32222 .3445 L
.32857 .34838 L
.33492 .3522 L
.34127 .35597 L
Mistroke
.34762 .35969 L
.35397 .36336 L
.36032 .36698 L
.36667 .37056 L
.37302 .37409 L
.37937 .37758 L
.38571 .38103 L
.39206 .38443 L
.39841 .3878 L
.40476 .39113 L
.41111 .39442 L
.41746 .39768 L
.42381 .4009 L
.43016 .40409 L
.43651 .40724 L
.44286 .41036 L
.44921 .41345 L
.45556 .41651 L
.4619 .41954 L
.46825 .42254 L
.4746 .42551 L
.48095 .42845 L
.4873 .43136 L
.49365 .43425 L
.5 .43711 L
.50635 .43995 L
.5127 .44276 L
.51905 .44555 L
.5254 .44831 L
.53175 .45105 L
.5381 .45377 L
.54444 .45646 L
.55079 .45913 L
.55714 .46178 L
.56349 .46441 L
.56984 .46702 L
.57619 .46961 L
.58254 .47217 L
.58889 .47472 L
.59524 .47725 L
.60159 .47976 L
.60794 .48225 L
.61429 .48473 L
.62063 .48718 L
.62698 .48962 L
.63333 .49204 L
.63968 .49445 L
.64603 .49683 L
.65238 .49921 L
.65873 .50156 L
Mistroke
.66508 .5039 L
.67143 .50622 L
.67778 .50853 L
.68413 .51083 L
.69048 .5131 L
.69683 .51537 L
.70317 .51762 L
.70952 .51985 L
.71587 .52207 L
.72222 .52428 L
.72857 .52648 L
.73492 .52866 L
.74127 .53083 L
.74762 .53298 L
.75397 .53512 L
.76032 .53725 L
.76667 .53937 L
.77302 .54148 L
.77937 .54357 L
.78571 .54565 L
.79206 .54772 L
.79841 .54978 L
.80476 .55183 L
.81111 .55387 L
.81746 .55589 L
.82381 .5579 L
.83016 .55991 L
.83651 .5619 L
.84286 .56388 L
.84921 .56586 L
.85556 .56782 L
.8619 .56977 L
.86825 .57171 L
.8746 .57364 L
.88095 .57557 L
.8873 .57748 L
.89365 .57938 L
.9 .58128 L
.90635 .58316 L
.9127 .58504 L
.91905 .5869 L
.9254 .58876 L
.93175 .59061 L
.9381 .59245 L
.94444 .59428 L
.95079 .59611 L
.95714 .59792 L
.96349 .59973 L
.96984 .60153 L
.97619 .60332 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo000^Ool4
0003Ool2000KOol30002Ool2000IOol30004Ool2000JOol20004Ool2000FOol50002Ool20004Ool2
000COol500000goo000000020003Ool2000COol50003Ool30002Ool2000JOol002ioo`03001oogoo
00=oo`04001oogoo000KOol01000Oomoo`000Woo00<007ooOol05Woo00@007ooOol0009oo`04001o
ogoo000HOol01000Oomoo`000Woo00@007ooOol001Moo`05001oogooOol00002Ool01000Oomoo`00
0Woo00<007ooOol04Woo00D007ooOomoo`0000Eoo`04001oogoo000DOol00`00Oomoo`04Ool01000
Oomoo`000Woo00<007ooOol05goo000_Ool00`00Oomoo`02Ool01000Oomoo`0067oo1@0000Eoo`00
Oomoo`0001Qoo`04001oogoo0002Ool01000Oomoo`0067oo00@007ooOol0009oo`04001oogoo000G
Ool01@00Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo019oo`03001oogoo009oo`03001o
ogoo009oo`04001oogoo000DOol01000Oomoogoo1@0000Eoo`00Oomoo`0001Uoo`00<7oo00D007oo
Oomoo`00009oo`03001oogoo01Ioo`04001oogoo0002Ool01000Oomoo`0067oo0`000goo00@007oo
Ool001Uoo`8000=oo`04001oogoo000GOol01@00Oomoogoo00000Woo00@007ooOol0009oo`03001o
ogoo019oo`03001oogoo00=oo`05001oogooOol00002Ool00`00Oomoo`0BOol01@00Oomoogoo0000
0Woo00@007ooOol0009oo`03001oogoo01Moo`00;Woo00@007ooOol0009oo`04001oogoo000IOol0
0`00Ool00002Ool01000Oomoo`006Goo00<007ooOol00Woo00@007ooOol001Qoo`04001oogoo0002
Ool01000Oomoo`005goo00D007ooOomoo`00009oo`04001oogoo0002Ool00`00Oomoo`0BOol01@00
Oomoogoo00000Woo00@007ooOol0009oo`03001oogoo019oo`03001oogoo009oo`03001oo`00009o
o`04001oogoo000IOol002moo`8000Aoo`8001]oo`8000=oo`8001Yoo`<000=oo`8001Yoo`8000Ao
o`8001Moo`8000Aoo`8000Aoo`8001Aoo`8000Aoo`8000Aoo`8001Aoo`8000Eoo`8000=oo`8001Yo
o`00ogoo8Goo003oOolQOol00?moob5oo`0047oo00<007ooOol0ogoo3Woo000@Ool00`00Oomoo`3o
Ool>Ool000Yoool000l000Qoo`0047oo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo
00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol01Woo00<007ooOol01Woo00<007ooOol037oo000@Ool00`00Ooml0002O00NOol00`00
Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0OOol00`00Oomoo`0NOol0011oo`03001oogoo009oo`03O01oogoo0?moo`Uoo`0047oo00<0
07ooOol00Woo00=l07ooOol0ogoo2Goo000@Ool20004Ool00g`0Oomoo`3oOol8Ool0011oo`03001o
ogoo00=oo`03O01oogoo0?moo`Qoo`0047oo00<007ooOol017oo00=l07ooOol0ogoo1goo000@Ool0
0`00Oomoo`04Ool00g`0Oomoo`3oOol7Ool0011oo`8000Eoo`03O01oogoo0?moo`Moo`0047oo00<0
07ooOol017oo00=l07ooOol0ogoo1goo000@Ool00`00Oomoo`05Ool00g`0Oomoo`3oOol6Ool0011o
o`03001oogoo00Eoo`03O01oogoo0?moo`Ioo`0047oo00<007ooOol01Woo00=l07ooOol0ogoo1Goo
000@Ool20007Ool00g`0Oomoo`3oOol5Ool0011oo`03001oogoo00Moo`03O01oogoo0?moo`Aoo`00
47oo00<007ooOol01goo00=l07ooOol0ogoo17oo000@Ool00`00Oomoo`08Ool00g`0Oomoo`3oOol3
Ool0011oo`03001oogoo00Qoo`03O01oogoo0?moo`=oo`0047oo0P002Goo00=l07ooOol0ogoo0goo
000@Ool00`00Oomoo`09Ool00g`0Oomoo`3oOol2Ool0011oo`03001oogoo00Uoo`03O01oogoo0?mo
o`9oo`002Goo0P001Goo00<007ooOol02Goo00=l07ooOol0ogoo0Woo0008Ool01000Oomoo`0017oo
00<007ooOol02Woo00=l07ooOol0ogoo0Goo000:Ool00`00Oomoo`03Ool3000:Ool00g`0Oomoo`3o
Ool1Ool000]oo`03001oogoo009oo`03001oogoo00]oo`03O01oogoo0?moo`0027oo00@007ooOol0
00Aoo`03001oogoo00aoo`03O01oogoo0?ioo`002Goo0P001Goo00<007ooOol037oo00=l07ooOol0
oWoo000@Ool2000>Ool00g`0Oomoo`3mOol0011oo`03001oogoo00ioo`03O01oogoo0?aoo`0047oo
00<007ooOol03Woo00=l07ooOol0o7oo000@Ool00`00Oomoo`0?Ool00g`0Oomoo`3kOol0011oo`03
001oogoo00moo`03O01oogoo0?]oo`0047oo0P004Goo00=l07ooOol0nWoo000@Ool00`00Oomoo`0@
Ool00g`0Oomoo`3jOol0011oo`03001oogoo015oo`03O01oogoo0?Uoo`0047oo00<007ooOol04Goo
00=l07ooOol0nGoo000@Ool00`00Oomoo`0BOol00g`0Oomoo`3hOol0011oo`8001Aoo`03O01oogoo
0?Moo`0047oo00<007ooOol057oo00=l07ooOol0mWoo000@Ool00`00Oomoo`0DOol00g`0Oomoo`3f
Ool0011oo`03001oogoo01Eoo`03O01oogoo0?Eoo`0047oo00<007ooOol05Goo00=l07ooOol0mGoo
000@Ool2000GOol00g`0Oomoo`3dOol0011oo`03001oogoo01Moo`03O01oogoo0?=oo`002Woo0`00
0goo00<007ooOol067oo00=l07ooOol0lWoo000;Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00g`0
Oomoo`3aOol000Qoo`D000=oo`<001Yoo`03O01oogoo0?1oo`0027oo00@007ooOol000Aoo`03001o
ogoo01Yoo`03O01oogoo0?1oo`002Goo00<007oo000017oo00<007ooOol06goo00=l07ooOol0kgoo
000:Ool20004Ool00`00Oomoo`0LOol00g`0Oomoo`3^Ool0011oo`03001oogoo01eoo`03O01oogoo
0>eoo`0047oo0P007goo00=l07ooOol0k7oo000@Ool00`00Oomoo`0OOol00g`0Oomoo`3[Ool0011o
o`03001oogoo021oo`03O01oogoo0>Yoo`0047oo00<007ooOol08Goo00=l07ooOol0jGoo000@Ool0
0`00Oomoo`0QOol00g`0Oomoo`3YOol0011oo`8002=oo`03O01oogoo0>Qoo`0047oo00<007ooOol0
8goo00=l07ooOol0igoo000@Ool00`00Oomoo`0TOol00g`0Oomoo`3VOol0011oo`03001oogoo02Eo
o`03O01oogoo0>Eoo`0047oo00<007ooOol09Woo00=l07ooOol0i7oo000@Ool2000XOol00g`0Oomo
o`3SOol0011oo`03001oogoo02Qoo`03O01oogoo0>9oo`0047oo00<007ooOol0:Goo0W`0hWoo000@
Ool00`00Oomoo`0[Ool00g`0Oomoo`3OOol0011oo`8002eoo`03O01oogoo0=ioo`0047oo00<007oo
Ool0;Goo00=l07ooOol0gGoo000@Ool00`00Oomoo`0^Ool00g`0Oomoo`3LOol000Uoo`8000Eoo`03
001oogoo02moo`03O01oogoo0=]oo`0027oo00@007ooOol000Aoo`03001oogoo031oo`9l0=]oo`00
2goo00<007ooOol00Woo0`00<Woo00=l07ooOol0f7oo0009Ool20005Ool00`00Oomoo`0bOol00g`0
Oomoo`3HOol000Uoo`03001oogoo00Aoo`03001oogoo03=oo`9l0=Qoo`002Goo0`0017oo00<007oo
Ool0=Goo0W`0eWoo000@Ool00`00Oomoo`0gOol00g`0Oomoo`3COol0011oo`8003Qoo`03O01oogoo
0==oo`0047oo00<007ooOol0>7oo0W`0dgoo000@Ool00`00Oomoo`0jOol2O03AOol0011oo`03001o
ogoo03aoo`03O01oogoo0<ioo`0047oo00<007ooOol0?Goo00=l07ooOol0cGoo000@Ool2000oOol0
0g`0Oomoo`3<Ool0011oo`03001oogoo03moo`9l0<aoo`0047oo00<007ooOol0@Goo0W`0bWoo000@
Ool00`00Oomoo`13Ool00g`0Oomoo`37Ool0011oo`8004Eoo`03O01oogoo0<Ioo`0047oo00<007oo
Ool0AGoo00=l07ooOol0aGoo000@Ool00`00Oomoo`16Ool2O035Ool0011oo`03001oogoo04Qoo`9l
0<=oo`0047oo00<007ooOol0BWoo00=l07ooOol0`7oo000@Ool2001<Ool2O030Ool0011oo`03001o
ogoo04eoo`9l0;ioo`0047oo00<007ooOol0Cgoo00=l07ooOol0^goo0008Ool30005Ool00`00Oomo
o`1@Ool2O02kOol000Qoo`04001oogoo0004Ool00`00Oomoo`1BOol2O02iOol000Qoo`04001oogoo
0004Ool3001DOol2O02gOol000Qoo`<000Eoo`03001oogoo05Ioo`03O01oogoo0;Aoo`002Goo00<0
07ooOol017oo00<007ooOol0Egoo0W`0]7oo0009Ool30004Ool00`00Oomoo`1IOol2O02bOol0011o
o`03001oogoo05]oo`03O01oogoo0:moo`0047oo0P00GGoo0W`0[goo000@Ool00`00Oomoo`1NOol2
O02]Ool0011oo`03001oogoo061oo`03O01oogoo0:Yoo`0047oo00<007ooOol0HGoo17`0Z7oo000@
Ool2001VOol2O02VOol0011oo`03001oogoo06Moo`03O01oogoo0:=oo`0047oo00<007ooOol0J7oo
0W`0Xgoo000@Ool00`00Oomoo`1ZOol2O02QOol0011oo`03001oogoo06aoo`03O01oogoo09ioo`00
47oo0P00KWoo17`0W7oo000@Ool00`00Oomoo`1aOol2O02JOol0011oo`03001oogoo07=oo`03O01o
ogoo09Moo`0047oo00<007ooOol0M7oo0W`0Ugoo000@Ool00`00Oomoo`1fOol2O02EOol0011oo`80
07Uoo`=l099oo`0047oo00<007ooOol0Ngoo0W`0T7oo000@Ool00`00Oomoo`1mOol00g`0Oomoo`2=
Ool000Yoo`03001oogoo00=oo`03001oogoo07ioo`Al08]oo`002Woo00<007ooOol00goo00<007oo
Ool0PWoo0W`0RGoo000:Ool00`00Oomoo`03Ool30024Ool00g`0Oomoo`26Ool000]oo`03001oogoo
009oo`03001oogoo08Eoo`Al08Aoo`0027oo00@007ooOol000Aoo`03001oogoo08Uoo`03O01oogoo
085oo`0027oo100017oo00<007ooOol0RWoo17`0Ogoo000@Ool2002?Ool2O01mOol0011oo`03001o
ogoo091oo`03O01oogoo07Yoo`0047oo00<007ooOol0TGoo17`0N7oo000@Ool00`00Oomoo`2EOol0
0g`0Oomoo`1eOol0011oo`03001oogoo09Ioo`Al07=oo`0047oo0P00Vgoo0W`0LGoo000@Ool00`00
Oomoo`2LOol3O01^Ool0011oo`03001oogoo09moo`9l06aoo`0047oo00<007ooOol0XGoo0g`0JGoo
000@Ool00`00Oomoo`2TOol2O01WOol0011oo`800:Moo`=l06Aoo`0047oo00<007ooOol0ZGoo17`0
H7oo000@Ool00`00Oomoo`2]Ool00g`0Oomoo`1MOol0011oo`03001oogoo0:ioo`Al05]oo`0047oo
00<007ooOol0/Woo00=l07ooOol0F7oo000@Ool2002dOol4O01FOol0011oo`03001oogoo0;Moo`=l
05=oo`002Goo0P001Goo00<007ooOol0^Woo17`0Cgoo0008Ool01000Oomoo`0017oo00<007ooOol0
_Woo00=l07ooOol0C7oo0008Ool01000Oomoo`0017oo0`00_goo17`0BWoo0009Ool20005Ool00`00
Oomoo`33Ool3O017Ool000Qoo`04001oogoo0004Ool00`00Oomoo`36Ool4O013Ool000Uoo`8000Eo
o`03001oogoo0<Yoo`03O01oogoo041oo`0047oo00<007ooOol0bgoo17`0?Woo000@Ool2003@Ool3
O00kOol0011oo`03001oogoo0=9oo`Al03Moo`0047oo00<007ooOol0eWoo0g`0=7oo000@Ool00`00
Oomoo`3IOol3O00aOol0011oo`03001oogoo0=aoo`9l02moo`0047oo0P00ggoo0g`0;7oo000@Ool0
0`00Oomoo`3QOol4O00XOol0011oo`03001oogoo0>Eoo`=l02Eoo`0047oo00<007ooOol0j7oo17`0
8Goo000@Ool00`00Oomoo`3/Ool3O00NOol0011oo`800?1oo`Al01Yoo`0047oo00<007ooOol0lgoo
0g`05goo000@Ool00`00Oomoo`3fOol3O00DOol0011oo`03001oogoo0?Uoo`Al011oo`0047oo0P00
oWoo0W`03Woo000@Ool00`00Oomoo`3oOol>Ool0011oo`03001oogoo0?moo`ioo`0047oo00<007oo
Ool0ogoo3Woo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-9.93251, 1.47927, 0.585823, \
0.0421288}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
CellGrouping->Manual,
WindowSize->{538, 617},
WindowMargins->{{2, Automatic}, {Automatic, 2}},
ShowSelection->True
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 716, 20, 262, "Title"],
Cell[2473, 73, 877, 19, 268, "Subsubtitle"],
Cell[3353, 94, 354, 9, 87, "Subsubtitle"],
Cell[3710, 105, 228, 5, 86, "Subsubtitle"],

Cell[CellGroupData[{
Cell[3963, 114, 134, 3, 46, "Subsubtitle"],
Cell[4100, 119, 39, 0, 30, "Input"],
Cell[4142, 121, 66, 0, 30, "Input"],
Cell[4211, 123, 24, 0, 30, "Input"],
Cell[4238, 125, 58, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[4321, 129, 69, 0, 30, "Input"],
Cell[4393, 131, 84, 1, 29, "Output"]
}, Open  ]],
Cell[4492, 135, 42, 0, 30, "Input"],
Cell[4537, 137, 294, 12, 210, "Input"],

Cell[CellGroupData[{
Cell[4856, 153, 69, 0, 30, "Input"],
Cell[4928, 155, 84, 1, 29, "Output"]
}, Open  ]],
Cell[5027, 159, 340, 14, 246, "Input"],
Cell[5370, 175, 98, 3, 48, "Input"],
Cell[5471, 180, 24, 0, 30, "Input"],
Cell[5498, 182, 22, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[5545, 186, 38, 0, 30, "Input"],
Cell[5586, 188, 109, 2, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5732, 195, 258, 5, 84, "Input"],
Cell[5993, 202, 34, 1, 25, "Print"],
Cell[6030, 205, 34, 1, 25, "Print"],
Cell[6067, 208, 34, 1, 25, "Print"],
Cell[6104, 211, 34, 1, 25, "Print"],
Cell[6141, 214, 34, 1, 25, "Print"],
Cell[6178, 217, 34, 1, 25, "Print"],
Cell[6215, 220, 34, 1, 25, "Print"],
Cell[6252, 223, 34, 1, 25, "Print"],
Cell[6289, 226, 34, 1, 25, "Print"],
Cell[6326, 229, 35, 1, 25, "Print"],
Cell[6364, 232, 35, 1, 25, "Print"],
Cell[6402, 235, 35, 1, 25, "Print"],
Cell[6440, 238, 35, 1, 25, "Print"],
Cell[6478, 241, 35, 1, 25, "Print"],
Cell[6516, 244, 35, 1, 25, "Print"],
Cell[6554, 247, 35, 1, 25, "Print"],
Cell[6592, 250, 35, 1, 25, "Print"],
Cell[6630, 253, 35, 1, 25, "Print"],
Cell[6668, 256, 35, 1, 25, "Print"],
Cell[6706, 259, 35, 1, 25, "Print"],
Cell[6744, 262, 35, 1, 25, "Print"],
Cell[6782, 265, 35, 1, 25, "Print"],
Cell[6820, 268, 35, 1, 25, "Print"],
Cell[6858, 271, 35, 1, 25, "Print"],
Cell[6896, 274, 35, 1, 25, "Print"],
Cell[6934, 277, 35, 1, 25, "Print"],
Cell[6972, 280, 35, 1, 25, "Print"],
Cell[7010, 283, 35, 1, 25, "Print"],
Cell[7048, 286, 35, 1, 25, "Print"],
Cell[7086, 289, 35, 1, 25, "Print"],
Cell[7124, 292, 35, 1, 25, "Print"],
Cell[7162, 295, 35, 1, 25, "Print"],
Cell[7200, 298, 35, 1, 25, "Print"],
Cell[7238, 301, 35, 1, 25, "Print"],
Cell[7276, 304, 35, 1, 25, "Print"],
Cell[7314, 307, 35, 1, 25, "Print"],
Cell[7352, 310, 35, 1, 25, "Print"],
Cell[7390, 313, 35, 1, 25, "Print"],
Cell[7428, 316, 35, 1, 25, "Print"],
Cell[7466, 319, 35, 1, 25, "Print"],
Cell[7504, 322, 35, 1, 25, "Print"],
Cell[7542, 325, 35, 1, 25, "Print"],
Cell[7580, 328, 35, 1, 25, "Print"],
Cell[7618, 331, 35, 1, 25, "Print"],
Cell[7656, 334, 35, 1, 25, "Print"],
Cell[7694, 337, 35, 1, 25, "Print"],
Cell[7732, 340, 35, 1, 25, "Print"],
Cell[7770, 343, 35, 1, 25, "Print"],
Cell[7808, 346, 35, 1, 25, "Print"],
Cell[7846, 349, 35, 1, 25, "Print"],
Cell[7884, 352, 35, 1, 25, "Print"],
Cell[7922, 355, 35, 1, 25, "Print"],
Cell[7960, 358, 35, 1, 25, "Print"],
Cell[7998, 361, 35, 1, 25, "Print"],
Cell[8036, 364, 35, 1, 25, "Print"],
Cell[8074, 367, 35, 1, 25, "Print"],
Cell[8112, 370, 35, 1, 25, "Print"],
Cell[8150, 373, 35, 1, 25, "Print"],
Cell[8188, 376, 35, 1, 25, "Print"],
Cell[8226, 379, 35, 1, 25, "Print"],
Cell[8264, 382, 35, 1, 25, "Print"],
Cell[8302, 385, 35, 1, 25, "Print"],
Cell[8340, 388, 35, 1, 25, "Print"],
Cell[8378, 391, 35, 1, 25, "Print"],
Cell[8416, 394, 35, 1, 25, "Print"],
Cell[8454, 397, 35, 1, 25, "Print"],
Cell[8492, 400, 35, 1, 25, "Print"],
Cell[8530, 403, 35, 1, 25, "Print"],
Cell[8568, 406, 35, 1, 25, "Print"],
Cell[8606, 409, 35, 1, 25, "Print"],
Cell[8644, 412, 35, 1, 25, "Print"],
Cell[8682, 415, 35, 1, 25, "Print"],
Cell[8720, 418, 35, 1, 25, "Print"],
Cell[8758, 421, 35, 1, 25, "Print"],
Cell[8796, 424, 35, 1, 25, "Print"],
Cell[8834, 427, 35, 1, 25, "Print"],
Cell[8872, 430, 35, 1, 25, "Print"],
Cell[8910, 433, 35, 1, 25, "Print"],
Cell[8948, 436, 35, 1, 25, "Print"],
Cell[8986, 439, 35, 1, 25, "Print"],
Cell[9024, 442, 35, 1, 25, "Print"],
Cell[9062, 445, 35, 1, 25, "Print"],
Cell[9100, 448, 35, 1, 25, "Print"],
Cell[9138, 451, 35, 1, 25, "Print"],
Cell[9176, 454, 35, 1, 25, "Print"],
Cell[9214, 457, 35, 1, 25, "Print"],
Cell[9252, 460, 35, 1, 25, "Print"],
Cell[9290, 463, 35, 1, 25, "Print"],
Cell[9328, 466, 35, 1, 25, "Print"],
Cell[9366, 469, 35, 1, 25, "Print"],
Cell[9404, 472, 35, 1, 25, "Print"],
Cell[9442, 475, 35, 1, 25, "Print"],
Cell[9480, 478, 35, 1, 25, "Print"],
Cell[9518, 481, 35, 1, 25, "Print"],
Cell[9556, 484, 35, 1, 25, "Print"],
Cell[9594, 487, 35, 1, 25, "Print"],
Cell[9632, 490, 35, 1, 25, "Print"],
Cell[9670, 493, 35, 1, 25, "Print"],
Cell[9708, 496, 35, 1, 25, "Print"],
Cell[9746, 499, 36, 1, 25, "Print"],
Cell[9785, 502, 36, 1, 25, "Print"],
Cell[9824, 505, 36, 1, 25, "Print"],
Cell[9863, 508, 36, 1, 25, "Print"],
Cell[9902, 511, 36, 1, 25, "Print"],
Cell[9941, 514, 36, 1, 25, "Print"],
Cell[9980, 517, 36, 1, 25, "Print"],
Cell[10019, 520, 36, 1, 25, "Print"],
Cell[10058, 523, 36, 1, 25, "Print"],
Cell[10097, 526, 36, 1, 25, "Print"],
Cell[10136, 529, 36, 1, 25, "Print"],
Cell[10175, 532, 36, 1, 25, "Print"],
Cell[10214, 535, 36, 1, 25, "Print"],
Cell[10253, 538, 36, 1, 25, "Print"],
Cell[10292, 541, 36, 1, 25, "Print"],
Cell[10331, 544, 36, 1, 25, "Print"],
Cell[10370, 547, 36, 1, 25, "Print"],
Cell[10409, 550, 36, 1, 25, "Print"],
Cell[10448, 553, 36, 1, 25, "Print"],
Cell[10487, 556, 36, 1, 25, "Print"],
Cell[10526, 559, 36, 1, 25, "Print"],
Cell[10565, 562, 36, 1, 25, "Print"],
Cell[10604, 565, 36, 1, 25, "Print"],
Cell[10643, 568, 36, 1, 25, "Print"],
Cell[10682, 571, 36, 1, 25, "Print"],
Cell[10721, 574, 36, 1, 25, "Print"],
Cell[10760, 577, 36, 1, 25, "Print"],
Cell[10799, 580, 36, 1, 25, "Print"],
Cell[10838, 583, 36, 1, 25, "Print"],
Cell[10877, 586, 36, 1, 25, "Print"],
Cell[10916, 589, 36, 1, 25, "Print"],
Cell[10955, 592, 36, 1, 25, "Print"],
Cell[10994, 595, 36, 1, 25, "Print"],
Cell[11033, 598, 36, 1, 25, "Print"],
Cell[11072, 601, 36, 1, 25, "Print"],
Cell[11111, 604, 36, 1, 25, "Print"],
Cell[11150, 607, 36, 1, 25, "Print"],
Cell[11189, 610, 36, 1, 25, "Print"],
Cell[11228, 613, 36, 1, 25, "Print"],
Cell[11267, 616, 36, 1, 25, "Print"],
Cell[11306, 619, 36, 1, 25, "Print"],
Cell[11345, 622, 36, 1, 25, "Print"],
Cell[11384, 625, 36, 1, 25, "Print"],
Cell[11423, 628, 36, 1, 25, "Print"],
Cell[11462, 631, 36, 1, 25, "Print"],
Cell[11501, 634, 36, 1, 25, "Print"],
Cell[11540, 637, 36, 1, 25, "Print"],
Cell[11579, 640, 36, 1, 25, "Print"],
Cell[11618, 643, 36, 1, 25, "Print"],
Cell[11657, 646, 36, 1, 25, "Print"],
Cell[11696, 649, 36, 1, 25, "Print"],
Cell[11735, 652, 36, 1, 25, "Print"],
Cell[11774, 655, 36, 1, 25, "Print"],
Cell[11813, 658, 36, 1, 25, "Print"],
Cell[11852, 661, 36, 1, 25, "Print"],
Cell[11891, 664, 36, 1, 25, "Print"],
Cell[11930, 667, 36, 1, 25, "Print"],
Cell[11969, 670, 36, 1, 25, "Print"],
Cell[12008, 673, 36, 1, 25, "Print"],
Cell[12047, 676, 36, 1, 25, "Print"],
Cell[12086, 679, 36, 1, 25, "Print"],
Cell[12125, 682, 36, 1, 25, "Print"],
Cell[12164, 685, 36, 1, 25, "Print"],
Cell[12203, 688, 36, 1, 25, "Print"],
Cell[12242, 691, 36, 1, 25, "Print"],
Cell[12281, 694, 36, 1, 25, "Print"],
Cell[12320, 697, 36, 1, 25, "Print"],
Cell[12359, 700, 36, 1, 25, "Print"],
Cell[12398, 703, 36, 1, 25, "Print"],
Cell[12437, 706, 36, 1, 25, "Print"],
Cell[12476, 709, 36, 1, 25, "Print"],
Cell[12515, 712, 36, 1, 25, "Print"],
Cell[12554, 715, 36, 1, 25, "Print"],
Cell[12593, 718, 36, 1, 25, "Print"],
Cell[12632, 721, 36, 1, 25, "Print"],
Cell[12671, 724, 36, 1, 25, "Print"],
Cell[12710, 727, 36, 1, 25, "Print"],
Cell[12749, 730, 36, 1, 25, "Print"],
Cell[12788, 733, 36, 1, 25, "Print"],
Cell[12827, 736, 36, 1, 25, "Print"],
Cell[12866, 739, 36, 1, 25, "Print"],
Cell[12905, 742, 36, 1, 25, "Print"],
Cell[12944, 745, 36, 1, 25, "Print"],
Cell[12983, 748, 36, 1, 25, "Print"],
Cell[13022, 751, 36, 1, 25, "Print"],
Cell[13061, 754, 36, 1, 25, "Print"],
Cell[13100, 757, 36, 1, 25, "Print"],
Cell[13139, 760, 36, 1, 25, "Print"],
Cell[13178, 763, 36, 1, 25, "Print"],
Cell[13217, 766, 36, 1, 25, "Print"],
Cell[13256, 769, 36, 1, 25, "Print"],
Cell[13295, 772, 36, 1, 25, "Print"],
Cell[13334, 775, 36, 1, 25, "Print"],
Cell[13373, 778, 36, 1, 25, "Print"],
Cell[13412, 781, 36, 1, 25, "Print"],
Cell[13451, 784, 36, 1, 25, "Print"],
Cell[13490, 787, 36, 1, 25, "Print"],
Cell[13529, 790, 36, 1, 25, "Print"],
Cell[13568, 793, 36, 1, 25, "Print"],
Cell[13607, 796, 36, 1, 25, "Print"],
Cell[13646, 799, 36, 1, 25, "Print"],
Cell[13685, 802, 36, 1, 25, "Print"],
Cell[13724, 805, 36, 1, 25, "Print"],
Cell[13763, 808, 36, 1, 25, "Print"],
Cell[13802, 811, 36, 1, 25, "Print"],
Cell[13841, 814, 36, 1, 25, "Print"],
Cell[13880, 817, 36, 1, 25, "Print"],
Cell[13919, 820, 36, 1, 25, "Print"],
Cell[13958, 823, 36, 1, 25, "Print"],
Cell[13997, 826, 36, 1, 25, "Print"],
Cell[14036, 829, 36, 1, 25, "Print"],
Cell[14075, 832, 36, 1, 25, "Print"],
Cell[14114, 835, 36, 1, 25, "Print"],
Cell[14153, 838, 36, 1, 25, "Print"],
Cell[14192, 841, 36, 1, 25, "Print"],
Cell[14231, 844, 36, 1, 25, "Print"],
Cell[14270, 847, 36, 1, 25, "Print"],
Cell[14309, 850, 36, 1, 25, "Print"],
Cell[14348, 853, 36, 1, 25, "Print"],
Cell[14387, 856, 36, 1, 25, "Print"],
Cell[14426, 859, 36, 1, 25, "Print"],
Cell[14465, 862, 36, 1, 25, "Print"],
Cell[14504, 865, 36, 1, 25, "Print"],
Cell[14543, 868, 36, 1, 25, "Print"],
Cell[14582, 871, 36, 1, 25, "Print"],
Cell[14621, 874, 36, 1, 25, "Print"],
Cell[14660, 877, 36, 1, 25, "Print"],
Cell[14699, 880, 36, 1, 25, "Print"],
Cell[14738, 883, 36, 1, 25, "Print"],
Cell[14777, 886, 36, 1, 25, "Print"],
Cell[14816, 889, 36, 1, 25, "Print"],
Cell[14855, 892, 36, 1, 25, "Print"],
Cell[14894, 895, 36, 1, 25, "Print"],
Cell[14933, 898, 36, 1, 25, "Print"],
Cell[14972, 901, 36, 1, 25, "Print"],
Cell[15011, 904, 36, 1, 25, "Print"],
Cell[15050, 907, 36, 1, 25, "Print"],
Cell[15089, 910, 36, 1, 25, "Print"],
Cell[15128, 913, 36, 1, 25, "Print"],
Cell[15167, 916, 36, 1, 25, "Print"],
Cell[15206, 919, 36, 1, 25, "Print"],
Cell[15245, 922, 36, 1, 25, "Print"],
Cell[15284, 925, 36, 1, 25, "Print"],
Cell[15323, 928, 36, 1, 25, "Print"],
Cell[15362, 931, 36, 1, 25, "Print"],
Cell[15401, 934, 36, 1, 25, "Print"],
Cell[15440, 937, 36, 1, 25, "Print"],
Cell[15479, 940, 36, 1, 25, "Print"],
Cell[15518, 943, 36, 1, 25, "Print"],
Cell[15557, 946, 36, 1, 25, "Print"],
Cell[15596, 949, 36, 1, 25, "Print"],
Cell[15635, 952, 36, 1, 25, "Print"],
Cell[15674, 955, 36, 1, 25, "Print"],
Cell[15713, 958, 36, 1, 25, "Print"],
Cell[15752, 961, 36, 1, 25, "Print"],
Cell[15791, 964, 36, 1, 25, "Print"],
Cell[15830, 967, 36, 1, 25, "Print"],
Cell[15869, 970, 36, 1, 25, "Print"],
Cell[15908, 973, 36, 1, 25, "Print"],
Cell[15947, 976, 36, 1, 25, "Print"],
Cell[15986, 979, 36, 1, 25, "Print"],
Cell[16025, 982, 36, 1, 25, "Print"],
Cell[16064, 985, 36, 1, 25, "Print"],
Cell[16103, 988, 36, 1, 25, "Print"],
Cell[16142, 991, 36, 1, 25, "Print"],
Cell[16181, 994, 36, 1, 25, "Print"],
Cell[16220, 997, 36, 1, 25, "Print"],
Cell[16259, 1000, 36, 1, 25, "Print"],
Cell[16298, 1003, 36, 1, 25, "Print"],
Cell[16337, 1006, 36, 1, 25, "Print"],
Cell[16376, 1009, 36, 1, 25, "Print"],
Cell[16415, 1012, 36, 1, 25, "Print"],
Cell[16454, 1015, 36, 1, 25, "Print"],
Cell[16493, 1018, 36, 1, 25, "Print"],
Cell[16532, 1021, 36, 1, 25, "Print"],
Cell[16571, 1024, 36, 1, 25, "Print"],
Cell[16610, 1027, 36, 1, 25, "Print"],
Cell[16649, 1030, 36, 1, 25, "Print"],
Cell[16688, 1033, 36, 1, 25, "Print"],
Cell[16727, 1036, 36, 1, 25, "Print"],
Cell[16766, 1039, 36, 1, 25, "Print"],
Cell[16805, 1042, 36, 1, 25, "Print"],
Cell[16844, 1045, 36, 1, 25, "Print"],
Cell[16883, 1048, 36, 1, 25, "Print"],
Cell[16922, 1051, 36, 1, 25, "Print"],
Cell[16961, 1054, 36, 1, 25, "Print"],
Cell[17000, 1057, 36, 1, 25, "Print"],
Cell[17039, 1060, 36, 1, 25, "Print"],
Cell[17078, 1063, 36, 1, 25, "Print"],
Cell[17117, 1066, 36, 1, 25, "Print"],
Cell[17156, 1069, 36, 1, 25, "Print"],
Cell[17195, 1072, 36, 1, 25, "Print"],
Cell[17234, 1075, 36, 1, 25, "Print"],
Cell[17273, 1078, 36, 1, 25, "Print"],
Cell[17312, 1081, 36, 1, 25, "Print"],
Cell[17351, 1084, 36, 1, 25, "Print"],
Cell[17390, 1087, 36, 1, 25, "Print"],
Cell[17429, 1090, 36, 1, 25, "Print"],
Cell[17468, 1093, 36, 1, 25, "Print"],
Cell[17507, 1096, 36, 1, 25, "Print"],
Cell[17546, 1099, 36, 1, 25, "Print"],
Cell[17585, 1102, 36, 1, 25, "Print"],
Cell[17624, 1105, 36, 1, 25, "Print"],
Cell[17663, 1108, 36, 1, 25, "Print"],
Cell[17702, 1111, 36, 1, 25, "Print"],
Cell[17741, 1114, 36, 1, 25, "Print"],
Cell[17780, 1117, 36, 1, 25, "Print"],
Cell[17819, 1120, 36, 1, 25, "Print"],
Cell[17858, 1123, 36, 1, 25, "Print"],
Cell[17897, 1126, 36, 1, 25, "Print"],
Cell[17936, 1129, 36, 1, 25, "Print"],
Cell[17975, 1132, 36, 1, 25, "Print"],
Cell[18014, 1135, 36, 1, 25, "Print"],
Cell[18053, 1138, 36, 1, 25, "Print"],
Cell[18092, 1141, 36, 1, 25, "Print"],
Cell[18131, 1144, 36, 1, 25, "Print"],
Cell[18170, 1147, 36, 1, 25, "Print"],
Cell[18209, 1150, 36, 1, 25, "Print"],
Cell[18248, 1153, 36, 1, 25, "Print"],
Cell[18287, 1156, 36, 1, 25, "Print"],
Cell[18326, 1159, 36, 1, 25, "Print"],
Cell[18365, 1162, 36, 1, 25, "Print"],
Cell[18404, 1165, 36, 1, 25, "Print"],
Cell[18443, 1168, 36, 1, 25, "Print"],
Cell[18482, 1171, 36, 1, 25, "Print"],
Cell[18521, 1174, 36, 1, 25, "Print"],
Cell[18560, 1177, 36, 1, 25, "Print"],
Cell[18599, 1180, 36, 1, 25, "Print"],
Cell[18638, 1183, 36, 1, 25, "Print"],
Cell[18677, 1186, 36, 1, 25, "Print"],
Cell[18716, 1189, 36, 1, 25, "Print"],
Cell[18755, 1192, 36, 1, 25, "Print"],
Cell[18794, 1195, 36, 1, 25, "Print"],
Cell[18833, 1198, 36, 1, 25, "Print"],
Cell[18872, 1201, 36, 1, 25, "Print"],
Cell[18911, 1204, 36, 1, 25, "Print"],
Cell[18950, 1207, 36, 1, 25, "Print"],
Cell[18989, 1210, 36, 1, 25, "Print"],
Cell[19028, 1213, 36, 1, 25, "Print"],
Cell[19067, 1216, 36, 1, 25, "Print"],
Cell[19106, 1219, 36, 1, 25, "Print"],
Cell[19145, 1222, 36, 1, 25, "Print"],
Cell[19184, 1225, 36, 1, 25, "Print"],
Cell[19223, 1228, 36, 1, 25, "Print"],
Cell[19262, 1231, 36, 1, 25, "Print"],
Cell[19301, 1234, 36, 1, 25, "Print"],
Cell[19340, 1237, 36, 1, 25, "Print"],
Cell[19379, 1240, 36, 1, 25, "Print"],
Cell[19418, 1243, 36, 1, 25, "Print"],
Cell[19457, 1246, 36, 1, 25, "Print"],
Cell[19496, 1249, 36, 1, 25, "Print"],
Cell[19535, 1252, 36, 1, 25, "Print"],
Cell[19574, 1255, 36, 1, 25, "Print"],
Cell[19613, 1258, 36, 1, 25, "Print"],
Cell[19652, 1261, 36, 1, 25, "Print"],
Cell[19691, 1264, 36, 1, 25, "Print"],
Cell[19730, 1267, 36, 1, 25, "Print"],
Cell[19769, 1270, 36, 1, 25, "Print"],
Cell[19808, 1273, 36, 1, 25, "Print"],
Cell[19847, 1276, 36, 1, 25, "Print"],
Cell[19886, 1279, 36, 1, 25, "Print"],
Cell[19925, 1282, 36, 1, 25, "Print"],
Cell[19964, 1285, 36, 1, 25, "Print"],
Cell[20003, 1288, 36, 1, 25, "Print"],
Cell[20042, 1291, 36, 1, 25, "Print"],
Cell[20081, 1294, 36, 1, 25, "Print"],
Cell[20120, 1297, 36, 1, 25, "Print"],
Cell[20159, 1300, 36, 1, 25, "Print"],
Cell[20198, 1303, 36, 1, 25, "Print"],
Cell[20237, 1306, 36, 1, 25, "Print"],
Cell[20276, 1309, 36, 1, 25, "Print"],
Cell[20315, 1312, 36, 1, 25, "Print"],
Cell[20354, 1315, 36, 1, 25, "Print"],
Cell[20393, 1318, 36, 1, 25, "Print"],
Cell[20432, 1321, 36, 1, 25, "Print"],
Cell[20471, 1324, 36, 1, 25, "Print"],
Cell[20510, 1327, 36, 1, 25, "Print"],
Cell[20549, 1330, 36, 1, 25, "Print"],
Cell[20588, 1333, 36, 1, 25, "Print"],
Cell[20627, 1336, 36, 1, 25, "Print"],
Cell[20666, 1339, 36, 1, 25, "Print"],
Cell[20705, 1342, 36, 1, 25, "Print"],
Cell[20744, 1345, 36, 1, 25, "Print"],
Cell[20783, 1348, 36, 1, 25, "Print"],
Cell[20822, 1351, 36, 1, 25, "Print"],
Cell[20861, 1354, 36, 1, 25, "Print"],
Cell[20900, 1357, 36, 1, 25, "Print"],
Cell[20939, 1360, 36, 1, 25, "Print"],
Cell[20978, 1363, 36, 1, 25, "Print"],
Cell[21017, 1366, 36, 1, 25, "Print"],
Cell[21056, 1369, 36, 1, 25, "Print"],
Cell[21095, 1372, 36, 1, 25, "Print"],
Cell[21134, 1375, 36, 1, 25, "Print"],
Cell[21173, 1378, 36, 1, 25, "Print"],
Cell[21212, 1381, 36, 1, 25, "Print"],
Cell[21251, 1384, 36, 1, 25, "Print"],
Cell[21290, 1387, 36, 1, 25, "Print"],
Cell[21329, 1390, 36, 1, 25, "Print"],
Cell[21368, 1393, 36, 1, 25, "Print"],
Cell[21407, 1396, 36, 1, 25, "Print"],
Cell[21446, 1399, 36, 1, 25, "Print"],
Cell[21485, 1402, 36, 1, 25, "Print"],
Cell[21524, 1405, 36, 1, 25, "Print"],
Cell[21563, 1408, 36, 1, 25, "Print"],
Cell[21602, 1411, 36, 1, 25, "Print"],
Cell[21641, 1414, 36, 1, 25, "Print"],
Cell[21680, 1417, 36, 1, 25, "Print"],
Cell[21719, 1420, 36, 1, 25, "Print"],
Cell[21758, 1423, 36, 1, 25, "Print"],
Cell[21797, 1426, 36, 1, 25, "Print"],
Cell[21836, 1429, 36, 1, 25, "Print"],
Cell[21875, 1432, 36, 1, 25, "Print"],
Cell[21914, 1435, 36, 1, 25, "Print"],
Cell[21953, 1438, 36, 1, 25, "Print"],
Cell[21992, 1441, 36, 1, 25, "Print"],
Cell[22031, 1444, 36, 1, 25, "Print"],
Cell[22070, 1447, 36, 1, 25, "Print"],
Cell[22109, 1450, 36, 1, 25, "Print"],
Cell[22148, 1453, 36, 1, 25, "Print"],
Cell[22187, 1456, 36, 1, 25, "Print"],
Cell[22226, 1459, 36, 1, 25, "Print"],
Cell[22265, 1462, 36, 1, 25, "Print"],
Cell[22304, 1465, 36, 1, 25, "Print"],
Cell[22343, 1468, 36, 1, 25, "Print"],
Cell[22382, 1471, 36, 1, 25, "Print"],
Cell[22421, 1474, 36, 1, 25, "Print"],
Cell[22460, 1477, 36, 1, 25, "Print"],
Cell[22499, 1480, 36, 1, 25, "Print"],
Cell[22538, 1483, 36, 1, 25, "Print"],
Cell[22577, 1486, 36, 1, 25, "Print"],
Cell[22616, 1489, 36, 1, 25, "Print"],
Cell[22655, 1492, 36, 1, 25, "Print"],
Cell[22694, 1495, 36, 1, 25, "Print"],
Cell[22733, 1498, 36, 1, 25, "Print"],
Cell[22772, 1501, 36, 1, 25, "Print"],
Cell[22811, 1504, 36, 1, 25, "Print"],
Cell[22850, 1507, 36, 1, 25, "Print"],
Cell[22889, 1510, 36, 1, 25, "Print"],
Cell[22928, 1513, 36, 1, 25, "Print"],
Cell[22967, 1516, 36, 1, 25, "Print"],
Cell[23006, 1519, 36, 1, 25, "Print"],
Cell[23045, 1522, 36, 1, 25, "Print"],
Cell[23084, 1525, 36, 1, 25, "Print"],
Cell[23123, 1528, 36, 1, 25, "Print"],
Cell[23162, 1531, 36, 1, 25, "Print"],
Cell[23201, 1534, 36, 1, 25, "Print"],
Cell[23240, 1537, 36, 1, 25, "Print"],
Cell[23279, 1540, 36, 1, 25, "Print"],
Cell[23318, 1543, 36, 1, 25, "Print"],
Cell[23357, 1546, 36, 1, 25, "Print"],
Cell[23396, 1549, 36, 1, 25, "Print"],
Cell[23435, 1552, 36, 1, 25, "Print"],
Cell[23474, 1555, 36, 1, 25, "Print"],
Cell[23513, 1558, 36, 1, 25, "Print"],
Cell[23552, 1561, 36, 1, 25, "Print"],
Cell[23591, 1564, 36, 1, 25, "Print"],
Cell[23630, 1567, 36, 1, 25, "Print"],
Cell[23669, 1570, 36, 1, 25, "Print"],
Cell[23708, 1573, 36, 1, 25, "Print"],
Cell[23747, 1576, 36, 1, 25, "Print"],
Cell[23786, 1579, 36, 1, 25, "Print"],
Cell[23825, 1582, 36, 1, 25, "Print"],
Cell[23864, 1585, 36, 1, 25, "Print"],
Cell[23903, 1588, 36, 1, 25, "Print"],
Cell[23942, 1591, 36, 1, 25, "Print"],
Cell[23981, 1594, 36, 1, 25, "Print"],
Cell[24020, 1597, 36, 1, 25, "Print"],
Cell[24059, 1600, 36, 1, 25, "Print"],
Cell[24098, 1603, 36, 1, 25, "Print"],
Cell[24137, 1606, 36, 1, 25, "Print"],
Cell[24176, 1609, 36, 1, 25, "Print"],
Cell[24215, 1612, 36, 1, 25, "Print"],
Cell[24254, 1615, 36, 1, 25, "Print"],
Cell[24293, 1618, 36, 1, 25, "Print"],
Cell[24332, 1621, 36, 1, 25, "Print"],
Cell[24371, 1624, 36, 1, 25, "Print"],
Cell[24410, 1627, 36, 1, 25, "Print"],
Cell[24449, 1630, 36, 1, 25, "Print"],
Cell[24488, 1633, 36, 1, 25, "Print"],
Cell[24527, 1636, 36, 1, 25, "Print"],
Cell[24566, 1639, 36, 1, 25, "Print"],
Cell[24605, 1642, 36, 1, 25, "Print"],
Cell[24644, 1645, 36, 1, 25, "Print"],
Cell[24683, 1648, 36, 1, 25, "Print"],
Cell[24722, 1651, 36, 1, 25, "Print"],
Cell[24761, 1654, 36, 1, 25, "Print"],
Cell[24800, 1657, 36, 1, 25, "Print"],
Cell[24839, 1660, 36, 1, 25, "Print"],
Cell[24878, 1663, 36, 1, 25, "Print"],
Cell[24917, 1666, 36, 1, 25, "Print"],
Cell[24956, 1669, 36, 1, 25, "Print"],
Cell[24995, 1672, 36, 1, 25, "Print"],
Cell[25034, 1675, 36, 1, 25, "Print"],
Cell[25073, 1678, 36, 1, 25, "Print"],
Cell[25112, 1681, 36, 1, 25, "Print"],
Cell[25151, 1684, 36, 1, 25, "Print"],
Cell[25190, 1687, 36, 1, 25, "Print"],
Cell[25229, 1690, 36, 1, 25, "Print"],
Cell[25268, 1693, 36, 1, 25, "Print"],
Cell[25307, 1696, 36, 1, 25, "Print"],
Cell[25346, 1699, 36, 1, 25, "Print"],
Cell[25385, 1702, 36, 1, 25, "Print"],
Cell[25424, 1705, 36, 1, 25, "Print"],
Cell[25463, 1708, 36, 1, 25, "Print"],
Cell[25502, 1711, 36, 1, 25, "Print"],
Cell[25541, 1714, 36, 1, 25, "Print"],
Cell[25580, 1717, 36, 1, 25, "Print"],
Cell[25619, 1720, 36, 1, 25, "Print"],
Cell[25658, 1723, 36, 1, 25, "Print"],
Cell[25697, 1726, 36, 1, 25, "Print"],
Cell[25736, 1729, 36, 1, 25, "Print"],
Cell[25775, 1732, 36, 1, 25, "Print"],
Cell[25814, 1735, 36, 1, 25, "Print"],
Cell[25853, 1738, 36, 1, 25, "Print"],
Cell[25892, 1741, 36, 1, 25, "Print"],
Cell[25931, 1744, 36, 1, 25, "Print"],
Cell[25970, 1747, 36, 1, 25, "Print"],
Cell[26009, 1750, 36, 1, 25, "Print"],
Cell[26048, 1753, 36, 1, 25, "Print"],
Cell[26087, 1756, 36, 1, 25, "Print"],
Cell[26126, 1759, 36, 1, 25, "Print"],
Cell[26165, 1762, 36, 1, 25, "Print"],
Cell[26204, 1765, 36, 1, 25, "Print"],
Cell[26243, 1768, 36, 1, 25, "Print"],
Cell[26282, 1771, 36, 1, 25, "Print"],
Cell[26321, 1774, 36, 1, 25, "Print"],
Cell[26360, 1777, 36, 1, 25, "Print"],
Cell[26399, 1780, 36, 1, 25, "Print"],
Cell[26438, 1783, 36, 1, 25, "Print"],
Cell[26477, 1786, 36, 1, 25, "Print"],
Cell[26516, 1789, 36, 1, 25, "Print"],
Cell[26555, 1792, 36, 1, 25, "Print"],
Cell[26594, 1795, 36, 1, 25, "Print"],
Cell[26633, 1798, 36, 1, 25, "Print"],
Cell[26672, 1801, 36, 1, 25, "Print"],
Cell[26711, 1804, 36, 1, 25, "Print"],
Cell[26750, 1807, 36, 1, 25, "Print"],
Cell[26789, 1810, 36, 1, 25, "Print"],
Cell[26828, 1813, 36, 1, 25, "Print"],
Cell[26867, 1816, 36, 1, 25, "Print"],
Cell[26906, 1819, 36, 1, 25, "Print"],
Cell[26945, 1822, 36, 1, 25, "Print"],
Cell[26984, 1825, 36, 1, 25, "Print"],
Cell[27023, 1828, 36, 1, 25, "Print"],
Cell[27062, 1831, 36, 1, 25, "Print"],
Cell[27101, 1834, 36, 1, 25, "Print"],
Cell[27140, 1837, 36, 1, 25, "Print"],
Cell[27179, 1840, 36, 1, 25, "Print"],
Cell[27218, 1843, 36, 1, 25, "Print"],
Cell[27257, 1846, 36, 1, 25, "Print"],
Cell[27296, 1849, 36, 1, 25, "Print"],
Cell[27335, 1852, 36, 1, 25, "Print"],
Cell[27374, 1855, 36, 1, 25, "Print"],
Cell[27413, 1858, 36, 1, 25, "Print"],
Cell[27452, 1861, 36, 1, 25, "Print"],
Cell[27491, 1864, 36, 1, 25, "Print"],
Cell[27530, 1867, 36, 1, 25, "Print"],
Cell[27569, 1870, 36, 1, 25, "Print"],
Cell[27608, 1873, 36, 1, 25, "Print"],
Cell[27647, 1876, 36, 1, 25, "Print"],
Cell[27686, 1879, 36, 1, 25, "Print"],
Cell[27725, 1882, 36, 1, 25, "Print"],
Cell[27764, 1885, 36, 1, 25, "Print"],
Cell[27803, 1888, 36, 1, 25, "Print"],
Cell[27842, 1891, 36, 1, 25, "Print"],
Cell[27881, 1894, 36, 1, 25, "Print"],
Cell[27920, 1897, 36, 1, 25, "Print"],
Cell[27959, 1900, 36, 1, 25, "Print"],
Cell[27998, 1903, 36, 1, 25, "Print"],
Cell[28037, 1906, 36, 1, 25, "Print"],
Cell[28076, 1909, 36, 1, 25, "Print"],
Cell[28115, 1912, 36, 1, 25, "Print"],
Cell[28154, 1915, 36, 1, 25, "Print"],
Cell[28193, 1918, 36, 1, 25, "Print"],
Cell[28232, 1921, 36, 1, 25, "Print"],
Cell[28271, 1924, 36, 1, 25, "Print"],
Cell[28310, 1927, 36, 1, 25, "Print"],
Cell[28349, 1930, 36, 1, 25, "Print"],
Cell[28388, 1933, 36, 1, 25, "Print"],
Cell[28427, 1936, 36, 1, 25, "Print"],
Cell[28466, 1939, 36, 1, 25, "Print"],
Cell[28505, 1942, 36, 1, 25, "Print"],
Cell[28544, 1945, 36, 1, 25, "Print"],
Cell[28583, 1948, 36, 1, 25, "Print"],
Cell[28622, 1951, 36, 1, 25, "Print"],
Cell[28661, 1954, 36, 1, 25, "Print"],
Cell[28700, 1957, 36, 1, 25, "Print"],
Cell[28739, 1960, 36, 1, 25, "Print"],
Cell[28778, 1963, 36, 1, 25, "Print"],
Cell[28817, 1966, 36, 1, 25, "Print"],
Cell[28856, 1969, 36, 1, 25, "Print"],
Cell[28895, 1972, 36, 1, 25, "Print"],
Cell[28934, 1975, 36, 1, 25, "Print"],
Cell[28973, 1978, 36, 1, 25, "Print"],
Cell[29012, 1981, 36, 1, 25, "Print"],
Cell[29051, 1984, 36, 1, 25, "Print"],
Cell[29090, 1987, 36, 1, 25, "Print"],
Cell[29129, 1990, 36, 1, 25, "Print"],
Cell[29168, 1993, 36, 1, 25, "Print"],
Cell[29207, 1996, 36, 1, 25, "Print"],
Cell[29246, 1999, 36, 1, 25, "Print"],
Cell[29285, 2002, 36, 1, 25, "Print"],
Cell[29324, 2005, 36, 1, 25, "Print"],
Cell[29363, 2008, 36, 1, 25, "Print"],
Cell[29402, 2011, 36, 1, 25, "Print"],
Cell[29441, 2014, 36, 1, 25, "Print"],
Cell[29480, 2017, 36, 1, 25, "Print"],
Cell[29519, 2020, 36, 1, 25, "Print"],
Cell[29558, 2023, 36, 1, 25, "Print"],
Cell[29597, 2026, 36, 1, 25, "Print"],
Cell[29636, 2029, 36, 1, 25, "Print"],
Cell[29675, 2032, 36, 1, 25, "Print"],
Cell[29714, 2035, 36, 1, 25, "Print"],
Cell[29753, 2038, 36, 1, 25, "Print"],
Cell[29792, 2041, 36, 1, 25, "Print"],
Cell[29831, 2044, 36, 1, 25, "Print"],
Cell[29870, 2047, 36, 1, 25, "Print"],
Cell[29909, 2050, 36, 1, 25, "Print"],
Cell[29948, 2053, 36, 1, 25, "Print"],
Cell[29987, 2056, 36, 1, 25, "Print"],
Cell[30026, 2059, 36, 1, 25, "Print"],
Cell[30065, 2062, 36, 1, 25, "Print"],
Cell[30104, 2065, 36, 1, 25, "Print"],
Cell[30143, 2068, 36, 1, 25, "Print"],
Cell[30182, 2071, 36, 1, 25, "Print"],
Cell[30221, 2074, 36, 1, 25, "Print"],
Cell[30260, 2077, 36, 1, 25, "Print"],
Cell[30299, 2080, 36, 1, 25, "Print"],
Cell[30338, 2083, 36, 1, 25, "Print"],
Cell[30377, 2086, 36, 1, 25, "Print"],
Cell[30416, 2089, 36, 1, 25, "Print"],
Cell[30455, 2092, 36, 1, 25, "Print"],
Cell[30494, 2095, 36, 1, 25, "Print"],
Cell[30533, 2098, 36, 1, 25, "Print"],
Cell[30572, 2101, 36, 1, 25, "Print"],
Cell[30611, 2104, 36, 1, 25, "Print"],
Cell[30650, 2107, 36, 1, 25, "Print"],
Cell[30689, 2110, 36, 1, 25, "Print"],
Cell[30728, 2113, 36, 1, 25, "Print"],
Cell[30767, 2116, 36, 1, 25, "Print"],
Cell[30806, 2119, 36, 1, 25, "Print"],
Cell[30845, 2122, 36, 1, 25, "Print"],
Cell[30884, 2125, 36, 1, 25, "Print"],
Cell[30923, 2128, 36, 1, 25, "Print"],
Cell[30962, 2131, 36, 1, 25, "Print"],
Cell[31001, 2134, 36, 1, 25, "Print"],
Cell[31040, 2137, 36, 1, 25, "Print"],
Cell[31079, 2140, 36, 1, 25, "Print"],
Cell[31118, 2143, 36, 1, 25, "Print"],
Cell[31157, 2146, 36, 1, 25, "Print"],
Cell[31196, 2149, 36, 1, 25, "Print"],
Cell[31235, 2152, 36, 1, 25, "Print"],
Cell[31274, 2155, 36, 1, 25, "Print"],
Cell[31313, 2158, 36, 1, 25, "Print"],
Cell[31352, 2161, 36, 1, 25, "Print"],
Cell[31391, 2164, 36, 1, 25, "Print"],
Cell[31430, 2167, 36, 1, 25, "Print"],
Cell[31469, 2170, 36, 1, 25, "Print"],
Cell[31508, 2173, 36, 1, 25, "Print"],
Cell[31547, 2176, 36, 1, 25, "Print"],
Cell[31586, 2179, 36, 1, 25, "Print"],
Cell[31625, 2182, 36, 1, 25, "Print"],
Cell[31664, 2185, 36, 1, 25, "Print"],
Cell[31703, 2188, 36, 1, 25, "Print"],
Cell[31742, 2191, 36, 1, 25, "Print"],
Cell[31781, 2194, 36, 1, 25, "Print"],
Cell[31820, 2197, 36, 1, 25, "Print"],
Cell[31859, 2200, 36, 1, 25, "Print"],
Cell[31898, 2203, 36, 1, 25, "Print"],
Cell[31937, 2206, 36, 1, 25, "Print"],
Cell[31976, 2209, 36, 1, 25, "Print"],
Cell[32015, 2212, 36, 1, 25, "Print"],
Cell[32054, 2215, 36, 1, 25, "Print"],
Cell[32093, 2218, 36, 1, 25, "Print"],
Cell[32132, 2221, 36, 1, 25, "Print"],
Cell[32171, 2224, 36, 1, 25, "Print"],
Cell[32210, 2227, 36, 1, 25, "Print"],
Cell[32249, 2230, 36, 1, 25, "Print"],
Cell[32288, 2233, 36, 1, 25, "Print"],
Cell[32327, 2236, 36, 1, 25, "Print"],
Cell[32366, 2239, 36, 1, 25, "Print"],
Cell[32405, 2242, 36, 1, 25, "Print"],
Cell[32444, 2245, 36, 1, 25, "Print"],
Cell[32483, 2248, 36, 1, 25, "Print"],
Cell[32522, 2251, 36, 1, 25, "Print"],
Cell[32561, 2254, 36, 1, 25, "Print"],
Cell[32600, 2257, 36, 1, 25, "Print"],
Cell[32639, 2260, 36, 1, 25, "Print"],
Cell[32678, 2263, 36, 1, 25, "Print"],
Cell[32717, 2266, 36, 1, 25, "Print"],
Cell[32756, 2269, 36, 1, 25, "Print"],
Cell[32795, 2272, 36, 1, 25, "Print"],
Cell[32834, 2275, 36, 1, 25, "Print"],
Cell[32873, 2278, 36, 1, 25, "Print"],
Cell[32912, 2281, 36, 1, 25, "Print"],
Cell[32951, 2284, 36, 1, 25, "Print"],
Cell[32990, 2287, 36, 1, 25, "Print"],
Cell[33029, 2290, 36, 1, 25, "Print"],
Cell[33068, 2293, 36, 1, 25, "Print"],
Cell[33107, 2296, 36, 1, 25, "Print"],
Cell[33146, 2299, 36, 1, 25, "Print"],
Cell[33185, 2302, 36, 1, 25, "Print"],
Cell[33224, 2305, 36, 1, 25, "Print"],
Cell[33263, 2308, 36, 1, 25, "Print"],
Cell[33302, 2311, 36, 1, 25, "Print"],
Cell[33341, 2314, 36, 1, 25, "Print"],
Cell[33380, 2317, 36, 1, 25, "Print"],
Cell[33419, 2320, 36, 1, 25, "Print"],
Cell[33458, 2323, 36, 1, 25, "Print"],
Cell[33497, 2326, 36, 1, 25, "Print"],
Cell[33536, 2329, 36, 1, 25, "Print"],
Cell[33575, 2332, 36, 1, 25, "Print"],
Cell[33614, 2335, 36, 1, 25, "Print"],
Cell[33653, 2338, 36, 1, 25, "Print"],
Cell[33692, 2341, 36, 1, 25, "Print"],
Cell[33731, 2344, 36, 1, 25, "Print"],
Cell[33770, 2347, 36, 1, 25, "Print"],
Cell[33809, 2350, 36, 1, 25, "Print"],
Cell[33848, 2353, 36, 1, 25, "Print"],
Cell[33887, 2356, 36, 1, 25, "Print"],
Cell[33926, 2359, 36, 1, 25, "Print"],
Cell[33965, 2362, 36, 1, 25, "Print"],
Cell[34004, 2365, 36, 1, 25, "Print"],
Cell[34043, 2368, 36, 1, 25, "Print"],
Cell[34082, 2371, 36, 1, 25, "Print"],
Cell[34121, 2374, 36, 1, 25, "Print"],
Cell[34160, 2377, 36, 1, 25, "Print"],
Cell[34199, 2380, 36, 1, 25, "Print"],
Cell[34238, 2383, 36, 1, 25, "Print"],
Cell[34277, 2386, 36, 1, 25, "Print"],
Cell[34316, 2389, 36, 1, 25, "Print"],
Cell[34355, 2392, 36, 1, 25, "Print"],
Cell[34394, 2395, 36, 1, 25, "Print"],
Cell[34433, 2398, 36, 1, 25, "Print"],
Cell[34472, 2401, 36, 1, 25, "Print"],
Cell[34511, 2404, 36, 1, 25, "Print"],
Cell[34550, 2407, 36, 1, 25, "Print"],
Cell[34589, 2410, 36, 1, 25, "Print"],
Cell[34628, 2413, 36, 1, 25, "Print"],
Cell[34667, 2416, 36, 1, 25, "Print"],
Cell[34706, 2419, 36, 1, 25, "Print"],
Cell[34745, 2422, 36, 1, 25, "Print"],
Cell[34784, 2425, 36, 1, 25, "Print"],
Cell[34823, 2428, 36, 1, 25, "Print"],
Cell[34862, 2431, 36, 1, 25, "Print"],
Cell[34901, 2434, 36, 1, 25, "Print"],
Cell[34940, 2437, 36, 1, 25, "Print"],
Cell[34979, 2440, 36, 1, 25, "Print"],
Cell[35018, 2443, 36, 1, 25, "Print"],
Cell[35057, 2446, 36, 1, 25, "Print"],
Cell[35096, 2449, 36, 1, 25, "Print"],
Cell[35135, 2452, 36, 1, 25, "Print"],
Cell[35174, 2455, 36, 1, 25, "Print"],
Cell[35213, 2458, 36, 1, 25, "Print"],
Cell[35252, 2461, 36, 1, 25, "Print"],
Cell[35291, 2464, 36, 1, 25, "Print"],
Cell[35330, 2467, 36, 1, 25, "Print"],
Cell[35369, 2470, 36, 1, 25, "Print"],
Cell[35408, 2473, 36, 1, 25, "Print"],
Cell[35447, 2476, 36, 1, 25, "Print"],
Cell[35486, 2479, 36, 1, 25, "Print"],
Cell[35525, 2482, 36, 1, 25, "Print"],
Cell[35564, 2485, 36, 1, 25, "Print"],
Cell[35603, 2488, 36, 1, 25, "Print"],
Cell[35642, 2491, 36, 1, 25, "Print"],
Cell[35681, 2494, 36, 1, 25, "Print"],
Cell[35720, 2497, 36, 1, 25, "Print"],
Cell[35759, 2500, 36, 1, 25, "Print"],
Cell[35798, 2503, 36, 1, 25, "Print"],
Cell[35837, 2506, 36, 1, 25, "Print"],
Cell[35876, 2509, 36, 1, 25, "Print"],
Cell[35915, 2512, 36, 1, 25, "Print"],
Cell[35954, 2515, 36, 1, 25, "Print"],
Cell[35993, 2518, 36, 1, 25, "Print"],
Cell[36032, 2521, 36, 1, 25, "Print"],
Cell[36071, 2524, 36, 1, 25, "Print"],
Cell[36110, 2527, 36, 1, 25, "Print"],
Cell[36149, 2530, 36, 1, 25, "Print"],
Cell[36188, 2533, 36, 1, 25, "Print"],
Cell[36227, 2536, 36, 1, 25, "Print"],
Cell[36266, 2539, 36, 1, 25, "Print"],
Cell[36305, 2542, 36, 1, 25, "Print"],
Cell[36344, 2545, 36, 1, 25, "Print"],
Cell[36383, 2548, 36, 1, 25, "Print"],
Cell[36422, 2551, 36, 1, 25, "Print"],
Cell[36461, 2554, 36, 1, 25, "Print"],
Cell[36500, 2557, 36, 1, 25, "Print"],
Cell[36539, 2560, 36, 1, 25, "Print"],
Cell[36578, 2563, 36, 1, 25, "Print"],
Cell[36617, 2566, 36, 1, 25, "Print"],
Cell[36656, 2569, 36, 1, 25, "Print"],
Cell[36695, 2572, 36, 1, 25, "Print"],
Cell[36734, 2575, 36, 1, 25, "Print"],
Cell[36773, 2578, 36, 1, 25, "Print"],
Cell[36812, 2581, 36, 1, 25, "Print"],
Cell[36851, 2584, 36, 1, 25, "Print"],
Cell[36890, 2587, 36, 1, 25, "Print"],
Cell[36929, 2590, 36, 1, 25, "Print"],
Cell[36968, 2593, 36, 1, 25, "Print"],
Cell[37007, 2596, 36, 1, 25, "Print"],
Cell[37046, 2599, 36, 1, 25, "Print"],
Cell[37085, 2602, 36, 1, 25, "Print"],
Cell[37124, 2605, 36, 1, 25, "Print"],
Cell[37163, 2608, 36, 1, 25, "Print"],
Cell[37202, 2611, 36, 1, 25, "Print"],
Cell[37241, 2614, 36, 1, 25, "Print"],
Cell[37280, 2617, 36, 1, 25, "Print"],
Cell[37319, 2620, 36, 1, 25, "Print"],
Cell[37358, 2623, 36, 1, 25, "Print"],
Cell[37397, 2626, 36, 1, 25, "Print"],
Cell[37436, 2629, 36, 1, 25, "Print"],
Cell[37475, 2632, 36, 1, 25, "Print"],
Cell[37514, 2635, 36, 1, 25, "Print"],
Cell[37553, 2638, 36, 1, 25, "Print"],
Cell[37592, 2641, 36, 1, 25, "Print"],
Cell[37631, 2644, 36, 1, 25, "Print"],
Cell[37670, 2647, 36, 1, 25, "Print"],
Cell[37709, 2650, 36, 1, 25, "Print"],
Cell[37748, 2653, 36, 1, 25, "Print"],
Cell[37787, 2656, 36, 1, 25, "Print"],
Cell[37826, 2659, 36, 1, 25, "Print"],
Cell[37865, 2662, 36, 1, 25, "Print"],
Cell[37904, 2665, 36, 1, 25, "Print"],
Cell[37943, 2668, 36, 1, 25, "Print"],
Cell[37982, 2671, 36, 1, 25, "Print"],
Cell[38021, 2674, 36, 1, 25, "Print"],
Cell[38060, 2677, 36, 1, 25, "Print"],
Cell[38099, 2680, 36, 1, 25, "Print"],
Cell[38138, 2683, 36, 1, 25, "Print"],
Cell[38177, 2686, 36, 1, 25, "Print"],
Cell[38216, 2689, 36, 1, 25, "Print"],
Cell[38255, 2692, 36, 1, 25, "Print"],
Cell[38294, 2695, 36, 1, 25, "Print"],
Cell[38333, 2698, 36, 1, 25, "Print"],
Cell[38372, 2701, 36, 1, 25, "Print"],
Cell[38411, 2704, 36, 1, 25, "Print"],
Cell[38450, 2707, 36, 1, 25, "Print"],
Cell[38489, 2710, 36, 1, 25, "Print"],
Cell[38528, 2713, 36, 1, 25, "Print"],
Cell[38567, 2716, 36, 1, 25, "Print"],
Cell[38606, 2719, 36, 1, 25, "Print"],
Cell[38645, 2722, 36, 1, 25, "Print"],
Cell[38684, 2725, 36, 1, 25, "Print"],
Cell[38723, 2728, 36, 1, 25, "Print"],
Cell[38762, 2731, 36, 1, 25, "Print"],
Cell[38801, 2734, 36, 1, 25, "Print"],
Cell[38840, 2737, 36, 1, 25, "Print"],
Cell[38879, 2740, 36, 1, 25, "Print"],
Cell[38918, 2743, 36, 1, 25, "Print"],
Cell[38957, 2746, 36, 1, 25, "Print"],
Cell[38996, 2749, 36, 1, 25, "Print"],
Cell[39035, 2752, 36, 1, 25, "Print"],
Cell[39074, 2755, 36, 1, 25, "Print"],
Cell[39113, 2758, 36, 1, 25, "Print"],
Cell[39152, 2761, 36, 1, 25, "Print"],
Cell[39191, 2764, 36, 1, 25, "Print"],
Cell[39230, 2767, 36, 1, 25, "Print"],
Cell[39269, 2770, 36, 1, 25, "Print"],
Cell[39308, 2773, 36, 1, 25, "Print"],
Cell[39347, 2776, 36, 1, 25, "Print"],
Cell[39386, 2779, 36, 1, 25, "Print"],
Cell[39425, 2782, 36, 1, 25, "Print"],
Cell[39464, 2785, 36, 1, 25, "Print"],
Cell[39503, 2788, 36, 1, 25, "Print"],
Cell[39542, 2791, 36, 1, 25, "Print"],
Cell[39581, 2794, 36, 1, 25, "Print"],
Cell[39620, 2797, 36, 1, 25, "Print"],
Cell[39659, 2800, 36, 1, 25, "Print"],
Cell[39698, 2803, 36, 1, 25, "Print"],
Cell[39737, 2806, 36, 1, 25, "Print"],
Cell[39776, 2809, 36, 1, 25, "Print"],
Cell[39815, 2812, 36, 1, 25, "Print"],
Cell[39854, 2815, 36, 1, 25, "Print"],
Cell[39893, 2818, 36, 1, 25, "Print"],
Cell[39932, 2821, 36, 1, 25, "Print"],
Cell[39971, 2824, 36, 1, 25, "Print"],
Cell[40010, 2827, 36, 1, 25, "Print"],
Cell[40049, 2830, 36, 1, 25, "Print"],
Cell[40088, 2833, 36, 1, 25, "Print"],
Cell[40127, 2836, 36, 1, 25, "Print"],
Cell[40166, 2839, 36, 1, 25, "Print"],
Cell[40205, 2842, 36, 1, 25, "Print"],
Cell[40244, 2845, 36, 1, 25, "Print"],
Cell[40283, 2848, 36, 1, 25, "Print"],
Cell[40322, 2851, 36, 1, 25, "Print"],
Cell[40361, 2854, 36, 1, 25, "Print"],
Cell[40400, 2857, 36, 1, 25, "Print"],
Cell[40439, 2860, 36, 1, 25, "Print"],
Cell[40478, 2863, 36, 1, 25, "Print"],
Cell[40517, 2866, 36, 1, 25, "Print"],
Cell[40556, 2869, 36, 1, 25, "Print"],
Cell[40595, 2872, 36, 1, 25, "Print"],
Cell[40634, 2875, 36, 1, 25, "Print"],
Cell[40673, 2878, 36, 1, 25, "Print"],
Cell[40712, 2881, 36, 1, 25, "Print"],
Cell[40751, 2884, 36, 1, 25, "Print"],
Cell[40790, 2887, 36, 1, 25, "Print"],
Cell[40829, 2890, 36, 1, 25, "Print"],
Cell[40868, 2893, 36, 1, 25, "Print"],
Cell[40907, 2896, 36, 1, 25, "Print"],
Cell[40946, 2899, 36, 1, 25, "Print"],
Cell[40985, 2902, 36, 1, 25, "Print"],
Cell[41024, 2905, 36, 1, 25, "Print"],
Cell[41063, 2908, 36, 1, 25, "Print"],
Cell[41102, 2911, 36, 1, 25, "Print"],
Cell[41141, 2914, 36, 1, 25, "Print"],
Cell[41180, 2917, 36, 1, 25, "Print"],
Cell[41219, 2920, 36, 1, 25, "Print"],
Cell[41258, 2923, 36, 1, 25, "Print"],
Cell[41297, 2926, 36, 1, 25, "Print"],
Cell[41336, 2929, 36, 1, 25, "Print"],
Cell[41375, 2932, 36, 1, 25, "Print"],
Cell[41414, 2935, 36, 1, 25, "Print"],
Cell[41453, 2938, 36, 1, 25, "Print"],
Cell[41492, 2941, 36, 1, 25, "Print"],
Cell[41531, 2944, 36, 1, 25, "Print"],
Cell[41570, 2947, 36, 1, 25, "Print"],
Cell[41609, 2950, 36, 1, 25, "Print"],
Cell[41648, 2953, 36, 1, 25, "Print"],
Cell[41687, 2956, 36, 1, 25, "Print"],
Cell[41726, 2959, 36, 1, 25, "Print"],
Cell[41765, 2962, 36, 1, 25, "Print"],
Cell[41804, 2965, 36, 1, 25, "Print"],
Cell[41843, 2968, 36, 1, 25, "Print"],
Cell[41882, 2971, 36, 1, 25, "Print"],
Cell[41921, 2974, 36, 1, 25, "Print"],
Cell[41960, 2977, 36, 1, 25, "Print"],
Cell[41999, 2980, 36, 1, 25, "Print"],
Cell[42038, 2983, 36, 1, 25, "Print"],
Cell[42077, 2986, 36, 1, 25, "Print"],
Cell[42116, 2989, 36, 1, 25, "Print"],
Cell[42155, 2992, 36, 1, 25, "Print"],
Cell[42194, 2995, 36, 1, 25, "Print"],
Cell[42233, 2998, 36, 1, 25, "Print"],
Cell[42272, 3001, 36, 1, 25, "Print"],
Cell[42311, 3004, 36, 1, 25, "Print"],
Cell[42350, 3007, 36, 1, 25, "Print"],
Cell[42389, 3010, 36, 1, 25, "Print"],
Cell[42428, 3013, 36, 1, 25, "Print"],
Cell[42467, 3016, 36, 1, 25, "Print"],
Cell[42506, 3019, 36, 1, 25, "Print"],
Cell[42545, 3022, 36, 1, 25, "Print"],
Cell[42584, 3025, 36, 1, 25, "Print"],
Cell[42623, 3028, 36, 1, 25, "Print"],
Cell[42662, 3031, 36, 1, 25, "Print"],
Cell[42701, 3034, 36, 1, 25, "Print"],
Cell[42740, 3037, 36, 1, 25, "Print"],
Cell[42779, 3040, 36, 1, 25, "Print"],
Cell[42818, 3043, 36, 1, 25, "Print"],
Cell[42857, 3046, 36, 1, 25, "Print"],
Cell[42896, 3049, 36, 1, 25, "Print"],
Cell[42935, 3052, 36, 1, 25, "Print"],
Cell[42974, 3055, 36, 1, 25, "Print"],
Cell[43013, 3058, 36, 1, 25, "Print"],
Cell[43052, 3061, 36, 1, 25, "Print"],
Cell[43091, 3064, 36, 1, 25, "Print"],
Cell[43130, 3067, 36, 1, 25, "Print"],
Cell[43169, 3070, 36, 1, 25, "Print"],
Cell[43208, 3073, 36, 1, 25, "Print"],
Cell[43247, 3076, 36, 1, 25, "Print"],
Cell[43286, 3079, 36, 1, 25, "Print"],
Cell[43325, 3082, 36, 1, 25, "Print"],
Cell[43364, 3085, 36, 1, 25, "Print"],
Cell[43403, 3088, 36, 1, 25, "Print"],
Cell[43442, 3091, 36, 1, 25, "Print"],
Cell[43481, 3094, 36, 1, 25, "Print"],
Cell[43520, 3097, 36, 1, 25, "Print"],
Cell[43559, 3100, 36, 1, 25, "Print"],
Cell[43598, 3103, 36, 1, 25, "Print"],
Cell[43637, 3106, 36, 1, 25, "Print"],
Cell[43676, 3109, 36, 1, 25, "Print"],
Cell[43715, 3112, 36, 1, 25, "Print"],
Cell[43754, 3115, 36, 1, 25, "Print"],
Cell[43793, 3118, 36, 1, 25, "Print"],
Cell[43832, 3121, 36, 1, 25, "Print"],
Cell[43871, 3124, 36, 1, 25, "Print"],
Cell[43910, 3127, 36, 1, 25, "Print"],
Cell[43949, 3130, 36, 1, 25, "Print"],
Cell[43988, 3133, 36, 1, 25, "Print"],
Cell[44027, 3136, 36, 1, 25, "Print"],
Cell[44066, 3139, 36, 1, 25, "Print"],
Cell[44105, 3142, 36, 1, 25, "Print"],
Cell[44144, 3145, 36, 1, 25, "Print"],
Cell[44183, 3148, 36, 1, 25, "Print"],
Cell[44222, 3151, 36, 1, 25, "Print"],
Cell[44261, 3154, 36, 1, 25, "Print"],
Cell[44300, 3157, 36, 1, 25, "Print"],
Cell[44339, 3160, 36, 1, 25, "Print"],
Cell[44378, 3163, 36, 1, 25, "Print"],
Cell[44417, 3166, 36, 1, 25, "Print"],
Cell[44456, 3169, 36, 1, 25, "Print"],
Cell[44495, 3172, 36, 1, 25, "Print"],
Cell[44534, 3175, 36, 1, 25, "Print"],
Cell[44573, 3178, 36, 1, 25, "Print"],
Cell[44612, 3181, 36, 1, 25, "Print"],
Cell[44651, 3184, 36, 1, 25, "Print"],
Cell[44690, 3187, 36, 1, 25, "Print"],
Cell[44729, 3190, 36, 1, 25, "Print"],
Cell[44768, 3193, 36, 1, 25, "Print"],
Cell[44807, 3196, 36, 1, 25, "Print"],
Cell[44846, 3199, 37, 1, 25, "Print"],
Cell[44886, 3202, 37, 1, 25, "Print"],
Cell[44926, 3205, 37, 1, 25, "Print"],
Cell[44966, 3208, 37, 1, 25, "Print"],
Cell[45006, 3211, 37, 1, 25, "Print"],
Cell[45046, 3214, 37, 1, 25, "Print"],
Cell[45086, 3217, 37, 1, 25, "Print"],
Cell[45126, 3220, 37, 1, 25, "Print"],
Cell[45166, 3223, 37, 1, 25, "Print"],
Cell[45206, 3226, 37, 1, 25, "Print"],
Cell[45246, 3229, 37, 1, 25, "Print"],
Cell[45286, 3232, 37, 1, 25, "Print"],
Cell[45326, 3235, 37, 1, 25, "Print"],
Cell[45366, 3238, 37, 1, 25, "Print"],
Cell[45406, 3241, 37, 1, 25, "Print"],
Cell[45446, 3244, 37, 1, 25, "Print"],
Cell[45486, 3247, 37, 1, 25, "Print"],
Cell[45526, 3250, 37, 1, 25, "Print"],
Cell[45566, 3253, 37, 1, 25, "Print"],
Cell[45606, 3256, 37, 1, 25, "Print"],
Cell[45646, 3259, 37, 1, 25, "Print"],
Cell[45686, 3262, 37, 1, 25, "Print"],
Cell[45726, 3265, 37, 1, 25, "Print"],
Cell[45766, 3268, 37, 1, 25, "Print"],
Cell[45806, 3271, 37, 1, 25, "Print"],
Cell[45846, 3274, 37, 1, 25, "Print"],
Cell[45886, 3277, 37, 1, 25, "Print"],
Cell[45926, 3280, 37, 1, 25, "Print"],
Cell[45966, 3283, 37, 1, 25, "Print"],
Cell[46006, 3286, 37, 1, 25, "Print"],
Cell[46046, 3289, 37, 1, 25, "Print"],
Cell[46086, 3292, 37, 1, 25, "Print"],
Cell[46126, 3295, 37, 1, 25, "Print"],
Cell[46166, 3298, 37, 1, 25, "Print"],
Cell[46206, 3301, 37, 1, 25, "Print"],
Cell[46246, 3304, 37, 1, 25, "Print"],
Cell[46286, 3307, 37, 1, 25, "Print"],
Cell[46326, 3310, 37, 1, 25, "Print"],
Cell[46366, 3313, 37, 1, 25, "Print"],
Cell[46406, 3316, 37, 1, 25, "Print"],
Cell[46446, 3319, 37, 1, 25, "Print"],
Cell[46486, 3322, 37, 1, 25, "Print"],
Cell[46526, 3325, 37, 1, 25, "Print"],
Cell[46566, 3328, 37, 1, 25, "Print"],
Cell[46606, 3331, 37, 1, 25, "Print"],
Cell[46646, 3334, 37, 1, 25, "Print"],
Cell[46686, 3337, 37, 1, 25, "Print"],
Cell[46726, 3340, 37, 1, 25, "Print"],
Cell[46766, 3343, 37, 1, 25, "Print"],
Cell[46806, 3346, 37, 1, 25, "Print"],
Cell[46846, 3349, 37, 1, 25, "Print"],
Cell[46886, 3352, 37, 1, 25, "Print"],
Cell[46926, 3355, 37, 1, 25, "Print"],
Cell[46966, 3358, 37, 1, 25, "Print"],
Cell[47006, 3361, 37, 1, 25, "Print"],
Cell[47046, 3364, 37, 1, 25, "Print"],
Cell[47086, 3367, 37, 1, 25, "Print"],
Cell[47126, 3370, 37, 1, 25, "Print"],
Cell[47166, 3373, 37, 1, 25, "Print"],
Cell[47206, 3376, 37, 1, 25, "Print"],
Cell[47246, 3379, 37, 1, 25, "Print"],
Cell[47286, 3382, 37, 1, 25, "Print"],
Cell[47326, 3385, 37, 1, 25, "Print"],
Cell[47366, 3388, 37, 1, 25, "Print"],
Cell[47406, 3391, 37, 1, 25, "Print"],
Cell[47446, 3394, 37, 1, 25, "Print"],
Cell[47486, 3397, 37, 1, 25, "Print"],
Cell[47526, 3400, 37, 1, 25, "Print"],
Cell[47566, 3403, 37, 1, 25, "Print"],
Cell[47606, 3406, 37, 1, 25, "Print"],
Cell[47646, 3409, 37, 1, 25, "Print"],
Cell[47686, 3412, 37, 1, 25, "Print"],
Cell[47726, 3415, 37, 1, 25, "Print"],
Cell[47766, 3418, 37, 1, 25, "Print"],
Cell[47806, 3421, 37, 1, 25, "Print"],
Cell[47846, 3424, 37, 1, 25, "Print"],
Cell[47886, 3427, 37, 1, 25, "Print"],
Cell[47926, 3430, 37, 1, 25, "Print"],
Cell[47966, 3433, 37, 1, 25, "Print"],
Cell[48006, 3436, 37, 1, 25, "Print"],
Cell[48046, 3439, 37, 1, 25, "Print"],
Cell[48086, 3442, 37, 1, 25, "Print"],
Cell[48126, 3445, 37, 1, 25, "Print"],
Cell[48166, 3448, 37, 1, 25, "Print"],
Cell[48206, 3451, 37, 1, 25, "Print"],
Cell[48246, 3454, 37, 1, 25, "Print"],
Cell[48286, 3457, 37, 1, 25, "Print"],
Cell[48326, 3460, 37, 1, 25, "Print"],
Cell[48366, 3463, 37, 1, 25, "Print"],
Cell[48406, 3466, 37, 1, 25, "Print"],
Cell[48446, 3469, 37, 1, 25, "Print"],
Cell[48486, 3472, 37, 1, 25, "Print"],
Cell[48526, 3475, 37, 1, 25, "Print"],
Cell[48566, 3478, 37, 1, 25, "Print"],
Cell[48606, 3481, 37, 1, 25, "Print"],
Cell[48646, 3484, 37, 1, 25, "Print"],
Cell[48686, 3487, 37, 1, 25, "Print"],
Cell[48726, 3490, 37, 1, 25, "Print"],
Cell[48766, 3493, 37, 1, 25, "Print"],
Cell[48806, 3496, 37, 1, 25, "Print"],
Cell[48846, 3499, 37, 1, 25, "Print"],
Cell[48886, 3502, 37, 1, 25, "Print"],
Cell[48926, 3505, 37, 1, 25, "Print"],
Cell[48966, 3508, 37, 1, 25, "Print"],
Cell[49006, 3511, 37, 1, 25, "Print"],
Cell[49046, 3514, 37, 1, 25, "Print"],
Cell[49086, 3517, 37, 1, 25, "Print"],
Cell[49126, 3520, 37, 1, 25, "Print"],
Cell[49166, 3523, 37, 1, 25, "Print"],
Cell[49206, 3526, 37, 1, 25, "Print"],
Cell[49246, 3529, 37, 1, 25, "Print"],
Cell[49286, 3532, 37, 1, 25, "Print"],
Cell[49326, 3535, 37, 1, 25, "Print"],
Cell[49366, 3538, 37, 1, 25, "Print"],
Cell[49406, 3541, 37, 1, 25, "Print"],
Cell[49446, 3544, 37, 1, 25, "Print"],
Cell[49486, 3547, 37, 1, 25, "Print"],
Cell[49526, 3550, 37, 1, 25, "Print"],
Cell[49566, 3553, 37, 1, 25, "Print"],
Cell[49606, 3556, 37, 1, 25, "Print"],
Cell[49646, 3559, 37, 1, 25, "Print"],
Cell[49686, 3562, 37, 1, 25, "Print"],
Cell[49726, 3565, 37, 1, 25, "Print"],
Cell[49766, 3568, 37, 1, 25, "Print"],
Cell[49806, 3571, 37, 1, 25, "Print"],
Cell[49846, 3574, 37, 1, 25, "Print"],
Cell[49886, 3577, 37, 1, 25, "Print"],
Cell[49926, 3580, 37, 1, 25, "Print"],
Cell[49966, 3583, 37, 1, 25, "Print"],
Cell[50006, 3586, 37, 1, 25, "Print"],
Cell[50046, 3589, 37, 1, 25, "Print"],
Cell[50086, 3592, 37, 1, 25, "Print"],
Cell[50126, 3595, 37, 1, 25, "Print"],
Cell[50166, 3598, 37, 1, 25, "Print"],
Cell[50206, 3601, 37, 1, 25, "Print"],
Cell[50246, 3604, 37, 1, 25, "Print"],
Cell[50286, 3607, 37, 1, 25, "Print"],
Cell[50326, 3610, 37, 1, 25, "Print"],
Cell[50366, 3613, 37, 1, 25, "Print"],
Cell[50406, 3616, 37, 1, 25, "Print"],
Cell[50446, 3619, 37, 1, 25, "Print"],
Cell[50486, 3622, 37, 1, 25, "Print"],
Cell[50526, 3625, 37, 1, 25, "Print"],
Cell[50566, 3628, 37, 1, 25, "Print"],
Cell[50606, 3631, 37, 1, 25, "Print"],
Cell[50646, 3634, 37, 1, 25, "Print"],
Cell[50686, 3637, 37, 1, 25, "Print"],
Cell[50726, 3640, 37, 1, 25, "Print"],
Cell[50766, 3643, 37, 1, 25, "Print"],
Cell[50806, 3646, 37, 1, 25, "Print"],
Cell[50846, 3649, 37, 1, 25, "Print"],
Cell[50886, 3652, 37, 1, 25, "Print"],
Cell[50926, 3655, 37, 1, 25, "Print"],
Cell[50966, 3658, 37, 1, 25, "Print"],
Cell[51006, 3661, 37, 1, 25, "Print"],
Cell[51046, 3664, 37, 1, 25, "Print"],
Cell[51086, 3667, 37, 1, 25, "Print"],
Cell[51126, 3670, 37, 1, 25, "Print"],
Cell[51166, 3673, 37, 1, 25, "Print"],
Cell[51206, 3676, 37, 1, 25, "Print"],
Cell[51246, 3679, 37, 1, 25, "Print"],
Cell[51286, 3682, 37, 1, 25, "Print"],
Cell[51326, 3685, 37, 1, 25, "Print"],
Cell[51366, 3688, 37, 1, 25, "Print"],
Cell[51406, 3691, 37, 1, 25, "Print"],
Cell[51446, 3694, 37, 1, 25, "Print"],
Cell[51486, 3697, 37, 1, 25, "Print"],
Cell[51526, 3700, 37, 1, 25, "Print"],
Cell[51566, 3703, 37, 1, 25, "Print"],
Cell[51606, 3706, 37, 1, 25, "Print"],
Cell[51646, 3709, 37, 1, 25, "Print"],
Cell[51686, 3712, 37, 1, 25, "Print"],
Cell[51726, 3715, 37, 1, 25, "Print"],
Cell[51766, 3718, 37, 1, 25, "Print"],
Cell[51806, 3721, 37, 1, 25, "Print"],
Cell[51846, 3724, 37, 1, 25, "Print"],
Cell[51886, 3727, 37, 1, 25, "Print"],
Cell[51926, 3730, 37, 1, 25, "Print"],
Cell[51966, 3733, 37, 1, 25, "Print"],
Cell[52006, 3736, 37, 1, 25, "Print"],
Cell[52046, 3739, 37, 1, 25, "Print"],
Cell[52086, 3742, 37, 1, 25, "Print"],
Cell[52126, 3745, 37, 1, 25, "Print"],
Cell[52166, 3748, 37, 1, 25, "Print"],
Cell[52206, 3751, 37, 1, 25, "Print"],
Cell[52246, 3754, 37, 1, 25, "Print"],
Cell[52286, 3757, 37, 1, 25, "Print"],
Cell[52326, 3760, 37, 1, 25, "Print"],
Cell[52366, 3763, 37, 1, 25, "Print"],
Cell[52406, 3766, 37, 1, 25, "Print"],
Cell[52446, 3769, 37, 1, 25, "Print"],
Cell[52486, 3772, 37, 1, 25, "Print"],
Cell[52526, 3775, 37, 1, 25, "Print"],
Cell[52566, 3778, 37, 1, 25, "Print"],
Cell[52606, 3781, 37, 1, 25, "Print"],
Cell[52646, 3784, 37, 1, 25, "Print"],
Cell[52686, 3787, 37, 1, 25, "Print"],
Cell[52726, 3790, 37, 1, 25, "Print"],
Cell[52766, 3793, 37, 1, 25, "Print"],
Cell[52806, 3796, 37, 1, 25, "Print"],
Cell[52846, 3799, 37, 1, 25, "Print"],
Cell[52886, 3802, 37, 1, 25, "Print"],
Cell[52926, 3805, 37, 1, 25, "Print"],
Cell[52966, 3808, 37, 1, 25, "Print"],
Cell[53006, 3811, 37, 1, 25, "Print"],
Cell[53046, 3814, 37, 1, 25, "Print"],
Cell[53086, 3817, 37, 1, 25, "Print"],
Cell[53126, 3820, 37, 1, 25, "Print"],
Cell[53166, 3823, 37, 1, 25, "Print"],
Cell[53206, 3826, 37, 1, 25, "Print"],
Cell[53246, 3829, 37, 1, 25, "Print"],
Cell[53286, 3832, 37, 1, 25, "Print"],
Cell[53326, 3835, 37, 1, 25, "Print"],
Cell[53366, 3838, 37, 1, 25, "Print"],
Cell[53406, 3841, 37, 1, 25, "Print"],
Cell[53446, 3844, 37, 1, 25, "Print"],
Cell[53486, 3847, 37, 1, 25, "Print"],
Cell[53526, 3850, 37, 1, 25, "Print"],
Cell[53566, 3853, 37, 1, 25, "Print"],
Cell[53606, 3856, 37, 1, 25, "Print"],
Cell[53646, 3859, 37, 1, 25, "Print"],
Cell[53686, 3862, 37, 1, 25, "Print"],
Cell[53726, 3865, 37, 1, 25, "Print"],
Cell[53766, 3868, 37, 1, 25, "Print"],
Cell[53806, 3871, 37, 1, 25, "Print"],
Cell[53846, 3874, 37, 1, 25, "Print"],
Cell[53886, 3877, 37, 1, 25, "Print"],
Cell[53926, 3880, 37, 1, 25, "Print"],
Cell[53966, 3883, 37, 1, 25, "Print"],
Cell[54006, 3886, 37, 1, 25, "Print"],
Cell[54046, 3889, 37, 1, 25, "Print"],
Cell[54086, 3892, 37, 1, 25, "Print"],
Cell[54126, 3895, 37, 1, 25, "Print"],
Cell[54166, 3898, 37, 1, 25, "Print"],
Cell[54206, 3901, 37, 1, 25, "Print"],
Cell[54246, 3904, 37, 1, 25, "Print"],
Cell[54286, 3907, 37, 1, 25, "Print"],
Cell[54326, 3910, 37, 1, 25, "Print"],
Cell[54366, 3913, 37, 1, 25, "Print"],
Cell[54406, 3916, 37, 1, 25, "Print"],
Cell[54446, 3919, 37, 1, 25, "Print"],
Cell[54486, 3922, 37, 1, 25, "Print"],
Cell[54526, 3925, 37, 1, 25, "Print"],
Cell[54566, 3928, 37, 1, 25, "Print"],
Cell[54606, 3931, 37, 1, 25, "Print"],
Cell[54646, 3934, 37, 1, 25, "Print"],
Cell[54686, 3937, 37, 1, 25, "Print"],
Cell[54726, 3940, 37, 1, 25, "Print"],
Cell[54766, 3943, 37, 1, 25, "Print"],
Cell[54806, 3946, 37, 1, 25, "Print"],
Cell[54846, 3949, 37, 1, 25, "Print"],
Cell[54886, 3952, 37, 1, 25, "Print"],
Cell[54926, 3955, 37, 1, 25, "Print"],
Cell[54966, 3958, 37, 1, 25, "Print"],
Cell[55006, 3961, 37, 1, 25, "Print"],
Cell[55046, 3964, 37, 1, 25, "Print"],
Cell[55086, 3967, 37, 1, 25, "Print"],
Cell[55126, 3970, 37, 1, 25, "Print"],
Cell[55166, 3973, 37, 1, 25, "Print"],
Cell[55206, 3976, 37, 1, 25, "Print"],
Cell[55246, 3979, 37, 1, 25, "Print"],
Cell[55286, 3982, 37, 1, 25, "Print"],
Cell[55326, 3985, 37, 1, 25, "Print"],
Cell[55366, 3988, 37, 1, 25, "Print"],
Cell[55406, 3991, 37, 1, 25, "Print"],
Cell[55446, 3994, 37, 1, 25, "Print"],
Cell[55486, 3997, 37, 1, 25, "Print"],
Cell[55526, 4000, 37, 1, 25, "Print"],
Cell[55566, 4003, 37, 1, 25, "Print"],
Cell[55606, 4006, 37, 1, 25, "Print"],
Cell[55646, 4009, 37, 1, 25, "Print"],
Cell[55686, 4012, 37, 1, 25, "Print"],
Cell[55726, 4015, 37, 1, 25, "Print"],
Cell[55766, 4018, 37, 1, 25, "Print"],
Cell[55806, 4021, 37, 1, 25, "Print"],
Cell[55846, 4024, 37, 1, 25, "Print"],
Cell[55886, 4027, 37, 1, 25, "Print"],
Cell[55926, 4030, 37, 1, 25, "Print"],
Cell[55966, 4033, 37, 1, 25, "Print"],
Cell[56006, 4036, 37, 1, 25, "Print"],
Cell[56046, 4039, 37, 1, 25, "Print"],
Cell[56086, 4042, 37, 1, 25, "Print"],
Cell[56126, 4045, 37, 1, 25, "Print"],
Cell[56166, 4048, 37, 1, 25, "Print"],
Cell[56206, 4051, 37, 1, 25, "Print"],
Cell[56246, 4054, 37, 1, 25, "Print"],
Cell[56286, 4057, 37, 1, 25, "Print"],
Cell[56326, 4060, 37, 1, 25, "Print"],
Cell[56366, 4063, 37, 1, 25, "Print"],
Cell[56406, 4066, 37, 1, 25, "Print"],
Cell[56446, 4069, 37, 1, 25, "Print"],
Cell[56486, 4072, 37, 1, 25, "Print"],
Cell[56526, 4075, 37, 1, 25, "Print"],
Cell[56566, 4078, 37, 1, 25, "Print"],
Cell[56606, 4081, 37, 1, 25, "Print"],
Cell[56646, 4084, 37, 1, 25, "Print"],
Cell[56686, 4087, 37, 1, 25, "Print"],
Cell[56726, 4090, 37, 1, 25, "Print"],
Cell[56766, 4093, 37, 1, 25, "Print"],
Cell[56806, 4096, 37, 1, 25, "Print"],
Cell[56846, 4099, 37, 1, 25, "Print"],
Cell[56886, 4102, 37, 1, 25, "Print"],
Cell[56926, 4105, 37, 1, 25, "Print"],
Cell[56966, 4108, 37, 1, 25, "Print"],
Cell[57006, 4111, 37, 1, 25, "Print"],
Cell[57046, 4114, 37, 1, 25, "Print"],
Cell[57086, 4117, 37, 1, 25, "Print"],
Cell[57126, 4120, 37, 1, 25, "Print"],
Cell[57166, 4123, 37, 1, 25, "Print"],
Cell[57206, 4126, 37, 1, 25, "Print"],
Cell[57246, 4129, 37, 1, 25, "Print"],
Cell[57286, 4132, 37, 1, 25, "Print"],
Cell[57326, 4135, 37, 1, 25, "Print"],
Cell[57366, 4138, 37, 1, 25, "Print"],
Cell[57406, 4141, 37, 1, 25, "Print"],
Cell[57446, 4144, 37, 1, 25, "Print"],
Cell[57486, 4147, 37, 1, 25, "Print"],
Cell[57526, 4150, 37, 1, 25, "Print"],
Cell[57566, 4153, 37, 1, 25, "Print"],
Cell[57606, 4156, 37, 1, 25, "Print"],
Cell[57646, 4159, 37, 1, 25, "Print"],
Cell[57686, 4162, 37, 1, 25, "Print"],
Cell[57726, 4165, 37, 1, 25, "Print"],
Cell[57766, 4168, 37, 1, 25, "Print"],
Cell[57806, 4171, 37, 1, 25, "Print"],
Cell[57846, 4174, 37, 1, 25, "Print"],
Cell[57886, 4177, 37, 1, 25, "Print"],
Cell[57926, 4180, 37, 1, 25, "Print"],
Cell[57966, 4183, 37, 1, 25, "Print"],
Cell[58006, 4186, 37, 1, 25, "Print"],
Cell[58046, 4189, 37, 1, 25, "Print"],
Cell[58086, 4192, 37, 1, 25, "Print"],
Cell[58126, 4195, 37, 1, 25, "Print"],
Cell[58166, 4198, 37, 1, 25, "Print"],
Cell[58206, 4201, 37, 1, 25, "Print"],
Cell[58246, 4204, 37, 1, 25, "Print"],
Cell[58286, 4207, 37, 1, 25, "Print"],
Cell[58326, 4210, 37, 1, 25, "Print"],
Cell[58366, 4213, 37, 1, 25, "Print"],
Cell[58406, 4216, 37, 1, 25, "Print"],
Cell[58446, 4219, 37, 1, 25, "Print"],
Cell[58486, 4222, 37, 1, 25, "Print"],
Cell[58526, 4225, 37, 1, 25, "Print"],
Cell[58566, 4228, 37, 1, 25, "Print"],
Cell[58606, 4231, 37, 1, 25, "Print"],
Cell[58646, 4234, 37, 1, 25, "Print"],
Cell[58686, 4237, 37, 1, 25, "Print"],
Cell[58726, 4240, 37, 1, 25, "Print"],
Cell[58766, 4243, 37, 1, 25, "Print"],
Cell[58806, 4246, 37, 1, 25, "Print"],
Cell[58846, 4249, 37, 1, 25, "Print"],
Cell[58886, 4252, 37, 1, 25, "Print"],
Cell[58926, 4255, 37, 1, 25, "Print"],
Cell[58966, 4258, 37, 1, 25, "Print"],
Cell[59006, 4261, 37, 1, 25, "Print"],
Cell[59046, 4264, 37, 1, 25, "Print"],
Cell[59086, 4267, 37, 1, 25, "Print"],
Cell[59126, 4270, 37, 1, 25, "Print"],
Cell[59166, 4273, 37, 1, 25, "Print"],
Cell[59206, 4276, 37, 1, 25, "Print"],
Cell[59246, 4279, 37, 1, 25, "Print"],
Cell[59286, 4282, 37, 1, 25, "Print"],
Cell[59326, 4285, 37, 1, 25, "Print"],
Cell[59366, 4288, 37, 1, 25, "Print"],
Cell[59406, 4291, 37, 1, 25, "Print"],
Cell[59446, 4294, 37, 1, 25, "Print"],
Cell[59486, 4297, 37, 1, 25, "Print"],
Cell[59526, 4300, 37, 1, 25, "Print"],
Cell[59566, 4303, 37, 1, 25, "Print"],
Cell[59606, 4306, 37, 1, 25, "Print"],
Cell[59646, 4309, 37, 1, 25, "Print"],
Cell[59686, 4312, 37, 1, 25, "Print"],
Cell[59726, 4315, 37, 1, 25, "Print"],
Cell[59766, 4318, 37, 1, 25, "Print"],
Cell[59806, 4321, 37, 1, 25, "Print"],
Cell[59846, 4324, 37, 1, 25, "Print"],
Cell[59886, 4327, 37, 1, 25, "Print"],
Cell[59926, 4330, 37, 1, 25, "Print"],
Cell[59966, 4333, 37, 1, 25, "Print"],
Cell[60006, 4336, 37, 1, 25, "Print"],
Cell[60046, 4339, 37, 1, 25, "Print"],
Cell[60086, 4342, 37, 1, 25, "Print"],
Cell[60126, 4345, 37, 1, 25, "Print"],
Cell[60166, 4348, 37, 1, 25, "Print"],
Cell[60206, 4351, 37, 1, 25, "Print"],
Cell[60246, 4354, 37, 1, 25, "Print"],
Cell[60286, 4357, 37, 1, 25, "Print"],
Cell[60326, 4360, 37, 1, 25, "Print"],
Cell[60366, 4363, 37, 1, 25, "Print"],
Cell[60406, 4366, 37, 1, 25, "Print"],
Cell[60446, 4369, 37, 1, 25, "Print"],
Cell[60486, 4372, 37, 1, 25, "Print"],
Cell[60526, 4375, 37, 1, 25, "Print"],
Cell[60566, 4378, 37, 1, 25, "Print"],
Cell[60606, 4381, 37, 1, 25, "Print"],
Cell[60646, 4384, 37, 1, 25, "Print"],
Cell[60686, 4387, 37, 1, 25, "Print"],
Cell[60726, 4390, 37, 1, 25, "Print"],
Cell[60766, 4393, 37, 1, 25, "Print"],
Cell[60806, 4396, 37, 1, 25, "Print"],
Cell[60846, 4399, 37, 1, 25, "Print"],
Cell[60886, 4402, 37, 1, 25, "Print"],
Cell[60926, 4405, 37, 1, 25, "Print"],
Cell[60966, 4408, 37, 1, 25, "Print"],
Cell[61006, 4411, 37, 1, 25, "Print"],
Cell[61046, 4414, 37, 1, 25, "Print"],
Cell[61086, 4417, 37, 1, 25, "Print"],
Cell[61126, 4420, 37, 1, 25, "Print"],
Cell[61166, 4423, 37, 1, 25, "Print"],
Cell[61206, 4426, 37, 1, 25, "Print"],
Cell[61246, 4429, 37, 1, 25, "Print"],
Cell[61286, 4432, 37, 1, 25, "Print"],
Cell[61326, 4435, 37, 1, 25, "Print"],
Cell[61366, 4438, 37, 1, 25, "Print"],
Cell[61406, 4441, 37, 1, 25, "Print"],
Cell[61446, 4444, 37, 1, 25, "Print"],
Cell[61486, 4447, 37, 1, 25, "Print"],
Cell[61526, 4450, 37, 1, 25, "Print"],
Cell[61566, 4453, 37, 1, 25, "Print"],
Cell[61606, 4456, 37, 1, 25, "Print"],
Cell[61646, 4459, 37, 1, 25, "Print"],
Cell[61686, 4462, 37, 1, 25, "Print"],
Cell[61726, 4465, 37, 1, 25, "Print"],
Cell[61766, 4468, 37, 1, 25, "Print"],
Cell[61806, 4471, 37, 1, 25, "Print"],
Cell[61846, 4474, 37, 1, 25, "Print"],
Cell[61886, 4477, 37, 1, 25, "Print"],
Cell[61926, 4480, 37, 1, 25, "Print"],
Cell[61966, 4483, 37, 1, 25, "Print"],
Cell[62006, 4486, 37, 1, 25, "Print"],
Cell[62046, 4489, 37, 1, 25, "Print"],
Cell[62086, 4492, 37, 1, 25, "Print"],
Cell[62126, 4495, 37, 1, 25, "Print"],
Cell[62166, 4498, 37, 1, 25, "Print"],
Cell[62206, 4501, 37, 1, 25, "Print"],
Cell[62246, 4504, 37, 1, 25, "Print"],
Cell[62286, 4507, 37, 1, 25, "Print"],
Cell[62326, 4510, 37, 1, 25, "Print"],
Cell[62366, 4513, 37, 1, 25, "Print"],
Cell[62406, 4516, 37, 1, 25, "Print"],
Cell[62446, 4519, 37, 1, 25, "Print"],
Cell[62486, 4522, 37, 1, 25, "Print"],
Cell[62526, 4525, 37, 1, 25, "Print"],
Cell[62566, 4528, 37, 1, 25, "Print"],
Cell[62606, 4531, 37, 1, 25, "Print"],
Cell[62646, 4534, 37, 1, 25, "Print"],
Cell[62686, 4537, 37, 1, 25, "Print"],
Cell[62726, 4540, 37, 1, 25, "Print"],
Cell[62766, 4543, 37, 1, 25, "Print"],
Cell[62806, 4546, 37, 1, 25, "Print"],
Cell[62846, 4549, 37, 1, 25, "Print"],
Cell[62886, 4552, 37, 1, 25, "Print"],
Cell[62926, 4555, 37, 1, 25, "Print"],
Cell[62966, 4558, 37, 1, 25, "Print"],
Cell[63006, 4561, 37, 1, 25, "Print"],
Cell[63046, 4564, 37, 1, 25, "Print"],
Cell[63086, 4567, 37, 1, 25, "Print"],
Cell[63126, 4570, 37, 1, 25, "Print"],
Cell[63166, 4573, 37, 1, 25, "Print"],
Cell[63206, 4576, 37, 1, 25, "Print"],
Cell[63246, 4579, 37, 1, 25, "Print"],
Cell[63286, 4582, 37, 1, 25, "Print"],
Cell[63326, 4585, 37, 1, 25, "Print"],
Cell[63366, 4588, 37, 1, 25, "Print"],
Cell[63406, 4591, 37, 1, 25, "Print"],
Cell[63446, 4594, 37, 1, 25, "Print"],
Cell[63486, 4597, 37, 1, 25, "Print"],
Cell[63526, 4600, 37, 1, 25, "Print"],
Cell[63566, 4603, 37, 1, 25, "Print"],
Cell[63606, 4606, 37, 1, 25, "Print"],
Cell[63646, 4609, 37, 1, 25, "Print"],
Cell[63686, 4612, 37, 1, 25, "Print"],
Cell[63726, 4615, 37, 1, 25, "Print"],
Cell[63766, 4618, 37, 1, 25, "Print"],
Cell[63806, 4621, 37, 1, 25, "Print"],
Cell[63846, 4624, 37, 1, 25, "Print"],
Cell[63886, 4627, 37, 1, 25, "Print"],
Cell[63926, 4630, 37, 1, 25, "Print"],
Cell[63966, 4633, 37, 1, 25, "Print"],
Cell[64006, 4636, 37, 1, 25, "Print"],
Cell[64046, 4639, 37, 1, 25, "Print"],
Cell[64086, 4642, 37, 1, 25, "Print"],
Cell[64126, 4645, 37, 1, 25, "Print"],
Cell[64166, 4648, 37, 1, 25, "Print"],
Cell[64206, 4651, 37, 1, 25, "Print"],
Cell[64246, 4654, 37, 1, 25, "Print"],
Cell[64286, 4657, 37, 1, 25, "Print"],
Cell[64326, 4660, 37, 1, 25, "Print"],
Cell[64366, 4663, 37, 1, 25, "Print"],
Cell[64406, 4666, 37, 1, 25, "Print"],
Cell[64446, 4669, 37, 1, 25, "Print"],
Cell[64486, 4672, 37, 1, 25, "Print"],
Cell[64526, 4675, 37, 1, 25, "Print"],
Cell[64566, 4678, 37, 1, 25, "Print"],
Cell[64606, 4681, 37, 1, 25, "Print"],
Cell[64646, 4684, 37, 1, 25, "Print"],
Cell[64686, 4687, 37, 1, 25, "Print"],
Cell[64726, 4690, 37, 1, 25, "Print"],
Cell[64766, 4693, 37, 1, 25, "Print"],
Cell[64806, 4696, 37, 1, 25, "Print"],
Cell[64846, 4699, 37, 1, 25, "Print"]
}, Open  ]],
Cell[64898, 4703, 223, 4, 84, "Input"],
Cell[65124, 4709, 38, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[65187, 4713, 45, 0, 30, "Input"],
Cell[65235, 4715, 19933, 775, 296, 5773, 596, "GraphicsData", "PostScript", \
"Graphics"],
Cell[85171, 5492, 19933, 775, 296, 5773, 596, "GraphicsData", "PostScript", \
"Graphics"],
Cell[105107, 6269, 19933, 775, 296, 5773, 596, "GraphicsData", "PostScript", \
"Graphics"],
Cell[125043, 7046, 19933, 775, 296, 5773, 596, "GraphicsData", "PostScript", \
"Graphics"],
Cell[144979, 7823, 19933, 775, 296, 5773, 596, "GraphicsData", "PostScript", \
"Graphics"],
Cell[164915, 8600, 19933, 775, 296, 5773, 596, "GraphicsData", "PostScript", \
"Graphics"],
Cell[184851, 9377, 19933, 775, 296, 5773, 596, "GraphicsData", "PostScript", \
"Graphics"],
Cell[204787, 10154, 19933, 775, 296, 5773, 596, "GraphicsData", "PostScript", \
"Graphics"],
Cell[224723, 10931, 19933, 775, 296, 5773, 596, "GraphicsData", "PostScript", \
"Graphics"],
Cell[244659, 11708, 19933, 775, 296, 5773, 596, "GraphicsData", "PostScript", \
"Graphics"],
Cell[264595, 12485, 184, 5, 29, "Output"]
}, Open  ]],
Cell[264794, 12493, 58, 0, 30, "Input"],
Cell[264855, 12495, 86, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[264966, 12501, 113, 3, 48, "Input"],
Cell[265082, 12506, 34806, 1896, 186, 27721, 1804, "GraphicsData", \
"PostScript", "Graphics"],
Cell[299891, 14404, 130, 3, 29, "Output"]
}, Open  ]],
Cell[300036, 14410, 86, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[300147, 14416, 75, 0, 30, "Input"],
Cell[300225, 14418, 32697, 1823, 186, 27115, 1750, "GraphicsData", \
"PostScript", "Graphics"],
Cell[332925, 16243, 130, 3, 29, "Output"]
}, Open  ]],
Cell[333070, 16249, 73, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[333168, 16253, 75, 0, 30, "Input"],
Cell[333246, 16255, 44437, 2003, 186, 27464, 1789, "GraphicsData", \
"PostScript", "Graphics"],
Cell[377686, 18260, 130, 3, 29, "Output"]
}, Open  ]],
Cell[377831, 18266, 73, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[377929, 18270, 75, 0, 30, "Input"],
Cell[378007, 18272, 53304, 2112, 186, 27514, 1789, "GraphicsData", \
"PostScript", "Graphics"],
Cell[431314, 20386, 130, 3, 29, "Output"]
}, Open  ]],
Cell[431459, 20392, 21, 0, 30, "Input"],
Cell[431483, 20394, 161, 5, 84, "Input"],
Cell[431647, 20401, 52, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[431724, 20405, 75, 0, 30, "Input"],
Cell[431802, 20407, 53026, 2114, 186, 27585, 1795, "GraphicsData", \
"PostScript", "Graphics"],
Cell[484831, 22523, 130, 3, 29, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[485010, 22532, 122, 2, 48, "Subsubtitle"],
Cell[485135, 22536, 39, 0, 30, "Input"],
Cell[485177, 22538, 66, 0, 30, "Input"],
Cell[485246, 22540, 24, 0, 30, "Input"],
Cell[485273, 22542, 58, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[485356, 22546, 69, 0, 30, "Input"],
Cell[485428, 22548, 84, 1, 29, "Output"]
}, Open  ]],
Cell[485527, 22552, 42, 0, 30, "Input"],
Cell[485572, 22554, 294, 12, 210, "Input"],

Cell[CellGroupData[{
Cell[485891, 22570, 69, 0, 30, "Input"],
Cell[485963, 22572, 84, 1, 29, "Output"]
}, Open  ]],
Cell[486062, 22576, 340, 14, 246, "Input"],
Cell[486405, 22592, 98, 3, 48, "Input"],
Cell[486506, 22597, 23, 0, 30, "Input"],
Cell[486532, 22599, 23, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[486580, 22603, 257, 5, 84, "Input"],
Cell[486840, 22610, 34, 1, 25, "Print"],
Cell[486877, 22613, 34, 1, 25, "Print"],
Cell[486914, 22616, 34, 1, 25, "Print"],
Cell[486951, 22619, 34, 1, 25, "Print"],
Cell[486988, 22622, 34, 1, 25, "Print"],
Cell[487025, 22625, 34, 1, 25, "Print"],
Cell[487062, 22628, 34, 1, 25, "Print"],
Cell[487099, 22631, 34, 1, 25, "Print"],
Cell[487136, 22634, 34, 1, 25, "Print"],
Cell[487173, 22637, 35, 1, 25, "Print"],
Cell[487211, 22640, 35, 1, 25, "Print"],
Cell[487249, 22643, 35, 1, 25, "Print"],
Cell[487287, 22646, 35, 1, 25, "Print"],
Cell[487325, 22649, 35, 1, 25, "Print"],
Cell[487363, 22652, 35, 1, 25, "Print"],
Cell[487401, 22655, 35, 1, 25, "Print"],
Cell[487439, 22658, 35, 1, 25, "Print"],
Cell[487477, 22661, 35, 1, 25, "Print"],
Cell[487515, 22664, 35, 1, 25, "Print"],
Cell[487553, 22667, 35, 1, 25, "Print"],
Cell[487591, 22670, 35, 1, 25, "Print"],
Cell[487629, 22673, 35, 1, 25, "Print"],
Cell[487667, 22676, 35, 1, 25, "Print"],
Cell[487705, 22679, 35, 1, 25, "Print"],
Cell[487743, 22682, 35, 1, 25, "Print"],
Cell[487781, 22685, 35, 1, 25, "Print"],
Cell[487819, 22688, 35, 1, 25, "Print"],
Cell[487857, 22691, 35, 1, 25, "Print"],
Cell[487895, 22694, 35, 1, 25, "Print"],
Cell[487933, 22697, 35, 1, 25, "Print"],
Cell[487971, 22700, 35, 1, 25, "Print"],
Cell[488009, 22703, 35, 1, 25, "Print"],
Cell[488047, 22706, 35, 1, 25, "Print"],
Cell[488085, 22709, 35, 1, 25, "Print"],
Cell[488123, 22712, 35, 1, 25, "Print"],
Cell[488161, 22715, 35, 1, 25, "Print"],
Cell[488199, 22718, 35, 1, 25, "Print"],
Cell[488237, 22721, 35, 1, 25, "Print"],
Cell[488275, 22724, 35, 1, 25, "Print"],
Cell[488313, 22727, 35, 1, 25, "Print"],
Cell[488351, 22730, 35, 1, 25, "Print"],
Cell[488389, 22733, 35, 1, 25, "Print"],
Cell[488427, 22736, 35, 1, 25, "Print"],
Cell[488465, 22739, 35, 1, 25, "Print"],
Cell[488503, 22742, 35, 1, 25, "Print"],
Cell[488541, 22745, 35, 1, 25, "Print"],
Cell[488579, 22748, 35, 1, 25, "Print"],
Cell[488617, 22751, 35, 1, 25, "Print"],
Cell[488655, 22754, 35, 1, 25, "Print"],
Cell[488693, 22757, 35, 1, 25, "Print"],
Cell[488731, 22760, 35, 1, 25, "Print"],
Cell[488769, 22763, 35, 1, 25, "Print"],
Cell[488807, 22766, 35, 1, 25, "Print"],
Cell[488845, 22769, 35, 1, 25, "Print"],
Cell[488883, 22772, 35, 1, 25, "Print"],
Cell[488921, 22775, 35, 1, 25, "Print"],
Cell[488959, 22778, 35, 1, 25, "Print"],
Cell[488997, 22781, 35, 1, 25, "Print"],
Cell[489035, 22784, 35, 1, 25, "Print"],
Cell[489073, 22787, 35, 1, 25, "Print"],
Cell[489111, 22790, 35, 1, 25, "Print"],
Cell[489149, 22793, 35, 1, 25, "Print"],
Cell[489187, 22796, 35, 1, 25, "Print"],
Cell[489225, 22799, 35, 1, 25, "Print"],
Cell[489263, 22802, 35, 1, 25, "Print"],
Cell[489301, 22805, 35, 1, 25, "Print"],
Cell[489339, 22808, 35, 1, 25, "Print"],
Cell[489377, 22811, 35, 1, 25, "Print"],
Cell[489415, 22814, 35, 1, 25, "Print"],
Cell[489453, 22817, 35, 1, 25, "Print"],
Cell[489491, 22820, 35, 1, 25, "Print"],
Cell[489529, 22823, 35, 1, 25, "Print"],
Cell[489567, 22826, 35, 1, 25, "Print"],
Cell[489605, 22829, 35, 1, 25, "Print"],
Cell[489643, 22832, 35, 1, 25, "Print"],
Cell[489681, 22835, 35, 1, 25, "Print"],
Cell[489719, 22838, 35, 1, 25, "Print"],
Cell[489757, 22841, 35, 1, 25, "Print"],
Cell[489795, 22844, 35, 1, 25, "Print"],
Cell[489833, 22847, 35, 1, 25, "Print"],
Cell[489871, 22850, 35, 1, 25, "Print"],
Cell[489909, 22853, 35, 1, 25, "Print"],
Cell[489947, 22856, 35, 1, 25, "Print"],
Cell[489985, 22859, 35, 1, 25, "Print"],
Cell[490023, 22862, 35, 1, 25, "Print"],
Cell[490061, 22865, 35, 1, 25, "Print"],
Cell[490099, 22868, 35, 1, 25, "Print"],
Cell[490137, 22871, 35, 1, 25, "Print"],
Cell[490175, 22874, 35, 1, 25, "Print"],
Cell[490213, 22877, 35, 1, 25, "Print"],
Cell[490251, 22880, 35, 1, 25, "Print"],
Cell[490289, 22883, 35, 1, 25, "Print"],
Cell[490327, 22886, 35, 1, 25, "Print"],
Cell[490365, 22889, 35, 1, 25, "Print"],
Cell[490403, 22892, 35, 1, 25, "Print"],
Cell[490441, 22895, 35, 1, 25, "Print"],
Cell[490479, 22898, 35, 1, 25, "Print"],
Cell[490517, 22901, 35, 1, 25, "Print"],
Cell[490555, 22904, 35, 1, 25, "Print"],
Cell[490593, 22907, 36, 1, 25, "Print"],
Cell[490632, 22910, 36, 1, 25, "Print"],
Cell[490671, 22913, 36, 1, 25, "Print"],
Cell[490710, 22916, 36, 1, 25, "Print"],
Cell[490749, 22919, 36, 1, 25, "Print"],
Cell[490788, 22922, 36, 1, 25, "Print"],
Cell[490827, 22925, 36, 1, 25, "Print"],
Cell[490866, 22928, 36, 1, 25, "Print"],
Cell[490905, 22931, 36, 1, 25, "Print"],
Cell[490944, 22934, 36, 1, 25, "Print"],
Cell[490983, 22937, 36, 1, 25, "Print"],
Cell[491022, 22940, 36, 1, 25, "Print"],
Cell[491061, 22943, 36, 1, 25, "Print"],
Cell[491100, 22946, 36, 1, 25, "Print"],
Cell[491139, 22949, 36, 1, 25, "Print"],
Cell[491178, 22952, 36, 1, 25, "Print"],
Cell[491217, 22955, 36, 1, 25, "Print"],
Cell[491256, 22958, 36, 1, 25, "Print"],
Cell[491295, 22961, 36, 1, 25, "Print"],
Cell[491334, 22964, 36, 1, 25, "Print"],
Cell[491373, 22967, 36, 1, 25, "Print"],
Cell[491412, 22970, 36, 1, 25, "Print"],
Cell[491451, 22973, 36, 1, 25, "Print"],
Cell[491490, 22976, 36, 1, 25, "Print"],
Cell[491529, 22979, 36, 1, 25, "Print"],
Cell[491568, 22982, 36, 1, 25, "Print"],
Cell[491607, 22985, 36, 1, 25, "Print"],
Cell[491646, 22988, 36, 1, 25, "Print"],
Cell[491685, 22991, 36, 1, 25, "Print"],
Cell[491724, 22994, 36, 1, 25, "Print"],
Cell[491763, 22997, 36, 1, 25, "Print"],
Cell[491802, 23000, 36, 1, 25, "Print"],
Cell[491841, 23003, 36, 1, 25, "Print"],
Cell[491880, 23006, 36, 1, 25, "Print"],
Cell[491919, 23009, 36, 1, 25, "Print"],
Cell[491958, 23012, 36, 1, 25, "Print"],
Cell[491997, 23015, 36, 1, 25, "Print"],
Cell[492036, 23018, 36, 1, 25, "Print"],
Cell[492075, 23021, 36, 1, 25, "Print"],
Cell[492114, 23024, 36, 1, 25, "Print"],
Cell[492153, 23027, 36, 1, 25, "Print"],
Cell[492192, 23030, 36, 1, 25, "Print"],
Cell[492231, 23033, 36, 1, 25, "Print"],
Cell[492270, 23036, 36, 1, 25, "Print"],
Cell[492309, 23039, 36, 1, 25, "Print"],
Cell[492348, 23042, 36, 1, 25, "Print"],
Cell[492387, 23045, 36, 1, 25, "Print"],
Cell[492426, 23048, 36, 1, 25, "Print"],
Cell[492465, 23051, 36, 1, 25, "Print"],
Cell[492504, 23054, 36, 1, 25, "Print"],
Cell[492543, 23057, 36, 1, 25, "Print"]
}, Open  ]],
Cell[492594, 23061, 225, 4, 84, "Input"],
Cell[492822, 23067, 38, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[492885, 23071, 45, 0, 30, "Input"],
Cell[492933, 23073, 16343, 612, 296, 4514, 461, "GraphicsData", "PostScript", \
"Graphics"],
Cell[509279, 23687, 16304, 611, 296, 4516, 461, "GraphicsData", "PostScript", \
"Graphics"],
Cell[525586, 24300, 16306, 611, 296, 4518, 461, "GraphicsData", "PostScript", \
"Graphics"],
Cell[541895, 24913, 16306, 611, 296, 4518, 461, "GraphicsData", "PostScript", \
"Graphics"],
Cell[558204, 25526, 16306, 611, 296, 4518, 461, "GraphicsData", "PostScript", \
"Graphics"],
Cell[574513, 26139, 16306, 611, 296, 4518, 461, "GraphicsData", "PostScript", \
"Graphics"],
Cell[590822, 26752, 16306, 611, 296, 4518, 461, "GraphicsData", "PostScript", \
"Graphics"],
Cell[607131, 27365, 16306, 611, 296, 4518, 461, "GraphicsData", "PostScript", \
"Graphics"],
Cell[623440, 27978, 16306, 611, 296, 4518, 461, "GraphicsData", "PostScript", \
"Graphics"],
Cell[639749, 28591, 16306, 611, 296, 4518, 461, "GraphicsData", "PostScript", \
"Graphics"],
Cell[656058, 29204, 16306, 611, 296, 4518, 461, "GraphicsData", "PostScript", \
"Graphics"],
Cell[672367, 29817, 16306, 611, 296, 4518, 461, "GraphicsData", "PostScript", \
"Graphics"],
Cell[688676, 30430, 16306, 611, 296, 4518, 461, "GraphicsData", "PostScript", \
"Graphics"],
Cell[704985, 31043, 16306, 611, 296, 4518, 461, "GraphicsData", "PostScript", \
"Graphics"],
Cell[721294, 31656, 16306, 611, 296, 4518, 461, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[737615, 32270, 77, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[737717, 32274, 75, 0, 30, "Input"],
Cell[737795, 32276, 13860, 527, 186, 6166, 427, "GraphicsData", "PostScript", \
"Graphics"],
Cell[751658, 32805, 130, 3, 29, "Output"]
}, Open  ]],
Cell[751803, 32811, 77, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[751905, 32815, 75, 0, 30, "Input"],
Cell[751983, 32817, 11997, 473, 186, 5730, 391, "GraphicsData", "PostScript", \
"Graphics"],
Cell[763983, 33292, 130, 3, 29, "Output"]
}, Open  ]],
Cell[764128, 33298, 72, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[764225, 33302, 75, 0, 30, "Input"],
Cell[764303, 33304, 14783, 540, 186, 6233, 430, "GraphicsData", "PostScript", \
"Graphics"],
Cell[779089, 33846, 130, 3, 29, "Output"]
}, Open  ]],
Cell[779234, 33852, 72, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[779331, 33856, 75, 0, 30, "Input"],
Cell[779409, 33858, 14701, 534, 186, 6171, 424, "GraphicsData", "PostScript", \
"Graphics"],
Cell[794113, 34394, 130, 3, 29, "Output"]
}, Open  ]],
Cell[794258, 34400, 21, 0, 30, "Input"],
Cell[794282, 34402, 160, 5, 84, "Input"],
Cell[794445, 34409, 51, 0, 30, "Input"],

Cell[CellGroupData[{
Cell[794521, 34413, 75, 0, 30, "Input"],
Cell[794599, 34415, 14947, 547, 186, 6348, 436, "GraphicsData", "PostScript", \
"Graphics"],
Cell[809549, 34964, 130, 3, 29, "Output"]
}, Open  ]]
}, Closed]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

